bm_fmesher: Mapper for general 'fmesher' function space objects

View source: R/mappers.R

bm_fmesherR Documentation

Mapper for general fmesher function space objects

Description

Creates a mapper for general fmesher function space objects.

Usage

bm_fmesher(mesh)

bru_mapper_fmesher(...)

## S3 method for class 'fm_mesh_2d'
bru_mapper(mesh, ...)

Arguments

mesh

An fmesher object to map, supported by fmesher::fm_basis⁠(mesh, input)⁠ and fmesher::fm_dof(mesh).

...

Arguments passed on to bm_fmesher()

Details

Handles indexed mapping for all fmesher classes that support fm_dof() and fm_basis() methods. For non-indexed mapping of fm_mesh_1d objects, use bru_mapper(mesh, indexed = FALSE) which invokes the bru_mapper.fm_mesh_1d() method.

Value

A bm_fmesher object.

Functions

  • bru_mapper(fm_mesh_2d): Equivalent to calling bm_fmesher(). Note: Prior to version ⁠2.12.0.9021⁠, this returned a bru_mapper_fm_mesh_2d object. Also see the note for bru_mapper.fm_mesh_1d().

See Also

bru_mapper, bru_mapper_generics

Other mappers: bm_aggregate(), bm_collect(), bm_const(), bm_expr(), bm_factor(), bm_fm_mesh_1d, bm_harmonics(), bm_index(), bm_linear(), bm_logitaverage(), bm_logsumexp(), bm_marginal(), bm_matrix(), bm_multi(), bm_pipe(), bm_reparam(), bm_repeat(), bm_scale(), bm_shift(), bm_sum(), bm_taylor(), bru_get_mapper(), bru_mapper()

Examples

m <- bm_fmesher(fmesher::fmexample$mesh)
ibm_n(m)
ibm_eval(m, as.matrix(expand.grid(-2:2, -2:2)), seq_len(ibm_n(m)))


inlabru documentation built on July 28, 2026, 9:07 a.m.