bm_multi: Mapper for tensor product domains

View source: R/mappers.R

bm_multiR Documentation

Mapper for tensor product domains

Description

Constructs a row-wise Kronecker product mapping of linear/affine mappers. Any offset in sub-mappers is added into a combined offset. Only linear/affine sub-mappers are allowed.

Usage

bm_multi(mappers, simplify = FALSE)

bru_mapper_multi(...)

## S3 method for class 'bm_multi'
x[i, drop = TRUE]

## S3 method for class 'bru_mapper_multi'
x[i, drop = TRUE]

Arguments

mappers

A list of bru_mapper objects

simplify

logical; If TRUE, removes trivial submappers. Currently only sub-mappers of class bm_index() with ibm_n() == 1L are removed, and only if the mappers are named (to avoid ordering mismatches). Default: FALSE

...

Arguments passed on to bm_multi()

x

object from which to extract element(s)

i

indices specifying element(s) to extract

drop

logical; For ⁠[.bm_multi⁠, whether to extract an individual mapper when i identifies a single element. If FALSE, a list of sub-mappers is returned (suitable e.g. for creating a new bm_multi object). Default: TRUE

Value

A bm_multi mapper object.

  • [-indexing a bm_multi extracts a subset bm_multi object (for drop FALSE) or an individual sub-mapper (for drop TRUE, and i identifies a single element)

See Also

bru_mapper, bru_mapper_generics

Other mappers: bm_aggregate(), bm_collect(), bm_const(), bm_expr(), bm_factor(), bm_fm_mesh_1d, bm_fmesher(), bm_harmonics(), bm_index(), bm_linear(), bm_logitaverage(), bm_logsumexp(), bm_marginal(), bm_matrix(), bm_pipe(), bm_reparam(), bm_repeat(), bm_scale(), bm_shift(), bm_sum(), bm_taylor(), bru_get_mapper(), bru_mapper()

Examples

(m <- bm_multi(list(a = bm_index(2), b = bm_index(3))))
ibm_eval2(m, list(a = c(1, 2, 1), b = c(1, 3, 2)), 1:6)


inlabru documentation built on July 28, 2026, 9:07 a.m.