bm_sum: Mapper for adding multiple mappers

View source: R/mapper_sum.R

bm_sumR Documentation

Mapper for adding multiple mappers

Description

Defines a mapper that adds the effects of each submapper. The ibm_n() method returns the sum of ibm_n(mappers[[k]]), and ibm_values() returns seq_len(ibm_n(mapper)).

Usage

bm_sum(mappers, single_input = FALSE)

bru_mapper_sum(...)

## S3 method for class 'bm_sum'
x[i, drop = TRUE]

## S3 method for class 'bru_mapper_sum'
x[i, drop = TRUE]

Arguments

mappers

A list of bru_mapper objects.

single_input

logical. If TRUE, the input is passed to all sub-mappers. Otherwise, the input should be a list, data.frame, or matrix. If the mappers list has named entries, the input can reference their corresponding sub-mapper using its name.

...

Arguments passed on to bm_sum()

x

object from which to extract element(s)

i

indices specifying element(s) to extract

drop

logical; For ⁠[.bm_sum⁠, whether to extract an individual mapper when i identifies a single element. If FALSE, a list of sub-mappers is returned (suitable e.g. for creating a new bm_sum object). Default: TRUE

Value

A bm_sum object.

  • [-indexing a bm_sum extracts a subset bm_sum object (for drop FALSE) or an individual sub-mapper (for drop TRUE, and i identifies a single element)

See Also

bru_mapper, bru_mapper_generics

Other mappers: bm_aggregate(), bm_collect(), bm_const(), bm_expr(), bm_factor(), bm_fm_mesh_1d, bm_fmesher(), bm_harmonics(), bm_index(), bm_linear(), bm_logitaverage(), bm_logsumexp(), bm_marginal(), bm_matrix(), bm_multi(), bm_pipe(), bm_reparam(), bm_repeat(), bm_scale(), bm_shift(), bm_taylor(), bru_get_mapper(), bru_mapper()

Examples

(m <- bm_sum(list(a = bm_index(3), b = bm_index(2))))
ibm_n(m)
ibm_values(m)
ibm_jacobian(m, list(a = 1:3, b = c(1, 1, 2)))
ibm_eval(
  m,
  list(a = 1:3, b = c(1, 1, 2)),
  seq_len(ibm_n(m))
)


inlabru documentation built on July 28, 2026, 9:07 a.m.