bru_eval_fun: Obtain bru component evaluation functions

View source: R/mapper_expr.R

bru_eval_funR Documentation

Obtain bru component evaluation functions

Description

Internal generic function and methods for generating evaluation functions for bru_comp objects, that can be used in generate.bru() and predict.bru() expressions.

Usage

bru_eval_fun(x, ...)

## S3 method for class 'bru_comp'
bru_eval_fun(x, ...)

## S3 method for class 'bru_comp_list'
bru_eval_fun(x, ...)

## S3 method for class 'bru_model'
bru_eval_fun(x, ...)

Value

A component evaluation function or a list of functions

Methods (by class)

  • bru_eval_fun(bru_comp): Returns function that takes the arguments main, group, replicate, weights, and .state and can be evaluated in the context of a data mask from bru_data_mask().

  • bru_eval_fun(bru_comp_list): Returns a list of component evaluation functions named ⁠<label>_eval⁠ for each component with label ⁠<label>⁠.

  • bru_eval_fun(bru_model): Returns a list of component evaluation functions named ⁠<label>_eval⁠ for each model component with label ⁠<label>⁠.


inlabru documentation built on July 28, 2026, 9:07 a.m.