| bru_formula_to_bru_obs_code | R Documentation |
Convert a formula describing latent model components to R code strings that can be evaluated to create the corresponding bru_comp objects.
bru_formula_to_bru_obs_code(components, add = "")
components |
A formula describing latent model components. |
a character vector of R code strings, one for each component in the formula.
Fabian E. Bachl bachlfab@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.