| bru_is_rowwise | R Documentation |
Checks if a predictor expression may be evaluated rowwise
bru_is_rowwise(x, ...)
## S3 method for class 'bru_pred_expr'
bru_is_rowwise(x, ...)
## S3 method for class 'bru_obs'
bru_is_rowwise(x, ...)
## S3 method for class 'bru_obs_list'
bru_is_rowwise(x, ...)
## S3 method for class 'bru_comp_list'
bru_is_rowwise(x, ...)
## S3 method for class 'bru_comp'
bru_is_rowwise(x, ...)
## S3 method for class 'bru_mapper'
bru_is_rowwise(x, ...)
x |
An object containing a predictor definition |
... |
Arguments passed on to submethods. |
TRUE if the expression is believed to be rowwise, FALSE
otherwise.
bru_is_rowwise(new_bru_pred_expr(~ x + y))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.