bru_mapper_generics: Generic methods for bru_mapper objects

bru_mapper_genericsR Documentation

Generic methods for bru_mapper objects

Description

A bru_mapper sub-class implementation must provide an ibm_jacobian() method. If the model size 'n' and definition values 'values' are stored in the object itself, default methods ibm_n() and ibm_values() are available. Otherwise the ibm_n() and ibm_values() methods also need to be provided.

See Also

bru_mapper for constructor methods, and bru_get_mapper for hooks to extract mappers from latent model object class objects.

Other mapper methods: ibm_as_taylor(), ibm_eval(), ibm_eval2(), ibm_inla_subset(), ibm_invalid_output(), ibm_is_linear(), ibm_is_rowwise(), ibm_jacobian(), ibm_n(), ibm_n_output(), ibm_names(), ibm_simplify(), ibm_values()


inlabru documentation built on July 28, 2026, 9:07 a.m.