bru_obs_methods: Utility functions for bru observation model objects

bru_obs_methodsR Documentation

Utility functions for bru observation model objects

Description

Utility functions for bru observation model objects

Usage

bru_obs_inla_family(x, ...)

## S3 method for class 'bru_obs'
bru_obs_inla_family(x, ...)

## S3 method for class 'bru_obs_list'
bru_obs_inla_family(x, ...)

## S3 method for class 'bru'
bru_obs_inla_family(x, ...)

bru_obs_family(x, ...)

## S3 method for class 'bru_obs'
bru_obs_family(x, ...)

## S3 method for class 'bru_obs_list'
bru_obs_family(x, ...)

## S3 method for class 'bru'
bru_obs_family(x, ...)

bru_obs_control_family(x, control.family = NULL, ...)

## S3 method for class 'bru_obs'
bru_obs_control_family(x, control.family = NULL, ...)

## S3 method for class 'bru_obs_list'
bru_obs_control_family(x, control.family = NULL, ...)

Arguments

x

Object of bru_obs or bru_obs_list type

...

Further arguments passed on to the submethods

control.family

list of INLA control.family options to override

Value

  • bru_obs_inla_family() returns a string or vector of strings of the family name(s) used in the INLA::inla() call for the observation model(s) in x.

  • bru_obs_family() returns a string or vector of strings of the family name(s) used to define each bru_obs(). This may be different the internal technical name(s) used in the INLA::inla() call.

  • bru_obs_control_family() returns a list with INLA::control.family options, or a list of such lists, with one element per observation model

See Also

summary.bru_obs()


inlabru documentation built on July 28, 2026, 9:07 a.m.