| bru_state | R Documentation |
Extracts model state summary values or generate samples
bru_state(x, ...)
## S3 method for class 'bru_model'
bru_state(x, ..., state = NULL)
## S3 method for class 'inla'
bru_state(
x,
property = "mode",
n = 1,
seed = 0L,
num.threads = NULL,
internal_hyperpar = FALSE,
...
)
## S3 method for class 'bru'
bru_state(x, property = "mode", ...)
x |
Object |
... |
Further arguments, passed on to |
state |
A list of initial state vectors, one for each component. If
|
property |
Property of the model components to obtain value from. Default: "mode". Other options are "mean", "0.025quant", "0.975quant", "sd" and "sample", "zeros", "joint_mode", "predictor_sd". In case of "sample" you will obtain samples from the posterior. For "zeros", all-zero vectors are returned for each component. |
n |
The number of samples to generate. Default: 1L |
seed |
Integer seed for random number generation. Default: 0L |
num.threads |
|
internal_hyperpar |
logical; If |
A list of length n
if (bru_safe_inla()) {}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.