bru_timings: Extract timing information from fitted bru object

bru_timingsR Documentation

Extract timing information from fitted bru object

Description

Extracts a data.frame or tibble with information about the Time (CPU), System, and Elapsed time for each step of a bru() run.

Usage

bru_timings(object, ...)

## S3 method for class 'bru'
bru_timings(object, ...)

Arguments

object

A fitted bru object

...

unused

Value

A data.frame or tibble with columns Task, Iteration, Time, System, and Elapsed.


inlabru documentation built on July 28, 2026, 9:07 a.m.