gorillas: Deprecated alias for sp version of the gorillas dataset

gorillasR Documentation

Deprecated alias for sp version of the gorillas dataset

Description

Deprecated dataset name for the sp version of gorillas_sf. Use gorillas_sp() instead.

See Also

gorillas_sf


inlabru documentation built on July 28, 2026, 9:07 a.m.