| ibm_input | R Documentation |
bru_input and bru_mapperAssociate bru_input objects with bru_mapper objects.
ibm_input_set(mapper, input)
ibm_input_new(mapper, ...)
ibm_input_available(mapper)
ibm_input_get(mapper)
bm_autodetect()
mapper |
A |
input |
A |
... |
Passed on to |
ibm_input_set: The mapper with the input associated with it.
ibm_input_new: The mapper with the new bru_input associated
with it.
ibm_input_available(): logical; TRUE if a bru_input is
associated with the mapper, and FALSE otherwise.
ibm_input_get: The bru_input associated with the mapper,
if it is available.
ibm_input_set(): Add an existing bru_input to a bru_mapper.
ibm_input_new(): Create and add a bru_input to a bru_mapper.
ibm_input_available(): Check if a bru_input is associated with a
bru_mapper.
ibm_input_get(): Get the bru_input associated with a bru_mapper.
bm_autodetect(): Create a bru_mapper placeholder object of class
bm_autodetect. The main purpose of this class is to attach bru_input
information to it, which is later used to determine a suitable 'real'
mapper type.
bru_input()
(m <- bm_autodetect())
ibm_input_available(m)
(m <- ibm_input_new(m, cos(x)))
ibm_input_available(m)
ibm_input_set(bm_linear(), m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.