ibm_is_rowwise: Check if a mapper is rowwise

View source: R/mappers.R

ibm_is_rowwiseR Documentation

Check if a mapper is rowwise

Description

Implementations must return TRUE or FALSE. If TRUE (returned by the default method unless the mapper contains an is_rowwise variable), users of the mapper may assume the mapper uses its inputs in "rowwise" manner, so that blockwise evaluation is always possible.

Usage

ibm_is_rowwise(mapper, ...)

## Default S3 method:
ibm_is_rowwise(mapper, ...)

Arguments

mapper

A mapper S3 object, inheriting from bru_mapper.

...

Arguments passed on to other methods

Value

logical; TRUE if the mapper is rowwise, FALSE otherwise.

Methods (by class)

  • ibm_is_rowwise(default): Returns logical is_rowwise from the mapper object if it exists, and otherwise TRUE.

See Also

Other mapper methods: bru_mapper_generics, ibm_as_taylor(), ibm_eval(), ibm_eval2(), ibm_inla_subset(), ibm_invalid_output(), ibm_is_linear(), ibm_jacobian(), ibm_n(), ibm_n_output(), ibm_names(), ibm_simplify(), ibm_values()

Examples

m <- bm_linear()
ibm_is_rowwise(m)


inlabru documentation built on July 28, 2026, 9:07 a.m.