| ibm_n_output | R Documentation |
Implementations must return an integer denoting the
mapper output length.
The default implementation returns NROW(input).
Mappers such as bm_multi and bm_collect,
that can accept list() inputs require their own method implementations.
ibm_n_output(mapper, input, state = NULL, inla_f = FALSE, ...)
## Default S3 method:
ibm_n_output(mapper, input, state = NULL, inla_f = FALSE, ...)
## S3 method for class 'bm_taylor'
ibm_n_output(mapper, input, ...)
## S3 method for class 'bm_shift'
ibm_n_output(mapper, input, state = NULL, ..., n_state = NULL)
## S3 method for class 'bm_scale'
ibm_n_output(mapper, input, state = NULL, ..., n_state = NULL)
## S3 method for class 'bm_aggregate'
ibm_n_output(mapper, input = NULL, ...)
## S3 method for class 'bm_marginal'
ibm_n_output(mapper, input, state = NULL, ..., n_state = NULL)
## S3 method for class 'bm_pipe'
ibm_n_output(mapper, input, state = NULL, ..., n_state = NULL)
## S3 method for class 'bm_multi'
ibm_n_output(mapper, input, ...)
## S3 method for class 'bm_reparam'
ibm_n_output(mapper, ...)
## S3 method for class 'bm_collect'
ibm_n_output(mapper, input, state = NULL, inla_f = FALSE, multi = FALSE, ...)
## S3 method for class 'bm_expr'
ibm_n_output(
mapper,
input,
state = NULL,
inla_f = FALSE,
...,
derived = NULL,
n_state = NULL,
data = NULL
)
## S3 method for class 'bm_repeat'
ibm_n_output(mapper, ...)
## S3 method for class 'bm_sum'
ibm_n_output(mapper, input, state = NULL, ...)
mapper |
A mapper S3 object, inheriting from |
input |
Data input for the mapper. |
state |
A vector of latent state values for the mapping,
of length |
inla_f |
logical; when |
... |
Arguments passed on to other methods |
n_state |
integer giving the length of the state vector for mappers that have state dependent output size. |
multi |
logical;
If |
derived |
The state vectors of variables derived from the root
variables. If |
data |
should be a list with data objects, with the main object called
|
An integer denoting the mapper output length.
ibm_n_output(default): Returns NROW(input)
Other mapper methods:
bru_mapper_generics,
ibm_as_taylor(),
ibm_eval(),
ibm_eval2(),
ibm_inla_subset(),
ibm_invalid_output(),
ibm_is_linear(),
ibm_is_rowwise(),
ibm_jacobian(),
ibm_n(),
ibm_names(),
ibm_simplify(),
ibm_values()
m <- bm_linear()
ibm_n_output(m, input = c(1, 3, 4, 5, 2), state = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.