ibm_names: Names of submapper

View source: R/mappers.R

ibm_namesR Documentation

Names of submapper

Description

Implementations must return a character vector of sub-mapper names, or NULL. Intended for providing information about multi-mappers and mapper collections.

Usage

ibm_names(mapper)

ibm_names(mapper) <- value

## Default S3 method:
ibm_names(mapper, ...)

## S3 method for class 'bm_multi'
ibm_names(mapper)

## S3 replacement method for class 'bm_multi'
ibm_names(mapper) <- value

## S3 replacement method for class 'bru_mapper_multi'
ibm_names(mapper) <- value

## S3 method for class 'bm_collect'
ibm_names(mapper)

## S3 replacement method for class 'bm_collect'
ibm_names(mapper) <- value

## S3 replacement method for class 'bru_mapper_collect'
ibm_names(mapper) <- value

## S3 method for class 'bm_sum'
ibm_names(mapper)

## S3 replacement method for class 'bm_sum'
ibm_names(mapper) <- value

## S3 replacement method for class 'bru_mapper_sum'
ibm_names(mapper) <- value

Arguments

mapper

A mapper S3 object, inheriting from bru_mapper.

value

a character vector of up to the same length as the number of mappers in the multi-mapper x

...

Arguments passed on to other methods

Value

A character vector or NULL

Methods (by class)

  • ibm_names(default): Returns NULL

  • ibm_names(bm_multi): Returns the names from the sub-mappers list

  • ibm_names(bm_collect): Returns the names from the sub-mappers list

  • ibm_names(bm_sum): Returns the names from the sub-mappers list

Functions

  • ibm_names(mapper) <- value: Set mapper names.

See Also

Other mapper methods: bru_mapper_generics, ibm_as_taylor(), ibm_eval(), ibm_eval2(), ibm_inla_subset(), ibm_invalid_output(), ibm_is_linear(), ibm_is_rowwise(), ibm_jacobian(), ibm_n(), ibm_n_output(), ibm_simplify(), ibm_values()

Examples

# ibm_names
mapper <- bm_multi(list(A = bm_index(2), B = bm_index(2)))
ibm_names(mapper)
ibm_names(mapper) <- c("new", "names")
ibm_names(mapper)
m <- bm_multi(list(A = bm_linear(), B = bm_linear()))
ibm_names(m)


inlabru documentation built on July 28, 2026, 9:07 a.m.