Skip to contents

This is an internal wrapper for iterated runs of INLA::inla. For nonlinear models, a linearisation is done with bru_compute_linearisation, with a line search method between each iteration. The INLA::inla.stack information is setup by bru_make_stack().

Usage

iinla(
  model,
  initial = NULL,
  options,
  lhoods = deprecated(),
  inputs = deprecated()
)

Arguments

model

A bru_model object

initial

A previous bru result or a list of named latent variable initial states (missing elements are set to zero), to be used as starting point, or NULL. If non-null, overrides options$bru_initial

options

A bru_options object.

lhoods

[Deprecated] Deprecated from version 2.14.1.9011, since the bru_obs_list information is now part of the bru_model object.

inputs

[Deprecated] Deprecated from version 2.14.1.9011, since the inputs information is now part of the bru_model object. Optional pre-computed list of per-likelihood component evaluations, from bru_input.bru_obs_list().

Value

An iinla object that inherits from INLA::inla, with an added field bru_iinla with elements

log

The diagnostic log messages produced by the run

states

The list of linearisation points, one for each inla run

inla_stack

The inla.stack object from the final inla run

track

A list of convergence tracking vectors

If an inla run is aborted by an error, the returned object also contains an element error with the error object.