| lgcp_IC | R Documentation |
Calculate information criteria for point process models, using a fitted
model and optionally new data. The interface is still under development
and may change without warning in future versions.
lgcp_IC(fit, data, predictor, domain, samplers, n.samples = 2000L)
delta_IC(data)
fit |
A fitted |
data |
A data frame containing the observed points, with columns for
coordinates and any covariates used in the model. The data frame may also
include a column named |
predictor |
An expression that evaluates to the linear predictor of the
model, given the data. This should be an expression that can be evaluated
in the context of the data frame and model components, just as in the
|
domain, samplers |
Arguments defining the integration domain(s) and
sampling regions, as for |
n.samples |
Integer. The number of posterior samples to draw for estimating the criteria. Default is 2000. |
A tibble with columns for the Criterion name, Method,
log pointwise predictive density (lppd), effective number of parameters
(p_eff), and the information criterion value (IC)
delta_IC(): Calculate IC differences based on joined output from
several lgcp_IC calls;
delta_IC(rbind(cbind(lgcp_IC(...), Model = "A"),
cbind(lgcp_IC(...), Model = "B")))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.