mexdolphin: Deprecated alias for sp version of the mexdolphin dataset

mexdolphinR Documentation

Deprecated alias for sp version of the mexdolphin dataset

Description

Deprecated dataset name for the sp version of mexdolphin_sf. Use mexdolphin_sp() instead.

See Also

mexdolphin_sf


inlabru documentation built on July 28, 2026, 9:07 a.m.