new_bru_log: Create a 'bru_log' object

View source: R/environment.R

new_bru_logR Documentation

Create a bru_log object

Description

Create a bru_log object, by default empty.

Usage

new_bru_log(x = NULL, bookmarks = NULL)

Arguments

x

An optional character vector of log messages, or data.frame with columns message, timestamp, and verbosity, or a bru_log object.

bookmarks

An optional integer vector of named bookmarks message in x.

Value

A new bru_log object.

See Also

Other inlabru log methods: bru_log(), bru_log_bookmark(), bru_log_message(), bru_log_offset(), bru_log_reset()

Examples

x <- new_bru_log()
x <- bru_log_message("Test message", x = x)
print(x)

inlabru documentation built on July 28, 2026, 9:07 a.m.