tidy.bru: Extract a bru model fit into a tidy tibble

View source: R/tidiers.R

tidy.bruR Documentation

Extract a bru model fit into a tidy tibble

Description

This function extracts the fixed effect coefficients or hyperparameters from a fitted bru object and returns them in a tidy tibble format. See generics::tidy() for more details on the tidy data format.

Usage

## S3 method for class 'bru'
tidy(x, effects = "fixed", ...)

Arguments

x

A fitted bru object.

effects

"fixed" (default) or "hyperpar".

...

Unused.

Value

A tibble with one row per term.


inlabru documentation built on July 28, 2026, 9:07 a.m.