| augment.bru | R Documentation |
Adds posterior mean and credible interval columns to data. The
user must supply pred_formula because inlabru prediction expressions are
arbitrary R and cannot be recovered from the fit object alone. Also see
generics::augment().
## S3 method for class 'bru'
augment(x, data, pred_formula, n_samples = 500L, seed = NULL, ...)
x |
A fitted |
data |
A data frame of covariate values. |
pred_formula |
A formula passed to |
n_samples |
Number of posterior samples (default 500). |
seed |
Optional integer. If non- |
... |
Passed to |
data with additional columns .fitted, .fitted_low,
.fitted_high, .fitted_sd.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.