| bm_marginal | R Documentation |
Constructs a mapper that transforms the marginal distribution state from
\textrm{N}(0,1) to the distribution of a given (continuous)
quantile function. The ... arguments are used as parameter arguments to
qfun, pfun, dfun, and dqfun.
bm_marginal(qfun, pfun = NULL, dfun = NULL, dqfun = NULL, ..., inverse = FALSE)
bru_mapper_marginal(...)
qfun |
A quantile function, supporting arguments |
pfun |
A CDF, supporting arguments |
dfun |
A pdf, supporting arguments |
dqfun |
A function evaluating the reciprocal of the derivative of
|
... |
Arguments passed on to |
inverse |
logical; If |
A bm_marginal mapper object.
bru_mapper, bru_mapper_generics
Other mappers:
bm_aggregate(),
bm_collect(),
bm_const(),
bm_expr(),
bm_factor(),
bm_fm_mesh_1d,
bm_fmesher(),
bm_harmonics(),
bm_index(),
bm_linear(),
bm_logitaverage(),
bm_logsumexp(),
bm_matrix(),
bm_multi(),
bm_pipe(),
bm_reparam(),
bm_repeat(),
bm_scale(),
bm_shift(),
bm_sum(),
bm_taylor(),
bru_get_mapper(),
bru_mapper()
m <- bm_marginal(qexp, pexp, rate = 1 / 8)
(val <- ibm_eval(m, state = -5:5))
ibm_eval(m, state = val, reverse = TRUE)
m <- bm_marginal(qexp, pexp, dexp, rate = 1 / 8)
ibm_eval2(m, state = -3:3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.