| bm_pipe | R Documentation |
Create a pipe mapper, where mappers is a list of mappers,
and the evaluated output of each mapper is handed as the state to the next
mapper.
The input format for the ibm_eval and ibm_jacobian methods is
a list of inputs, one for each mapper.
bm_pipe(mappers)
bru_mapper_pipe(...)
mappers |
A list of |
... |
Arguments passed on to |
A bm_pipe mapper object.
bru_mapper, bru_mapper_generics
Other mappers:
bm_aggregate(),
bm_collect(),
bm_const(),
bm_expr(),
bm_factor(),
bm_fm_mesh_1d,
bm_fmesher(),
bm_harmonics(),
bm_index(),
bm_linear(),
bm_logitaverage(),
bm_logsumexp(),
bm_marginal(),
bm_matrix(),
bm_multi(),
bm_reparam(),
bm_repeat(),
bm_scale(),
bm_shift(),
bm_sum(),
bm_taylor(),
bru_get_mapper(),
bru_mapper()
m <- bm_pipe(list(
scale = bm_scale(),
shift = bm_shift()
))
ibm_eval2(m, input = list(scale = 2, shift = 1:4), state = 1:4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.