| bru_get_mapper | R Documentation |
The component definitions will automatically attempt to extract mapper
information from any model object by calling the generic bru_get_mapper.
Any class method implementation should return a bru_mapper object suitable
for the given latent model.
bru_get_mapper(model, ...)
## S3 method for class 'inla.spde'
bru_get_mapper(model, ...)
## S3 method for class 'inla.rgeneric'
bru_get_mapper(model, ...)
## S3 method for class 'inla.cgeneric'
bru_get_mapper(model, ...)
bru_get_mapper_safely(model, ...)
## S3 method for class 'inla_model_reparam'
bru_get_mapper(model, ...)
model |
A model component object |
... |
Arguments passed on to other methods |
Before implementing your own bru_get_mapper method, check if there
is already a general method available that handles your model class, such as
bru_get_mapper.inla.spde(), bru_get_mapper.inla.rgeneric(), and
bru_get_mapper.inla.cgeneric().
A bru_mapper object defined by the model component
bru_get_mapper(inla.spde): Extract an indexed mapper for
the model$mesh object contained in the model object,
which is assumed to be of a class supporting relevant fmesher methods.
bru_get_mapper(inla.rgeneric): Returns the mapper given by a pre-computed mapper,
or an index mapper mapping the size of the model graph.
The easiest method to define a mapper for an inla.rgeneric model is to
store the mapper in the object.
Alternatively, define your model using a subclass and define a
bru_get_mapper.<subclass> method that should return the
corresponding bru_mapper object.
The order of precedence for the mapper construction when calling
bru_get_mapper(model) has the following precedence:
bru_get_mapper.<subclass>, if model has a subclass, otherwise
model[["mapper"]] if that is NULL, and otherwise
bm_index() using the size of the graph returned by model[["f"]][["n"]]
bru_get_mapper(inla.cgeneric): Works the same as the method of inla.rgeneric
bru_get_mapper(inla_model_reparam): Reparameterised inla model mapper, see
inla.spde2.pcmatern_B()
bru_get_mapper_safely(): Tries to call the bru_get_mapper,
and returns NULL if it fails (e.g. due to no available class method).
If the call succeeds and returns non-NULL, it checks that the object
inherits from the bru_mapper class, and gives an error if it does not.
bru_mapper for mapper constructor methods, and the individual mappers for specific implementation details.
Other mappers:
bm_aggregate(),
bm_collect(),
bm_const(),
bm_expr(),
bm_factor(),
bm_fm_mesh_1d,
bm_fmesher(),
bm_harmonics(),
bm_index(),
bm_linear(),
bm_logitaverage(),
bm_logsumexp(),
bm_marginal(),
bm_matrix(),
bm_multi(),
bm_pipe(),
bm_reparam(),
bm_repeat(),
bm_scale(),
bm_shift(),
bm_sum(),
bm_taylor(),
bru_mapper()
if (bru_safe_inla()) {
mesh <- fmesher::fm_rcdt_2d_inla(globe = 2)
spde <- INLA::inla.spde2.pcmatern(mesh,
prior.range = c(1, 0.5),
prior.sigma = c(1, 0.5)
)
mapper <- bru_get_mapper(spde)
ibm_n(mapper)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.