| bru_is_additive | R Documentation |
Checks if a predictor expression is additive or not
bru_is_additive(x, ...)
## Default S3 method:
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'numeric'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'name'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'call'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'expression'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'quosure'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'formula'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'character'
bru_is_additive(x, ..., verbose = FALSE)
## S3 method for class 'bru_pred_expr'
bru_is_additive(x, ...)
## S3 method for class 'bru_obs'
bru_is_additive(x, ...)
## S3 method for class 'bru_obs_list'
bru_is_additive(x, ...)
x |
A predictor |
... |
Arguments passed on recursively. |
verbose |
logical; if |
TRUE if the expression is detected to be additive, FALSE
otherwise.
bru_is_additive(~ x + y)
bru_is_additive(~ x * y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.