Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-05-12 12:21:37.041017: inlabru loaded
#> 2026-05-12 12:21:37.04151: Clear override options
#> 2026-05-12 12:21:47.481979: bru: Preprocessing
#> 2026-05-12 12:21:47.59885: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:48.178531: bru: Preprocessing
#> 2026-05-12 12:21:48.491837: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:48.862519: bru: Preprocessing
#> 2026-05-12 12:21:48.971767: iinla: Iteration 1 [max: 10]
#> 2026-05-12 12:21:49.325551: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-12 12:21:49.362447: iinla: Iteration 2 [max: 10]
#> 2026-05-12 12:21:49.958757: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-12 12:21:49.986386: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:49.988795: iinla: Iteration 3 [max: 10]
#> 2026-05-12 12:21:50.316335: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-12 12:21:50.344769: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:50.347246: iinla: Iteration 4 [max: 10]
#> 2026-05-12 12:21:50.703877: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:50.705108: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-12 12:21:50.707563: iinla: Iteration 5 [max: 10]
#> 2026-05-12 12:21:52.086668: bru: Preprocessing
#> 2026-05-12 12:21:52.16661: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:57.252197: bru: Preprocessing
format(bru_log())
#> 2026-05-12 12:21:37.041017: inlabru loaded
#> 2026-05-12 12:21:37.04151: Clear override options
#> 2026-05-12 12:21:47.481979: bru: Preprocessing
#> 2026-05-12 12:21:47.497303: Evaluate component inputs for each observation model
#> 2026-05-12 12:21:47.498781: bru_input(bru_comp_list)
#> 2026-05-12 12:21:47.500228: bru_input.bru_comp(x)
#> 2026-05-12 12:21:47.501612: bru_input.bm_pipe(x)
#> 2026-05-12 12:21:47.503229: bru_input.bm_multi(x:core)
#> 2026-05-12 12:21:47.504752: bru_input.bru_mapper(x:core:main)
#> 2026-05-12 12:21:47.506389: bru_input(bru_input) for (x)
#> 2026-05-12 12:21:47.514152: bru_input.bru_comp(Intercept)
#> 2026-05-12 12:21:47.515516: bru_input.bm_pipe(Intercept)
#> 2026-05-12 12:21:47.517033: bru_input.bm_multi(Intercept:core)
#> 2026-05-12 12:21:47.518533: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-12 12:21:47.519884: bru_input(bru_input) for (Intercept)
#> 2026-05-12 12:21:47.535248: iinla: Start
#> 2026-05-12 12:21:47.53689: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:47.538129: Linearise components for each observation model
#> 2026-05-12 12:21:47.539582: Linearise component 'x'
#> 2026-05-12 12:21:47.542475: Linearise component 'Intercept'
#> 2026-05-12 12:21:47.545293: iinla: Evaluate component simplifications
#> 2026-05-12 12:21:47.546544: Simplify component mappers for each observation model
#> 2026-05-12 12:21:47.548074: Simplify component 'x'
#> 2026-05-12 12:21:47.551206: Simplify component 'Intercept'
#> 2026-05-12 12:21:47.560361: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:47.575192: iinla: Construct inla stack
#> 2026-05-12 12:21:47.597381: iinla: Model initialisation completed
#> 2026-05-12 12:21:47.59885: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:48.154656: iinla: Computation completed
#> 2026-05-12 12:21:48.178531: bru: Preprocessing
#> 2026-05-12 12:21:48.18737: Evaluate component inputs for each observation model
#> 2026-05-12 12:21:48.188702: bru_input(bru_comp_list)
#> 2026-05-12 12:21:48.190052: bru_input.bru_comp(x)
#> 2026-05-12 12:21:48.191411: bru_input.bm_pipe(x)
#> 2026-05-12 12:21:48.192907: bru_input.bm_multi(x:core)
#> 2026-05-12 12:21:48.424634: bru_input.bru_mapper(x:core:main)
#> 2026-05-12 12:21:48.426105: bru_input(bru_input) for (x)
#> 2026-05-12 12:21:48.434126: bru_input.bru_comp(Intercept)
#> 2026-05-12 12:21:48.435446: bru_input.bm_pipe(Intercept)
#> 2026-05-12 12:21:48.436875: bru_input.bm_multi(Intercept:core)
#> 2026-05-12 12:21:48.438291: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-12 12:21:48.439562: bru_input(bru_input) for (Intercept)
#> 2026-05-12 12:21:48.453353: iinla: Start
#> 2026-05-12 12:21:48.454909: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:48.456033: Linearise components for each observation model
#> 2026-05-12 12:21:48.45735: Linearise component 'x'
#> 2026-05-12 12:21:48.460213: Linearise component 'Intercept'
#> 2026-05-12 12:21:48.462946: iinla: Evaluate component simplifications
#> 2026-05-12 12:21:48.464128: Simplify component mappers for each observation model
#> 2026-05-12 12:21:48.465443: Simplify component 'x'
#> 2026-05-12 12:21:48.468398: Simplify component 'Intercept'
#> 2026-05-12 12:21:48.471375: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:48.477921: iinla: Construct inla stack
#> 2026-05-12 12:21:48.490451: iinla: Model initialisation completed
#> 2026-05-12 12:21:48.491837: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:48.835215: iinla: Computation completed
#> 2026-05-12 12:21:48.862519: bru: Preprocessing
#> 2026-05-12 12:21:48.873465: Evaluate component inputs for each observation model
#> 2026-05-12 12:21:48.875208: bru_input(bru_comp_list)
#> 2026-05-12 12:21:48.876987: bru_input.bru_comp(z)
#> 2026-05-12 12:21:48.878822: bru_input.bm_pipe(z)
#> 2026-05-12 12:21:48.880914: bru_input.bm_multi(z:core)
#> 2026-05-12 12:21:48.882916: bru_input.bru_mapper(z:core:main)
#> 2026-05-12 12:21:48.8847: bru_input(bru_input) for (z)
#> 2026-05-12 12:21:48.89382: bru_input.bru_comp(Intercept)
#> 2026-05-12 12:21:48.895624: bru_input.bm_pipe(Intercept)
#> 2026-05-12 12:21:48.897617: bru_input.bm_multi(Intercept:core)
#> 2026-05-12 12:21:48.899549: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-12 12:21:48.901414: bru_input(bru_input) for (Intercept)
#> 2026-05-12 12:21:48.916587: iinla: Start
#> 2026-05-12 12:21:48.918729: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:48.920316: Linearise components for each observation model
#> 2026-05-12 12:21:48.922228: Linearise component 'z'
#> 2026-05-12 12:21:48.925756: Linearise component 'Intercept'
#> 2026-05-12 12:21:48.929209: iinla: Evaluate component simplifications
#> 2026-05-12 12:21:48.930774: Simplify component mappers for each observation model
#> 2026-05-12 12:21:48.932586: Simplify component 'z'
#> 2026-05-12 12:21:48.936247: Simplify component 'Intercept'
#> 2026-05-12 12:21:48.939855: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:48.943726: Linearise with respect to component 'z'
#> 2026-05-12 12:21:48.950227: Linearise with respect to component 'Intercept'
#> 2026-05-12 12:21:48.954483: iinla: Construct inla stack
#> 2026-05-12 12:21:48.969891: iinla: Model initialisation completed
#> 2026-05-12 12:21:48.971767: iinla: Iteration 1 [max: 10]
#> 2026-05-12 12:21:49.313174: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8)
#> 2026-05-12 12:21:49.316911: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8)
#> 2026-05-12 12:21:49.321616: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-12 12:21:49.323599: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4
#> 2026-05-12 12:21:49.325551: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-12 12:21:49.327819: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:49.329432: Linearise components for each observation model
#> 2026-05-12 12:21:49.331244: Linearise component 'z'
#> 2026-05-12 12:21:49.334708: Linearise component 'Intercept'
#> 2026-05-12 12:21:49.338263: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:49.341491: Linearise with respect to component 'z'
#> 2026-05-12 12:21:49.346105: Linearise with respect to component 'Intercept'
#> 2026-05-12 12:21:49.362447: iinla: Iteration 2 [max: 10]
#> 2026-05-12 12:21:49.94943: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4)
#> 2026-05-12 12:21:49.952363: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4)
#> 2026-05-12 12:21:49.955859: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-12 12:21:49.957343: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63
#> 2026-05-12 12:21:49.958757: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-12 12:21:49.960459: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:49.961578: Linearise components for each observation model
#> 2026-05-12 12:21:49.96288: Linearise component 'z'
#> 2026-05-12 12:21:49.965688: Linearise component 'Intercept'
#> 2026-05-12 12:21:49.968492: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:49.971011: Linearise with respect to component 'z'
#> 2026-05-12 12:21:49.97456: Linearise with respect to component 'Intercept'
#> 2026-05-12 12:21:49.986386: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:49.988795: iinla: Iteration 3 [max: 10]
#> 2026-05-12 12:21:50.306846: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68)
#> 2026-05-12 12:21:50.309779: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-05-12 12:21:50.313387: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-12 12:21:50.314869: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-05-12 12:21:50.316335: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-12 12:21:50.318104: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:50.319293: Linearise components for each observation model
#> 2026-05-12 12:21:50.320743: Linearise component 'z'
#> 2026-05-12 12:21:50.323613: Linearise component 'Intercept'
#> 2026-05-12 12:21:50.326504: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:50.329137: Linearise with respect to component 'z'
#> 2026-05-12 12:21:50.332736: Linearise with respect to component 'Intercept'
#> 2026-05-12 12:21:50.344769: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:50.347246: iinla: Iteration 4 [max: 10]
#> 2026-05-12 12:21:50.666978: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007267, norm01 = 0.01176)
#> 2026-05-12 12:21:50.670117: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-05-12 12:21:50.67373: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-05-12 12:21:50.675248: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.228e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-05-12 12:21:50.677007: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:50.678332: Linearise components for each observation model
#> 2026-05-12 12:21:50.679703: Linearise component 'z'
#> 2026-05-12 12:21:50.682554: Linearise component 'Intercept'
#> 2026-05-12 12:21:50.685396: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:50.688092: Linearise with respect to component 'z'
#> 2026-05-12 12:21:50.691729: Linearise with respect to component 'Intercept'
#> 2026-05-12 12:21:50.703877: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:50.705108: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-12 12:21:50.707563: iinla: Iteration 5 [max: 10]
#> 2026-05-12 12:21:51.044178: iinla: Computation completed
#> 2026-05-12 12:21:52.086668: bru: Preprocessing
#> 2026-05-12 12:21:52.096545: Evaluate component inputs for each observation model
#> 2026-05-12 12:21:52.097836: bru_input(bru_comp_list)
#> 2026-05-12 12:21:52.099207: bru_input.bru_comp(field)
#> 2026-05-12 12:21:52.10054: bru_input.bm_pipe(field)
#> 2026-05-12 12:21:52.102014: bru_input.bm_multi(field:core)
#> 2026-05-12 12:21:52.103523: bru_input.bru_mapper(field:core:main)
#> 2026-05-12 12:21:52.10485: bru_input(bru_input) for (field)
#> 2026-05-12 12:21:52.118: iinla: Start
#> 2026-05-12 12:21:52.119637: iinla: Evaluate component linearisations
#> 2026-05-12 12:21:52.120798: Linearise components for each observation model
#> 2026-05-12 12:21:52.122167: Linearise component 'field'
#> 2026-05-12 12:21:52.12943: iinla: Evaluate component simplifications
#> 2026-05-12 12:21:52.13063: Simplify component mappers for each observation model
#> 2026-05-12 12:21:52.131962: Simplify component 'field'
#> 2026-05-12 12:21:52.138318: iinla: Evaluate predictor linearisation
#> 2026-05-12 12:21:52.141761: iinla: Construct inla stack
#> 2026-05-12 12:21:52.165262: iinla: Model initialisation completed
#> 2026-05-12 12:21:52.16661: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:52.595885: iinla: Computation completed
#> 2026-05-12 12:21:54.74701: bru_input(bru_comp_list)
#> 2026-05-12 12:21:57.252197: bru: Preprocessing
#> 2026-05-12 12:21:57.265314: Evaluate component inputs for each observation model
#> 2026-05-12 12:21:57.266592: bru_input(bru_comp_list)
#> 2026-05-12 12:21:57.2679: bru_input.bru_comp(x)
#> 2026-05-12 12:21:57.269205: bru_input.bm_pipe(x)
#> 2026-05-12 12:21:57.270674: bru_input.bm_multi(x:core)
#> 2026-05-12 12:21:57.272112: bru_input.bru_mapper(x:core:main)
#> 2026-05-12 12:21:57.273376: bru_input(bru_input) for (x)
#> 2026-05-12 12:21:57.281662: bru_input(bru_comp_list)
#> 2026-05-12 12:21:57.282964: bru_input.bru_comp(x)
#> 2026-05-12 12:21:57.284267: bru_input.bm_pipe(x)
#> 2026-05-12 12:21:57.285697: bru_input.bm_multi(x:core)
#> 2026-05-12 12:21:57.287102: bru_input.bru_mapper(x:core:main)
#> 2026-05-12 12:21:57.28836: bru_input(bru_input) for (x)
#> 2026-05-12 12:22:00.420202: bru_input(bru_input) for (LABEL)
#> 2026-05-12 12:22:02.249989: bru_input_text(bru_input) for (LABEL)
#> 2026-05-12 12:22:02.261255: bru_input.bru_comp(x)
#> 2026-05-12 12:22:02.262345: bru_input_text.bm_pipe(x)
#> 2026-05-12 12:22:02.263554: bru_input_text.bm_multi(x:core)
#> 2026-05-12 12:22:02.264787: bru_input_text.bru_mapper(x:core:main)
#> 2026-05-12 12:22:02.265786: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-05-12 12:21:37.041017: inlabru loaded
#> 2026-05-12 12:21:37.04151: Clear override options
#> 2026-05-12 12:21:47.481979: bru: Preprocessing
#> 2026-05-12 12:21:47.59885: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:48.178531: bru: Preprocessing
#> 2026-05-12 12:21:48.491837: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:48.862519: bru: Preprocessing
#> 2026-05-12 12:21:48.971767: iinla: Iteration 1 [max: 10]
#> 2026-05-12 12:21:49.325551: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-12 12:21:49.362447: iinla: Iteration 2 [max: 10]
#> 2026-05-12 12:21:49.958757: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-12 12:21:49.986386: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:49.988795: iinla: Iteration 3 [max: 10]
#> 2026-05-12 12:21:50.316335: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-12 12:21:50.344769: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:50.347246: iinla: Iteration 4 [max: 10]
#> 2026-05-12 12:21:50.703877: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-12 12:21:50.705108: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-12 12:21:50.707563: iinla: Iteration 5 [max: 10]
#> 2026-05-12 12:21:52.086668: bru: Preprocessing
#> 2026-05-12 12:21:52.16661: iinla: Iteration 1 [max: 1]
#> 2026-05-12 12:21:57.252197: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-05-12 12:21:37.041017: inlabru loaded (level 1)
#> 2026-05-12 12:21:37.04151: Clear override options (level 1)
#> 2026-05-12 12:21:47.481979: bru: Preprocessing (level 1)
#> 2026-05-12 12:21:47.497303: Evaluate component inputs for each observation model (level 3)
#> 2026-05-12 12:21:47.498781: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:47.500228: bru_input.bru_comp(x) (level 4)
#> 2026-05-12 12:21:47.501612: bru_input.bm_pipe(x) (level 5)
#> 2026-05-12 12:21:47.503229: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-12 12:21:47.504752: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-12 12:21:47.506389: bru_input(bru_input) for (x) (level 5)
#> 2026-05-12 12:21:47.514152: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-12 12:21:47.515516: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-12 12:21:47.517033: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-12 12:21:47.518533: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-12 12:21:47.519884: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-12 12:21:47.535248: iinla: Start (level 3)
#> 2026-05-12 12:21:47.53689: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:47.538129: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:47.539582: Linearise component 'x' (level 4)
#> 2026-05-12 12:21:47.542475: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:47.545293: iinla: Evaluate component simplifications (level 3)
#> 2026-05-12 12:21:47.546544: Simplify component mappers for each observation model (level 3)
#> 2026-05-12 12:21:47.548074: Simplify component 'x' (level 4)
#> 2026-05-12 12:21:47.551206: Simplify component 'Intercept' (level 4)
#> 2026-05-12 12:21:47.560361: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:47.575192: iinla: Construct inla stack (level 3)
#> 2026-05-12 12:21:47.597381: iinla: Model initialisation completed (level 3)
#> 2026-05-12 12:21:47.59885: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-12 12:21:48.154656: iinla: Computation completed (level 3)
#> 2026-05-12 12:21:48.178531: bru: Preprocessing (level 1)
#> 2026-05-12 12:21:48.18737: Evaluate component inputs for each observation model (level 3)
#> 2026-05-12 12:21:48.188702: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:48.190052: bru_input.bru_comp(x) (level 4)
#> 2026-05-12 12:21:48.191411: bru_input.bm_pipe(x) (level 5)
#> 2026-05-12 12:21:48.192907: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-12 12:21:48.424634: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-12 12:21:48.426105: bru_input(bru_input) for (x) (level 5)
#> 2026-05-12 12:21:48.434126: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-12 12:21:48.435446: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-12 12:21:48.436875: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-12 12:21:48.438291: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-12 12:21:48.439562: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-12 12:21:48.453353: iinla: Start (level 3)
#> 2026-05-12 12:21:48.454909: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:48.456033: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:48.45735: Linearise component 'x' (level 4)
#> 2026-05-12 12:21:48.460213: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:48.462946: iinla: Evaluate component simplifications (level 3)
#> 2026-05-12 12:21:48.464128: Simplify component mappers for each observation model (level 3)
#> 2026-05-12 12:21:48.465443: Simplify component 'x' (level 4)
#> 2026-05-12 12:21:48.468398: Simplify component 'Intercept' (level 4)
#> 2026-05-12 12:21:48.471375: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:48.477921: iinla: Construct inla stack (level 3)
#> 2026-05-12 12:21:48.490451: iinla: Model initialisation completed (level 3)
#> 2026-05-12 12:21:48.491837: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-12 12:21:48.835215: iinla: Computation completed (level 3)
#> 2026-05-12 12:21:48.862519: bru: Preprocessing (level 1)
#> 2026-05-12 12:21:48.873465: Evaluate component inputs for each observation model (level 3)
#> 2026-05-12 12:21:48.875208: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:48.876987: bru_input.bru_comp(z) (level 4)
#> 2026-05-12 12:21:48.878822: bru_input.bm_pipe(z) (level 5)
#> 2026-05-12 12:21:48.880914: bru_input.bm_multi(z:core) (level 5)
#> 2026-05-12 12:21:48.882916: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-05-12 12:21:48.8847: bru_input(bru_input) for (z) (level 5)
#> 2026-05-12 12:21:48.89382: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-12 12:21:48.895624: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-12 12:21:48.897617: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-12 12:21:48.899549: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-12 12:21:48.901414: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-12 12:21:48.916587: iinla: Start (level 3)
#> 2026-05-12 12:21:48.918729: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:48.920316: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:48.922228: Linearise component 'z' (level 4)
#> 2026-05-12 12:21:48.925756: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:48.929209: iinla: Evaluate component simplifications (level 3)
#> 2026-05-12 12:21:48.930774: Simplify component mappers for each observation model (level 3)
#> 2026-05-12 12:21:48.932586: Simplify component 'z' (level 4)
#> 2026-05-12 12:21:48.936247: Simplify component 'Intercept' (level 4)
#> 2026-05-12 12:21:48.939855: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:48.943726: Linearise with respect to component 'z' (level 5)
#> 2026-05-12 12:21:48.950227: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-12 12:21:48.954483: iinla: Construct inla stack (level 3)
#> 2026-05-12 12:21:48.969891: iinla: Model initialisation completed (level 3)
#> 2026-05-12 12:21:48.971767: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-05-12 12:21:49.313174: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8) (level 3)
#> 2026-05-12 12:21:49.316911: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8) (level 3)
#> 2026-05-12 12:21:49.321616: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 3)
#> 2026-05-12 12:21:49.323599: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4 (level 4)
#> 2026-05-12 12:21:49.325551: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 2)
#> 2026-05-12 12:21:49.327819: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:49.329432: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:49.331244: Linearise component 'z' (level 4)
#> 2026-05-12 12:21:49.334708: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:49.338263: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:49.341491: Linearise with respect to component 'z' (level 5)
#> 2026-05-12 12:21:49.346105: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-12 12:21:49.362447: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-05-12 12:21:49.94943: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4) (level 3)
#> 2026-05-12 12:21:49.952363: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4) (level 3)
#> 2026-05-12 12:21:49.955859: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 3)
#> 2026-05-12 12:21:49.957343: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63 (level 4)
#> 2026-05-12 12:21:49.958757: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 2)
#> 2026-05-12 12:21:49.960459: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:49.961578: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:49.96288: Linearise component 'z' (level 4)
#> 2026-05-12 12:21:49.965688: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:49.968492: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:49.971011: Linearise with respect to component 'z' (level 5)
#> 2026-05-12 12:21:49.97456: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-12 12:21:49.986386: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-12 12:21:49.988795: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-05-12 12:21:50.306846: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68) (level 3)
#> 2026-05-12 12:21:50.309779: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-05-12 12:21:50.313387: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-05-12 12:21:50.314869: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-05-12 12:21:50.316335: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-05-12 12:21:50.318104: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:50.319293: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:50.320743: Linearise component 'z' (level 4)
#> 2026-05-12 12:21:50.323613: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:50.326504: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:50.329137: Linearise with respect to component 'z' (level 5)
#> 2026-05-12 12:21:50.332736: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-12 12:21:50.344769: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-12 12:21:50.347246: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-05-12 12:21:50.666978: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007267, norm01 = 0.01176) (level 3)
#> 2026-05-12 12:21:50.670117: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-05-12 12:21:50.67373: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-05-12 12:21:50.675248: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.228e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-05-12 12:21:50.677007: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:50.678332: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:50.679703: Linearise component 'z' (level 4)
#> 2026-05-12 12:21:50.682554: Linearise component 'Intercept' (level 4)
#> 2026-05-12 12:21:50.685396: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:50.688092: Linearise with respect to component 'z' (level 5)
#> 2026-05-12 12:21:50.691729: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-12 12:21:50.703877: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-12 12:21:50.705108: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-05-12 12:21:50.707563: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-05-12 12:21:51.044178: iinla: Computation completed (level 3)
#> 2026-05-12 12:21:52.086668: bru: Preprocessing (level 1)
#> 2026-05-12 12:21:52.096545: Evaluate component inputs for each observation model (level 3)
#> 2026-05-12 12:21:52.097836: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:52.099207: bru_input.bru_comp(field) (level 4)
#> 2026-05-12 12:21:52.10054: bru_input.bm_pipe(field) (level 5)
#> 2026-05-12 12:21:52.102014: bru_input.bm_multi(field:core) (level 5)
#> 2026-05-12 12:21:52.103523: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-05-12 12:21:52.10485: bru_input(bru_input) for (field) (level 5)
#> 2026-05-12 12:21:52.118: iinla: Start (level 3)
#> 2026-05-12 12:21:52.119637: iinla: Evaluate component linearisations (level 3)
#> 2026-05-12 12:21:52.120798: Linearise components for each observation model (level 3)
#> 2026-05-12 12:21:52.122167: Linearise component 'field' (level 4)
#> 2026-05-12 12:21:52.12943: iinla: Evaluate component simplifications (level 3)
#> 2026-05-12 12:21:52.13063: Simplify component mappers for each observation model (level 3)
#> 2026-05-12 12:21:52.131962: Simplify component 'field' (level 4)
#> 2026-05-12 12:21:52.138318: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-12 12:21:52.141761: iinla: Construct inla stack (level 3)
#> 2026-05-12 12:21:52.165262: iinla: Model initialisation completed (level 3)
#> 2026-05-12 12:21:52.16661: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-12 12:21:52.595885: iinla: Computation completed (level 3)
#> 2026-05-12 12:21:54.74701: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:57.252197: bru: Preprocessing (level 1)
#> 2026-05-12 12:21:57.265314: Evaluate component inputs for each observation model (level 3)
#> 2026-05-12 12:21:57.266592: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:57.2679: bru_input.bru_comp(x) (level 4)
#> 2026-05-12 12:21:57.269205: bru_input.bm_pipe(x) (level 5)
#> 2026-05-12 12:21:57.270674: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-12 12:21:57.272112: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-12 12:21:57.273376: bru_input(bru_input) for (x) (level 5)
#> 2026-05-12 12:21:57.281662: bru_input(bru_comp_list) (level 4)
#> 2026-05-12 12:21:57.282964: bru_input.bru_comp(x) (level 4)
#> 2026-05-12 12:21:57.284267: bru_input.bm_pipe(x) (level 5)
#> 2026-05-12 12:21:57.285697: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-12 12:21:57.287102: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-12 12:21:57.28836: bru_input(bru_input) for (x) (level 5)
#> 2026-05-12 12:22:00.420202: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-05-12 12:22:02.249989: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-05-12 12:22:02.261255: bru_input.bru_comp(x) (level 4)
#> 2026-05-12 12:22:02.262345: bru_input_text.bm_pipe(x) (level 5)
#> 2026-05-12 12:22:02.263554: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-05-12 12:22:02.264787: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-05-12 12:22:02.265786: bru_input_text(bru_input) for (x) (level 5)