Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-05-07 18:23:57.34723: inlabru loaded
#> 2026-05-07 18:23:57.347719: Clear override options
#> 2026-05-07 18:24:07.664059: bru: Preprocessing
#> 2026-05-07 18:24:07.783624: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:08.312451: bru: Preprocessing
#> 2026-05-07 18:24:08.446438: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:09.088582: bru: Preprocessing
#> 2026-05-07 18:24:09.176819: iinla: Iteration 1 [max: 10]
#> 2026-05-07 18:24:09.509046: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-07 18:24:09.546516: iinla: Iteration 2 [max: 10]
#> 2026-05-07 18:24:10.225415: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-07 18:24:10.252645: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.255049: iinla: Iteration 3 [max: 10]
#> 2026-05-07 18:24:10.560458: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-07 18:24:10.589045: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.591566: iinla: Iteration 4 [max: 10]
#> 2026-05-07 18:24:10.930753: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.932021: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-07 18:24:10.934508: iinla: Iteration 5 [max: 10]
#> 2026-05-07 18:24:12.304396: bru: Preprocessing
#> 2026-05-07 18:24:12.370711: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:17.017564: bru: Preprocessing
format(bru_log())
#> 2026-05-07 18:23:57.34723: inlabru loaded
#> 2026-05-07 18:23:57.347719: Clear override options
#> 2026-05-07 18:24:07.664059: bru: Preprocessing
#> 2026-05-07 18:24:07.680296: Evaluate component inputs for each observation model
#> 2026-05-07 18:24:07.681754: bru_input(bru_comp_list)
#> 2026-05-07 18:24:07.683182: bru_input.bru_comp(x)
#> 2026-05-07 18:24:07.684582: bru_input.bm_pipe(x)
#> 2026-05-07 18:24:07.686573: bru_input.bm_multi(x:core)
#> 2026-05-07 18:24:07.688098: bru_input.bru_mapper(x:core:main)
#> 2026-05-07 18:24:07.68978: bru_input(bru_input) for (x)
#> 2026-05-07 18:24:07.69778: bru_input.bru_comp(Intercept)
#> 2026-05-07 18:24:07.699128: bru_input.bm_pipe(Intercept)
#> 2026-05-07 18:24:07.700583: bru_input.bm_multi(Intercept:core)
#> 2026-05-07 18:24:07.701996: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-07 18:24:07.703279: bru_input(bru_input) for (Intercept)
#> 2026-05-07 18:24:07.719235: iinla: Start
#> 2026-05-07 18:24:07.727742: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:07.73: Linearise components for each observation model
#> 2026-05-07 18:24:07.731572: Linearise component 'x'
#> 2026-05-07 18:24:07.734619: Linearise component 'Intercept'
#> 2026-05-07 18:24:07.73748: iinla: Evaluate component simplifications
#> 2026-05-07 18:24:07.738794: Simplify component mappers for each observation model
#> 2026-05-07 18:24:07.740244: Simplify component 'x'
#> 2026-05-07 18:24:07.743366: Simplify component 'Intercept'
#> 2026-05-07 18:24:07.746364: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:07.759779: iinla: Construct inla stack
#> 2026-05-07 18:24:07.782163: iinla: Model initialisation completed
#> 2026-05-07 18:24:07.783624: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:08.287907: iinla: Computation completed
#> 2026-05-07 18:24:08.312451: bru: Preprocessing
#> 2026-05-07 18:24:08.321484: Evaluate component inputs for each observation model
#> 2026-05-07 18:24:08.322817: bru_input(bru_comp_list)
#> 2026-05-07 18:24:08.324128: bru_input.bru_comp(x)
#> 2026-05-07 18:24:08.325441: bru_input.bm_pipe(x)
#> 2026-05-07 18:24:08.326892: bru_input.bm_multi(x:core)
#> 2026-05-07 18:24:08.32831: bru_input.bru_mapper(x:core:main)
#> 2026-05-07 18:24:08.329567: bru_input(bru_input) for (x)
#> 2026-05-07 18:24:08.336877: bru_input.bru_comp(Intercept)
#> 2026-05-07 18:24:08.338207: bru_input.bm_pipe(Intercept)
#> 2026-05-07 18:24:08.387512: bru_input.bm_multi(Intercept:core)
#> 2026-05-07 18:24:08.390148: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-07 18:24:08.392361: bru_input(bru_input) for (Intercept)
#> 2026-05-07 18:24:08.406596: iinla: Start
#> 2026-05-07 18:24:08.408488: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:08.409633: Linearise components for each observation model
#> 2026-05-07 18:24:08.410982: Linearise component 'x'
#> 2026-05-07 18:24:08.413993: Linearise component 'Intercept'
#> 2026-05-07 18:24:08.416815: iinla: Evaluate component simplifications
#> 2026-05-07 18:24:08.418053: Simplify component mappers for each observation model
#> 2026-05-07 18:24:08.419415: Simplify component 'x'
#> 2026-05-07 18:24:08.422417: Simplify component 'Intercept'
#> 2026-05-07 18:24:08.425446: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:08.43219: iinla: Construct inla stack
#> 2026-05-07 18:24:08.444936: iinla: Model initialisation completed
#> 2026-05-07 18:24:08.446438: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:09.06455: iinla: Computation completed
#> 2026-05-07 18:24:09.088582: bru: Preprocessing
#> 2026-05-07 18:24:09.097682: Evaluate component inputs for each observation model
#> 2026-05-07 18:24:09.099029: bru_input(bru_comp_list)
#> 2026-05-07 18:24:09.100324: bru_input.bru_comp(z)
#> 2026-05-07 18:24:09.10161: bru_input.bm_pipe(z)
#> 2026-05-07 18:24:09.10304: bru_input.bm_multi(z:core)
#> 2026-05-07 18:24:09.104419: bru_input.bru_mapper(z:core:main)
#> 2026-05-07 18:24:09.105676: bru_input(bru_input) for (z)
#> 2026-05-07 18:24:09.113204: bru_input.bru_comp(Intercept)
#> 2026-05-07 18:24:09.114534: bru_input.bm_pipe(Intercept)
#> 2026-05-07 18:24:09.115936: bru_input.bm_multi(Intercept:core)
#> 2026-05-07 18:24:09.117311: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-07 18:24:09.11867: bru_input(bru_input) for (Intercept)
#> 2026-05-07 18:24:09.131962: iinla: Start
#> 2026-05-07 18:24:09.133557: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:09.134666: Linearise components for each observation model
#> 2026-05-07 18:24:09.136012: Linearise component 'z'
#> 2026-05-07 18:24:09.13895: Linearise component 'Intercept'
#> 2026-05-07 18:24:09.141726: iinla: Evaluate component simplifications
#> 2026-05-07 18:24:09.142979: Simplify component mappers for each observation model
#> 2026-05-07 18:24:09.144346: Simplify component 'z'
#> 2026-05-07 18:24:09.147408: Simplify component 'Intercept'
#> 2026-05-07 18:24:09.150412: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:09.153683: Linearise with respect to component 'z'
#> 2026-05-07 18:24:09.159283: Linearise with respect to component 'Intercept'
#> 2026-05-07 18:24:09.162742: iinla: Construct inla stack
#> 2026-05-07 18:24:09.175351: iinla: Model initialisation completed
#> 2026-05-07 18:24:09.176819: iinla: Iteration 1 [max: 10]
#> 2026-05-07 18:24:09.496366: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8)
#> 2026-05-07 18:24:09.500272: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8)
#> 2026-05-07 18:24:09.504996: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-07 18:24:09.507081: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4
#> 2026-05-07 18:24:09.509046: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-07 18:24:09.511319: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:09.512881: Linearise components for each observation model
#> 2026-05-07 18:24:09.514823: Linearise component 'z'
#> 2026-05-07 18:24:09.518473: Linearise component 'Intercept'
#> 2026-05-07 18:24:09.521905: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:09.525238: Linearise with respect to component 'z'
#> 2026-05-07 18:24:09.529917: Linearise with respect to component 'Intercept'
#> 2026-05-07 18:24:09.546516: iinla: Iteration 2 [max: 10]
#> 2026-05-07 18:24:10.216579: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4)
#> 2026-05-07 18:24:10.219402: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4)
#> 2026-05-07 18:24:10.222701: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-07 18:24:10.224081: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63
#> 2026-05-07 18:24:10.225415: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-07 18:24:10.227011: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:10.228085: Linearise components for each observation model
#> 2026-05-07 18:24:10.229333: Linearise component 'z'
#> 2026-05-07 18:24:10.232102: Linearise component 'Intercept'
#> 2026-05-07 18:24:10.234997: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:10.237639: Linearise with respect to component 'z'
#> 2026-05-07 18:24:10.241103: Linearise with respect to component 'Intercept'
#> 2026-05-07 18:24:10.252645: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.255049: iinla: Iteration 3 [max: 10]
#> 2026-05-07 18:24:10.550812: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68)
#> 2026-05-07 18:24:10.553742: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-05-07 18:24:10.557441: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-07 18:24:10.558939: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-05-07 18:24:10.560458: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-07 18:24:10.562167: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:10.563371: Linearise components for each observation model
#> 2026-05-07 18:24:10.564725: Linearise component 'z'
#> 2026-05-07 18:24:10.567734: Linearise component 'Intercept'
#> 2026-05-07 18:24:10.570669: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:10.573375: Linearise with respect to component 'z'
#> 2026-05-07 18:24:10.576943: Linearise with respect to component 'Intercept'
#> 2026-05-07 18:24:10.589045: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.591566: iinla: Iteration 4 [max: 10]
#> 2026-05-07 18:24:10.893609: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007267, norm01 = 0.01176)
#> 2026-05-07 18:24:10.896672: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-05-07 18:24:10.900592: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-05-07 18:24:10.902119: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.228e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-05-07 18:24:10.90388: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:10.905106: Linearise components for each observation model
#> 2026-05-07 18:24:10.906461: Linearise component 'z'
#> 2026-05-07 18:24:10.909532: Linearise component 'Intercept'
#> 2026-05-07 18:24:10.912393: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:10.915098: Linearise with respect to component 'z'
#> 2026-05-07 18:24:10.918709: Linearise with respect to component 'Intercept'
#> 2026-05-07 18:24:10.930753: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.932021: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-07 18:24:10.934508: iinla: Iteration 5 [max: 10]
#> 2026-05-07 18:24:11.252308: iinla: Computation completed
#> 2026-05-07 18:24:12.304396: bru: Preprocessing
#> 2026-05-07 18:24:12.314256: Evaluate component inputs for each observation model
#> 2026-05-07 18:24:12.315517: bru_input(bru_comp_list)
#> 2026-05-07 18:24:12.316796: bru_input.bru_comp(field)
#> 2026-05-07 18:24:12.318092: bru_input.bm_pipe(field)
#> 2026-05-07 18:24:12.319506: bru_input.bm_multi(field:core)
#> 2026-05-07 18:24:12.3209: bru_input.bru_mapper(field:core:main)
#> 2026-05-07 18:24:12.322152: bru_input(bru_input) for (field)
#> 2026-05-07 18:24:12.335166: iinla: Start
#> 2026-05-07 18:24:12.336669: iinla: Evaluate component linearisations
#> 2026-05-07 18:24:12.337752: Linearise components for each observation model
#> 2026-05-07 18:24:12.338995: Linearise component 'field'
#> 2026-05-07 18:24:12.346669: iinla: Evaluate component simplifications
#> 2026-05-07 18:24:12.348013: Simplify component mappers for each observation model
#> 2026-05-07 18:24:12.34938: Simplify component 'field'
#> 2026-05-07 18:24:12.355741: iinla: Evaluate predictor linearisation
#> 2026-05-07 18:24:12.359158: iinla: Construct inla stack
#> 2026-05-07 18:24:12.369312: iinla: Model initialisation completed
#> 2026-05-07 18:24:12.370711: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:12.767173: iinla: Computation completed
#> 2026-05-07 18:24:14.572939: bru_input(bru_comp_list)
#> 2026-05-07 18:24:17.017564: bru: Preprocessing
#> 2026-05-07 18:24:17.031027: Evaluate component inputs for each observation model
#> 2026-05-07 18:24:17.032392: bru_input(bru_comp_list)
#> 2026-05-07 18:24:17.033844: bru_input.bru_comp(x)
#> 2026-05-07 18:24:17.035153: bru_input.bm_pipe(x)
#> 2026-05-07 18:24:17.036591: bru_input.bm_multi(x:core)
#> 2026-05-07 18:24:17.038089: bru_input.bru_mapper(x:core:main)
#> 2026-05-07 18:24:17.039425: bru_input(bru_input) for (x)
#> 2026-05-07 18:24:17.047379: bru_input(bru_comp_list)
#> 2026-05-07 18:24:17.048781: bru_input.bru_comp(x)
#> 2026-05-07 18:24:17.050084: bru_input.bm_pipe(x)
#> 2026-05-07 18:24:17.051524: bru_input.bm_multi(x:core)
#> 2026-05-07 18:24:17.052923: bru_input.bru_mapper(x:core:main)
#> 2026-05-07 18:24:17.054208: bru_input(bru_input) for (x)
#> 2026-05-07 18:24:20.336019: bru_input(bru_input) for (LABEL)
#> 2026-05-07 18:24:22.481557: bru_input_text(bru_input) for (LABEL)
#> 2026-05-07 18:24:22.493606: bru_input.bru_comp(x)
#> 2026-05-07 18:24:22.494784: bru_input_text.bm_pipe(x)
#> 2026-05-07 18:24:22.496007: bru_input_text.bm_multi(x:core)
#> 2026-05-07 18:24:22.497164: bru_input_text.bru_mapper(x:core:main)
#> 2026-05-07 18:24:22.498149: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-05-07 18:23:57.34723: inlabru loaded
#> 2026-05-07 18:23:57.347719: Clear override options
#> 2026-05-07 18:24:07.664059: bru: Preprocessing
#> 2026-05-07 18:24:07.783624: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:08.312451: bru: Preprocessing
#> 2026-05-07 18:24:08.446438: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:09.088582: bru: Preprocessing
#> 2026-05-07 18:24:09.176819: iinla: Iteration 1 [max: 10]
#> 2026-05-07 18:24:09.509046: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-07 18:24:09.546516: iinla: Iteration 2 [max: 10]
#> 2026-05-07 18:24:10.225415: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-07 18:24:10.252645: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.255049: iinla: Iteration 3 [max: 10]
#> 2026-05-07 18:24:10.560458: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-07 18:24:10.589045: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.591566: iinla: Iteration 4 [max: 10]
#> 2026-05-07 18:24:10.930753: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-07 18:24:10.932021: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-07 18:24:10.934508: iinla: Iteration 5 [max: 10]
#> 2026-05-07 18:24:12.304396: bru: Preprocessing
#> 2026-05-07 18:24:12.370711: iinla: Iteration 1 [max: 1]
#> 2026-05-07 18:24:17.017564: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-05-07 18:23:57.34723: inlabru loaded (level 1)
#> 2026-05-07 18:23:57.347719: Clear override options (level 1)
#> 2026-05-07 18:24:07.664059: bru: Preprocessing (level 1)
#> 2026-05-07 18:24:07.680296: Evaluate component inputs for each observation model (level 3)
#> 2026-05-07 18:24:07.681754: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:07.683182: bru_input.bru_comp(x) (level 4)
#> 2026-05-07 18:24:07.684582: bru_input.bm_pipe(x) (level 5)
#> 2026-05-07 18:24:07.686573: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-07 18:24:07.688098: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-07 18:24:07.68978: bru_input(bru_input) for (x) (level 5)
#> 2026-05-07 18:24:07.69778: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-07 18:24:07.699128: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-07 18:24:07.700583: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-07 18:24:07.701996: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-07 18:24:07.703279: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-07 18:24:07.719235: iinla: Start (level 3)
#> 2026-05-07 18:24:07.727742: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:07.73: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:07.731572: Linearise component 'x' (level 4)
#> 2026-05-07 18:24:07.734619: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:07.73748: iinla: Evaluate component simplifications (level 3)
#> 2026-05-07 18:24:07.738794: Simplify component mappers for each observation model (level 3)
#> 2026-05-07 18:24:07.740244: Simplify component 'x' (level 4)
#> 2026-05-07 18:24:07.743366: Simplify component 'Intercept' (level 4)
#> 2026-05-07 18:24:07.746364: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:07.759779: iinla: Construct inla stack (level 3)
#> 2026-05-07 18:24:07.782163: iinla: Model initialisation completed (level 3)
#> 2026-05-07 18:24:07.783624: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-07 18:24:08.287907: iinla: Computation completed (level 3)
#> 2026-05-07 18:24:08.312451: bru: Preprocessing (level 1)
#> 2026-05-07 18:24:08.321484: Evaluate component inputs for each observation model (level 3)
#> 2026-05-07 18:24:08.322817: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:08.324128: bru_input.bru_comp(x) (level 4)
#> 2026-05-07 18:24:08.325441: bru_input.bm_pipe(x) (level 5)
#> 2026-05-07 18:24:08.326892: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-07 18:24:08.32831: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-07 18:24:08.329567: bru_input(bru_input) for (x) (level 5)
#> 2026-05-07 18:24:08.336877: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-07 18:24:08.338207: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-07 18:24:08.387512: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-07 18:24:08.390148: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-07 18:24:08.392361: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-07 18:24:08.406596: iinla: Start (level 3)
#> 2026-05-07 18:24:08.408488: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:08.409633: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:08.410982: Linearise component 'x' (level 4)
#> 2026-05-07 18:24:08.413993: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:08.416815: iinla: Evaluate component simplifications (level 3)
#> 2026-05-07 18:24:08.418053: Simplify component mappers for each observation model (level 3)
#> 2026-05-07 18:24:08.419415: Simplify component 'x' (level 4)
#> 2026-05-07 18:24:08.422417: Simplify component 'Intercept' (level 4)
#> 2026-05-07 18:24:08.425446: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:08.43219: iinla: Construct inla stack (level 3)
#> 2026-05-07 18:24:08.444936: iinla: Model initialisation completed (level 3)
#> 2026-05-07 18:24:08.446438: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-07 18:24:09.06455: iinla: Computation completed (level 3)
#> 2026-05-07 18:24:09.088582: bru: Preprocessing (level 1)
#> 2026-05-07 18:24:09.097682: Evaluate component inputs for each observation model (level 3)
#> 2026-05-07 18:24:09.099029: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:09.100324: bru_input.bru_comp(z) (level 4)
#> 2026-05-07 18:24:09.10161: bru_input.bm_pipe(z) (level 5)
#> 2026-05-07 18:24:09.10304: bru_input.bm_multi(z:core) (level 5)
#> 2026-05-07 18:24:09.104419: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-05-07 18:24:09.105676: bru_input(bru_input) for (z) (level 5)
#> 2026-05-07 18:24:09.113204: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-07 18:24:09.114534: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-07 18:24:09.115936: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-07 18:24:09.117311: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-07 18:24:09.11867: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-07 18:24:09.131962: iinla: Start (level 3)
#> 2026-05-07 18:24:09.133557: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:09.134666: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:09.136012: Linearise component 'z' (level 4)
#> 2026-05-07 18:24:09.13895: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:09.141726: iinla: Evaluate component simplifications (level 3)
#> 2026-05-07 18:24:09.142979: Simplify component mappers for each observation model (level 3)
#> 2026-05-07 18:24:09.144346: Simplify component 'z' (level 4)
#> 2026-05-07 18:24:09.147408: Simplify component 'Intercept' (level 4)
#> 2026-05-07 18:24:09.150412: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:09.153683: Linearise with respect to component 'z' (level 5)
#> 2026-05-07 18:24:09.159283: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-07 18:24:09.162742: iinla: Construct inla stack (level 3)
#> 2026-05-07 18:24:09.175351: iinla: Model initialisation completed (level 3)
#> 2026-05-07 18:24:09.176819: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-05-07 18:24:09.496366: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8) (level 3)
#> 2026-05-07 18:24:09.500272: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8) (level 3)
#> 2026-05-07 18:24:09.504996: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 3)
#> 2026-05-07 18:24:09.507081: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4 (level 4)
#> 2026-05-07 18:24:09.509046: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 2)
#> 2026-05-07 18:24:09.511319: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:09.512881: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:09.514823: Linearise component 'z' (level 4)
#> 2026-05-07 18:24:09.518473: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:09.521905: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:09.525238: Linearise with respect to component 'z' (level 5)
#> 2026-05-07 18:24:09.529917: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-07 18:24:09.546516: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-05-07 18:24:10.216579: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4) (level 3)
#> 2026-05-07 18:24:10.219402: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4) (level 3)
#> 2026-05-07 18:24:10.222701: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 3)
#> 2026-05-07 18:24:10.224081: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63 (level 4)
#> 2026-05-07 18:24:10.225415: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 2)
#> 2026-05-07 18:24:10.227011: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:10.228085: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:10.229333: Linearise component 'z' (level 4)
#> 2026-05-07 18:24:10.232102: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:10.234997: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:10.237639: Linearise with respect to component 'z' (level 5)
#> 2026-05-07 18:24:10.241103: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-07 18:24:10.252645: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-07 18:24:10.255049: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-05-07 18:24:10.550812: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68) (level 3)
#> 2026-05-07 18:24:10.553742: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-05-07 18:24:10.557441: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-05-07 18:24:10.558939: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-05-07 18:24:10.560458: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-05-07 18:24:10.562167: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:10.563371: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:10.564725: Linearise component 'z' (level 4)
#> 2026-05-07 18:24:10.567734: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:10.570669: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:10.573375: Linearise with respect to component 'z' (level 5)
#> 2026-05-07 18:24:10.576943: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-07 18:24:10.589045: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-07 18:24:10.591566: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-05-07 18:24:10.893609: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007267, norm01 = 0.01176) (level 3)
#> 2026-05-07 18:24:10.896672: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-05-07 18:24:10.900592: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-05-07 18:24:10.902119: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.228e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-05-07 18:24:10.90388: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:10.905106: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:10.906461: Linearise component 'z' (level 4)
#> 2026-05-07 18:24:10.909532: Linearise component 'Intercept' (level 4)
#> 2026-05-07 18:24:10.912393: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:10.915098: Linearise with respect to component 'z' (level 5)
#> 2026-05-07 18:24:10.918709: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-07 18:24:10.930753: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-07 18:24:10.932021: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-05-07 18:24:10.934508: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-05-07 18:24:11.252308: iinla: Computation completed (level 3)
#> 2026-05-07 18:24:12.304396: bru: Preprocessing (level 1)
#> 2026-05-07 18:24:12.314256: Evaluate component inputs for each observation model (level 3)
#> 2026-05-07 18:24:12.315517: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:12.316796: bru_input.bru_comp(field) (level 4)
#> 2026-05-07 18:24:12.318092: bru_input.bm_pipe(field) (level 5)
#> 2026-05-07 18:24:12.319506: bru_input.bm_multi(field:core) (level 5)
#> 2026-05-07 18:24:12.3209: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-05-07 18:24:12.322152: bru_input(bru_input) for (field) (level 5)
#> 2026-05-07 18:24:12.335166: iinla: Start (level 3)
#> 2026-05-07 18:24:12.336669: iinla: Evaluate component linearisations (level 3)
#> 2026-05-07 18:24:12.337752: Linearise components for each observation model (level 3)
#> 2026-05-07 18:24:12.338995: Linearise component 'field' (level 4)
#> 2026-05-07 18:24:12.346669: iinla: Evaluate component simplifications (level 3)
#> 2026-05-07 18:24:12.348013: Simplify component mappers for each observation model (level 3)
#> 2026-05-07 18:24:12.34938: Simplify component 'field' (level 4)
#> 2026-05-07 18:24:12.355741: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-07 18:24:12.359158: iinla: Construct inla stack (level 3)
#> 2026-05-07 18:24:12.369312: iinla: Model initialisation completed (level 3)
#> 2026-05-07 18:24:12.370711: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-07 18:24:12.767173: iinla: Computation completed (level 3)
#> 2026-05-07 18:24:14.572939: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:17.017564: bru: Preprocessing (level 1)
#> 2026-05-07 18:24:17.031027: Evaluate component inputs for each observation model (level 3)
#> 2026-05-07 18:24:17.032392: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:17.033844: bru_input.bru_comp(x) (level 4)
#> 2026-05-07 18:24:17.035153: bru_input.bm_pipe(x) (level 5)
#> 2026-05-07 18:24:17.036591: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-07 18:24:17.038089: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-07 18:24:17.039425: bru_input(bru_input) for (x) (level 5)
#> 2026-05-07 18:24:17.047379: bru_input(bru_comp_list) (level 4)
#> 2026-05-07 18:24:17.048781: bru_input.bru_comp(x) (level 4)
#> 2026-05-07 18:24:17.050084: bru_input.bm_pipe(x) (level 5)
#> 2026-05-07 18:24:17.051524: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-07 18:24:17.052923: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-07 18:24:17.054208: bru_input(bru_input) for (x) (level 5)
#> 2026-05-07 18:24:20.336019: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-05-07 18:24:22.481557: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-05-07 18:24:22.493606: bru_input.bru_comp(x) (level 4)
#> 2026-05-07 18:24:22.494784: bru_input_text.bm_pipe(x) (level 5)
#> 2026-05-07 18:24:22.496007: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-05-07 18:24:22.497164: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-05-07 18:24:22.498149: bru_input_text(bru_input) for (x) (level 5)