Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-04-03 16:59:30.73312: inlabru loaded
#> 2026-04-03 16:59:30.733691: Clear override options
#> 2026-04-03 16:59:41.608984: bru: Preprocessing
#> 2026-04-03 16:59:41.730579: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:42.292632: bru: Preprocessing
#> 2026-04-03 16:59:42.643578: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:42.969397: bru: Preprocessing
#> 2026-04-03 16:59:43.071273: iinla: Iteration 1 [max: 10]
#> 2026-04-03 16:59:43.399063: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-04-03 16:59:43.437258: iinla: Iteration 2 [max: 10]
#> 2026-04-03 16:59:44.033789: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-04-03 16:59:44.061818: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.064305: iinla: Iteration 3 [max: 10]
#> 2026-04-03 16:59:44.358873: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-04-03 16:59:44.386691: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.389187: iinla: Iteration 4 [max: 10]
#> 2026-04-03 16:59:44.71218: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.713442: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-04-03 16:59:44.715979: iinla: Iteration 5 [max: 10]
#> 2026-04-03 16:59:46.134925: bru: Preprocessing
#> 2026-04-03 16:59:46.204771: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:50.929134: bru: Preprocessing
format(bru_log())
#> 2026-04-03 16:59:30.73312: inlabru loaded
#> 2026-04-03 16:59:30.733691: Clear override options
#> 2026-04-03 16:59:41.608984: bru: Preprocessing
#> 2026-04-03 16:59:41.624449: Evaluate component inputs for each observation model
#> 2026-04-03 16:59:41.625916: bru_input(bru_comp_list)
#> 2026-04-03 16:59:41.62736: bru_input.bru_comp(x)
#> 2026-04-03 16:59:41.628823: bru_input.bm_pipe(x)
#> 2026-04-03 16:59:41.630442: bru_input.bm_multi(x:core)
#> 2026-04-03 16:59:41.63204: bru_input.bru_mapper(x:core:main)
#> 2026-04-03 16:59:41.633738: bru_input(bru_input) for (x)
#> 2026-04-03 16:59:41.642236: bru_input.bru_comp(Intercept)
#> 2026-04-03 16:59:41.64389: bru_input.bm_pipe(Intercept)
#> 2026-04-03 16:59:41.645628: bru_input.bm_multi(Intercept:core)
#> 2026-04-03 16:59:41.647272: bru_input.bru_mapper(Intercept:core:main)
#> 2026-04-03 16:59:41.648664: bru_input(bru_input) for (Intercept)
#> 2026-04-03 16:59:41.665782: iinla: Start
#> 2026-04-03 16:59:41.66703: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:41.668293: Linearise components for each observation model
#> 2026-04-03 16:59:41.669849: Linearise component 'x'
#> 2026-04-03 16:59:41.672851: Linearise component 'Intercept'
#> 2026-04-03 16:59:41.675605: iinla: Evaluate component simplifications
#> 2026-04-03 16:59:41.676971: Simplify component mappers for each observation model
#> 2026-04-03 16:59:41.678474: Simplify component 'x'
#> 2026-04-03 16:59:41.681564: Simplify component 'Intercept'
#> 2026-04-03 16:59:41.684535: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:41.698102: iinla: Construct inla stack
#> 2026-04-03 16:59:41.728969: iinla: Model initialisation completed
#> 2026-04-03 16:59:41.730579: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:42.268195: iinla: Computation completed
#> 2026-04-03 16:59:42.292632: bru: Preprocessing
#> 2026-04-03 16:59:42.302021: Evaluate component inputs for each observation model
#> 2026-04-03 16:59:42.303412: bru_input(bru_comp_list)
#> 2026-04-03 16:59:42.304909: bru_input.bru_comp(x)
#> 2026-04-03 16:59:42.306338: bru_input.bm_pipe(x)
#> 2026-04-03 16:59:42.307922: bru_input.bm_multi(x:core)
#> 2026-04-03 16:59:42.309491: bru_input.bru_mapper(x:core:main)
#> 2026-04-03 16:59:42.31091: bru_input(bru_input) for (x)
#> 2026-04-03 16:59:42.318647: bru_input.bru_comp(Intercept)
#> 2026-04-03 16:59:42.320125: bru_input.bm_pipe(Intercept)
#> 2026-04-03 16:59:42.321681: bru_input.bm_multi(Intercept:core)
#> 2026-04-03 16:59:42.323255: bru_input.bru_mapper(Intercept:core:main)
#> 2026-04-03 16:59:42.324732: bru_input(bru_input) for (Intercept)
#> 2026-04-03 16:59:42.339038: iinla: Start
#> 2026-04-03 16:59:42.340422: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:42.341907: Linearise components for each observation model
#> 2026-04-03 16:59:42.343538: Linearise component 'x'
#> 2026-04-03 16:59:42.346854: Linearise component 'Intercept'
#> 2026-04-03 16:59:42.349689: iinla: Evaluate component simplifications
#> 2026-04-03 16:59:42.350934: Simplify component mappers for each observation model
#> 2026-04-03 16:59:42.352344: Simplify component 'x'
#> 2026-04-03 16:59:42.355464: Simplify component 'Intercept'
#> 2026-04-03 16:59:42.358552: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:42.365367: iinla: Construct inla stack
#> 2026-04-03 16:59:42.378284: iinla: Model initialisation completed
#> 2026-04-03 16:59:42.643578: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:42.946109: iinla: Computation completed
#> 2026-04-03 16:59:42.969397: bru: Preprocessing
#> 2026-04-03 16:59:42.978751: Evaluate component inputs for each observation model
#> 2026-04-03 16:59:42.980126: bru_input(bru_comp_list)
#> 2026-04-03 16:59:42.981563: bru_input.bru_comp(z)
#> 2026-04-03 16:59:42.98301: bru_input.bm_pipe(z)
#> 2026-04-03 16:59:42.984572: bru_input.bm_multi(z:core)
#> 2026-04-03 16:59:42.986229: bru_input.bru_mapper(z:core:main)
#> 2026-04-03 16:59:42.987654: bru_input(bru_input) for (z)
#> 2026-04-03 16:59:42.995202: bru_input.bru_comp(Intercept)
#> 2026-04-03 16:59:42.996639: bru_input.bm_pipe(Intercept)
#> 2026-04-03 16:59:42.99831: bru_input.bm_multi(Intercept:core)
#> 2026-04-03 16:59:42.999871: bru_input.bru_mapper(Intercept:core:main)
#> 2026-04-03 16:59:43.001281: bru_input(bru_input) for (Intercept)
#> 2026-04-03 16:59:43.014743: iinla: Start
#> 2026-04-03 16:59:43.015994: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:43.017433: Linearise components for each observation model
#> 2026-04-03 16:59:43.019363: Linearise component 'z'
#> 2026-04-03 16:59:43.023153: Linearise component 'Intercept'
#> 2026-04-03 16:59:43.026643: iinla: Evaluate component simplifications
#> 2026-04-03 16:59:43.028277: Simplify component mappers for each observation model
#> 2026-04-03 16:59:43.03017: Simplify component 'z'
#> 2026-04-03 16:59:43.034028: Simplify component 'Intercept'
#> 2026-04-03 16:59:43.037755: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:43.041745: Linearise with respect to component 'z'
#> 2026-04-03 16:59:43.04865: Linearise with respect to component 'Intercept'
#> 2026-04-03 16:59:43.053145: iinla: Construct inla stack
#> 2026-04-03 16:59:43.069199: iinla: Model initialisation completed
#> 2026-04-03 16:59:43.071273: iinla: Iteration 1 [max: 10]
#> 2026-04-03 16:59:43.386558: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9)
#> 2026-04-03 16:59:43.390381: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9)
#> 2026-04-03 16:59:43.395007: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-04-03 16:59:43.397095: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-04-03 16:59:43.399063: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-04-03 16:59:43.401407: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:43.403016: Linearise components for each observation model
#> 2026-04-03 16:59:43.404885: Linearise component 'z'
#> 2026-04-03 16:59:43.408686: Linearise component 'Intercept'
#> 2026-04-03 16:59:43.412172: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:43.415674: Linearise with respect to component 'z'
#> 2026-04-03 16:59:43.420388: Linearise with respect to component 'Intercept'
#> 2026-04-03 16:59:43.437258: iinla: Iteration 2 [max: 10]
#> 2026-04-03 16:59:44.023975: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-04-03 16:59:44.027098: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-04-03 16:59:44.030772: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-04-03 16:59:44.032297: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-04-03 16:59:44.033789: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-04-03 16:59:44.035521: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:44.036669: Linearise components for each observation model
#> 2026-04-03 16:59:44.038029: Linearise component 'z'
#> 2026-04-03 16:59:44.040939: Linearise component 'Intercept'
#> 2026-04-03 16:59:44.043756: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:44.046348: Linearise with respect to component 'z'
#> 2026-04-03 16:59:44.049907: Linearise with respect to component 'Intercept'
#> 2026-04-03 16:59:44.061818: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.064305: iinla: Iteration 3 [max: 10]
#> 2026-04-03 16:59:44.349512: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-04-03 16:59:44.352382: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-04-03 16:59:44.355957: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-04-03 16:59:44.357419: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-04-03 16:59:44.358873: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-04-03 16:59:44.360546: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:44.36171: Linearise components for each observation model
#> 2026-04-03 16:59:44.36306: Linearise component 'z'
#> 2026-04-03 16:59:44.365934: Linearise component 'Intercept'
#> 2026-04-03 16:59:44.368711: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:44.371281: Linearise with respect to component 'z'
#> 2026-04-03 16:59:44.374831: Linearise with respect to component 'Intercept'
#> 2026-04-03 16:59:44.386691: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.389187: iinla: Iteration 4 [max: 10]
#> 2026-04-03 16:59:44.675139: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-04-03 16:59:44.678231: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-04-03 16:59:44.681777: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-04-03 16:59:44.683313: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-04-03 16:59:44.685198: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:44.686406: Linearise components for each observation model
#> 2026-04-03 16:59:44.687816: Linearise component 'z'
#> 2026-04-03 16:59:44.690762: Linearise component 'Intercept'
#> 2026-04-03 16:59:44.693558: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:44.696319: Linearise with respect to component 'z'
#> 2026-04-03 16:59:44.699999: Linearise with respect to component 'Intercept'
#> 2026-04-03 16:59:44.71218: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.713442: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-04-03 16:59:44.715979: iinla: Iteration 5 [max: 10]
#> 2026-04-03 16:59:45.029425: iinla: Computation completed
#> 2026-04-03 16:59:46.134925: bru: Preprocessing
#> 2026-04-03 16:59:46.145371: Evaluate component inputs for each observation model
#> 2026-04-03 16:59:46.146653: bru_input(bru_comp_list)
#> 2026-04-03 16:59:46.148041: bru_input.bru_comp(field)
#> 2026-04-03 16:59:46.149377: bru_input.bm_pipe(field)
#> 2026-04-03 16:59:46.150888: bru_input.bm_multi(field:core)
#> 2026-04-03 16:59:46.152369: bru_input.bru_mapper(field:core:main)
#> 2026-04-03 16:59:46.153734: bru_input(bru_input) for (field)
#> 2026-04-03 16:59:46.168818: iinla: Start
#> 2026-04-03 16:59:46.17002: iinla: Evaluate component linearisations
#> 2026-04-03 16:59:46.171193: Linearise components for each observation model
#> 2026-04-03 16:59:46.172543: Linearise component 'field'
#> 2026-04-03 16:59:46.180278: iinla: Evaluate component simplifications
#> 2026-04-03 16:59:46.181493: Simplify component mappers for each observation model
#> 2026-04-03 16:59:46.182858: Simplify component 'field'
#> 2026-04-03 16:59:46.189307: iinla: Evaluate predictor linearisation
#> 2026-04-03 16:59:46.192837: iinla: Construct inla stack
#> 2026-04-03 16:59:46.203341: iinla: Model initialisation completed
#> 2026-04-03 16:59:46.204771: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:46.609452: iinla: Computation completed
#> 2026-04-03 16:59:48.531655: bru_input(bru_comp_list)
#> 2026-04-03 16:59:50.929134: bru: Preprocessing
#> 2026-04-03 16:59:50.942805: Evaluate component inputs for each observation model
#> 2026-04-03 16:59:50.944139: bru_input(bru_comp_list)
#> 2026-04-03 16:59:50.945541: bru_input.bru_comp(x)
#> 2026-04-03 16:59:50.946964: bru_input.bm_pipe(x)
#> 2026-04-03 16:59:50.955731: bru_input.bm_multi(x:core)
#> 2026-04-03 16:59:50.957238: bru_input.bru_mapper(x:core:main)
#> 2026-04-03 16:59:50.958601: bru_input(bru_input) for (x)
#> 2026-04-03 16:59:50.966337: bru_input(bru_comp_list)
#> 2026-04-03 16:59:50.967808: bru_input.bru_comp(x)
#> 2026-04-03 16:59:50.969183: bru_input.bm_pipe(x)
#> 2026-04-03 16:59:50.970722: bru_input.bm_multi(x:core)
#> 2026-04-03 16:59:50.972198: bru_input.bru_mapper(x:core:main)
#> 2026-04-03 16:59:50.973542: bru_input(bru_input) for (x)
#> 2026-04-03 17:00:39.833431: bru_input(bru_input) for (LABEL)
#> 2026-04-03 17:00:41.423004: bru_input_text(bru_input) for (LABEL)
#> 2026-04-03 17:00:41.43469: bru_input.bru_comp(x)
#> 2026-04-03 17:00:41.435898: bru_input_text.bm_pipe(x)
#> 2026-04-03 17:00:41.437171: bru_input_text.bm_multi(x:core)
#> 2026-04-03 17:00:41.438416: bru_input_text.bru_mapper(x:core:main)
#> 2026-04-03 17:00:41.439491: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-04-03 16:59:30.73312: inlabru loaded
#> 2026-04-03 16:59:30.733691: Clear override options
#> 2026-04-03 16:59:41.608984: bru: Preprocessing
#> 2026-04-03 16:59:41.730579: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:42.292632: bru: Preprocessing
#> 2026-04-03 16:59:42.643578: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:42.969397: bru: Preprocessing
#> 2026-04-03 16:59:43.071273: iinla: Iteration 1 [max: 10]
#> 2026-04-03 16:59:43.399063: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-04-03 16:59:43.437258: iinla: Iteration 2 [max: 10]
#> 2026-04-03 16:59:44.033789: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-04-03 16:59:44.061818: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.064305: iinla: Iteration 3 [max: 10]
#> 2026-04-03 16:59:44.358873: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-04-03 16:59:44.386691: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.389187: iinla: Iteration 4 [max: 10]
#> 2026-04-03 16:59:44.71218: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-04-03 16:59:44.713442: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-04-03 16:59:44.715979: iinla: Iteration 5 [max: 10]
#> 2026-04-03 16:59:46.134925: bru: Preprocessing
#> 2026-04-03 16:59:46.204771: iinla: Iteration 1 [max: 1]
#> 2026-04-03 16:59:50.929134: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-04-03 16:59:30.73312: inlabru loaded (level 1)
#> 2026-04-03 16:59:30.733691: Clear override options (level 1)
#> 2026-04-03 16:59:41.608984: bru: Preprocessing (level 1)
#> 2026-04-03 16:59:41.624449: Evaluate component inputs for each observation model (level 3)
#> 2026-04-03 16:59:41.625916: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:41.62736: bru_input.bru_comp(x) (level 4)
#> 2026-04-03 16:59:41.628823: bru_input.bm_pipe(x) (level 5)
#> 2026-04-03 16:59:41.630442: bru_input.bm_multi(x:core) (level 5)
#> 2026-04-03 16:59:41.63204: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-04-03 16:59:41.633738: bru_input(bru_input) for (x) (level 5)
#> 2026-04-03 16:59:41.642236: bru_input.bru_comp(Intercept) (level 4)
#> 2026-04-03 16:59:41.64389: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-04-03 16:59:41.645628: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-04-03 16:59:41.647272: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-04-03 16:59:41.648664: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-04-03 16:59:41.665782: iinla: Start (level 3)
#> 2026-04-03 16:59:41.66703: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:41.668293: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:41.669849: Linearise component 'x' (level 4)
#> 2026-04-03 16:59:41.672851: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:41.675605: iinla: Evaluate component simplifications (level 3)
#> 2026-04-03 16:59:41.676971: Simplify component mappers for each observation model (level 3)
#> 2026-04-03 16:59:41.678474: Simplify component 'x' (level 4)
#> 2026-04-03 16:59:41.681564: Simplify component 'Intercept' (level 4)
#> 2026-04-03 16:59:41.684535: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:41.698102: iinla: Construct inla stack (level 3)
#> 2026-04-03 16:59:41.728969: iinla: Model initialisation completed (level 3)
#> 2026-04-03 16:59:41.730579: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-04-03 16:59:42.268195: iinla: Computation completed (level 3)
#> 2026-04-03 16:59:42.292632: bru: Preprocessing (level 1)
#> 2026-04-03 16:59:42.302021: Evaluate component inputs for each observation model (level 3)
#> 2026-04-03 16:59:42.303412: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:42.304909: bru_input.bru_comp(x) (level 4)
#> 2026-04-03 16:59:42.306338: bru_input.bm_pipe(x) (level 5)
#> 2026-04-03 16:59:42.307922: bru_input.bm_multi(x:core) (level 5)
#> 2026-04-03 16:59:42.309491: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-04-03 16:59:42.31091: bru_input(bru_input) for (x) (level 5)
#> 2026-04-03 16:59:42.318647: bru_input.bru_comp(Intercept) (level 4)
#> 2026-04-03 16:59:42.320125: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-04-03 16:59:42.321681: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-04-03 16:59:42.323255: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-04-03 16:59:42.324732: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-04-03 16:59:42.339038: iinla: Start (level 3)
#> 2026-04-03 16:59:42.340422: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:42.341907: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:42.343538: Linearise component 'x' (level 4)
#> 2026-04-03 16:59:42.346854: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:42.349689: iinla: Evaluate component simplifications (level 3)
#> 2026-04-03 16:59:42.350934: Simplify component mappers for each observation model (level 3)
#> 2026-04-03 16:59:42.352344: Simplify component 'x' (level 4)
#> 2026-04-03 16:59:42.355464: Simplify component 'Intercept' (level 4)
#> 2026-04-03 16:59:42.358552: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:42.365367: iinla: Construct inla stack (level 3)
#> 2026-04-03 16:59:42.378284: iinla: Model initialisation completed (level 3)
#> 2026-04-03 16:59:42.643578: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-04-03 16:59:42.946109: iinla: Computation completed (level 3)
#> 2026-04-03 16:59:42.969397: bru: Preprocessing (level 1)
#> 2026-04-03 16:59:42.978751: Evaluate component inputs for each observation model (level 3)
#> 2026-04-03 16:59:42.980126: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:42.981563: bru_input.bru_comp(z) (level 4)
#> 2026-04-03 16:59:42.98301: bru_input.bm_pipe(z) (level 5)
#> 2026-04-03 16:59:42.984572: bru_input.bm_multi(z:core) (level 5)
#> 2026-04-03 16:59:42.986229: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-04-03 16:59:42.987654: bru_input(bru_input) for (z) (level 5)
#> 2026-04-03 16:59:42.995202: bru_input.bru_comp(Intercept) (level 4)
#> 2026-04-03 16:59:42.996639: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-04-03 16:59:42.99831: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-04-03 16:59:42.999871: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-04-03 16:59:43.001281: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-04-03 16:59:43.014743: iinla: Start (level 3)
#> 2026-04-03 16:59:43.015994: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:43.017433: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:43.019363: Linearise component 'z' (level 4)
#> 2026-04-03 16:59:43.023153: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:43.026643: iinla: Evaluate component simplifications (level 3)
#> 2026-04-03 16:59:43.028277: Simplify component mappers for each observation model (level 3)
#> 2026-04-03 16:59:43.03017: Simplify component 'z' (level 4)
#> 2026-04-03 16:59:43.034028: Simplify component 'Intercept' (level 4)
#> 2026-04-03 16:59:43.037755: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:43.041745: Linearise with respect to component 'z' (level 5)
#> 2026-04-03 16:59:43.04865: Linearise with respect to component 'Intercept' (level 5)
#> 2026-04-03 16:59:43.053145: iinla: Construct inla stack (level 3)
#> 2026-04-03 16:59:43.069199: iinla: Model initialisation completed (level 3)
#> 2026-04-03 16:59:43.071273: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-04-03 16:59:43.386558: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9) (level 3)
#> 2026-04-03 16:59:43.390381: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9) (level 3)
#> 2026-04-03 16:59:43.395007: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 3)
#> 2026-04-03 16:59:43.397095: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-04-03 16:59:43.399063: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 2)
#> 2026-04-03 16:59:43.401407: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:43.403016: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:43.404885: Linearise component 'z' (level 4)
#> 2026-04-03 16:59:43.408686: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:43.412172: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:43.415674: Linearise with respect to component 'z' (level 5)
#> 2026-04-03 16:59:43.420388: Linearise with respect to component 'Intercept' (level 5)
#> 2026-04-03 16:59:43.437258: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-04-03 16:59:44.023975: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-04-03 16:59:44.027098: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-04-03 16:59:44.030772: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-04-03 16:59:44.032297: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-04-03 16:59:44.033789: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-04-03 16:59:44.035521: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:44.036669: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:44.038029: Linearise component 'z' (level 4)
#> 2026-04-03 16:59:44.040939: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:44.043756: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:44.046348: Linearise with respect to component 'z' (level 5)
#> 2026-04-03 16:59:44.049907: Linearise with respect to component 'Intercept' (level 5)
#> 2026-04-03 16:59:44.061818: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-04-03 16:59:44.064305: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-04-03 16:59:44.349512: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-04-03 16:59:44.352382: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-04-03 16:59:44.355957: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-04-03 16:59:44.357419: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-04-03 16:59:44.358873: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-04-03 16:59:44.360546: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:44.36171: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:44.36306: Linearise component 'z' (level 4)
#> 2026-04-03 16:59:44.365934: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:44.368711: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:44.371281: Linearise with respect to component 'z' (level 5)
#> 2026-04-03 16:59:44.374831: Linearise with respect to component 'Intercept' (level 5)
#> 2026-04-03 16:59:44.386691: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-04-03 16:59:44.389187: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-04-03 16:59:44.675139: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-04-03 16:59:44.678231: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-04-03 16:59:44.681777: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-04-03 16:59:44.683313: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-04-03 16:59:44.685198: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:44.686406: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:44.687816: Linearise component 'z' (level 4)
#> 2026-04-03 16:59:44.690762: Linearise component 'Intercept' (level 4)
#> 2026-04-03 16:59:44.693558: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:44.696319: Linearise with respect to component 'z' (level 5)
#> 2026-04-03 16:59:44.699999: Linearise with respect to component 'Intercept' (level 5)
#> 2026-04-03 16:59:44.71218: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-04-03 16:59:44.713442: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-04-03 16:59:44.715979: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-04-03 16:59:45.029425: iinla: Computation completed (level 3)
#> 2026-04-03 16:59:46.134925: bru: Preprocessing (level 1)
#> 2026-04-03 16:59:46.145371: Evaluate component inputs for each observation model (level 3)
#> 2026-04-03 16:59:46.146653: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:46.148041: bru_input.bru_comp(field) (level 4)
#> 2026-04-03 16:59:46.149377: bru_input.bm_pipe(field) (level 5)
#> 2026-04-03 16:59:46.150888: bru_input.bm_multi(field:core) (level 5)
#> 2026-04-03 16:59:46.152369: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-04-03 16:59:46.153734: bru_input(bru_input) for (field) (level 5)
#> 2026-04-03 16:59:46.168818: iinla: Start (level 3)
#> 2026-04-03 16:59:46.17002: iinla: Evaluate component linearisations (level 3)
#> 2026-04-03 16:59:46.171193: Linearise components for each observation model (level 3)
#> 2026-04-03 16:59:46.172543: Linearise component 'field' (level 4)
#> 2026-04-03 16:59:46.180278: iinla: Evaluate component simplifications (level 3)
#> 2026-04-03 16:59:46.181493: Simplify component mappers for each observation model (level 3)
#> 2026-04-03 16:59:46.182858: Simplify component 'field' (level 4)
#> 2026-04-03 16:59:46.189307: iinla: Evaluate predictor linearisation (level 3)
#> 2026-04-03 16:59:46.192837: iinla: Construct inla stack (level 3)
#> 2026-04-03 16:59:46.203341: iinla: Model initialisation completed (level 3)
#> 2026-04-03 16:59:46.204771: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-04-03 16:59:46.609452: iinla: Computation completed (level 3)
#> 2026-04-03 16:59:48.531655: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:50.929134: bru: Preprocessing (level 1)
#> 2026-04-03 16:59:50.942805: Evaluate component inputs for each observation model (level 3)
#> 2026-04-03 16:59:50.944139: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:50.945541: bru_input.bru_comp(x) (level 4)
#> 2026-04-03 16:59:50.946964: bru_input.bm_pipe(x) (level 5)
#> 2026-04-03 16:59:50.955731: bru_input.bm_multi(x:core) (level 5)
#> 2026-04-03 16:59:50.957238: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-04-03 16:59:50.958601: bru_input(bru_input) for (x) (level 5)
#> 2026-04-03 16:59:50.966337: bru_input(bru_comp_list) (level 4)
#> 2026-04-03 16:59:50.967808: bru_input.bru_comp(x) (level 4)
#> 2026-04-03 16:59:50.969183: bru_input.bm_pipe(x) (level 5)
#> 2026-04-03 16:59:50.970722: bru_input.bm_multi(x:core) (level 5)
#> 2026-04-03 16:59:50.972198: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-04-03 16:59:50.973542: bru_input(bru_input) for (x) (level 5)
#> 2026-04-03 17:00:39.833431: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-04-03 17:00:41.423004: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-04-03 17:00:41.43469: bru_input.bru_comp(x) (level 4)
#> 2026-04-03 17:00:41.435898: bru_input_text.bm_pipe(x) (level 5)
#> 2026-04-03 17:00:41.437171: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-04-03 17:00:41.438416: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-04-03 17:00:41.439491: bru_input_text(bru_input) for (x) (level 5)