Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-03-31 16:46:04.213539: inlabru loaded
#> 2026-03-31 16:46:04.214123: Clear override options
#> 2026-03-31 16:46:14.690034: bru: Preprocessing
#> 2026-03-31 16:46:14.805386: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:15.347755: bru: Preprocessing
#> 2026-03-31 16:46:15.67292: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:15.986929: bru: Preprocessing
#> 2026-03-31 16:46:16.084686: iinla: Iteration 1 [max: 10]
#> 2026-03-31 16:46:16.401683: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-31 16:46:16.438538: iinla: Iteration 2 [max: 10]
#> 2026-03-31 16:46:17.018954: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-31 16:46:17.046561: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.049056: iinla: Iteration 3 [max: 10]
#> 2026-03-31 16:46:17.340139: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-31 16:46:17.367866: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.370278: iinla: Iteration 4 [max: 10]
#> 2026-03-31 16:46:17.688787: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.69002: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-31 16:46:17.692475: iinla: Iteration 5 [max: 10]
#> 2026-03-31 16:46:19.065344: bru: Preprocessing
#> 2026-03-31 16:46:19.130926: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:23.869757: bru: Preprocessing
format(bru_log())
#> 2026-03-31 16:46:04.213539: inlabru loaded
#> 2026-03-31 16:46:04.214123: Clear override options
#> 2026-03-31 16:46:14.690034: bru: Preprocessing
#> 2026-03-31 16:46:14.704996: Evaluate component inputs for each observation model
#> 2026-03-31 16:46:14.706383: bru_input(bru_comp_list)
#> 2026-03-31 16:46:14.707894: bru_input.bru_comp(x)
#> 2026-03-31 16:46:14.709355: bru_input.bm_pipe(x)
#> 2026-03-31 16:46:14.710934: bru_input.bm_multi(x:core)
#> 2026-03-31 16:46:14.712483: bru_input.bru_mapper(x:core:main)
#> 2026-03-31 16:46:14.714243: bru_input(bru_input) for (x)
#> 2026-03-31 16:46:14.721768: bru_input.bru_comp(Intercept)
#> 2026-03-31 16:46:14.723249: bru_input.bm_pipe(Intercept)
#> 2026-03-31 16:46:14.724972: bru_input.bm_multi(Intercept:core)
#> 2026-03-31 16:46:14.726634: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-31 16:46:14.728093: bru_input(bru_input) for (Intercept)
#> 2026-03-31 16:46:14.743758: iinla: Start
#> 2026-03-31 16:46:14.744953: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:14.746192: Linearise components for each observation model
#> 2026-03-31 16:46:14.747683: Linearise component 'x'
#> 2026-03-31 16:46:14.750524: Linearise component 'Intercept'
#> 2026-03-31 16:46:14.753247: iinla: Evaluate component simplifications
#> 2026-03-31 16:46:14.75453: Simplify component mappers for each observation model
#> 2026-03-31 16:46:14.756017: Simplify component 'x'
#> 2026-03-31 16:46:14.759023: Simplify component 'Intercept'
#> 2026-03-31 16:46:14.761948: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:14.775111: iinla: Construct inla stack
#> 2026-03-31 16:46:14.80382: iinla: Model initialisation completed
#> 2026-03-31 16:46:14.805386: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:15.324094: iinla: Computation completed
#> 2026-03-31 16:46:15.347755: bru: Preprocessing
#> 2026-03-31 16:46:15.356761: Evaluate component inputs for each observation model
#> 2026-03-31 16:46:15.358068: bru_input(bru_comp_list)
#> 2026-03-31 16:46:15.359467: bru_input.bru_comp(x)
#> 2026-03-31 16:46:15.360918: bru_input.bm_pipe(x)
#> 2026-03-31 16:46:15.362478: bru_input.bm_multi(x:core)
#> 2026-03-31 16:46:15.364026: bru_input.bru_mapper(x:core:main)
#> 2026-03-31 16:46:15.365391: bru_input(bru_input) for (x)
#> 2026-03-31 16:46:15.372348: bru_input.bru_comp(Intercept)
#> 2026-03-31 16:46:15.373764: bru_input.bm_pipe(Intercept)
#> 2026-03-31 16:46:15.375276: bru_input.bm_multi(Intercept:core)
#> 2026-03-31 16:46:15.376868: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-31 16:46:15.37833: bru_input(bru_input) for (Intercept)
#> 2026-03-31 16:46:15.391104: iinla: Start
#> 2026-03-31 16:46:15.392381: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:15.393783: Linearise components for each observation model
#> 2026-03-31 16:46:15.39535: Linearise component 'x'
#> 2026-03-31 16:46:15.398402: Linearise component 'Intercept'
#> 2026-03-31 16:46:15.40117: iinla: Evaluate component simplifications
#> 2026-03-31 16:46:15.402373: Simplify component mappers for each observation model
#> 2026-03-31 16:46:15.403758: Simplify component 'x'
#> 2026-03-31 16:46:15.406791: Simplify component 'Intercept'
#> 2026-03-31 16:46:15.409769: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:15.416192: iinla: Construct inla stack
#> 2026-03-31 16:46:15.428474: iinla: Model initialisation completed
#> 2026-03-31 16:46:15.67292: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:15.964356: iinla: Computation completed
#> 2026-03-31 16:46:15.986929: bru: Preprocessing
#> 2026-03-31 16:46:15.995848: Evaluate component inputs for each observation model
#> 2026-03-31 16:46:15.997142: bru_input(bru_comp_list)
#> 2026-03-31 16:46:15.998544: bru_input.bru_comp(z)
#> 2026-03-31 16:46:15.999954: bru_input.bm_pipe(z)
#> 2026-03-31 16:46:16.001482: bru_input.bm_multi(z:core)
#> 2026-03-31 16:46:16.003078: bru_input.bru_mapper(z:core:main)
#> 2026-03-31 16:46:16.004431: bru_input(bru_input) for (z)
#> 2026-03-31 16:46:16.011548: bru_input.bru_comp(Intercept)
#> 2026-03-31 16:46:16.012975: bru_input.bm_pipe(Intercept)
#> 2026-03-31 16:46:16.014592: bru_input.bm_multi(Intercept:core)
#> 2026-03-31 16:46:16.016143: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-31 16:46:16.017517: bru_input(bru_input) for (Intercept)
#> 2026-03-31 16:46:16.02984: iinla: Start
#> 2026-03-31 16:46:16.031076: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:16.032389: Linearise components for each observation model
#> 2026-03-31 16:46:16.03425: Linearise component 'z'
#> 2026-03-31 16:46:16.037864: Linearise component 'Intercept'
#> 2026-03-31 16:46:16.041327: iinla: Evaluate component simplifications
#> 2026-03-31 16:46:16.04294: Simplify component mappers for each observation model
#> 2026-03-31 16:46:16.0448: Simplify component 'z'
#> 2026-03-31 16:46:16.0485: Simplify component 'Intercept'
#> 2026-03-31 16:46:16.052196: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:16.056114: Linearise with respect to component 'z'
#> 2026-03-31 16:46:16.06285: Linearise with respect to component 'Intercept'
#> 2026-03-31 16:46:16.067194: iinla: Construct inla stack
#> 2026-03-31 16:46:16.082741: iinla: Model initialisation completed
#> 2026-03-31 16:46:16.084686: iinla: Iteration 1 [max: 10]
#> 2026-03-31 16:46:16.389109: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9)
#> 2026-03-31 16:46:16.392986: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9)
#> 2026-03-31 16:46:16.397603: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-31 16:46:16.399683: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-03-31 16:46:16.401683: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-31 16:46:16.404004: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:16.405651: Linearise components for each observation model
#> 2026-03-31 16:46:16.407494: Linearise component 'z'
#> 2026-03-31 16:46:16.411034: Linearise component 'Intercept'
#> 2026-03-31 16:46:16.414499: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:16.417736: Linearise with respect to component 'z'
#> 2026-03-31 16:46:16.422302: Linearise with respect to component 'Intercept'
#> 2026-03-31 16:46:16.438538: iinla: Iteration 2 [max: 10]
#> 2026-03-31 16:46:17.00941: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-03-31 16:46:17.012394: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-03-31 16:46:17.015998: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-31 16:46:17.0175: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-03-31 16:46:17.018954: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-31 16:46:17.02069: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:17.021837: Linearise components for each observation model
#> 2026-03-31 16:46:17.023166: Linearise component 'z'
#> 2026-03-31 16:46:17.026023: Linearise component 'Intercept'
#> 2026-03-31 16:46:17.02884: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:17.031376: Linearise with respect to component 'z'
#> 2026-03-31 16:46:17.034887: Linearise with respect to component 'Intercept'
#> 2026-03-31 16:46:17.046561: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.049056: iinla: Iteration 3 [max: 10]
#> 2026-03-31 16:46:17.330779: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-03-31 16:46:17.333653: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-03-31 16:46:17.337235: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-31 16:46:17.338718: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-03-31 16:46:17.340139: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-31 16:46:17.341836: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:17.342983: Linearise components for each observation model
#> 2026-03-31 16:46:17.344325: Linearise component 'z'
#> 2026-03-31 16:46:17.347218: Linearise component 'Intercept'
#> 2026-03-31 16:46:17.350052: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:17.352585: Linearise with respect to component 'z'
#> 2026-03-31 16:46:17.356205: Linearise with respect to component 'Intercept'
#> 2026-03-31 16:46:17.367866: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.370278: iinla: Iteration 4 [max: 10]
#> 2026-03-31 16:46:17.652496: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-03-31 16:46:17.655497: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-03-31 16:46:17.659106: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-03-31 16:46:17.660677: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-03-31 16:46:17.662517: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:17.663755: Linearise components for each observation model
#> 2026-03-31 16:46:17.665115: Linearise component 'z'
#> 2026-03-31 16:46:17.667968: Linearise component 'Intercept'
#> 2026-03-31 16:46:17.670755: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:17.673336: Linearise with respect to component 'z'
#> 2026-03-31 16:46:17.676918: Linearise with respect to component 'Intercept'
#> 2026-03-31 16:46:17.688787: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.69002: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-31 16:46:17.692475: iinla: Iteration 5 [max: 10]
#> 2026-03-31 16:46:18.002305: iinla: Computation completed
#> 2026-03-31 16:46:19.065344: bru: Preprocessing
#> 2026-03-31 16:46:19.075508: Evaluate component inputs for each observation model
#> 2026-03-31 16:46:19.076772: bru_input(bru_comp_list)
#> 2026-03-31 16:46:19.078132: bru_input.bru_comp(field)
#> 2026-03-31 16:46:19.079458: bru_input.bm_pipe(field)
#> 2026-03-31 16:46:19.080959: bru_input.bm_multi(field:core)
#> 2026-03-31 16:46:19.082432: bru_input.bru_mapper(field:core:main)
#> 2026-03-31 16:46:19.083765: bru_input(bru_input) for (field)
#> 2026-03-31 16:46:19.096277: iinla: Start
#> 2026-03-31 16:46:19.097449: iinla: Evaluate component linearisations
#> 2026-03-31 16:46:19.098616: Linearise components for each observation model
#> 2026-03-31 16:46:19.099965: Linearise component 'field'
#> 2026-03-31 16:46:19.107222: iinla: Evaluate component simplifications
#> 2026-03-31 16:46:19.108431: Simplify component mappers for each observation model
#> 2026-03-31 16:46:19.109783: Simplify component 'field'
#> 2026-03-31 16:46:19.115943: iinla: Evaluate predictor linearisation
#> 2026-03-31 16:46:19.119324: iinla: Construct inla stack
#> 2026-03-31 16:46:19.129523: iinla: Model initialisation completed
#> 2026-03-31 16:46:19.130926: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:19.526147: iinla: Computation completed
#> 2026-03-31 16:46:21.42271: bru_input(bru_comp_list)
#> 2026-03-31 16:46:23.869757: bru: Preprocessing
#> 2026-03-31 16:46:23.88301: Evaluate component inputs for each observation model
#> 2026-03-31 16:46:23.884326: bru_input(bru_comp_list)
#> 2026-03-31 16:46:23.885795: bru_input.bru_comp(x)
#> 2026-03-31 16:46:23.887154: bru_input.bm_pipe(x)
#> 2026-03-31 16:46:23.894924: bru_input.bm_multi(x:core)
#> 2026-03-31 16:46:23.896814: bru_input.bru_mapper(x:core:main)
#> 2026-03-31 16:46:23.898171: bru_input(bru_input) for (x)
#> 2026-03-31 16:46:23.904795: bru_input(bru_comp_list)
#> 2026-03-31 16:46:23.906183: bru_input.bru_comp(x)
#> 2026-03-31 16:46:23.907531: bru_input.bm_pipe(x)
#> 2026-03-31 16:46:23.90902: bru_input.bm_multi(x:core)
#> 2026-03-31 16:46:23.910476: bru_input.bru_mapper(x:core:main)
#> 2026-03-31 16:46:23.911816: bru_input(bru_input) for (x)
#> 2026-03-31 16:47:11.892726: bru_input(bru_input) for (LABEL)
#> 2026-03-31 16:47:13.453653: bru_input_text(bru_input) for (LABEL)
#> 2026-03-31 16:47:13.464928: bru_input.bru_comp(x)
#> 2026-03-31 16:47:13.466084: bru_input_text.bm_pipe(x)
#> 2026-03-31 16:47:13.467331: bru_input_text.bm_multi(x:core)
#> 2026-03-31 16:47:13.468557: bru_input_text.bru_mapper(x:core:main)
#> 2026-03-31 16:47:13.469614: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-03-31 16:46:04.213539: inlabru loaded
#> 2026-03-31 16:46:04.214123: Clear override options
#> 2026-03-31 16:46:14.690034: bru: Preprocessing
#> 2026-03-31 16:46:14.805386: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:15.347755: bru: Preprocessing
#> 2026-03-31 16:46:15.67292: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:15.986929: bru: Preprocessing
#> 2026-03-31 16:46:16.084686: iinla: Iteration 1 [max: 10]
#> 2026-03-31 16:46:16.401683: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-31 16:46:16.438538: iinla: Iteration 2 [max: 10]
#> 2026-03-31 16:46:17.018954: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-31 16:46:17.046561: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.049056: iinla: Iteration 3 [max: 10]
#> 2026-03-31 16:46:17.340139: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-31 16:46:17.367866: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.370278: iinla: Iteration 4 [max: 10]
#> 2026-03-31 16:46:17.688787: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-31 16:46:17.69002: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-31 16:46:17.692475: iinla: Iteration 5 [max: 10]
#> 2026-03-31 16:46:19.065344: bru: Preprocessing
#> 2026-03-31 16:46:19.130926: iinla: Iteration 1 [max: 1]
#> 2026-03-31 16:46:23.869757: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-03-31 16:46:04.213539: inlabru loaded (level 1)
#> 2026-03-31 16:46:04.214123: Clear override options (level 1)
#> 2026-03-31 16:46:14.690034: bru: Preprocessing (level 1)
#> 2026-03-31 16:46:14.704996: Evaluate component inputs for each observation model (level 3)
#> 2026-03-31 16:46:14.706383: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:14.707894: bru_input.bru_comp(x) (level 4)
#> 2026-03-31 16:46:14.709355: bru_input.bm_pipe(x) (level 5)
#> 2026-03-31 16:46:14.710934: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-31 16:46:14.712483: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-31 16:46:14.714243: bru_input(bru_input) for (x) (level 5)
#> 2026-03-31 16:46:14.721768: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-31 16:46:14.723249: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-31 16:46:14.724972: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-31 16:46:14.726634: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-31 16:46:14.728093: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-31 16:46:14.743758: iinla: Start (level 3)
#> 2026-03-31 16:46:14.744953: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:14.746192: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:14.747683: Linearise component 'x' (level 4)
#> 2026-03-31 16:46:14.750524: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:14.753247: iinla: Evaluate component simplifications (level 3)
#> 2026-03-31 16:46:14.75453: Simplify component mappers for each observation model (level 3)
#> 2026-03-31 16:46:14.756017: Simplify component 'x' (level 4)
#> 2026-03-31 16:46:14.759023: Simplify component 'Intercept' (level 4)
#> 2026-03-31 16:46:14.761948: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:14.775111: iinla: Construct inla stack (level 3)
#> 2026-03-31 16:46:14.80382: iinla: Model initialisation completed (level 3)
#> 2026-03-31 16:46:14.805386: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-31 16:46:15.324094: iinla: Computation completed (level 3)
#> 2026-03-31 16:46:15.347755: bru: Preprocessing (level 1)
#> 2026-03-31 16:46:15.356761: Evaluate component inputs for each observation model (level 3)
#> 2026-03-31 16:46:15.358068: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:15.359467: bru_input.bru_comp(x) (level 4)
#> 2026-03-31 16:46:15.360918: bru_input.bm_pipe(x) (level 5)
#> 2026-03-31 16:46:15.362478: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-31 16:46:15.364026: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-31 16:46:15.365391: bru_input(bru_input) for (x) (level 5)
#> 2026-03-31 16:46:15.372348: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-31 16:46:15.373764: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-31 16:46:15.375276: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-31 16:46:15.376868: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-31 16:46:15.37833: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-31 16:46:15.391104: iinla: Start (level 3)
#> 2026-03-31 16:46:15.392381: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:15.393783: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:15.39535: Linearise component 'x' (level 4)
#> 2026-03-31 16:46:15.398402: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:15.40117: iinla: Evaluate component simplifications (level 3)
#> 2026-03-31 16:46:15.402373: Simplify component mappers for each observation model (level 3)
#> 2026-03-31 16:46:15.403758: Simplify component 'x' (level 4)
#> 2026-03-31 16:46:15.406791: Simplify component 'Intercept' (level 4)
#> 2026-03-31 16:46:15.409769: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:15.416192: iinla: Construct inla stack (level 3)
#> 2026-03-31 16:46:15.428474: iinla: Model initialisation completed (level 3)
#> 2026-03-31 16:46:15.67292: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-31 16:46:15.964356: iinla: Computation completed (level 3)
#> 2026-03-31 16:46:15.986929: bru: Preprocessing (level 1)
#> 2026-03-31 16:46:15.995848: Evaluate component inputs for each observation model (level 3)
#> 2026-03-31 16:46:15.997142: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:15.998544: bru_input.bru_comp(z) (level 4)
#> 2026-03-31 16:46:15.999954: bru_input.bm_pipe(z) (level 5)
#> 2026-03-31 16:46:16.001482: bru_input.bm_multi(z:core) (level 5)
#> 2026-03-31 16:46:16.003078: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-03-31 16:46:16.004431: bru_input(bru_input) for (z) (level 5)
#> 2026-03-31 16:46:16.011548: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-31 16:46:16.012975: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-31 16:46:16.014592: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-31 16:46:16.016143: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-31 16:46:16.017517: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-31 16:46:16.02984: iinla: Start (level 3)
#> 2026-03-31 16:46:16.031076: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:16.032389: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:16.03425: Linearise component 'z' (level 4)
#> 2026-03-31 16:46:16.037864: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:16.041327: iinla: Evaluate component simplifications (level 3)
#> 2026-03-31 16:46:16.04294: Simplify component mappers for each observation model (level 3)
#> 2026-03-31 16:46:16.0448: Simplify component 'z' (level 4)
#> 2026-03-31 16:46:16.0485: Simplify component 'Intercept' (level 4)
#> 2026-03-31 16:46:16.052196: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:16.056114: Linearise with respect to component 'z' (level 5)
#> 2026-03-31 16:46:16.06285: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-31 16:46:16.067194: iinla: Construct inla stack (level 3)
#> 2026-03-31 16:46:16.082741: iinla: Model initialisation completed (level 3)
#> 2026-03-31 16:46:16.084686: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-03-31 16:46:16.389109: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9) (level 3)
#> 2026-03-31 16:46:16.392986: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9) (level 3)
#> 2026-03-31 16:46:16.397603: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 3)
#> 2026-03-31 16:46:16.399683: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-03-31 16:46:16.401683: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 2)
#> 2026-03-31 16:46:16.404004: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:16.405651: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:16.407494: Linearise component 'z' (level 4)
#> 2026-03-31 16:46:16.411034: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:16.414499: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:16.417736: Linearise with respect to component 'z' (level 5)
#> 2026-03-31 16:46:16.422302: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-31 16:46:16.438538: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-03-31 16:46:17.00941: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-03-31 16:46:17.012394: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-03-31 16:46:17.015998: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-03-31 16:46:17.0175: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-03-31 16:46:17.018954: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-03-31 16:46:17.02069: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:17.021837: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:17.023166: Linearise component 'z' (level 4)
#> 2026-03-31 16:46:17.026023: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:17.02884: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:17.031376: Linearise with respect to component 'z' (level 5)
#> 2026-03-31 16:46:17.034887: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-31 16:46:17.046561: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-31 16:46:17.049056: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-03-31 16:46:17.330779: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-03-31 16:46:17.333653: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-03-31 16:46:17.337235: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-03-31 16:46:17.338718: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-03-31 16:46:17.340139: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-03-31 16:46:17.341836: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:17.342983: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:17.344325: Linearise component 'z' (level 4)
#> 2026-03-31 16:46:17.347218: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:17.350052: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:17.352585: Linearise with respect to component 'z' (level 5)
#> 2026-03-31 16:46:17.356205: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-31 16:46:17.367866: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-31 16:46:17.370278: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-03-31 16:46:17.652496: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-03-31 16:46:17.655497: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-03-31 16:46:17.659106: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-03-31 16:46:17.660677: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-03-31 16:46:17.662517: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:17.663755: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:17.665115: Linearise component 'z' (level 4)
#> 2026-03-31 16:46:17.667968: Linearise component 'Intercept' (level 4)
#> 2026-03-31 16:46:17.670755: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:17.673336: Linearise with respect to component 'z' (level 5)
#> 2026-03-31 16:46:17.676918: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-31 16:46:17.688787: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-31 16:46:17.69002: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-03-31 16:46:17.692475: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-03-31 16:46:18.002305: iinla: Computation completed (level 3)
#> 2026-03-31 16:46:19.065344: bru: Preprocessing (level 1)
#> 2026-03-31 16:46:19.075508: Evaluate component inputs for each observation model (level 3)
#> 2026-03-31 16:46:19.076772: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:19.078132: bru_input.bru_comp(field) (level 4)
#> 2026-03-31 16:46:19.079458: bru_input.bm_pipe(field) (level 5)
#> 2026-03-31 16:46:19.080959: bru_input.bm_multi(field:core) (level 5)
#> 2026-03-31 16:46:19.082432: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-03-31 16:46:19.083765: bru_input(bru_input) for (field) (level 5)
#> 2026-03-31 16:46:19.096277: iinla: Start (level 3)
#> 2026-03-31 16:46:19.097449: iinla: Evaluate component linearisations (level 3)
#> 2026-03-31 16:46:19.098616: Linearise components for each observation model (level 3)
#> 2026-03-31 16:46:19.099965: Linearise component 'field' (level 4)
#> 2026-03-31 16:46:19.107222: iinla: Evaluate component simplifications (level 3)
#> 2026-03-31 16:46:19.108431: Simplify component mappers for each observation model (level 3)
#> 2026-03-31 16:46:19.109783: Simplify component 'field' (level 4)
#> 2026-03-31 16:46:19.115943: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-31 16:46:19.119324: iinla: Construct inla stack (level 3)
#> 2026-03-31 16:46:19.129523: iinla: Model initialisation completed (level 3)
#> 2026-03-31 16:46:19.130926: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-31 16:46:19.526147: iinla: Computation completed (level 3)
#> 2026-03-31 16:46:21.42271: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:23.869757: bru: Preprocessing (level 1)
#> 2026-03-31 16:46:23.88301: Evaluate component inputs for each observation model (level 3)
#> 2026-03-31 16:46:23.884326: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:23.885795: bru_input.bru_comp(x) (level 4)
#> 2026-03-31 16:46:23.887154: bru_input.bm_pipe(x) (level 5)
#> 2026-03-31 16:46:23.894924: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-31 16:46:23.896814: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-31 16:46:23.898171: bru_input(bru_input) for (x) (level 5)
#> 2026-03-31 16:46:23.904795: bru_input(bru_comp_list) (level 4)
#> 2026-03-31 16:46:23.906183: bru_input.bru_comp(x) (level 4)
#> 2026-03-31 16:46:23.907531: bru_input.bm_pipe(x) (level 5)
#> 2026-03-31 16:46:23.90902: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-31 16:46:23.910476: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-31 16:46:23.911816: bru_input(bru_input) for (x) (level 5)
#> 2026-03-31 16:47:11.892726: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-03-31 16:47:13.453653: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-03-31 16:47:13.464928: bru_input.bru_comp(x) (level 4)
#> 2026-03-31 16:47:13.466084: bru_input_text.bm_pipe(x) (level 5)
#> 2026-03-31 16:47:13.467331: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-03-31 16:47:13.468557: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-03-31 16:47:13.469614: bru_input_text(bru_input) for (x) (level 5)