Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-03-24 16:36:35.656516: inlabru loaded
#> 2026-03-24 16:36:35.65713: Clear override options
#> 2026-03-24 16:36:46.398562: bru: Preprocessing
#> 2026-03-24 16:36:46.517418: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:47.033749: bru: Preprocessing
#> 2026-03-24 16:36:47.155147: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:47.710698: bru: Preprocessing
#> 2026-03-24 16:36:47.800678: iinla: Iteration 1 [max: 10]
#> 2026-03-24 16:36:48.11548: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-24 16:36:48.153776: iinla: Iteration 2 [max: 10]
#> 2026-03-24 16:36:48.755036: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-24 16:36:48.783: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:48.785539: iinla: Iteration 3 [max: 10]
#> 2026-03-24 16:36:49.083397: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-24 16:36:49.111777: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:49.114482: iinla: Iteration 4 [max: 10]
#> 2026-03-24 16:36:49.442188: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:49.443492: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-24 16:36:49.446043: iinla: Iteration 5 [max: 10]
#> 2026-03-24 16:36:50.823555: bru: Preprocessing
#> 2026-03-24 16:36:50.890234: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:55.642082: bru: Preprocessing
format(bru_log())
#> 2026-03-24 16:36:35.656516: inlabru loaded
#> 2026-03-24 16:36:35.65713: Clear override options
#> 2026-03-24 16:36:46.398562: bru: Preprocessing
#> 2026-03-24 16:36:46.413461: Evaluate component inputs for each observation model
#> 2026-03-24 16:36:46.414973: bru_input(bru_comp_list)
#> 2026-03-24 16:36:46.41648: bru_input.bru_comp(x)
#> 2026-03-24 16:36:46.417924: bru_input.bm_pipe(x)
#> 2026-03-24 16:36:46.419626: bru_input.bm_multi(x:core)
#> 2026-03-24 16:36:46.421206: bru_input.bru_mapper(x:core:main)
#> 2026-03-24 16:36:46.422823: bru_input(bru_input) for (x)
#> 2026-03-24 16:36:46.430523: bru_input.bru_comp(Intercept)
#> 2026-03-24 16:36:46.438577: bru_input.bm_pipe(Intercept)
#> 2026-03-24 16:36:46.440641: bru_input.bm_multi(Intercept:core)
#> 2026-03-24 16:36:46.442205: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-24 16:36:46.443689: bru_input(bru_input) for (Intercept)
#> 2026-03-24 16:36:46.461179: iinla: Start
#> 2026-03-24 16:36:46.462604: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:46.463883: Linearise components for each observation model
#> 2026-03-24 16:36:46.465434: Linearise component 'x'
#> 2026-03-24 16:36:46.468405: Linearise component 'Intercept'
#> 2026-03-24 16:36:46.471208: iinla: Evaluate component simplifications
#> 2026-03-24 16:36:46.472532: Simplify component mappers for each observation model
#> 2026-03-24 16:36:46.47404: Simplify component 'x'
#> 2026-03-24 16:36:46.477228: Simplify component 'Intercept'
#> 2026-03-24 16:36:46.480318: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:46.494049: iinla: Construct inla stack
#> 2026-03-24 16:36:46.51593: iinla: Model initialisation completed
#> 2026-03-24 16:36:46.517418: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:47.009505: iinla: Computation completed
#> 2026-03-24 16:36:47.033749: bru: Preprocessing
#> 2026-03-24 16:36:47.042632: Evaluate component inputs for each observation model
#> 2026-03-24 16:36:47.043897: bru_input(bru_comp_list)
#> 2026-03-24 16:36:47.045303: bru_input.bru_comp(x)
#> 2026-03-24 16:36:47.046667: bru_input.bm_pipe(x)
#> 2026-03-24 16:36:47.048179: bru_input.bm_multi(x:core)
#> 2026-03-24 16:36:47.049678: bru_input.bru_mapper(x:core:main)
#> 2026-03-24 16:36:47.050998: bru_input(bru_input) for (x)
#> 2026-03-24 16:36:47.058055: bru_input.bru_comp(Intercept)
#> 2026-03-24 16:36:47.059432: bru_input.bm_pipe(Intercept)
#> 2026-03-24 16:36:47.06094: bru_input.bm_multi(Intercept:core)
#> 2026-03-24 16:36:47.06243: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-24 16:36:47.063766: bru_input(bru_input) for (Intercept)
#> 2026-03-24 16:36:47.115687: iinla: Start
#> 2026-03-24 16:36:47.116992: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:47.118267: Linearise components for each observation model
#> 2026-03-24 16:36:47.119719: Linearise component 'x'
#> 2026-03-24 16:36:47.122721: Linearise component 'Intercept'
#> 2026-03-24 16:36:47.125604: iinla: Evaluate component simplifications
#> 2026-03-24 16:36:47.126892: Simplify component mappers for each observation model
#> 2026-03-24 16:36:47.128373: Simplify component 'x'
#> 2026-03-24 16:36:47.131433: Simplify component 'Intercept'
#> 2026-03-24 16:36:47.134472: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:47.141204: iinla: Construct inla stack
#> 2026-03-24 16:36:47.153664: iinla: Model initialisation completed
#> 2026-03-24 16:36:47.155147: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:47.687663: iinla: Computation completed
#> 2026-03-24 16:36:47.710698: bru: Preprocessing
#> 2026-03-24 16:36:47.719478: Evaluate component inputs for each observation model
#> 2026-03-24 16:36:47.720723: bru_input(bru_comp_list)
#> 2026-03-24 16:36:47.722064: bru_input.bru_comp(z)
#> 2026-03-24 16:36:47.723437: bru_input.bm_pipe(z)
#> 2026-03-24 16:36:47.72501: bru_input.bm_multi(z:core)
#> 2026-03-24 16:36:47.726596: bru_input.bru_mapper(z:core:main)
#> 2026-03-24 16:36:47.728072: bru_input(bru_input) for (z)
#> 2026-03-24 16:36:47.734903: bru_input.bru_comp(Intercept)
#> 2026-03-24 16:36:47.7363: bru_input.bm_pipe(Intercept)
#> 2026-03-24 16:36:47.737763: bru_input.bm_multi(Intercept:core)
#> 2026-03-24 16:36:47.739227: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-24 16:36:47.740534: bru_input(bru_input) for (Intercept)
#> 2026-03-24 16:36:47.753006: iinla: Start
#> 2026-03-24 16:36:47.754194: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:47.756464: Linearise components for each observation model
#> 2026-03-24 16:36:47.76079: Linearise component 'z'
#> 2026-03-24 16:36:47.763899: Linearise component 'Intercept'
#> 2026-03-24 16:36:47.76668: iinla: Evaluate component simplifications
#> 2026-03-24 16:36:47.767892: Simplify component mappers for each observation model
#> 2026-03-24 16:36:47.769332: Simplify component 'z'
#> 2026-03-24 16:36:47.772392: Simplify component 'Intercept'
#> 2026-03-24 16:36:47.775381: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:47.77849: Linearise with respect to component 'z'
#> 2026-03-24 16:36:47.783756: Linearise with respect to component 'Intercept'
#> 2026-03-24 16:36:47.787033: iinla: Construct inla stack
#> 2026-03-24 16:36:47.799272: iinla: Model initialisation completed
#> 2026-03-24 16:36:47.800678: iinla: Iteration 1 [max: 10]
#> 2026-03-24 16:36:48.102531: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9)
#> 2026-03-24 16:36:48.106428: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9)
#> 2026-03-24 16:36:48.11129: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-24 16:36:48.113385: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-03-24 16:36:48.11548: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-24 16:36:48.117898: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:48.119713: Linearise components for each observation model
#> 2026-03-24 16:36:48.121648: Linearise component 'z'
#> 2026-03-24 16:36:48.125268: Linearise component 'Intercept'
#> 2026-03-24 16:36:48.128782: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:48.13221: Linearise with respect to component 'z'
#> 2026-03-24 16:36:48.136964: Linearise with respect to component 'Intercept'
#> 2026-03-24 16:36:48.153776: iinla: Iteration 2 [max: 10]
#> 2026-03-24 16:36:48.745419: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-03-24 16:36:48.748423: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-03-24 16:36:48.752114: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-24 16:36:48.753592: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-03-24 16:36:48.755036: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-24 16:36:48.756748: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:48.75791: Linearise components for each observation model
#> 2026-03-24 16:36:48.759255: Linearise component 'z'
#> 2026-03-24 16:36:48.762095: Linearise component 'Intercept'
#> 2026-03-24 16:36:48.764833: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:48.7674: Linearise with respect to component 'z'
#> 2026-03-24 16:36:48.77088: Linearise with respect to component 'Intercept'
#> 2026-03-24 16:36:48.783: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:48.785539: iinla: Iteration 3 [max: 10]
#> 2026-03-24 16:36:49.07368: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-03-24 16:36:49.076657: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-03-24 16:36:49.08028: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-24 16:36:49.081786: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-03-24 16:36:49.083397: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-24 16:36:49.085168: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:49.086379: Linearise components for each observation model
#> 2026-03-24 16:36:49.087787: Linearise component 'z'
#> 2026-03-24 16:36:49.090684: Linearise component 'Intercept'
#> 2026-03-24 16:36:49.093519: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:49.096124: Linearise with respect to component 'z'
#> 2026-03-24 16:36:49.099735: Linearise with respect to component 'Intercept'
#> 2026-03-24 16:36:49.111777: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:49.114482: iinla: Iteration 4 [max: 10]
#> 2026-03-24 16:36:49.405283: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-03-24 16:36:49.408206: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-03-24 16:36:49.411818: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-03-24 16:36:49.413387: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-03-24 16:36:49.41517: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:49.416379: Linearise components for each observation model
#> 2026-03-24 16:36:49.417774: Linearise component 'z'
#> 2026-03-24 16:36:49.420774: Linearise component 'Intercept'
#> 2026-03-24 16:36:49.423609: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:49.426249: Linearise with respect to component 'z'
#> 2026-03-24 16:36:49.429889: Linearise with respect to component 'Intercept'
#> 2026-03-24 16:36:49.442188: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:49.443492: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-24 16:36:49.446043: iinla: Iteration 5 [max: 10]
#> 2026-03-24 16:36:49.749744: iinla: Computation completed
#> 2026-03-24 16:36:50.823555: bru: Preprocessing
#> 2026-03-24 16:36:50.833608: Evaluate component inputs for each observation model
#> 2026-03-24 16:36:50.83501: bru_input(bru_comp_list)
#> 2026-03-24 16:36:50.836456: bru_input.bru_comp(field)
#> 2026-03-24 16:36:50.837883: bru_input.bm_pipe(field)
#> 2026-03-24 16:36:50.839413: bru_input.bm_multi(field:core)
#> 2026-03-24 16:36:50.840923: bru_input.bru_mapper(field:core:main)
#> 2026-03-24 16:36:50.84231: bru_input(bru_input) for (field)
#> 2026-03-24 16:36:50.855211: iinla: Start
#> 2026-03-24 16:36:50.856392: iinla: Evaluate component linearisations
#> 2026-03-24 16:36:50.857565: Linearise components for each observation model
#> 2026-03-24 16:36:50.858889: Linearise component 'field'
#> 2026-03-24 16:36:50.866225: iinla: Evaluate component simplifications
#> 2026-03-24 16:36:50.86746: Simplify component mappers for each observation model
#> 2026-03-24 16:36:50.868817: Simplify component 'field'
#> 2026-03-24 16:36:50.875007: iinla: Evaluate predictor linearisation
#> 2026-03-24 16:36:50.878484: iinla: Construct inla stack
#> 2026-03-24 16:36:50.888816: iinla: Model initialisation completed
#> 2026-03-24 16:36:50.890234: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:51.294333: iinla: Computation completed
#> 2026-03-24 16:36:53.195413: bru_input(bru_comp_list)
#> 2026-03-24 16:36:55.642082: bru: Preprocessing
#> 2026-03-24 16:36:55.655558: Evaluate component inputs for each observation model
#> 2026-03-24 16:36:55.656869: bru_input(bru_comp_list)
#> 2026-03-24 16:36:55.658304: bru_input.bru_comp(x)
#> 2026-03-24 16:36:55.659673: bru_input.bm_pipe(x)
#> 2026-03-24 16:36:55.661207: bru_input.bm_multi(x:core)
#> 2026-03-24 16:36:55.662751: bru_input.bru_mapper(x:core:main)
#> 2026-03-24 16:36:55.670814: bru_input(bru_input) for (x)
#> 2026-03-24 16:36:55.677794: bru_input(bru_comp_list)
#> 2026-03-24 16:36:55.679212: bru_input.bru_comp(x)
#> 2026-03-24 16:36:55.680549: bru_input.bm_pipe(x)
#> 2026-03-24 16:36:55.682074: bru_input.bm_multi(x:core)
#> 2026-03-24 16:36:55.683538: bru_input.bru_mapper(x:core:main)
#> 2026-03-24 16:36:55.684876: bru_input(bru_input) for (x)
#> 2026-03-24 16:37:00.114892: bru_input(bru_input) for (LABEL)
#> 2026-03-24 16:37:01.819416: bru_input_text(bru_input) for (LABEL)
#> 2026-03-24 16:37:01.831645: bru_input.bru_comp(x)
#> 2026-03-24 16:37:01.83287: bru_input_text.bm_pipe(x)
#> 2026-03-24 16:37:01.83419: bru_input_text.bm_multi(x:core)
#> 2026-03-24 16:37:01.835416: bru_input_text.bru_mapper(x:core:main)
#> 2026-03-24 16:37:01.836442: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-03-24 16:36:35.656516: inlabru loaded
#> 2026-03-24 16:36:35.65713: Clear override options
#> 2026-03-24 16:36:46.398562: bru: Preprocessing
#> 2026-03-24 16:36:46.517418: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:47.033749: bru: Preprocessing
#> 2026-03-24 16:36:47.155147: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:47.710698: bru: Preprocessing
#> 2026-03-24 16:36:47.800678: iinla: Iteration 1 [max: 10]
#> 2026-03-24 16:36:48.11548: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-24 16:36:48.153776: iinla: Iteration 2 [max: 10]
#> 2026-03-24 16:36:48.755036: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-24 16:36:48.783: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:48.785539: iinla: Iteration 3 [max: 10]
#> 2026-03-24 16:36:49.083397: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-24 16:36:49.111777: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:49.114482: iinla: Iteration 4 [max: 10]
#> 2026-03-24 16:36:49.442188: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-24 16:36:49.443492: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-24 16:36:49.446043: iinla: Iteration 5 [max: 10]
#> 2026-03-24 16:36:50.823555: bru: Preprocessing
#> 2026-03-24 16:36:50.890234: iinla: Iteration 1 [max: 1]
#> 2026-03-24 16:36:55.642082: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-03-24 16:36:35.656516: inlabru loaded (level 1)
#> 2026-03-24 16:36:35.65713: Clear override options (level 1)
#> 2026-03-24 16:36:46.398562: bru: Preprocessing (level 1)
#> 2026-03-24 16:36:46.413461: Evaluate component inputs for each observation model (level 3)
#> 2026-03-24 16:36:46.414973: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:46.41648: bru_input.bru_comp(x) (level 4)
#> 2026-03-24 16:36:46.417924: bru_input.bm_pipe(x) (level 5)
#> 2026-03-24 16:36:46.419626: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-24 16:36:46.421206: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-24 16:36:46.422823: bru_input(bru_input) for (x) (level 5)
#> 2026-03-24 16:36:46.430523: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-24 16:36:46.438577: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-24 16:36:46.440641: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-24 16:36:46.442205: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-24 16:36:46.443689: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-24 16:36:46.461179: iinla: Start (level 3)
#> 2026-03-24 16:36:46.462604: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:46.463883: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:46.465434: Linearise component 'x' (level 4)
#> 2026-03-24 16:36:46.468405: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:46.471208: iinla: Evaluate component simplifications (level 3)
#> 2026-03-24 16:36:46.472532: Simplify component mappers for each observation model (level 3)
#> 2026-03-24 16:36:46.47404: Simplify component 'x' (level 4)
#> 2026-03-24 16:36:46.477228: Simplify component 'Intercept' (level 4)
#> 2026-03-24 16:36:46.480318: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:46.494049: iinla: Construct inla stack (level 3)
#> 2026-03-24 16:36:46.51593: iinla: Model initialisation completed (level 3)
#> 2026-03-24 16:36:46.517418: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-24 16:36:47.009505: iinla: Computation completed (level 3)
#> 2026-03-24 16:36:47.033749: bru: Preprocessing (level 1)
#> 2026-03-24 16:36:47.042632: Evaluate component inputs for each observation model (level 3)
#> 2026-03-24 16:36:47.043897: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:47.045303: bru_input.bru_comp(x) (level 4)
#> 2026-03-24 16:36:47.046667: bru_input.bm_pipe(x) (level 5)
#> 2026-03-24 16:36:47.048179: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-24 16:36:47.049678: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-24 16:36:47.050998: bru_input(bru_input) for (x) (level 5)
#> 2026-03-24 16:36:47.058055: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-24 16:36:47.059432: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-24 16:36:47.06094: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-24 16:36:47.06243: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-24 16:36:47.063766: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-24 16:36:47.115687: iinla: Start (level 3)
#> 2026-03-24 16:36:47.116992: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:47.118267: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:47.119719: Linearise component 'x' (level 4)
#> 2026-03-24 16:36:47.122721: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:47.125604: iinla: Evaluate component simplifications (level 3)
#> 2026-03-24 16:36:47.126892: Simplify component mappers for each observation model (level 3)
#> 2026-03-24 16:36:47.128373: Simplify component 'x' (level 4)
#> 2026-03-24 16:36:47.131433: Simplify component 'Intercept' (level 4)
#> 2026-03-24 16:36:47.134472: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:47.141204: iinla: Construct inla stack (level 3)
#> 2026-03-24 16:36:47.153664: iinla: Model initialisation completed (level 3)
#> 2026-03-24 16:36:47.155147: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-24 16:36:47.687663: iinla: Computation completed (level 3)
#> 2026-03-24 16:36:47.710698: bru: Preprocessing (level 1)
#> 2026-03-24 16:36:47.719478: Evaluate component inputs for each observation model (level 3)
#> 2026-03-24 16:36:47.720723: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:47.722064: bru_input.bru_comp(z) (level 4)
#> 2026-03-24 16:36:47.723437: bru_input.bm_pipe(z) (level 5)
#> 2026-03-24 16:36:47.72501: bru_input.bm_multi(z:core) (level 5)
#> 2026-03-24 16:36:47.726596: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-03-24 16:36:47.728072: bru_input(bru_input) for (z) (level 5)
#> 2026-03-24 16:36:47.734903: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-24 16:36:47.7363: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-24 16:36:47.737763: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-24 16:36:47.739227: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-24 16:36:47.740534: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-24 16:36:47.753006: iinla: Start (level 3)
#> 2026-03-24 16:36:47.754194: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:47.756464: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:47.76079: Linearise component 'z' (level 4)
#> 2026-03-24 16:36:47.763899: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:47.76668: iinla: Evaluate component simplifications (level 3)
#> 2026-03-24 16:36:47.767892: Simplify component mappers for each observation model (level 3)
#> 2026-03-24 16:36:47.769332: Simplify component 'z' (level 4)
#> 2026-03-24 16:36:47.772392: Simplify component 'Intercept' (level 4)
#> 2026-03-24 16:36:47.775381: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:47.77849: Linearise with respect to component 'z' (level 5)
#> 2026-03-24 16:36:47.783756: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-24 16:36:47.787033: iinla: Construct inla stack (level 3)
#> 2026-03-24 16:36:47.799272: iinla: Model initialisation completed (level 3)
#> 2026-03-24 16:36:47.800678: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-03-24 16:36:48.102531: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9) (level 3)
#> 2026-03-24 16:36:48.106428: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9) (level 3)
#> 2026-03-24 16:36:48.11129: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 3)
#> 2026-03-24 16:36:48.113385: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-03-24 16:36:48.11548: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 2)
#> 2026-03-24 16:36:48.117898: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:48.119713: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:48.121648: Linearise component 'z' (level 4)
#> 2026-03-24 16:36:48.125268: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:48.128782: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:48.13221: Linearise with respect to component 'z' (level 5)
#> 2026-03-24 16:36:48.136964: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-24 16:36:48.153776: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-03-24 16:36:48.745419: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-03-24 16:36:48.748423: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-03-24 16:36:48.752114: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-03-24 16:36:48.753592: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-03-24 16:36:48.755036: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-03-24 16:36:48.756748: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:48.75791: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:48.759255: Linearise component 'z' (level 4)
#> 2026-03-24 16:36:48.762095: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:48.764833: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:48.7674: Linearise with respect to component 'z' (level 5)
#> 2026-03-24 16:36:48.77088: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-24 16:36:48.783: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-24 16:36:48.785539: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-03-24 16:36:49.07368: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-03-24 16:36:49.076657: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-03-24 16:36:49.08028: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-03-24 16:36:49.081786: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-03-24 16:36:49.083397: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-03-24 16:36:49.085168: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:49.086379: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:49.087787: Linearise component 'z' (level 4)
#> 2026-03-24 16:36:49.090684: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:49.093519: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:49.096124: Linearise with respect to component 'z' (level 5)
#> 2026-03-24 16:36:49.099735: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-24 16:36:49.111777: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-24 16:36:49.114482: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-03-24 16:36:49.405283: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-03-24 16:36:49.408206: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-03-24 16:36:49.411818: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-03-24 16:36:49.413387: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-03-24 16:36:49.41517: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:49.416379: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:49.417774: Linearise component 'z' (level 4)
#> 2026-03-24 16:36:49.420774: Linearise component 'Intercept' (level 4)
#> 2026-03-24 16:36:49.423609: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:49.426249: Linearise with respect to component 'z' (level 5)
#> 2026-03-24 16:36:49.429889: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-24 16:36:49.442188: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-24 16:36:49.443492: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-03-24 16:36:49.446043: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-03-24 16:36:49.749744: iinla: Computation completed (level 3)
#> 2026-03-24 16:36:50.823555: bru: Preprocessing (level 1)
#> 2026-03-24 16:36:50.833608: Evaluate component inputs for each observation model (level 3)
#> 2026-03-24 16:36:50.83501: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:50.836456: bru_input.bru_comp(field) (level 4)
#> 2026-03-24 16:36:50.837883: bru_input.bm_pipe(field) (level 5)
#> 2026-03-24 16:36:50.839413: bru_input.bm_multi(field:core) (level 5)
#> 2026-03-24 16:36:50.840923: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-03-24 16:36:50.84231: bru_input(bru_input) for (field) (level 5)
#> 2026-03-24 16:36:50.855211: iinla: Start (level 3)
#> 2026-03-24 16:36:50.856392: iinla: Evaluate component linearisations (level 3)
#> 2026-03-24 16:36:50.857565: Linearise components for each observation model (level 3)
#> 2026-03-24 16:36:50.858889: Linearise component 'field' (level 4)
#> 2026-03-24 16:36:50.866225: iinla: Evaluate component simplifications (level 3)
#> 2026-03-24 16:36:50.86746: Simplify component mappers for each observation model (level 3)
#> 2026-03-24 16:36:50.868817: Simplify component 'field' (level 4)
#> 2026-03-24 16:36:50.875007: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-24 16:36:50.878484: iinla: Construct inla stack (level 3)
#> 2026-03-24 16:36:50.888816: iinla: Model initialisation completed (level 3)
#> 2026-03-24 16:36:50.890234: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-24 16:36:51.294333: iinla: Computation completed (level 3)
#> 2026-03-24 16:36:53.195413: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:55.642082: bru: Preprocessing (level 1)
#> 2026-03-24 16:36:55.655558: Evaluate component inputs for each observation model (level 3)
#> 2026-03-24 16:36:55.656869: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:55.658304: bru_input.bru_comp(x) (level 4)
#> 2026-03-24 16:36:55.659673: bru_input.bm_pipe(x) (level 5)
#> 2026-03-24 16:36:55.661207: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-24 16:36:55.662751: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-24 16:36:55.670814: bru_input(bru_input) for (x) (level 5)
#> 2026-03-24 16:36:55.677794: bru_input(bru_comp_list) (level 4)
#> 2026-03-24 16:36:55.679212: bru_input.bru_comp(x) (level 4)
#> 2026-03-24 16:36:55.680549: bru_input.bm_pipe(x) (level 5)
#> 2026-03-24 16:36:55.682074: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-24 16:36:55.683538: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-24 16:36:55.684876: bru_input(bru_input) for (x) (level 5)
#> 2026-03-24 16:37:00.114892: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-03-24 16:37:01.819416: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-03-24 16:37:01.831645: bru_input.bru_comp(x) (level 4)
#> 2026-03-24 16:37:01.83287: bru_input_text.bm_pipe(x) (level 5)
#> 2026-03-24 16:37:01.83419: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-03-24 16:37:01.835416: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-03-24 16:37:01.836442: bru_input_text(bru_input) for (x) (level 5)