Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-03-17 17:06:20.156394: inlabru loaded
#> 2026-03-17 17:06:20.157068: Clear override options
#> 2026-03-17 17:06:31.201399: bru: Preprocessing
#> 2026-03-17 17:06:31.322804: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:31.848389: bru: Preprocessing
#> 2026-03-17 17:06:31.97431: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:32.544444: bru: Preprocessing
#> 2026-03-17 17:06:32.636144: iinla: Iteration 1 [max: 10]
#> 2026-03-17 17:06:32.959145: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-17 17:06:32.998358: iinla: Iteration 2 [max: 10]
#> 2026-03-17 17:06:33.609971: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-17 17:06:33.641016: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:33.643607: iinla: Iteration 3 [max: 10]
#> 2026-03-17 17:06:33.945985: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-17 17:06:33.974806: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:33.977336: iinla: Iteration 4 [max: 10]
#> 2026-03-17 17:06:34.314698: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:34.315997: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-17 17:06:34.318651: iinla: Iteration 5 [max: 10]
#> 2026-03-17 17:06:35.736171: bru: Preprocessing
#> 2026-03-17 17:06:35.803675: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:40.508297: bru: Preprocessing
format(bru_log())
#> 2026-03-17 17:06:20.156394: inlabru loaded
#> 2026-03-17 17:06:20.157068: Clear override options
#> 2026-03-17 17:06:31.201399: bru: Preprocessing
#> 2026-03-17 17:06:31.216795: Evaluate component inputs for each observation model
#> 2026-03-17 17:06:31.218247: bru_input(bru_comp_list)
#> 2026-03-17 17:06:31.219739: bru_input.bru_comp(x)
#> 2026-03-17 17:06:31.221266: bru_input.bm_pipe(x)
#> 2026-03-17 17:06:31.222853: bru_input.bm_multi(x:core)
#> 2026-03-17 17:06:31.224416: bru_input.bru_mapper(x:core:main)
#> 2026-03-17 17:06:31.226069: bru_input(bru_input) for (x)
#> 2026-03-17 17:06:31.234607: bru_input.bru_comp(Intercept)
#> 2026-03-17 17:06:31.236053: bru_input.bm_pipe(Intercept)
#> 2026-03-17 17:06:31.237637: bru_input.bm_multi(Intercept:core)
#> 2026-03-17 17:06:31.245465: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-17 17:06:31.247645: bru_input(bru_input) for (Intercept)
#> 2026-03-17 17:06:31.265759: iinla: Start
#> 2026-03-17 17:06:31.26712: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:31.268481: Linearise components for each observation model
#> 2026-03-17 17:06:31.270078: Linearise component 'x'
#> 2026-03-17 17:06:31.273263: Linearise component 'Intercept'
#> 2026-03-17 17:06:31.276008: iinla: Evaluate component simplifications
#> 2026-03-17 17:06:31.2773: Simplify component mappers for each observation model
#> 2026-03-17 17:06:31.278807: Simplify component 'x'
#> 2026-03-17 17:06:31.281889: Simplify component 'Intercept'
#> 2026-03-17 17:06:31.284883: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:31.298658: iinla: Construct inla stack
#> 2026-03-17 17:06:31.321225: iinla: Model initialisation completed
#> 2026-03-17 17:06:31.322804: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:31.823737: iinla: Computation completed
#> 2026-03-17 17:06:31.848389: bru: Preprocessing
#> 2026-03-17 17:06:31.857826: Evaluate component inputs for each observation model
#> 2026-03-17 17:06:31.859114: bru_input(bru_comp_list)
#> 2026-03-17 17:06:31.860533: bru_input.bru_comp(x)
#> 2026-03-17 17:06:31.861895: bru_input.bm_pipe(x)
#> 2026-03-17 17:06:31.863391: bru_input.bm_multi(x:core)
#> 2026-03-17 17:06:31.864852: bru_input.bru_mapper(x:core:main)
#> 2026-03-17 17:06:31.86619: bru_input(bru_input) for (x)
#> 2026-03-17 17:06:31.874365: bru_input.bru_comp(Intercept)
#> 2026-03-17 17:06:31.87572: bru_input.bm_pipe(Intercept)
#> 2026-03-17 17:06:31.877203: bru_input.bm_multi(Intercept:core)
#> 2026-03-17 17:06:31.878671: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-17 17:06:31.879977: bru_input(bru_input) for (Intercept)
#> 2026-03-17 17:06:31.932895: iinla: Start
#> 2026-03-17 17:06:31.934892: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:31.936192: Linearise components for each observation model
#> 2026-03-17 17:06:31.937638: Linearise component 'x'
#> 2026-03-17 17:06:31.940691: Linearise component 'Intercept'
#> 2026-03-17 17:06:31.943579: iinla: Evaluate component simplifications
#> 2026-03-17 17:06:31.944859: Simplify component mappers for each observation model
#> 2026-03-17 17:06:31.946391: Simplify component 'x'
#> 2026-03-17 17:06:31.949525: Simplify component 'Intercept'
#> 2026-03-17 17:06:31.952706: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:31.959873: iinla: Construct inla stack
#> 2026-03-17 17:06:31.972801: iinla: Model initialisation completed
#> 2026-03-17 17:06:31.97431: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:32.52049: iinla: Computation completed
#> 2026-03-17 17:06:32.544444: bru: Preprocessing
#> 2026-03-17 17:06:32.553502: Evaluate component inputs for each observation model
#> 2026-03-17 17:06:32.55478: bru_input(bru_comp_list)
#> 2026-03-17 17:06:32.556175: bru_input.bru_comp(z)
#> 2026-03-17 17:06:32.5575: bru_input.bm_pipe(z)
#> 2026-03-17 17:06:32.559045: bru_input.bm_multi(z:core)
#> 2026-03-17 17:06:32.56068: bru_input.bru_mapper(z:core:main)
#> 2026-03-17 17:06:32.562189: bru_input(bru_input) for (z)
#> 2026-03-17 17:06:32.570827: bru_input.bru_comp(Intercept)
#> 2026-03-17 17:06:32.572312: bru_input.bm_pipe(Intercept)
#> 2026-03-17 17:06:32.57389: bru_input.bm_multi(Intercept:core)
#> 2026-03-17 17:06:32.575423: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-17 17:06:32.576743: bru_input(bru_input) for (Intercept)
#> 2026-03-17 17:06:32.590775: iinla: Start
#> 2026-03-17 17:06:32.591982: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:32.593173: Linearise components for each observation model
#> 2026-03-17 17:06:32.594534: Linearise component 'z'
#> 2026-03-17 17:06:32.59773: Linearise component 'Intercept'
#> 2026-03-17 17:06:32.600619: iinla: Evaluate component simplifications
#> 2026-03-17 17:06:32.601833: Simplify component mappers for each observation model
#> 2026-03-17 17:06:32.603228: Simplify component 'z'
#> 2026-03-17 17:06:32.606257: Simplify component 'Intercept'
#> 2026-03-17 17:06:32.609296: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:32.612443: Linearise with respect to component 'z'
#> 2026-03-17 17:06:32.617728: Linearise with respect to component 'Intercept'
#> 2026-03-17 17:06:32.621058: iinla: Construct inla stack
#> 2026-03-17 17:06:32.634585: iinla: Model initialisation completed
#> 2026-03-17 17:06:32.636144: iinla: Iteration 1 [max: 10]
#> 2026-03-17 17:06:32.946051: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9)
#> 2026-03-17 17:06:32.949921: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9)
#> 2026-03-17 17:06:32.955009: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-17 17:06:32.957121: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-03-17 17:06:32.959145: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-17 17:06:32.96156: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:32.963266: Linearise components for each observation model
#> 2026-03-17 17:06:32.965211: Linearise component 'z'
#> 2026-03-17 17:06:32.968929: Linearise component 'Intercept'
#> 2026-03-17 17:06:32.972513: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:32.976115: Linearise with respect to component 'z'
#> 2026-03-17 17:06:32.981164: Linearise with respect to component 'Intercept'
#> 2026-03-17 17:06:32.998358: iinla: Iteration 2 [max: 10]
#> 2026-03-17 17:06:33.600226: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-03-17 17:06:33.603286: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-03-17 17:06:33.606932: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-17 17:06:33.608516: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-03-17 17:06:33.609971: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-17 17:06:33.611748: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:33.61291: Linearise components for each observation model
#> 2026-03-17 17:06:33.614369: Linearise component 'z'
#> 2026-03-17 17:06:33.618281: Linearise component 'Intercept'
#> 2026-03-17 17:06:33.62201: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:33.624757: Linearise with respect to component 'z'
#> 2026-03-17 17:06:33.628476: Linearise with respect to component 'Intercept'
#> 2026-03-17 17:06:33.641016: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:33.643607: iinla: Iteration 3 [max: 10]
#> 2026-03-17 17:06:33.936275: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-03-17 17:06:33.939322: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-03-17 17:06:33.942927: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-17 17:06:33.944477: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-03-17 17:06:33.945985: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-17 17:06:33.947769: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:33.948999: Linearise components for each observation model
#> 2026-03-17 17:06:33.950429: Linearise component 'z'
#> 2026-03-17 17:06:33.95344: Linearise component 'Intercept'
#> 2026-03-17 17:06:33.956351: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:33.958952: Linearise with respect to component 'z'
#> 2026-03-17 17:06:33.962606: Linearise with respect to component 'Intercept'
#> 2026-03-17 17:06:33.974806: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:33.977336: iinla: Iteration 4 [max: 10]
#> 2026-03-17 17:06:34.276632: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-03-17 17:06:34.279712: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-03-17 17:06:34.283556: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-03-17 17:06:34.28513: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-03-17 17:06:34.28694: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:34.288177: Linearise components for each observation model
#> 2026-03-17 17:06:34.289582: Linearise component 'z'
#> 2026-03-17 17:06:34.292601: Linearise component 'Intercept'
#> 2026-03-17 17:06:34.295525: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:34.29828: Linearise with respect to component 'z'
#> 2026-03-17 17:06:34.302009: Linearise with respect to component 'Intercept'
#> 2026-03-17 17:06:34.314698: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:34.315997: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-17 17:06:34.318651: iinla: Iteration 5 [max: 10]
#> 2026-03-17 17:06:34.625172: iinla: Computation completed
#> 2026-03-17 17:06:35.736171: bru: Preprocessing
#> 2026-03-17 17:06:35.746271: Evaluate component inputs for each observation model
#> 2026-03-17 17:06:35.747673: bru_input(bru_comp_list)
#> 2026-03-17 17:06:35.749063: bru_input.bru_comp(field)
#> 2026-03-17 17:06:35.750481: bru_input.bm_pipe(field)
#> 2026-03-17 17:06:35.751993: bru_input.bm_multi(field:core)
#> 2026-03-17 17:06:35.753498: bru_input.bru_mapper(field:core:main)
#> 2026-03-17 17:06:35.754802: bru_input(bru_input) for (field)
#> 2026-03-17 17:06:35.768153: iinla: Start
#> 2026-03-17 17:06:35.769341: iinla: Evaluate component linearisations
#> 2026-03-17 17:06:35.770501: Linearise components for each observation model
#> 2026-03-17 17:06:35.77184: Linearise component 'field'
#> 2026-03-17 17:06:35.779322: iinla: Evaluate component simplifications
#> 2026-03-17 17:06:35.780535: Simplify component mappers for each observation model
#> 2026-03-17 17:06:35.781877: Simplify component 'field'
#> 2026-03-17 17:06:35.788242: iinla: Evaluate predictor linearisation
#> 2026-03-17 17:06:35.791713: iinla: Construct inla stack
#> 2026-03-17 17:06:35.802281: iinla: Model initialisation completed
#> 2026-03-17 17:06:35.803675: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:36.21119: iinla: Computation completed
#> 2026-03-17 17:06:38.096132: bru_input(bru_comp_list)
#> 2026-03-17 17:06:40.508297: bru: Preprocessing
#> 2026-03-17 17:06:40.521592: Evaluate component inputs for each observation model
#> 2026-03-17 17:06:40.522926: bru_input(bru_comp_list)
#> 2026-03-17 17:06:40.524364: bru_input.bru_comp(x)
#> 2026-03-17 17:06:40.525735: bru_input.bm_pipe(x)
#> 2026-03-17 17:06:40.527246: bru_input.bm_multi(x:core)
#> 2026-03-17 17:06:40.535293: bru_input.bru_mapper(x:core:main)
#> 2026-03-17 17:06:40.536688: bru_input(bru_input) for (x)
#> 2026-03-17 17:06:40.543735: bru_input(bru_comp_list)
#> 2026-03-17 17:06:40.545132: bru_input.bru_comp(x)
#> 2026-03-17 17:06:40.546464: bru_input.bm_pipe(x)
#> 2026-03-17 17:06:40.547957: bru_input.bm_multi(x:core)
#> 2026-03-17 17:06:40.549436: bru_input.bru_mapper(x:core:main)
#> 2026-03-17 17:06:40.550792: bru_input(bru_input) for (x)
#> 2026-03-17 17:06:44.498042: bru_input(bru_input) for (LABEL)
#> 2026-03-17 17:06:46.129612: bru_input_text(bru_input) for (LABEL)
#> 2026-03-17 17:06:46.141791: bru_input.bru_comp(x)
#> 2026-03-17 17:06:46.142996: bru_input_text.bm_pipe(x)
#> 2026-03-17 17:06:46.144361: bru_input_text.bm_multi(x:core)
#> 2026-03-17 17:06:46.145597: bru_input_text.bru_mapper(x:core:main)
#> 2026-03-17 17:06:46.146655: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-03-17 17:06:20.156394: inlabru loaded
#> 2026-03-17 17:06:20.157068: Clear override options
#> 2026-03-17 17:06:31.201399: bru: Preprocessing
#> 2026-03-17 17:06:31.322804: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:31.848389: bru: Preprocessing
#> 2026-03-17 17:06:31.97431: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:32.544444: bru: Preprocessing
#> 2026-03-17 17:06:32.636144: iinla: Iteration 1 [max: 10]
#> 2026-03-17 17:06:32.959145: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-17 17:06:32.998358: iinla: Iteration 2 [max: 10]
#> 2026-03-17 17:06:33.609971: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-17 17:06:33.641016: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:33.643607: iinla: Iteration 3 [max: 10]
#> 2026-03-17 17:06:33.945985: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-17 17:06:33.974806: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:33.977336: iinla: Iteration 4 [max: 10]
#> 2026-03-17 17:06:34.314698: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-17 17:06:34.315997: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-17 17:06:34.318651: iinla: Iteration 5 [max: 10]
#> 2026-03-17 17:06:35.736171: bru: Preprocessing
#> 2026-03-17 17:06:35.803675: iinla: Iteration 1 [max: 1]
#> 2026-03-17 17:06:40.508297: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-03-17 17:06:20.156394: inlabru loaded (level 1)
#> 2026-03-17 17:06:20.157068: Clear override options (level 1)
#> 2026-03-17 17:06:31.201399: bru: Preprocessing (level 1)
#> 2026-03-17 17:06:31.216795: Evaluate component inputs for each observation model (level 3)
#> 2026-03-17 17:06:31.218247: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:31.219739: bru_input.bru_comp(x) (level 4)
#> 2026-03-17 17:06:31.221266: bru_input.bm_pipe(x) (level 5)
#> 2026-03-17 17:06:31.222853: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-17 17:06:31.224416: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-17 17:06:31.226069: bru_input(bru_input) for (x) (level 5)
#> 2026-03-17 17:06:31.234607: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-17 17:06:31.236053: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-17 17:06:31.237637: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-17 17:06:31.245465: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-17 17:06:31.247645: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-17 17:06:31.265759: iinla: Start (level 3)
#> 2026-03-17 17:06:31.26712: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:31.268481: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:31.270078: Linearise component 'x' (level 4)
#> 2026-03-17 17:06:31.273263: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:31.276008: iinla: Evaluate component simplifications (level 3)
#> 2026-03-17 17:06:31.2773: Simplify component mappers for each observation model (level 3)
#> 2026-03-17 17:06:31.278807: Simplify component 'x' (level 4)
#> 2026-03-17 17:06:31.281889: Simplify component 'Intercept' (level 4)
#> 2026-03-17 17:06:31.284883: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:31.298658: iinla: Construct inla stack (level 3)
#> 2026-03-17 17:06:31.321225: iinla: Model initialisation completed (level 3)
#> 2026-03-17 17:06:31.322804: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-17 17:06:31.823737: iinla: Computation completed (level 3)
#> 2026-03-17 17:06:31.848389: bru: Preprocessing (level 1)
#> 2026-03-17 17:06:31.857826: Evaluate component inputs for each observation model (level 3)
#> 2026-03-17 17:06:31.859114: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:31.860533: bru_input.bru_comp(x) (level 4)
#> 2026-03-17 17:06:31.861895: bru_input.bm_pipe(x) (level 5)
#> 2026-03-17 17:06:31.863391: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-17 17:06:31.864852: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-17 17:06:31.86619: bru_input(bru_input) for (x) (level 5)
#> 2026-03-17 17:06:31.874365: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-17 17:06:31.87572: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-17 17:06:31.877203: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-17 17:06:31.878671: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-17 17:06:31.879977: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-17 17:06:31.932895: iinla: Start (level 3)
#> 2026-03-17 17:06:31.934892: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:31.936192: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:31.937638: Linearise component 'x' (level 4)
#> 2026-03-17 17:06:31.940691: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:31.943579: iinla: Evaluate component simplifications (level 3)
#> 2026-03-17 17:06:31.944859: Simplify component mappers for each observation model (level 3)
#> 2026-03-17 17:06:31.946391: Simplify component 'x' (level 4)
#> 2026-03-17 17:06:31.949525: Simplify component 'Intercept' (level 4)
#> 2026-03-17 17:06:31.952706: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:31.959873: iinla: Construct inla stack (level 3)
#> 2026-03-17 17:06:31.972801: iinla: Model initialisation completed (level 3)
#> 2026-03-17 17:06:31.97431: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-17 17:06:32.52049: iinla: Computation completed (level 3)
#> 2026-03-17 17:06:32.544444: bru: Preprocessing (level 1)
#> 2026-03-17 17:06:32.553502: Evaluate component inputs for each observation model (level 3)
#> 2026-03-17 17:06:32.55478: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:32.556175: bru_input.bru_comp(z) (level 4)
#> 2026-03-17 17:06:32.5575: bru_input.bm_pipe(z) (level 5)
#> 2026-03-17 17:06:32.559045: bru_input.bm_multi(z:core) (level 5)
#> 2026-03-17 17:06:32.56068: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-03-17 17:06:32.562189: bru_input(bru_input) for (z) (level 5)
#> 2026-03-17 17:06:32.570827: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-17 17:06:32.572312: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-17 17:06:32.57389: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-17 17:06:32.575423: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-17 17:06:32.576743: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-17 17:06:32.590775: iinla: Start (level 3)
#> 2026-03-17 17:06:32.591982: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:32.593173: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:32.594534: Linearise component 'z' (level 4)
#> 2026-03-17 17:06:32.59773: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:32.600619: iinla: Evaluate component simplifications (level 3)
#> 2026-03-17 17:06:32.601833: Simplify component mappers for each observation model (level 3)
#> 2026-03-17 17:06:32.603228: Simplify component 'z' (level 4)
#> 2026-03-17 17:06:32.606257: Simplify component 'Intercept' (level 4)
#> 2026-03-17 17:06:32.609296: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:32.612443: Linearise with respect to component 'z' (level 5)
#> 2026-03-17 17:06:32.617728: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-17 17:06:32.621058: iinla: Construct inla stack (level 3)
#> 2026-03-17 17:06:32.634585: iinla: Model initialisation completed (level 3)
#> 2026-03-17 17:06:32.636144: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-03-17 17:06:32.946051: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9) (level 3)
#> 2026-03-17 17:06:32.949921: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9) (level 3)
#> 2026-03-17 17:06:32.955009: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 3)
#> 2026-03-17 17:06:32.957121: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-03-17 17:06:32.959145: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 2)
#> 2026-03-17 17:06:32.96156: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:32.963266: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:32.965211: Linearise component 'z' (level 4)
#> 2026-03-17 17:06:32.968929: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:32.972513: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:32.976115: Linearise with respect to component 'z' (level 5)
#> 2026-03-17 17:06:32.981164: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-17 17:06:32.998358: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-03-17 17:06:33.600226: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-03-17 17:06:33.603286: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-03-17 17:06:33.606932: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-03-17 17:06:33.608516: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-03-17 17:06:33.609971: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-03-17 17:06:33.611748: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:33.61291: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:33.614369: Linearise component 'z' (level 4)
#> 2026-03-17 17:06:33.618281: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:33.62201: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:33.624757: Linearise with respect to component 'z' (level 5)
#> 2026-03-17 17:06:33.628476: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-17 17:06:33.641016: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-17 17:06:33.643607: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-03-17 17:06:33.936275: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-03-17 17:06:33.939322: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-03-17 17:06:33.942927: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-03-17 17:06:33.944477: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-03-17 17:06:33.945985: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-03-17 17:06:33.947769: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:33.948999: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:33.950429: Linearise component 'z' (level 4)
#> 2026-03-17 17:06:33.95344: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:33.956351: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:33.958952: Linearise with respect to component 'z' (level 5)
#> 2026-03-17 17:06:33.962606: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-17 17:06:33.974806: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-17 17:06:33.977336: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-03-17 17:06:34.276632: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-03-17 17:06:34.279712: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-03-17 17:06:34.283556: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-03-17 17:06:34.28513: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-03-17 17:06:34.28694: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:34.288177: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:34.289582: Linearise component 'z' (level 4)
#> 2026-03-17 17:06:34.292601: Linearise component 'Intercept' (level 4)
#> 2026-03-17 17:06:34.295525: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:34.29828: Linearise with respect to component 'z' (level 5)
#> 2026-03-17 17:06:34.302009: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-17 17:06:34.314698: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-17 17:06:34.315997: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-03-17 17:06:34.318651: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-03-17 17:06:34.625172: iinla: Computation completed (level 3)
#> 2026-03-17 17:06:35.736171: bru: Preprocessing (level 1)
#> 2026-03-17 17:06:35.746271: Evaluate component inputs for each observation model (level 3)
#> 2026-03-17 17:06:35.747673: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:35.749063: bru_input.bru_comp(field) (level 4)
#> 2026-03-17 17:06:35.750481: bru_input.bm_pipe(field) (level 5)
#> 2026-03-17 17:06:35.751993: bru_input.bm_multi(field:core) (level 5)
#> 2026-03-17 17:06:35.753498: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-03-17 17:06:35.754802: bru_input(bru_input) for (field) (level 5)
#> 2026-03-17 17:06:35.768153: iinla: Start (level 3)
#> 2026-03-17 17:06:35.769341: iinla: Evaluate component linearisations (level 3)
#> 2026-03-17 17:06:35.770501: Linearise components for each observation model (level 3)
#> 2026-03-17 17:06:35.77184: Linearise component 'field' (level 4)
#> 2026-03-17 17:06:35.779322: iinla: Evaluate component simplifications (level 3)
#> 2026-03-17 17:06:35.780535: Simplify component mappers for each observation model (level 3)
#> 2026-03-17 17:06:35.781877: Simplify component 'field' (level 4)
#> 2026-03-17 17:06:35.788242: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-17 17:06:35.791713: iinla: Construct inla stack (level 3)
#> 2026-03-17 17:06:35.802281: iinla: Model initialisation completed (level 3)
#> 2026-03-17 17:06:35.803675: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-17 17:06:36.21119: iinla: Computation completed (level 3)
#> 2026-03-17 17:06:38.096132: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:40.508297: bru: Preprocessing (level 1)
#> 2026-03-17 17:06:40.521592: Evaluate component inputs for each observation model (level 3)
#> 2026-03-17 17:06:40.522926: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:40.524364: bru_input.bru_comp(x) (level 4)
#> 2026-03-17 17:06:40.525735: bru_input.bm_pipe(x) (level 5)
#> 2026-03-17 17:06:40.527246: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-17 17:06:40.535293: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-17 17:06:40.536688: bru_input(bru_input) for (x) (level 5)
#> 2026-03-17 17:06:40.543735: bru_input(bru_comp_list) (level 4)
#> 2026-03-17 17:06:40.545132: bru_input.bru_comp(x) (level 4)
#> 2026-03-17 17:06:40.546464: bru_input.bm_pipe(x) (level 5)
#> 2026-03-17 17:06:40.547957: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-17 17:06:40.549436: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-17 17:06:40.550792: bru_input(bru_input) for (x) (level 5)
#> 2026-03-17 17:06:44.498042: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-03-17 17:06:46.129612: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-03-17 17:06:46.141791: bru_input.bru_comp(x) (level 4)
#> 2026-03-17 17:06:46.142996: bru_input_text.bm_pipe(x) (level 5)
#> 2026-03-17 17:06:46.144361: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-03-17 17:06:46.145597: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-03-17 17:06:46.146655: bru_input_text(bru_input) for (x) (level 5)