Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-03-16 11:45:41.739845: inlabru loaded
#> 2026-03-16 11:45:41.740437: Clear override options
#> 2026-03-16 11:45:52.772186: bru: Preprocessing
#> 2026-03-16 11:45:52.887204: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:53.399963: bru: Preprocessing
#> 2026-03-16 11:45:53.522675: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:54.082607: bru: Preprocessing
#> 2026-03-16 11:45:54.169549: iinla: Iteration 1 [max: 10]
#> 2026-03-16 11:45:54.487758: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-16 11:45:54.526097: iinla: Iteration 2 [max: 10]
#> 2026-03-16 11:45:55.126138: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-16 11:45:55.153811: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.156291: iinla: Iteration 3 [max: 10]
#> 2026-03-16 11:45:55.455316: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-16 11:45:55.483523: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.486033: iinla: Iteration 4 [max: 10]
#> 2026-03-16 11:45:55.81338: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.814649: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-16 11:45:55.817189: iinla: Iteration 5 [max: 10]
#> 2026-03-16 11:45:57.232305: bru: Preprocessing
#> 2026-03-16 11:45:57.298415: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:46:02.338284: bru: Preprocessing
format(bru_log())
#> 2026-03-16 11:45:41.739845: inlabru loaded
#> 2026-03-16 11:45:41.740437: Clear override options
#> 2026-03-16 11:45:52.772186: bru: Preprocessing
#> 2026-03-16 11:45:52.786955: Evaluate component inputs for each observation model
#> 2026-03-16 11:45:52.788351: bru_input(bru_comp_list)
#> 2026-03-16 11:45:52.789855: bru_input.bru_comp(x)
#> 2026-03-16 11:45:52.791393: bru_input.bm_pipe(x)
#> 2026-03-16 11:45:52.792977: bru_input.bm_multi(x:core)
#> 2026-03-16 11:45:52.794512: bru_input.bru_mapper(x:core:main)
#> 2026-03-16 11:45:52.796144: bru_input(bru_input) for (x)
#> 2026-03-16 11:45:52.803575: bru_input.bru_comp(Intercept)
#> 2026-03-16 11:45:52.804977: bru_input.bm_pipe(Intercept)
#> 2026-03-16 11:45:52.806525: bru_input.bm_multi(Intercept:core)
#> 2026-03-16 11:45:52.813127: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-16 11:45:52.81523: bru_input(bru_input) for (Intercept)
#> 2026-03-16 11:45:52.83154: iinla: Start
#> 2026-03-16 11:45:52.832848: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:52.834176: Linearise components for each observation model
#> 2026-03-16 11:45:52.835718: Linearise component 'x'
#> 2026-03-16 11:45:52.838773: Linearise component 'Intercept'
#> 2026-03-16 11:45:52.841545: iinla: Evaluate component simplifications
#> 2026-03-16 11:45:52.842819: Simplify component mappers for each observation model
#> 2026-03-16 11:45:52.844337: Simplify component 'x'
#> 2026-03-16 11:45:52.847436: Simplify component 'Intercept'
#> 2026-03-16 11:45:52.850461: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:52.863711: iinla: Construct inla stack
#> 2026-03-16 11:45:52.885686: iinla: Model initialisation completed
#> 2026-03-16 11:45:52.887204: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:53.376029: iinla: Computation completed
#> 2026-03-16 11:45:53.399963: bru: Preprocessing
#> 2026-03-16 11:45:53.40901: Evaluate component inputs for each observation model
#> 2026-03-16 11:45:53.410275: bru_input(bru_comp_list)
#> 2026-03-16 11:45:53.411666: bru_input.bru_comp(x)
#> 2026-03-16 11:45:53.413101: bru_input.bm_pipe(x)
#> 2026-03-16 11:45:53.414595: bru_input.bm_multi(x:core)
#> 2026-03-16 11:45:53.416116: bru_input.bru_mapper(x:core:main)
#> 2026-03-16 11:45:53.417979: bru_input(bru_input) for (x)
#> 2026-03-16 11:45:53.42504: bru_input.bru_comp(Intercept)
#> 2026-03-16 11:45:53.426425: bru_input.bm_pipe(Intercept)
#> 2026-03-16 11:45:53.427941: bru_input.bm_multi(Intercept:core)
#> 2026-03-16 11:45:53.429447: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-16 11:45:53.430801: bru_input(bru_input) for (Intercept)
#> 2026-03-16 11:45:53.482181: iinla: Start
#> 2026-03-16 11:45:53.484114: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:53.485482: Linearise components for each observation model
#> 2026-03-16 11:45:53.486988: Linearise component 'x'
#> 2026-03-16 11:45:53.490102: Linearise component 'Intercept'
#> 2026-03-16 11:45:53.493018: iinla: Evaluate component simplifications
#> 2026-03-16 11:45:53.494277: Simplify component mappers for each observation model
#> 2026-03-16 11:45:53.495739: Simplify component 'x'
#> 2026-03-16 11:45:53.498796: Simplify component 'Intercept'
#> 2026-03-16 11:45:53.501896: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:53.508665: iinla: Construct inla stack
#> 2026-03-16 11:45:53.521213: iinla: Model initialisation completed
#> 2026-03-16 11:45:53.522675: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:54.059268: iinla: Computation completed
#> 2026-03-16 11:45:54.082607: bru: Preprocessing
#> 2026-03-16 11:45:54.091458: Evaluate component inputs for each observation model
#> 2026-03-16 11:45:54.092721: bru_input(bru_comp_list)
#> 2026-03-16 11:45:54.094065: bru_input.bru_comp(z)
#> 2026-03-16 11:45:54.095413: bru_input.bm_pipe(z)
#> 2026-03-16 11:45:54.0969: bru_input.bm_multi(z:core)
#> 2026-03-16 11:45:54.0985: bru_input.bru_mapper(z:core:main)
#> 2026-03-16 11:45:54.099894: bru_input(bru_input) for (z)
#> 2026-03-16 11:45:54.10714: bru_input.bru_comp(Intercept)
#> 2026-03-16 11:45:54.108563: bru_input.bm_pipe(Intercept)
#> 2026-03-16 11:45:54.110128: bru_input.bm_multi(Intercept:core)
#> 2026-03-16 11:45:54.111592: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-16 11:45:54.112942: bru_input(bru_input) for (Intercept)
#> 2026-03-16 11:45:54.1257: iinla: Start
#> 2026-03-16 11:45:54.126894: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:54.128089: Linearise components for each observation model
#> 2026-03-16 11:45:54.129479: Linearise component 'z'
#> 2026-03-16 11:45:54.132423: Linearise component 'Intercept'
#> 2026-03-16 11:45:54.135217: iinla: Evaluate component simplifications
#> 2026-03-16 11:45:54.136419: Simplify component mappers for each observation model
#> 2026-03-16 11:45:54.137801: Simplify component 'z'
#> 2026-03-16 11:45:54.140828: Simplify component 'Intercept'
#> 2026-03-16 11:45:54.143884: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:54.147012: Linearise with respect to component 'z'
#> 2026-03-16 11:45:54.152331: Linearise with respect to component 'Intercept'
#> 2026-03-16 11:45:54.155649: iinla: Construct inla stack
#> 2026-03-16 11:45:54.168084: iinla: Model initialisation completed
#> 2026-03-16 11:45:54.169549: iinla: Iteration 1 [max: 10]
#> 2026-03-16 11:45:54.474831: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9)
#> 2026-03-16 11:45:54.478812: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9)
#> 2026-03-16 11:45:54.483592: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-16 11:45:54.485687: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-03-16 11:45:54.487758: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-16 11:45:54.490179: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:54.491859: Linearise components for each observation model
#> 2026-03-16 11:45:54.493814: Linearise component 'z'
#> 2026-03-16 11:45:54.49745: Linearise component 'Intercept'
#> 2026-03-16 11:45:54.500954: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:54.504314: Linearise with respect to component 'z'
#> 2026-03-16 11:45:54.509116: Linearise with respect to component 'Intercept'
#> 2026-03-16 11:45:54.526097: iinla: Iteration 2 [max: 10]
#> 2026-03-16 11:45:55.116562: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-03-16 11:45:55.119615: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-03-16 11:45:55.123215: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-16 11:45:55.124683: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-03-16 11:45:55.126138: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-16 11:45:55.127856: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:55.129037: Linearise components for each observation model
#> 2026-03-16 11:45:55.130388: Linearise component 'z'
#> 2026-03-16 11:45:55.133249: Linearise component 'Intercept'
#> 2026-03-16 11:45:55.136006: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:55.138558: Linearise with respect to component 'z'
#> 2026-03-16 11:45:55.14206: Linearise with respect to component 'Intercept'
#> 2026-03-16 11:45:55.153811: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.156291: iinla: Iteration 3 [max: 10]
#> 2026-03-16 11:45:55.445675: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-03-16 11:45:55.448642: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-03-16 11:45:55.452142: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-16 11:45:55.453787: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-03-16 11:45:55.455316: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-16 11:45:55.457117: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:55.458313: Linearise components for each observation model
#> 2026-03-16 11:45:55.459717: Linearise component 'z'
#> 2026-03-16 11:45:55.462622: Linearise component 'Intercept'
#> 2026-03-16 11:45:55.465454: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:55.468048: Linearise with respect to component 'z'
#> 2026-03-16 11:45:55.471659: Linearise with respect to component 'Intercept'
#> 2026-03-16 11:45:55.483523: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.486033: iinla: Iteration 4 [max: 10]
#> 2026-03-16 11:45:55.776537: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-03-16 11:45:55.779484: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-03-16 11:45:55.783144: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-03-16 11:45:55.784668: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-03-16 11:45:55.786469: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:55.787686: Linearise components for each observation model
#> 2026-03-16 11:45:55.789112: Linearise component 'z'
#> 2026-03-16 11:45:55.792058: Linearise component 'Intercept'
#> 2026-03-16 11:45:55.794878: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:55.797545: Linearise with respect to component 'z'
#> 2026-03-16 11:45:55.801229: Linearise with respect to component 'Intercept'
#> 2026-03-16 11:45:55.81338: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.814649: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-16 11:45:55.817189: iinla: Iteration 5 [max: 10]
#> 2026-03-16 11:45:56.127987: iinla: Computation completed
#> 2026-03-16 11:45:57.232305: bru: Preprocessing
#> 2026-03-16 11:45:57.242309: Evaluate component inputs for each observation model
#> 2026-03-16 11:45:57.243615: bru_input(bru_comp_list)
#> 2026-03-16 11:45:57.245086: bru_input.bru_comp(field)
#> 2026-03-16 11:45:57.246439: bru_input.bm_pipe(field)
#> 2026-03-16 11:45:57.247923: bru_input.bm_multi(field:core)
#> 2026-03-16 11:45:57.24943: bru_input.bru_mapper(field:core:main)
#> 2026-03-16 11:45:57.250752: bru_input(bru_input) for (field)
#> 2026-03-16 11:45:57.263572: iinla: Start
#> 2026-03-16 11:45:57.264746: iinla: Evaluate component linearisations
#> 2026-03-16 11:45:57.265912: Linearise components for each observation model
#> 2026-03-16 11:45:57.267263: Linearise component 'field'
#> 2026-03-16 11:45:57.274497: iinla: Evaluate component simplifications
#> 2026-03-16 11:45:57.275807: Simplify component mappers for each observation model
#> 2026-03-16 11:45:57.277204: Simplify component 'field'
#> 2026-03-16 11:45:57.28346: iinla: Evaluate predictor linearisation
#> 2026-03-16 11:45:57.286869: iinla: Construct inla stack
#> 2026-03-16 11:45:57.297048: iinla: Model initialisation completed
#> 2026-03-16 11:45:57.298415: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:57.70062: iinla: Computation completed
#> 2026-03-16 11:45:59.585841: bru_input(bru_comp_list)
#> 2026-03-16 11:46:02.338284: bru: Preprocessing
#> 2026-03-16 11:46:02.351174: Evaluate component inputs for each observation model
#> 2026-03-16 11:46:02.352438: bru_input(bru_comp_list)
#> 2026-03-16 11:46:02.353809: bru_input.bru_comp(x)
#> 2026-03-16 11:46:02.35519: bru_input.bm_pipe(x)
#> 2026-03-16 11:46:02.356693: bru_input.bm_multi(x:core)
#> 2026-03-16 11:46:02.364459: bru_input.bru_mapper(x:core:main)
#> 2026-03-16 11:46:02.365864: bru_input(bru_input) for (x)
#> 2026-03-16 11:46:02.372658: bru_input(bru_comp_list)
#> 2026-03-16 11:46:02.374097: bru_input.bru_comp(x)
#> 2026-03-16 11:46:02.375455: bru_input.bm_pipe(x)
#> 2026-03-16 11:46:02.376982: bru_input.bm_multi(x:core)
#> 2026-03-16 11:46:02.378475: bru_input.bru_mapper(x:core:main)
#> 2026-03-16 11:46:02.379823: bru_input(bru_input) for (x)
#> 2026-03-16 11:46:06.300953: bru_input(bru_input) for (LABEL)
#> 2026-03-16 11:46:07.975361: bru_input_text(bru_input) for (LABEL)
#> 2026-03-16 11:46:07.987001: bru_input.bru_comp(x)
#> 2026-03-16 11:46:07.98812: bru_input_text.bm_pipe(x)
#> 2026-03-16 11:46:07.989344: bru_input_text.bm_multi(x:core)
#> 2026-03-16 11:46:07.990585: bru_input_text.bru_mapper(x:core:main)
#> 2026-03-16 11:46:07.991645: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-03-16 11:45:41.739845: inlabru loaded
#> 2026-03-16 11:45:41.740437: Clear override options
#> 2026-03-16 11:45:52.772186: bru: Preprocessing
#> 2026-03-16 11:45:52.887204: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:53.399963: bru: Preprocessing
#> 2026-03-16 11:45:53.522675: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:45:54.082607: bru: Preprocessing
#> 2026-03-16 11:45:54.169549: iinla: Iteration 1 [max: 10]
#> 2026-03-16 11:45:54.487758: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-16 11:45:54.526097: iinla: Iteration 2 [max: 10]
#> 2026-03-16 11:45:55.126138: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-16 11:45:55.153811: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.156291: iinla: Iteration 3 [max: 10]
#> 2026-03-16 11:45:55.455316: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-16 11:45:55.483523: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.486033: iinla: Iteration 4 [max: 10]
#> 2026-03-16 11:45:55.81338: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-16 11:45:55.814649: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-16 11:45:55.817189: iinla: Iteration 5 [max: 10]
#> 2026-03-16 11:45:57.232305: bru: Preprocessing
#> 2026-03-16 11:45:57.298415: iinla: Iteration 1 [max: 1]
#> 2026-03-16 11:46:02.338284: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-03-16 11:45:41.739845: inlabru loaded (level 1)
#> 2026-03-16 11:45:41.740437: Clear override options (level 1)
#> 2026-03-16 11:45:52.772186: bru: Preprocessing (level 1)
#> 2026-03-16 11:45:52.786955: Evaluate component inputs for each observation model (level 3)
#> 2026-03-16 11:45:52.788351: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:45:52.789855: bru_input.bru_comp(x) (level 4)
#> 2026-03-16 11:45:52.791393: bru_input.bm_pipe(x) (level 5)
#> 2026-03-16 11:45:52.792977: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-16 11:45:52.794512: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-16 11:45:52.796144: bru_input(bru_input) for (x) (level 5)
#> 2026-03-16 11:45:52.803575: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-16 11:45:52.804977: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-16 11:45:52.806525: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-16 11:45:52.813127: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-16 11:45:52.81523: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-16 11:45:52.83154: iinla: Start (level 3)
#> 2026-03-16 11:45:52.832848: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:52.834176: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:52.835718: Linearise component 'x' (level 4)
#> 2026-03-16 11:45:52.838773: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:52.841545: iinla: Evaluate component simplifications (level 3)
#> 2026-03-16 11:45:52.842819: Simplify component mappers for each observation model (level 3)
#> 2026-03-16 11:45:52.844337: Simplify component 'x' (level 4)
#> 2026-03-16 11:45:52.847436: Simplify component 'Intercept' (level 4)
#> 2026-03-16 11:45:52.850461: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:52.863711: iinla: Construct inla stack (level 3)
#> 2026-03-16 11:45:52.885686: iinla: Model initialisation completed (level 3)
#> 2026-03-16 11:45:52.887204: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-16 11:45:53.376029: iinla: Computation completed (level 3)
#> 2026-03-16 11:45:53.399963: bru: Preprocessing (level 1)
#> 2026-03-16 11:45:53.40901: Evaluate component inputs for each observation model (level 3)
#> 2026-03-16 11:45:53.410275: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:45:53.411666: bru_input.bru_comp(x) (level 4)
#> 2026-03-16 11:45:53.413101: bru_input.bm_pipe(x) (level 5)
#> 2026-03-16 11:45:53.414595: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-16 11:45:53.416116: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-16 11:45:53.417979: bru_input(bru_input) for (x) (level 5)
#> 2026-03-16 11:45:53.42504: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-16 11:45:53.426425: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-16 11:45:53.427941: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-16 11:45:53.429447: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-16 11:45:53.430801: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-16 11:45:53.482181: iinla: Start (level 3)
#> 2026-03-16 11:45:53.484114: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:53.485482: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:53.486988: Linearise component 'x' (level 4)
#> 2026-03-16 11:45:53.490102: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:53.493018: iinla: Evaluate component simplifications (level 3)
#> 2026-03-16 11:45:53.494277: Simplify component mappers for each observation model (level 3)
#> 2026-03-16 11:45:53.495739: Simplify component 'x' (level 4)
#> 2026-03-16 11:45:53.498796: Simplify component 'Intercept' (level 4)
#> 2026-03-16 11:45:53.501896: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:53.508665: iinla: Construct inla stack (level 3)
#> 2026-03-16 11:45:53.521213: iinla: Model initialisation completed (level 3)
#> 2026-03-16 11:45:53.522675: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-16 11:45:54.059268: iinla: Computation completed (level 3)
#> 2026-03-16 11:45:54.082607: bru: Preprocessing (level 1)
#> 2026-03-16 11:45:54.091458: Evaluate component inputs for each observation model (level 3)
#> 2026-03-16 11:45:54.092721: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:45:54.094065: bru_input.bru_comp(z) (level 4)
#> 2026-03-16 11:45:54.095413: bru_input.bm_pipe(z) (level 5)
#> 2026-03-16 11:45:54.0969: bru_input.bm_multi(z:core) (level 5)
#> 2026-03-16 11:45:54.0985: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-03-16 11:45:54.099894: bru_input(bru_input) for (z) (level 5)
#> 2026-03-16 11:45:54.10714: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-16 11:45:54.108563: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-16 11:45:54.110128: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-16 11:45:54.111592: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-16 11:45:54.112942: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-16 11:45:54.1257: iinla: Start (level 3)
#> 2026-03-16 11:45:54.126894: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:54.128089: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:54.129479: Linearise component 'z' (level 4)
#> 2026-03-16 11:45:54.132423: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:54.135217: iinla: Evaluate component simplifications (level 3)
#> 2026-03-16 11:45:54.136419: Simplify component mappers for each observation model (level 3)
#> 2026-03-16 11:45:54.137801: Simplify component 'z' (level 4)
#> 2026-03-16 11:45:54.140828: Simplify component 'Intercept' (level 4)
#> 2026-03-16 11:45:54.143884: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:54.147012: Linearise with respect to component 'z' (level 5)
#> 2026-03-16 11:45:54.152331: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-16 11:45:54.155649: iinla: Construct inla stack (level 3)
#> 2026-03-16 11:45:54.168084: iinla: Model initialisation completed (level 3)
#> 2026-03-16 11:45:54.169549: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-03-16 11:45:54.474831: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9) (level 3)
#> 2026-03-16 11:45:54.478812: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9) (level 3)
#> 2026-03-16 11:45:54.483592: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 3)
#> 2026-03-16 11:45:54.485687: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-03-16 11:45:54.487758: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 2)
#> 2026-03-16 11:45:54.490179: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:54.491859: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:54.493814: Linearise component 'z' (level 4)
#> 2026-03-16 11:45:54.49745: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:54.500954: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:54.504314: Linearise with respect to component 'z' (level 5)
#> 2026-03-16 11:45:54.509116: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-16 11:45:54.526097: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-03-16 11:45:55.116562: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-03-16 11:45:55.119615: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-03-16 11:45:55.123215: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-03-16 11:45:55.124683: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-03-16 11:45:55.126138: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-03-16 11:45:55.127856: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:55.129037: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:55.130388: Linearise component 'z' (level 4)
#> 2026-03-16 11:45:55.133249: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:55.136006: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:55.138558: Linearise with respect to component 'z' (level 5)
#> 2026-03-16 11:45:55.14206: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-16 11:45:55.153811: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-16 11:45:55.156291: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-03-16 11:45:55.445675: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-03-16 11:45:55.448642: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-03-16 11:45:55.452142: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-03-16 11:45:55.453787: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-03-16 11:45:55.455316: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-03-16 11:45:55.457117: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:55.458313: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:55.459717: Linearise component 'z' (level 4)
#> 2026-03-16 11:45:55.462622: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:55.465454: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:55.468048: Linearise with respect to component 'z' (level 5)
#> 2026-03-16 11:45:55.471659: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-16 11:45:55.483523: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-16 11:45:55.486033: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-03-16 11:45:55.776537: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-03-16 11:45:55.779484: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-03-16 11:45:55.783144: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-03-16 11:45:55.784668: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-03-16 11:45:55.786469: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:55.787686: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:55.789112: Linearise component 'z' (level 4)
#> 2026-03-16 11:45:55.792058: Linearise component 'Intercept' (level 4)
#> 2026-03-16 11:45:55.794878: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:55.797545: Linearise with respect to component 'z' (level 5)
#> 2026-03-16 11:45:55.801229: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-16 11:45:55.81338: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-16 11:45:55.814649: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-03-16 11:45:55.817189: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-03-16 11:45:56.127987: iinla: Computation completed (level 3)
#> 2026-03-16 11:45:57.232305: bru: Preprocessing (level 1)
#> 2026-03-16 11:45:57.242309: Evaluate component inputs for each observation model (level 3)
#> 2026-03-16 11:45:57.243615: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:45:57.245086: bru_input.bru_comp(field) (level 4)
#> 2026-03-16 11:45:57.246439: bru_input.bm_pipe(field) (level 5)
#> 2026-03-16 11:45:57.247923: bru_input.bm_multi(field:core) (level 5)
#> 2026-03-16 11:45:57.24943: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-03-16 11:45:57.250752: bru_input(bru_input) for (field) (level 5)
#> 2026-03-16 11:45:57.263572: iinla: Start (level 3)
#> 2026-03-16 11:45:57.264746: iinla: Evaluate component linearisations (level 3)
#> 2026-03-16 11:45:57.265912: Linearise components for each observation model (level 3)
#> 2026-03-16 11:45:57.267263: Linearise component 'field' (level 4)
#> 2026-03-16 11:45:57.274497: iinla: Evaluate component simplifications (level 3)
#> 2026-03-16 11:45:57.275807: Simplify component mappers for each observation model (level 3)
#> 2026-03-16 11:45:57.277204: Simplify component 'field' (level 4)
#> 2026-03-16 11:45:57.28346: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-16 11:45:57.286869: iinla: Construct inla stack (level 3)
#> 2026-03-16 11:45:57.297048: iinla: Model initialisation completed (level 3)
#> 2026-03-16 11:45:57.298415: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-16 11:45:57.70062: iinla: Computation completed (level 3)
#> 2026-03-16 11:45:59.585841: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:46:02.338284: bru: Preprocessing (level 1)
#> 2026-03-16 11:46:02.351174: Evaluate component inputs for each observation model (level 3)
#> 2026-03-16 11:46:02.352438: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:46:02.353809: bru_input.bru_comp(x) (level 4)
#> 2026-03-16 11:46:02.35519: bru_input.bm_pipe(x) (level 5)
#> 2026-03-16 11:46:02.356693: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-16 11:46:02.364459: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-16 11:46:02.365864: bru_input(bru_input) for (x) (level 5)
#> 2026-03-16 11:46:02.372658: bru_input(bru_comp_list) (level 4)
#> 2026-03-16 11:46:02.374097: bru_input.bru_comp(x) (level 4)
#> 2026-03-16 11:46:02.375455: bru_input.bm_pipe(x) (level 5)
#> 2026-03-16 11:46:02.376982: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-16 11:46:02.378475: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-16 11:46:02.379823: bru_input(bru_input) for (x) (level 5)
#> 2026-03-16 11:46:06.300953: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-03-16 11:46:07.975361: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-03-16 11:46:07.987001: bru_input.bru_comp(x) (level 4)
#> 2026-03-16 11:46:07.98812: bru_input_text.bm_pipe(x) (level 5)
#> 2026-03-16 11:46:07.989344: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-03-16 11:46:07.990585: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-03-16 11:46:07.991645: bru_input_text(bru_input) for (x) (level 5)