Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-03-09 14:33:50.40882: inlabru loaded
#> 2026-03-09 14:33:50.409328: Clear override options
#> 2026-03-09 14:34:01.551305: bru: Preprocessing
#> 2026-03-09 14:34:01.66194: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:02.176262: bru: Preprocessing
#> 2026-03-09 14:34:02.258206: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:02.589226: bru: Preprocessing
#> 2026-03-09 14:34:02.679622: iinla: Iteration 1 [max: 10]
#> 2026-03-09 14:34:02.98368: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-09 14:34:03.013554: iinla: Iteration 2 [max: 10]
#> 2026-03-09 14:34:03.613089: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-09 14:34:03.641179: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:03.643648: iinla: Iteration 3 [max: 10]
#> 2026-03-09 14:34:03.946752: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-09 14:34:03.975476: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:03.978126: iinla: Iteration 4 [max: 10]
#> 2026-03-09 14:34:04.317062: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:04.318263: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-09 14:34:04.320687: iinla: Iteration 5 [max: 10]
#> 2026-03-09 14:34:05.692771: bru: Preprocessing
#> 2026-03-09 14:34:05.76116: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:10.551584: bru: Preprocessing
format(bru_log())
#> 2026-03-09 14:33:50.40882: inlabru loaded
#> 2026-03-09 14:33:50.409328: Clear override options
#> 2026-03-09 14:34:01.551305: bru: Preprocessing
#> 2026-03-09 14:34:01.566379: Evaluate component inputs for each observation model
#> 2026-03-09 14:34:01.56777: bru_input(bru_comp_list)
#> 2026-03-09 14:34:01.569183: bru_input.bru_comp(x)
#> 2026-03-09 14:34:01.570621: bru_input.bm_pipe(x)
#> 2026-03-09 14:34:01.572285: bru_input.bm_multi(x:core)
#> 2026-03-09 14:34:01.573867: bru_input.bru_mapper(x:core:main)
#> 2026-03-09 14:34:01.575608: bru_input(bru_input) for (x)
#> 2026-03-09 14:34:01.583377: bru_input.bru_comp(Intercept)
#> 2026-03-09 14:34:01.584784: bru_input.bm_pipe(Intercept)
#> 2026-03-09 14:34:01.586364: bru_input.bm_multi(Intercept:core)
#> 2026-03-09 14:34:01.587881: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-09 14:34:01.589386: bru_input(bru_input) for (Intercept)
#> 2026-03-09 14:34:01.605838: iinla: Start
#> 2026-03-09 14:34:01.607073: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:01.608284: Linearise components for each observation model
#> 2026-03-09 14:34:01.609767: Linearise component 'x'
#> 2026-03-09 14:34:01.612808: Linearise component 'Intercept'
#> 2026-03-09 14:34:01.615649: iinla: Evaluate component simplifications
#> 2026-03-09 14:34:01.61692: Simplify component mappers for each observation model
#> 2026-03-09 14:34:01.618437: Simplify component 'x'
#> 2026-03-09 14:34:01.621616: Simplify component 'Intercept'
#> 2026-03-09 14:34:01.624746: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:01.639068: iinla: Construct inla stack
#> 2026-03-09 14:34:01.660459: iinla: Model initialisation completed
#> 2026-03-09 14:34:01.66194: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:02.152158: iinla: Computation completed
#> 2026-03-09 14:34:02.176262: bru: Preprocessing
#> 2026-03-09 14:34:02.184951: Evaluate component inputs for each observation model
#> 2026-03-09 14:34:02.186266: bru_input(bru_comp_list)
#> 2026-03-09 14:34:02.187646: bru_input.bru_comp(x)
#> 2026-03-09 14:34:02.189024: bru_input.bm_pipe(x)
#> 2026-03-09 14:34:02.190547: bru_input.bm_multi(x:core)
#> 2026-03-09 14:34:02.19206: bru_input.bru_mapper(x:core:main)
#> 2026-03-09 14:34:02.193408: bru_input(bru_input) for (x)
#> 2026-03-09 14:34:02.200658: bru_input.bru_comp(Intercept)
#> 2026-03-09 14:34:02.202095: bru_input.bm_pipe(Intercept)
#> 2026-03-09 14:34:02.203615: bru_input.bm_multi(Intercept:core)
#> 2026-03-09 14:34:02.205111: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-09 14:34:02.206472: bru_input(bru_input) for (Intercept)
#> 2026-03-09 14:34:02.219744: iinla: Start
#> 2026-03-09 14:34:02.220945: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:02.22217: Linearise components for each observation model
#> 2026-03-09 14:34:02.223554: Linearise component 'x'
#> 2026-03-09 14:34:02.226435: Linearise component 'Intercept'
#> 2026-03-09 14:34:02.229145: iinla: Evaluate component simplifications
#> 2026-03-09 14:34:02.230382: Simplify component mappers for each observation model
#> 2026-03-09 14:34:02.231774: Simplify component 'x'
#> 2026-03-09 14:34:02.234696: Simplify component 'Intercept'
#> 2026-03-09 14:34:02.237637: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:02.244223: iinla: Construct inla stack
#> 2026-03-09 14:34:02.256756: iinla: Model initialisation completed
#> 2026-03-09 14:34:02.258206: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:02.565674: iinla: Computation completed
#> 2026-03-09 14:34:02.589226: bru: Preprocessing
#> 2026-03-09 14:34:02.598472: Evaluate component inputs for each observation model
#> 2026-03-09 14:34:02.599772: bru_input(bru_comp_list)
#> 2026-03-09 14:34:02.601173: bru_input.bru_comp(z)
#> 2026-03-09 14:34:02.602542: bru_input.bm_pipe(z)
#> 2026-03-09 14:34:02.604105: bru_input.bm_multi(z:core)
#> 2026-03-09 14:34:02.60559: bru_input.bru_mapper(z:core:main)
#> 2026-03-09 14:34:02.606939: bru_input(bru_input) for (z)
#> 2026-03-09 14:34:02.614736: bru_input.bru_comp(Intercept)
#> 2026-03-09 14:34:02.616178: bru_input.bm_pipe(Intercept)
#> 2026-03-09 14:34:02.617715: bru_input.bm_multi(Intercept:core)
#> 2026-03-09 14:34:02.619231: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-09 14:34:02.620594: bru_input(bru_input) for (Intercept)
#> 2026-03-09 14:34:02.634591: iinla: Start
#> 2026-03-09 14:34:02.635814: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:02.637034: Linearise components for each observation model
#> 2026-03-09 14:34:02.638462: Linearise component 'z'
#> 2026-03-09 14:34:02.641494: Linearise component 'Intercept'
#> 2026-03-09 14:34:02.644336: iinla: Evaluate component simplifications
#> 2026-03-09 14:34:02.645587: Simplify component mappers for each observation model
#> 2026-03-09 14:34:02.647097: Simplify component 'z'
#> 2026-03-09 14:34:02.650214: Simplify component 'Intercept'
#> 2026-03-09 14:34:02.653363: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:02.656568: Linearise with respect to component 'z'
#> 2026-03-09 14:34:02.662048: Linearise with respect to component 'Intercept'
#> 2026-03-09 14:34:02.665446: iinla: Construct inla stack
#> 2026-03-09 14:34:02.678137: iinla: Model initialisation completed
#> 2026-03-09 14:34:02.679622: iinla: Iteration 1 [max: 10]
#> 2026-03-09 14:34:02.974034: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9)
#> 2026-03-09 14:34:02.976949: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9)
#> 2026-03-09 14:34:02.980598: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-09 14:34:02.982176: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-03-09 14:34:02.98368: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-09 14:34:02.985523: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:02.986748: Linearise components for each observation model
#> 2026-03-09 14:34:02.988392: Linearise component 'z'
#> 2026-03-09 14:34:02.991341: Linearise component 'Intercept'
#> 2026-03-09 14:34:02.994138: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:02.996789: Linearise with respect to component 'z'
#> 2026-03-09 14:34:03.000413: Linearise with respect to component 'Intercept'
#> 2026-03-09 14:34:03.013554: iinla: Iteration 2 [max: 10]
#> 2026-03-09 14:34:03.603233: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-03-09 14:34:03.606406: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-03-09 14:34:03.610122: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-09 14:34:03.611643: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-03-09 14:34:03.613089: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-09 14:34:03.614795: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:03.615964: Linearise components for each observation model
#> 2026-03-09 14:34:03.617359: Linearise component 'z'
#> 2026-03-09 14:34:03.620251: Linearise component 'Intercept'
#> 2026-03-09 14:34:03.623026: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:03.625641: Linearise with respect to component 'z'
#> 2026-03-09 14:34:03.629204: Linearise with respect to component 'Intercept'
#> 2026-03-09 14:34:03.641179: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:03.643648: iinla: Iteration 3 [max: 10]
#> 2026-03-09 14:34:03.937171: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-03-09 14:34:03.940139: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-03-09 14:34:03.94377: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-09 14:34:03.945295: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-03-09 14:34:03.946752: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-09 14:34:03.948505: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:03.949676: Linearise components for each observation model
#> 2026-03-09 14:34:03.951062: Linearise component 'z'
#> 2026-03-09 14:34:03.953953: Linearise component 'Intercept'
#> 2026-03-09 14:34:03.956775: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:03.9594: Linearise with respect to component 'z'
#> 2026-03-09 14:34:03.96305: Linearise with respect to component 'Intercept'
#> 2026-03-09 14:34:03.975476: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:03.978126: iinla: Iteration 4 [max: 10]
#> 2026-03-09 14:34:04.280881: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-03-09 14:34:04.283755: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-03-09 14:34:04.287344: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-03-09 14:34:04.288827: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-03-09 14:34:04.290559: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:04.291714: Linearise components for each observation model
#> 2026-03-09 14:34:04.293108: Linearise component 'z'
#> 2026-03-09 14:34:04.296015: Linearise component 'Intercept'
#> 2026-03-09 14:34:04.298757: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:04.301362: Linearise with respect to component 'z'
#> 2026-03-09 14:34:04.304888: Linearise with respect to component 'Intercept'
#> 2026-03-09 14:34:04.317062: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:04.318263: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-09 14:34:04.320687: iinla: Iteration 5 [max: 10]
#> 2026-03-09 14:34:04.621532: iinla: Computation completed
#> 2026-03-09 14:34:05.692771: bru: Preprocessing
#> 2026-03-09 14:34:05.702253: Evaluate component inputs for each observation model
#> 2026-03-09 14:34:05.70349: bru_input(bru_comp_list)
#> 2026-03-09 14:34:05.704864: bru_input.bru_comp(field)
#> 2026-03-09 14:34:05.706266: bru_input.bm_pipe(field)
#> 2026-03-09 14:34:05.707838: bru_input.bm_multi(field:core)
#> 2026-03-09 14:34:05.709359: bru_input.bru_mapper(field:core:main)
#> 2026-03-09 14:34:05.710771: bru_input(bru_input) for (field)
#> 2026-03-09 14:34:05.725989: iinla: Start
#> 2026-03-09 14:34:05.727216: iinla: Evaluate component linearisations
#> 2026-03-09 14:34:05.728416: Linearise components for each observation model
#> 2026-03-09 14:34:05.729788: Linearise component 'field'
#> 2026-03-09 14:34:05.737179: iinla: Evaluate component simplifications
#> 2026-03-09 14:34:05.738401: Simplify component mappers for each observation model
#> 2026-03-09 14:34:05.739764: Simplify component 'field'
#> 2026-03-09 14:34:05.745959: iinla: Evaluate predictor linearisation
#> 2026-03-09 14:34:05.749426: iinla: Construct inla stack
#> 2026-03-09 14:34:05.759708: iinla: Model initialisation completed
#> 2026-03-09 14:34:05.76116: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:06.17614: iinla: Computation completed
#> 2026-03-09 14:34:08.092814: bru_input(bru_comp_list)
#> 2026-03-09 14:34:10.551584: bru: Preprocessing
#> 2026-03-09 14:34:10.564481: Evaluate component inputs for each observation model
#> 2026-03-09 14:34:10.565745: bru_input(bru_comp_list)
#> 2026-03-09 14:34:10.56717: bru_input.bru_comp(x)
#> 2026-03-09 14:34:10.568552: bru_input.bm_pipe(x)
#> 2026-03-09 14:34:10.570098: bru_input.bm_multi(x:core)
#> 2026-03-09 14:34:10.571615: bru_input.bru_mapper(x:core:main)
#> 2026-03-09 14:34:10.57298: bru_input(bru_input) for (x)
#> 2026-03-09 14:34:10.580294: bru_input(bru_comp_list)
#> 2026-03-09 14:34:10.587207: bru_input.bru_comp(x)
#> 2026-03-09 14:34:10.588949: bru_input.bm_pipe(x)
#> 2026-03-09 14:34:10.59059: bru_input.bm_multi(x:core)
#> 2026-03-09 14:34:10.592104: bru_input.bru_mapper(x:core:main)
#> 2026-03-09 14:34:10.593468: bru_input(bru_input) for (x)
#> 2026-03-09 14:34:15.240071: bru_input(bru_input) for (LABEL)
#> 2026-03-09 14:34:16.763779: bru_input_text(bru_input) for (LABEL)
#> 2026-03-09 14:34:16.775555: bru_input.bru_comp(x)
#> 2026-03-09 14:34:16.776701: bru_input_text.bm_pipe(x)
#> 2026-03-09 14:34:16.777983: bru_input_text.bm_multi(x:core)
#> 2026-03-09 14:34:16.779281: bru_input_text.bru_mapper(x:core:main)
#> 2026-03-09 14:34:16.780351: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-03-09 14:33:50.40882: inlabru loaded
#> 2026-03-09 14:33:50.409328: Clear override options
#> 2026-03-09 14:34:01.551305: bru: Preprocessing
#> 2026-03-09 14:34:01.66194: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:02.176262: bru: Preprocessing
#> 2026-03-09 14:34:02.258206: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:02.589226: bru: Preprocessing
#> 2026-03-09 14:34:02.679622: iinla: Iteration 1 [max: 10]
#> 2026-03-09 14:34:02.98368: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9)
#> 2026-03-09 14:34:03.013554: iinla: Iteration 2 [max: 10]
#> 2026-03-09 14:34:03.613089: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-03-09 14:34:03.641179: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:03.643648: iinla: Iteration 3 [max: 10]
#> 2026-03-09 14:34:03.946752: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-03-09 14:34:03.975476: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:03.978126: iinla: Iteration 4 [max: 10]
#> 2026-03-09 14:34:04.317062: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-09 14:34:04.318263: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-09 14:34:04.320687: iinla: Iteration 5 [max: 10]
#> 2026-03-09 14:34:05.692771: bru: Preprocessing
#> 2026-03-09 14:34:05.76116: iinla: Iteration 1 [max: 1]
#> 2026-03-09 14:34:10.551584: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-03-09 14:33:50.40882: inlabru loaded (level 1)
#> 2026-03-09 14:33:50.409328: Clear override options (level 1)
#> 2026-03-09 14:34:01.551305: bru: Preprocessing (level 1)
#> 2026-03-09 14:34:01.566379: Evaluate component inputs for each observation model (level 3)
#> 2026-03-09 14:34:01.56777: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:01.569183: bru_input.bru_comp(x) (level 4)
#> 2026-03-09 14:34:01.570621: bru_input.bm_pipe(x) (level 5)
#> 2026-03-09 14:34:01.572285: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-09 14:34:01.573867: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-09 14:34:01.575608: bru_input(bru_input) for (x) (level 5)
#> 2026-03-09 14:34:01.583377: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-09 14:34:01.584784: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-09 14:34:01.586364: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-09 14:34:01.587881: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-09 14:34:01.589386: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-09 14:34:01.605838: iinla: Start (level 3)
#> 2026-03-09 14:34:01.607073: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:01.608284: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:01.609767: Linearise component 'x' (level 4)
#> 2026-03-09 14:34:01.612808: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:01.615649: iinla: Evaluate component simplifications (level 3)
#> 2026-03-09 14:34:01.61692: Simplify component mappers for each observation model (level 3)
#> 2026-03-09 14:34:01.618437: Simplify component 'x' (level 4)
#> 2026-03-09 14:34:01.621616: Simplify component 'Intercept' (level 4)
#> 2026-03-09 14:34:01.624746: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:01.639068: iinla: Construct inla stack (level 3)
#> 2026-03-09 14:34:01.660459: iinla: Model initialisation completed (level 3)
#> 2026-03-09 14:34:01.66194: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-09 14:34:02.152158: iinla: Computation completed (level 3)
#> 2026-03-09 14:34:02.176262: bru: Preprocessing (level 1)
#> 2026-03-09 14:34:02.184951: Evaluate component inputs for each observation model (level 3)
#> 2026-03-09 14:34:02.186266: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:02.187646: bru_input.bru_comp(x) (level 4)
#> 2026-03-09 14:34:02.189024: bru_input.bm_pipe(x) (level 5)
#> 2026-03-09 14:34:02.190547: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-09 14:34:02.19206: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-09 14:34:02.193408: bru_input(bru_input) for (x) (level 5)
#> 2026-03-09 14:34:02.200658: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-09 14:34:02.202095: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-09 14:34:02.203615: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-09 14:34:02.205111: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-09 14:34:02.206472: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-09 14:34:02.219744: iinla: Start (level 3)
#> 2026-03-09 14:34:02.220945: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:02.22217: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:02.223554: Linearise component 'x' (level 4)
#> 2026-03-09 14:34:02.226435: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:02.229145: iinla: Evaluate component simplifications (level 3)
#> 2026-03-09 14:34:02.230382: Simplify component mappers for each observation model (level 3)
#> 2026-03-09 14:34:02.231774: Simplify component 'x' (level 4)
#> 2026-03-09 14:34:02.234696: Simplify component 'Intercept' (level 4)
#> 2026-03-09 14:34:02.237637: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:02.244223: iinla: Construct inla stack (level 3)
#> 2026-03-09 14:34:02.256756: iinla: Model initialisation completed (level 3)
#> 2026-03-09 14:34:02.258206: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-09 14:34:02.565674: iinla: Computation completed (level 3)
#> 2026-03-09 14:34:02.589226: bru: Preprocessing (level 1)
#> 2026-03-09 14:34:02.598472: Evaluate component inputs for each observation model (level 3)
#> 2026-03-09 14:34:02.599772: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:02.601173: bru_input.bru_comp(z) (level 4)
#> 2026-03-09 14:34:02.602542: bru_input.bm_pipe(z) (level 5)
#> 2026-03-09 14:34:02.604105: bru_input.bm_multi(z:core) (level 5)
#> 2026-03-09 14:34:02.60559: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-03-09 14:34:02.606939: bru_input(bru_input) for (z) (level 5)
#> 2026-03-09 14:34:02.614736: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-09 14:34:02.616178: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-09 14:34:02.617715: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-09 14:34:02.619231: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-09 14:34:02.620594: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-09 14:34:02.634591: iinla: Start (level 3)
#> 2026-03-09 14:34:02.635814: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:02.637034: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:02.638462: Linearise component 'z' (level 4)
#> 2026-03-09 14:34:02.641494: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:02.644336: iinla: Evaluate component simplifications (level 3)
#> 2026-03-09 14:34:02.645587: Simplify component mappers for each observation model (level 3)
#> 2026-03-09 14:34:02.647097: Simplify component 'z' (level 4)
#> 2026-03-09 14:34:02.650214: Simplify component 'Intercept' (level 4)
#> 2026-03-09 14:34:02.653363: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:02.656568: Linearise with respect to component 'z' (level 5)
#> 2026-03-09 14:34:02.662048: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-09 14:34:02.665446: iinla: Construct inla stack (level 3)
#> 2026-03-09 14:34:02.678137: iinla: Model initialisation completed (level 3)
#> 2026-03-09 14:34:02.679622: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-03-09 14:34:02.974034: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 347.9) (level 3)
#> 2026-03-09 14:34:02.976949: iinla: Step rescaling: 38.2%, Contract (norm0 = 399, norm1 = 295.2, norm01 = 347.9) (level 3)
#> 2026-03-09 14:34:02.980598: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 3)
#> 2026-03-09 14:34:02.982176: iinla: |lin1-lin0| = 347.9
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-03-09 14:34:02.98368: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.6, norm01 = 347.9) (level 2)
#> 2026-03-09 14:34:02.985523: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:02.986748: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:02.988392: Linearise component 'z' (level 4)
#> 2026-03-09 14:34:02.991341: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:02.994138: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:02.996789: Linearise with respect to component 'z' (level 5)
#> 2026-03-09 14:34:03.000413: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-09 14:34:03.013554: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-03-09 14:34:03.603233: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-03-09 14:34:03.606406: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-03-09 14:34:03.610122: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-03-09 14:34:03.611643: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-03-09 14:34:03.613089: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-03-09 14:34:03.614795: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:03.615964: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:03.617359: Linearise component 'z' (level 4)
#> 2026-03-09 14:34:03.620251: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:03.623026: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:03.625641: Linearise with respect to component 'z' (level 5)
#> 2026-03-09 14:34:03.629204: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-09 14:34:03.641179: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-09 14:34:03.643648: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-03-09 14:34:03.937171: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-03-09 14:34:03.940139: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-03-09 14:34:03.94377: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-03-09 14:34:03.945295: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-03-09 14:34:03.946752: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-03-09 14:34:03.948505: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:03.949676: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:03.951062: Linearise component 'z' (level 4)
#> 2026-03-09 14:34:03.953953: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:03.956775: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:03.9594: Linearise with respect to component 'z' (level 5)
#> 2026-03-09 14:34:03.96305: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-09 14:34:03.975476: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-09 14:34:03.978126: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-03-09 14:34:04.280881: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-03-09 14:34:04.283755: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-03-09 14:34:04.287344: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-03-09 14:34:04.288827: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.232e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-03-09 14:34:04.290559: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:04.291714: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:04.293108: Linearise component 'z' (level 4)
#> 2026-03-09 14:34:04.296015: Linearise component 'Intercept' (level 4)
#> 2026-03-09 14:34:04.298757: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:04.301362: Linearise with respect to component 'z' (level 5)
#> 2026-03-09 14:34:04.304888: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-09 14:34:04.317062: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-09 14:34:04.318263: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-03-09 14:34:04.320687: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-03-09 14:34:04.621532: iinla: Computation completed (level 3)
#> 2026-03-09 14:34:05.692771: bru: Preprocessing (level 1)
#> 2026-03-09 14:34:05.702253: Evaluate component inputs for each observation model (level 3)
#> 2026-03-09 14:34:05.70349: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:05.704864: bru_input.bru_comp(field) (level 4)
#> 2026-03-09 14:34:05.706266: bru_input.bm_pipe(field) (level 5)
#> 2026-03-09 14:34:05.707838: bru_input.bm_multi(field:core) (level 5)
#> 2026-03-09 14:34:05.709359: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-03-09 14:34:05.710771: bru_input(bru_input) for (field) (level 5)
#> 2026-03-09 14:34:05.725989: iinla: Start (level 3)
#> 2026-03-09 14:34:05.727216: iinla: Evaluate component linearisations (level 3)
#> 2026-03-09 14:34:05.728416: Linearise components for each observation model (level 3)
#> 2026-03-09 14:34:05.729788: Linearise component 'field' (level 4)
#> 2026-03-09 14:34:05.737179: iinla: Evaluate component simplifications (level 3)
#> 2026-03-09 14:34:05.738401: Simplify component mappers for each observation model (level 3)
#> 2026-03-09 14:34:05.739764: Simplify component 'field' (level 4)
#> 2026-03-09 14:34:05.745959: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-09 14:34:05.749426: iinla: Construct inla stack (level 3)
#> 2026-03-09 14:34:05.759708: iinla: Model initialisation completed (level 3)
#> 2026-03-09 14:34:05.76116: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-09 14:34:06.17614: iinla: Computation completed (level 3)
#> 2026-03-09 14:34:08.092814: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:10.551584: bru: Preprocessing (level 1)
#> 2026-03-09 14:34:10.564481: Evaluate component inputs for each observation model (level 3)
#> 2026-03-09 14:34:10.565745: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:10.56717: bru_input.bru_comp(x) (level 4)
#> 2026-03-09 14:34:10.568552: bru_input.bm_pipe(x) (level 5)
#> 2026-03-09 14:34:10.570098: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-09 14:34:10.571615: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-09 14:34:10.57298: bru_input(bru_input) for (x) (level 5)
#> 2026-03-09 14:34:10.580294: bru_input(bru_comp_list) (level 4)
#> 2026-03-09 14:34:10.587207: bru_input.bru_comp(x) (level 4)
#> 2026-03-09 14:34:10.588949: bru_input.bm_pipe(x) (level 5)
#> 2026-03-09 14:34:10.59059: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-09 14:34:10.592104: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-09 14:34:10.593468: bru_input(bru_input) for (x) (level 5)
#> 2026-03-09 14:34:15.240071: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-03-09 14:34:16.763779: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-03-09 14:34:16.775555: bru_input.bru_comp(x) (level 4)
#> 2026-03-09 14:34:16.776701: bru_input_text.bm_pipe(x) (level 5)
#> 2026-03-09 14:34:16.777983: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-03-09 14:34:16.779281: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-03-09 14:34:16.780351: bru_input_text(bru_input) for (x) (level 5)