Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-03-06 17:28:11.098842: inlabru loaded
#> 2026-03-06 17:28:11.099334: Clear override options
#> 2026-03-06 17:28:23.56739: bru: Preprocessing
#> 2026-03-06 17:28:23.706055: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:24.551177: bru: Preprocessing
#> 2026-03-06 17:28:24.650846: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:25.030202: bru: Preprocessing
#> 2026-03-06 17:28:25.154843: iinla: Iteration 1 [max: 10]
#> 2026-03-06 17:28:25.505666: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-03-06 17:28:25.537443: iinla: Iteration 2 [max: 10]
#> 2026-03-06 17:28:26.17451: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-03-06 17:28:26.206093: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.208846: iinla: Iteration 3 [max: 10]
#> 2026-03-06 17:28:26.537099: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-03-06 17:28:26.571949: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.574738: iinla: Iteration 4 [max: 10]
#> 2026-03-06 17:28:26.93382: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.936719: iinla: Iteration 5 [max: 10]
#> 2026-03-06 17:28:27.309393: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:27.310821: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-06 17:28:27.313555: iinla: Iteration 6 [max: 10]
#> 2026-03-06 17:28:28.846772: bru: Preprocessing
#> 2026-03-06 17:28:28.921427: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:33.95893: bru: Preprocessing
format(bru_log())
#> 2026-03-06 17:28:11.098842: inlabru loaded
#> 2026-03-06 17:28:11.099334: Clear override options
#> 2026-03-06 17:28:23.56739: bru: Preprocessing
#> 2026-03-06 17:28:23.58364: Evaluate component inputs for each observation model
#> 2026-03-06 17:28:23.585103: bru_input(bru_comp_list)
#> 2026-03-06 17:28:23.586632: bru_input.bru_comp(x)
#> 2026-03-06 17:28:23.588124: bru_input.bm_pipe(x)
#> 2026-03-06 17:28:23.589724: bru_input.bm_multi(x:core)
#> 2026-03-06 17:28:23.591306: bru_input.bru_mapper(x:core:main)
#> 2026-03-06 17:28:23.593088: bru_input(bru_input) for (x)
#> 2026-03-06 17:28:23.602819: bru_input.bru_comp(Intercept)
#> 2026-03-06 17:28:23.604332: bru_input.bm_pipe(Intercept)
#> 2026-03-06 17:28:23.606015: bru_input.bm_multi(Intercept:core)
#> 2026-03-06 17:28:23.607586: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-06 17:28:23.609013: bru_input(bru_input) for (Intercept)
#> 2026-03-06 17:28:23.628047: iinla: Start
#> 2026-03-06 17:28:23.62932: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:23.630627: Linearise components for each observation model
#> 2026-03-06 17:28:23.632191: Linearise component 'x'
#> 2026-03-06 17:28:23.635311: Linearise component 'Intercept'
#> 2026-03-06 17:28:23.638243: iinla: Evaluate component simplifications
#> 2026-03-06 17:28:23.639553: Simplify component mappers for each observation model
#> 2026-03-06 17:28:23.641128: Simplify component 'x'
#> 2026-03-06 17:28:23.644403: Simplify component 'Intercept'
#> 2026-03-06 17:28:23.647514: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:23.661586: iinla: Construct inla stack
#> 2026-03-06 17:28:23.704096: iinla: Model initialisation completed
#> 2026-03-06 17:28:23.706055: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:24.523852: iinla: Computation completed
#> 2026-03-06 17:28:24.551177: bru: Preprocessing
#> 2026-03-06 17:28:24.561252: Evaluate component inputs for each observation model
#> 2026-03-06 17:28:24.56272: bru_input(bru_comp_list)
#> 2026-03-06 17:28:24.564283: bru_input.bru_comp(x)
#> 2026-03-06 17:28:24.565859: bru_input.bm_pipe(x)
#> 2026-03-06 17:28:24.567555: bru_input.bm_multi(x:core)
#> 2026-03-06 17:28:24.569153: bru_input.bru_mapper(x:core:main)
#> 2026-03-06 17:28:24.570726: bru_input(bru_input) for (x)
#> 2026-03-06 17:28:24.580142: bru_input.bru_comp(Intercept)
#> 2026-03-06 17:28:24.581742: bru_input.bm_pipe(Intercept)
#> 2026-03-06 17:28:24.583506: bru_input.bm_multi(Intercept:core)
#> 2026-03-06 17:28:24.585159: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-06 17:28:24.586584: bru_input(bru_input) for (Intercept)
#> 2026-03-06 17:28:24.603139: iinla: Start
#> 2026-03-06 17:28:24.604434: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:24.605708: Linearise components for each observation model
#> 2026-03-06 17:28:24.607327: Linearise component 'x'
#> 2026-03-06 17:28:24.610605: Linearise component 'Intercept'
#> 2026-03-06 17:28:24.613624: iinla: Evaluate component simplifications
#> 2026-03-06 17:28:24.614914: Simplify component mappers for each observation model
#> 2026-03-06 17:28:24.616426: Simplify component 'x'
#> 2026-03-06 17:28:24.619802: Simplify component 'Intercept'
#> 2026-03-06 17:28:24.62311: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:24.630802: iinla: Construct inla stack
#> 2026-03-06 17:28:24.648641: iinla: Model initialisation completed
#> 2026-03-06 17:28:24.650846: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:24.998841: iinla: Computation completed
#> 2026-03-06 17:28:25.030202: bru: Preprocessing
#> 2026-03-06 17:28:25.042382: Evaluate component inputs for each observation model
#> 2026-03-06 17:28:25.044324: bru_input(bru_comp_list)
#> 2026-03-06 17:28:25.046369: bru_input.bru_comp(z)
#> 2026-03-06 17:28:25.048353: bru_input.bm_pipe(z)
#> 2026-03-06 17:28:25.050527: bru_input.bm_multi(z:core)
#> 2026-03-06 17:28:25.052711: bru_input.bru_mapper(z:core:main)
#> 2026-03-06 17:28:25.054695: bru_input(bru_input) for (z)
#> 2026-03-06 17:28:25.064447: bru_input.bru_comp(Intercept)
#> 2026-03-06 17:28:25.066589: bru_input.bm_pipe(Intercept)
#> 2026-03-06 17:28:25.068787: bru_input.bm_multi(Intercept:core)
#> 2026-03-06 17:28:25.070947: bru_input.bru_mapper(Intercept:core:main)
#> 2026-03-06 17:28:25.072893: bru_input(bru_input) for (Intercept)
#> 2026-03-06 17:28:25.092237: iinla: Start
#> 2026-03-06 17:28:25.094013: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:25.095763: Linearise components for each observation model
#> 2026-03-06 17:28:25.097838: Linearise component 'z'
#> 2026-03-06 17:28:25.101926: Linearise component 'Intercept'
#> 2026-03-06 17:28:25.105748: iinla: Evaluate component simplifications
#> 2026-03-06 17:28:25.107515: Simplify component mappers for each observation model
#> 2026-03-06 17:28:25.109552: Simplify component 'z'
#> 2026-03-06 17:28:25.113839: Simplify component 'Intercept'
#> 2026-03-06 17:28:25.117929: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:25.122172: Linearise with respect to component 'z'
#> 2026-03-06 17:28:25.129776: Linearise with respect to component 'Intercept'
#> 2026-03-06 17:28:25.134776: iinla: Construct inla stack
#> 2026-03-06 17:28:25.152589: iinla: Model initialisation completed
#> 2026-03-06 17:28:25.154843: iinla: Iteration 1 [max: 10]
#> 2026-03-06 17:28:25.487459: iinla: Step rescaling: 61.8%, Contract (norm0 = 2398, norm1 = 2207, norm01 = 403.5)
#> 2026-03-06 17:28:25.498494: iinla: Step rescaling: 38.2%, Contract (norm0 = 477.1, norm1 = 350.8, norm01 = 403.5)
#> 2026-03-06 17:28:25.502603: iinla: Step rescaling: 27.01%, Approx Optimisation (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-03-06 17:28:25.504193: iinla: |lin1-lin0| = 403.5
#> <eta-lin1,delta>/|delta| = -231
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 123.1
#> 2026-03-06 17:28:25.505666: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-03-06 17:28:25.50741: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:25.508589: Linearise components for each observation model
#> 2026-03-06 17:28:25.510028: Linearise component 'z'
#> 2026-03-06 17:28:25.513256: Linearise component 'Intercept'
#> 2026-03-06 17:28:25.516186: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:25.519053: Linearise with respect to component 'z'
#> 2026-03-06 17:28:25.522949: Linearise with respect to component 'Intercept'
#> 2026-03-06 17:28:25.537443: iinla: Iteration 2 [max: 10]
#> 2026-03-06 17:28:26.171142: iinla: Step rescaling: 99.5%, Approx Optimisation (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-03-06 17:28:26.172896: iinla: |lin1-lin0| = 261.6
#> <eta-lin1,delta>/|delta| = -1.48
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 13.86
#> 2026-03-06 17:28:26.17451: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-03-06 17:28:26.176332: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:26.177509: Linearise components for each observation model
#> 2026-03-06 17:28:26.178971: Linearise component 'z'
#> 2026-03-06 17:28:26.182213: Linearise component 'Intercept'
#> 2026-03-06 17:28:26.185441: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:26.188462: Linearise with respect to component 'z'
#> 2026-03-06 17:28:26.192518: Linearise with respect to component 'Intercept'
#> 2026-03-06 17:28:26.206093: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.208846: iinla: Iteration 3 [max: 10]
#> 2026-03-06 17:28:26.525385: iinla: Step rescaling: 162%, Expand (norm0 = 21.91, norm1 = 7.974, norm01 = 13.93)
#> 2026-03-06 17:28:26.52915: iinla: Step rescaling: 100%, Overstep (norm0 = 13.69, norm1 = 0.2466, norm01 = 13.93)
#> 2026-03-06 17:28:26.533359: iinla: Step rescaling: 101.8%, Approx Optimisation (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-03-06 17:28:26.535043: iinla: |lin1-lin0| = 13.93
#> <eta-lin1,delta>/|delta| = -5.552e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.02384
#> 2026-03-06 17:28:26.537099: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-03-06 17:28:26.540141: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:26.541862: Linearise components for each observation model
#> 2026-03-06 17:28:26.543567: Linearise component 'z'
#> 2026-03-06 17:28:26.547089: Linearise component 'Intercept'
#> 2026-03-06 17:28:26.550226: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:26.553364: Linearise with respect to component 'z'
#> 2026-03-06 17:28:26.557701: Linearise with respect to component 'Intercept'
#> 2026-03-06 17:28:26.571949: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.574738: iinla: Iteration 4 [max: 10]
#> 2026-03-06 17:28:26.891783: iinla: Step rescaling: 162%, Expand (norm0 = 0.03859, norm1 = 0.01474, norm01 = 0.02385)
#> 2026-03-06 17:28:26.895229: iinla: Step rescaling: 100%, Overstep (norm0 = 0.02385, norm1 = 1.944e-07, norm01 = 0.02385)
#> 2026-03-06 17:28:26.899471: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.02385, norm1 = 1.935e-07, norm01 = 0.02385)
#> 2026-03-06 17:28:26.901174: iinla: |lin1-lin0| = 0.02385
#> <eta-lin1,delta>/|delta| = 3.925e-10
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 1.935e-07
#> 2026-03-06 17:28:26.90322: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:26.904455: Linearise components for each observation model
#> 2026-03-06 17:28:26.905972: Linearise component 'z'
#> 2026-03-06 17:28:26.909315: Linearise component 'Intercept'
#> 2026-03-06 17:28:26.912571: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:26.915854: Linearise with respect to component 'z'
#> 2026-03-06 17:28:26.92: Linearise with respect to component 'Intercept'
#> 2026-03-06 17:28:26.93382: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.936719: iinla: Iteration 5 [max: 10]
#> 2026-03-06 17:28:27.259512: iinla: Step rescaling: 162%, Expand (norm0 = 7.019e-07, norm1 = 2.681e-07, norm01 = 4.338e-07)
#> 2026-03-06 17:28:27.26285: iinla: Step rescaling: 100%, Overstep (norm0 = 4.338e-07, norm1 = 4.827e-13, norm01 = 4.338e-07)
#> 2026-03-06 17:28:27.267353: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 4.338e-07, norm1 = 4.611e-13, norm01 = 4.338e-07)
#> 2026-03-06 17:28:27.269106: iinla: |lin1-lin0| = 4.338e-07
#> <eta-lin1,delta>/|delta| = -1.302e-15
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 4.611e-13
#> 2026-03-06 17:28:27.271081: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:27.272378: Linearise components for each observation model
#> 2026-03-06 17:28:27.273939: Linearise component 'z'
#> 2026-03-06 17:28:27.285096: Linearise component 'Intercept'
#> 2026-03-06 17:28:27.288196: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:27.291246: Linearise with respect to component 'z'
#> 2026-03-06 17:28:27.295308: Linearise with respect to component 'Intercept'
#> 2026-03-06 17:28:27.309393: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:27.310821: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-06 17:28:27.313555: iinla: Iteration 6 [max: 10]
#> 2026-03-06 17:28:27.635629: iinla: Computation completed
#> 2026-03-06 17:28:28.846772: bru: Preprocessing
#> 2026-03-06 17:28:28.857373: Evaluate component inputs for each observation model
#> 2026-03-06 17:28:28.858723: bru_input(bru_comp_list)
#> 2026-03-06 17:28:28.860198: bru_input.bru_comp(field)
#> 2026-03-06 17:28:28.861598: bru_input.bm_pipe(field)
#> 2026-03-06 17:28:28.863148: bru_input.bm_multi(field:core)
#> 2026-03-06 17:28:28.864665: bru_input.bru_mapper(field:core:main)
#> 2026-03-06 17:28:28.866028: bru_input(bru_input) for (field)
#> 2026-03-06 17:28:28.881757: iinla: Start
#> 2026-03-06 17:28:28.883055: iinla: Evaluate component linearisations
#> 2026-03-06 17:28:28.884256: Linearise components for each observation model
#> 2026-03-06 17:28:28.885715: Linearise component 'field'
#> 2026-03-06 17:28:28.894013: iinla: Evaluate component simplifications
#> 2026-03-06 17:28:28.89539: Simplify component mappers for each observation model
#> 2026-03-06 17:28:28.896873: Simplify component 'field'
#> 2026-03-06 17:28:28.904327: iinla: Evaluate predictor linearisation
#> 2026-03-06 17:28:28.908266: iinla: Construct inla stack
#> 2026-03-06 17:28:28.919852: iinla: Model initialisation completed
#> 2026-03-06 17:28:28.921427: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:29.356424: iinla: Computation completed
#> 2026-03-06 17:28:31.309234: bru_input(bru_comp_list)
#> 2026-03-06 17:28:33.95893: bru: Preprocessing
#> 2026-03-06 17:28:33.973856: Evaluate component inputs for each observation model
#> 2026-03-06 17:28:33.975324: bru_input(bru_comp_list)
#> 2026-03-06 17:28:33.976933: bru_input.bru_comp(x)
#> 2026-03-06 17:28:33.97849: bru_input.bm_pipe(x)
#> 2026-03-06 17:28:33.9802: bru_input.bm_multi(x:core)
#> 2026-03-06 17:28:33.981936: bru_input.bru_mapper(x:core:main)
#> 2026-03-06 17:28:33.983453: bru_input(bru_input) for (x)
#> 2026-03-06 17:28:33.993447: bru_input(bru_comp_list)
#> 2026-03-06 17:28:33.995045: bru_input.bru_comp(x)
#> 2026-03-06 17:28:33.996535: bru_input.bm_pipe(x)
#> 2026-03-06 17:28:33.998165: bru_input.bm_multi(x:core)
#> 2026-03-06 17:28:33.999838: bru_input.bru_mapper(x:core:main)
#> 2026-03-06 17:28:34.001342: bru_input(bru_input) for (x)
#> 2026-03-06 17:28:39.08228: bru_input(bru_input) for (LABEL)
bru_log(verbosity = 2L)
#> 2026-03-06 17:28:11.098842: inlabru loaded
#> 2026-03-06 17:28:11.099334: Clear override options
#> 2026-03-06 17:28:23.56739: bru: Preprocessing
#> 2026-03-06 17:28:23.706055: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:24.551177: bru: Preprocessing
#> 2026-03-06 17:28:24.650846: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:25.030202: bru: Preprocessing
#> 2026-03-06 17:28:25.154843: iinla: Iteration 1 [max: 10]
#> 2026-03-06 17:28:25.505666: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-03-06 17:28:25.537443: iinla: Iteration 2 [max: 10]
#> 2026-03-06 17:28:26.17451: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-03-06 17:28:26.206093: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.208846: iinla: Iteration 3 [max: 10]
#> 2026-03-06 17:28:26.537099: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-03-06 17:28:26.571949: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.574738: iinla: Iteration 4 [max: 10]
#> 2026-03-06 17:28:26.93382: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:26.936719: iinla: Iteration 5 [max: 10]
#> 2026-03-06 17:28:27.309393: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-03-06 17:28:27.310821: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-03-06 17:28:27.313555: iinla: Iteration 6 [max: 10]
#> 2026-03-06 17:28:28.846772: bru: Preprocessing
#> 2026-03-06 17:28:28.921427: iinla: Iteration 1 [max: 1]
#> 2026-03-06 17:28:33.95893: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-03-06 17:28:11.098842: inlabru loaded (level 1)
#> 2026-03-06 17:28:11.099334: Clear override options (level 1)
#> 2026-03-06 17:28:23.56739: bru: Preprocessing (level 1)
#> 2026-03-06 17:28:23.58364: Evaluate component inputs for each observation model (level 3)
#> 2026-03-06 17:28:23.585103: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:23.586632: bru_input.bru_comp(x) (level 4)
#> 2026-03-06 17:28:23.588124: bru_input.bm_pipe(x) (level 5)
#> 2026-03-06 17:28:23.589724: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-06 17:28:23.591306: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-06 17:28:23.593088: bru_input(bru_input) for (x) (level 5)
#> 2026-03-06 17:28:23.602819: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-06 17:28:23.604332: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-06 17:28:23.606015: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-06 17:28:23.607586: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-06 17:28:23.609013: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-06 17:28:23.628047: iinla: Start (level 3)
#> 2026-03-06 17:28:23.62932: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:23.630627: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:23.632191: Linearise component 'x' (level 4)
#> 2026-03-06 17:28:23.635311: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:23.638243: iinla: Evaluate component simplifications (level 3)
#> 2026-03-06 17:28:23.639553: Simplify component mappers for each observation model (level 3)
#> 2026-03-06 17:28:23.641128: Simplify component 'x' (level 4)
#> 2026-03-06 17:28:23.644403: Simplify component 'Intercept' (level 4)
#> 2026-03-06 17:28:23.647514: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:23.661586: iinla: Construct inla stack (level 3)
#> 2026-03-06 17:28:23.704096: iinla: Model initialisation completed (level 3)
#> 2026-03-06 17:28:23.706055: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-06 17:28:24.523852: iinla: Computation completed (level 3)
#> 2026-03-06 17:28:24.551177: bru: Preprocessing (level 1)
#> 2026-03-06 17:28:24.561252: Evaluate component inputs for each observation model (level 3)
#> 2026-03-06 17:28:24.56272: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:24.564283: bru_input.bru_comp(x) (level 4)
#> 2026-03-06 17:28:24.565859: bru_input.bm_pipe(x) (level 5)
#> 2026-03-06 17:28:24.567555: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-06 17:28:24.569153: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-06 17:28:24.570726: bru_input(bru_input) for (x) (level 5)
#> 2026-03-06 17:28:24.580142: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-06 17:28:24.581742: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-06 17:28:24.583506: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-06 17:28:24.585159: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-06 17:28:24.586584: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-06 17:28:24.603139: iinla: Start (level 3)
#> 2026-03-06 17:28:24.604434: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:24.605708: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:24.607327: Linearise component 'x' (level 4)
#> 2026-03-06 17:28:24.610605: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:24.613624: iinla: Evaluate component simplifications (level 3)
#> 2026-03-06 17:28:24.614914: Simplify component mappers for each observation model (level 3)
#> 2026-03-06 17:28:24.616426: Simplify component 'x' (level 4)
#> 2026-03-06 17:28:24.619802: Simplify component 'Intercept' (level 4)
#> 2026-03-06 17:28:24.62311: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:24.630802: iinla: Construct inla stack (level 3)
#> 2026-03-06 17:28:24.648641: iinla: Model initialisation completed (level 3)
#> 2026-03-06 17:28:24.650846: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-06 17:28:24.998841: iinla: Computation completed (level 3)
#> 2026-03-06 17:28:25.030202: bru: Preprocessing (level 1)
#> 2026-03-06 17:28:25.042382: Evaluate component inputs for each observation model (level 3)
#> 2026-03-06 17:28:25.044324: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:25.046369: bru_input.bru_comp(z) (level 4)
#> 2026-03-06 17:28:25.048353: bru_input.bm_pipe(z) (level 5)
#> 2026-03-06 17:28:25.050527: bru_input.bm_multi(z:core) (level 5)
#> 2026-03-06 17:28:25.052711: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-03-06 17:28:25.054695: bru_input(bru_input) for (z) (level 5)
#> 2026-03-06 17:28:25.064447: bru_input.bru_comp(Intercept) (level 4)
#> 2026-03-06 17:28:25.066589: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-03-06 17:28:25.068787: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-03-06 17:28:25.070947: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-03-06 17:28:25.072893: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-03-06 17:28:25.092237: iinla: Start (level 3)
#> 2026-03-06 17:28:25.094013: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:25.095763: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:25.097838: Linearise component 'z' (level 4)
#> 2026-03-06 17:28:25.101926: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:25.105748: iinla: Evaluate component simplifications (level 3)
#> 2026-03-06 17:28:25.107515: Simplify component mappers for each observation model (level 3)
#> 2026-03-06 17:28:25.109552: Simplify component 'z' (level 4)
#> 2026-03-06 17:28:25.113839: Simplify component 'Intercept' (level 4)
#> 2026-03-06 17:28:25.117929: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:25.122172: Linearise with respect to component 'z' (level 5)
#> 2026-03-06 17:28:25.129776: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-06 17:28:25.134776: iinla: Construct inla stack (level 3)
#> 2026-03-06 17:28:25.152589: iinla: Model initialisation completed (level 3)
#> 2026-03-06 17:28:25.154843: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-03-06 17:28:25.487459: iinla: Step rescaling: 61.8%, Contract (norm0 = 2398, norm1 = 2207, norm01 = 403.5) (level 3)
#> 2026-03-06 17:28:25.498494: iinla: Step rescaling: 38.2%, Contract (norm0 = 477.1, norm1 = 350.8, norm01 = 403.5) (level 3)
#> 2026-03-06 17:28:25.502603: iinla: Step rescaling: 27.01%, Approx Optimisation (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5) (level 3)
#> 2026-03-06 17:28:25.504193: iinla: |lin1-lin0| = 403.5
#> <eta-lin1,delta>/|delta| = -231
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 123.1 (level 4)
#> 2026-03-06 17:28:25.505666: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5) (level 2)
#> 2026-03-06 17:28:25.50741: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:25.508589: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:25.510028: Linearise component 'z' (level 4)
#> 2026-03-06 17:28:25.513256: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:25.516186: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:25.519053: Linearise with respect to component 'z' (level 5)
#> 2026-03-06 17:28:25.522949: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-06 17:28:25.537443: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-03-06 17:28:26.171142: iinla: Step rescaling: 99.5%, Approx Optimisation (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6) (level 3)
#> 2026-03-06 17:28:26.172896: iinla: |lin1-lin0| = 261.6
#> <eta-lin1,delta>/|delta| = -1.48
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 13.86 (level 4)
#> 2026-03-06 17:28:26.17451: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6) (level 2)
#> 2026-03-06 17:28:26.176332: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:26.177509: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:26.178971: Linearise component 'z' (level 4)
#> 2026-03-06 17:28:26.182213: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:26.185441: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:26.188462: Linearise with respect to component 'z' (level 5)
#> 2026-03-06 17:28:26.192518: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-06 17:28:26.206093: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-06 17:28:26.208846: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-03-06 17:28:26.525385: iinla: Step rescaling: 162%, Expand (norm0 = 21.91, norm1 = 7.974, norm01 = 13.93) (level 3)
#> 2026-03-06 17:28:26.52915: iinla: Step rescaling: 100%, Overstep (norm0 = 13.69, norm1 = 0.2466, norm01 = 13.93) (level 3)
#> 2026-03-06 17:28:26.533359: iinla: Step rescaling: 101.8%, Approx Optimisation (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93) (level 3)
#> 2026-03-06 17:28:26.535043: iinla: |lin1-lin0| = 13.93
#> <eta-lin1,delta>/|delta| = -5.552e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.02384 (level 4)
#> 2026-03-06 17:28:26.537099: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93) (level 2)
#> 2026-03-06 17:28:26.540141: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:26.541862: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:26.543567: Linearise component 'z' (level 4)
#> 2026-03-06 17:28:26.547089: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:26.550226: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:26.553364: Linearise with respect to component 'z' (level 5)
#> 2026-03-06 17:28:26.557701: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-06 17:28:26.571949: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-06 17:28:26.574738: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-03-06 17:28:26.891783: iinla: Step rescaling: 162%, Expand (norm0 = 0.03859, norm1 = 0.01474, norm01 = 0.02385) (level 3)
#> 2026-03-06 17:28:26.895229: iinla: Step rescaling: 100%, Overstep (norm0 = 0.02385, norm1 = 1.944e-07, norm01 = 0.02385) (level 3)
#> 2026-03-06 17:28:26.899471: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.02385, norm1 = 1.935e-07, norm01 = 0.02385) (level 3)
#> 2026-03-06 17:28:26.901174: iinla: |lin1-lin0| = 0.02385
#> <eta-lin1,delta>/|delta| = 3.925e-10
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 1.935e-07 (level 4)
#> 2026-03-06 17:28:26.90322: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:26.904455: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:26.905972: Linearise component 'z' (level 4)
#> 2026-03-06 17:28:26.909315: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:26.912571: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:26.915854: Linearise with respect to component 'z' (level 5)
#> 2026-03-06 17:28:26.92: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-06 17:28:26.93382: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-06 17:28:26.936719: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-03-06 17:28:27.259512: iinla: Step rescaling: 162%, Expand (norm0 = 7.019e-07, norm1 = 2.681e-07, norm01 = 4.338e-07) (level 3)
#> 2026-03-06 17:28:27.26285: iinla: Step rescaling: 100%, Overstep (norm0 = 4.338e-07, norm1 = 4.827e-13, norm01 = 4.338e-07) (level 3)
#> 2026-03-06 17:28:27.267353: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 4.338e-07, norm1 = 4.611e-13, norm01 = 4.338e-07) (level 3)
#> 2026-03-06 17:28:27.269106: iinla: |lin1-lin0| = 4.338e-07
#> <eta-lin1,delta>/|delta| = -1.302e-15
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 4.611e-13 (level 4)
#> 2026-03-06 17:28:27.271081: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:27.272378: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:27.273939: Linearise component 'z' (level 4)
#> 2026-03-06 17:28:27.285096: Linearise component 'Intercept' (level 4)
#> 2026-03-06 17:28:27.288196: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:27.291246: Linearise with respect to component 'z' (level 5)
#> 2026-03-06 17:28:27.295308: Linearise with respect to component 'Intercept' (level 5)
#> 2026-03-06 17:28:27.309393: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-03-06 17:28:27.310821: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-03-06 17:28:27.313555: iinla: Iteration 6 [max: 10] (level 1)
#> 2026-03-06 17:28:27.635629: iinla: Computation completed (level 3)
#> 2026-03-06 17:28:28.846772: bru: Preprocessing (level 1)
#> 2026-03-06 17:28:28.857373: Evaluate component inputs for each observation model (level 3)
#> 2026-03-06 17:28:28.858723: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:28.860198: bru_input.bru_comp(field) (level 4)
#> 2026-03-06 17:28:28.861598: bru_input.bm_pipe(field) (level 5)
#> 2026-03-06 17:28:28.863148: bru_input.bm_multi(field:core) (level 5)
#> 2026-03-06 17:28:28.864665: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-03-06 17:28:28.866028: bru_input(bru_input) for (field) (level 5)
#> 2026-03-06 17:28:28.881757: iinla: Start (level 3)
#> 2026-03-06 17:28:28.883055: iinla: Evaluate component linearisations (level 3)
#> 2026-03-06 17:28:28.884256: Linearise components for each observation model (level 3)
#> 2026-03-06 17:28:28.885715: Linearise component 'field' (level 4)
#> 2026-03-06 17:28:28.894013: iinla: Evaluate component simplifications (level 3)
#> 2026-03-06 17:28:28.89539: Simplify component mappers for each observation model (level 3)
#> 2026-03-06 17:28:28.896873: Simplify component 'field' (level 4)
#> 2026-03-06 17:28:28.904327: iinla: Evaluate predictor linearisation (level 3)
#> 2026-03-06 17:28:28.908266: iinla: Construct inla stack (level 3)
#> 2026-03-06 17:28:28.919852: iinla: Model initialisation completed (level 3)
#> 2026-03-06 17:28:28.921427: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-03-06 17:28:29.356424: iinla: Computation completed (level 3)
#> 2026-03-06 17:28:31.309234: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:33.95893: bru: Preprocessing (level 1)
#> 2026-03-06 17:28:33.973856: Evaluate component inputs for each observation model (level 3)
#> 2026-03-06 17:28:33.975324: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:33.976933: bru_input.bru_comp(x) (level 4)
#> 2026-03-06 17:28:33.97849: bru_input.bm_pipe(x) (level 5)
#> 2026-03-06 17:28:33.9802: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-06 17:28:33.981936: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-06 17:28:33.983453: bru_input(bru_input) for (x) (level 5)
#> 2026-03-06 17:28:33.993447: bru_input(bru_comp_list) (level 4)
#> 2026-03-06 17:28:33.995045: bru_input.bru_comp(x) (level 4)
#> 2026-03-06 17:28:33.996535: bru_input.bm_pipe(x) (level 5)
#> 2026-03-06 17:28:33.998165: bru_input.bm_multi(x:core) (level 5)
#> 2026-03-06 17:28:33.999838: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-03-06 17:28:34.001342: bru_input(bru_input) for (x) (level 5)
#> 2026-03-06 17:28:39.08228: bru_input(bru_input) for (LABEL) (level 5)