Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-02-26 16:00:19.149533: inlabru loaded
#> 2026-02-26 16:00:19.149998: Clear override options
#> 2026-02-26 16:00:30.365678: bru: Preprocessing
#> 2026-02-26 16:00:30.491198: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:31.274547: bru: Preprocessing
#> 2026-02-26 16:00:31.37119: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:31.739747: bru: Preprocessing
#> 2026-02-26 16:00:31.857333: iinla: Iteration 1 [max: 10]
#> 2026-02-26 16:00:32.178835: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-02-26 16:00:32.209512: iinla: Iteration 2 [max: 10]
#> 2026-02-26 16:00:32.791536: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-02-26 16:00:32.820339: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:32.822834: iinla: Iteration 3 [max: 10]
#> 2026-02-26 16:00:33.124537: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-02-26 16:00:33.15347: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.155967: iinla: Iteration 4 [max: 10]
#> 2026-02-26 16:00:33.489967: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.492554: iinla: Iteration 5 [max: 10]
#> 2026-02-26 16:00:33.832424: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.833647: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-02-26 16:00:33.836154: iinla: Iteration 6 [max: 10]
#> 2026-02-26 16:00:35.235011: bru: Preprocessing
#> 2026-02-26 16:00:35.302529: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:40.210706: bru: Preprocessing
format(bru_log())
#> 2026-02-26 16:00:19.149533: inlabru loaded
#> 2026-02-26 16:00:19.149998: Clear override options
#> 2026-02-26 16:00:30.365678: bru: Preprocessing
#> 2026-02-26 16:00:30.380701: Evaluate component inputs for each observation model
#> 2026-02-26 16:00:30.38209: bru_input(bru_comp_list)
#> 2026-02-26 16:00:30.383559: bru_input.bru_comp(x)
#> 2026-02-26 16:00:30.385006: bru_input.bm_pipe(x)
#> 2026-02-26 16:00:30.386665: bru_input.bm_multi(x:mapper)
#> 2026-02-26 16:00:30.388228: bru_input.bru_mapper(x:mapper:main)
#> 2026-02-26 16:00:30.389898: bru_input(bru_input) for (x)
#> 2026-02-26 16:00:30.398958: bru_input.bru_comp(Intercept)
#> 2026-02-26 16:00:30.400437: bru_input.bm_pipe(Intercept)
#> 2026-02-26 16:00:30.401974: bru_input.bm_multi(Intercept:mapper)
#> 2026-02-26 16:00:30.403512: bru_input.bru_mapper(Intercept:mapper:main)
#> 2026-02-26 16:00:30.404899: bru_input(bru_input) for (Intercept)
#> 2026-02-26 16:00:30.421041: iinla: Start
#> 2026-02-26 16:00:30.422291: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:30.423551: Linearise components for each observation model
#> 2026-02-26 16:00:30.42506: Linearise component 'x'
#> 2026-02-26 16:00:30.427937: Linearise component 'Intercept'
#> 2026-02-26 16:00:30.430669: iinla: Evaluate component simplifications
#> 2026-02-26 16:00:30.443782: Simplify component mappers for each observation model
#> 2026-02-26 16:00:30.446181: Simplify component 'x'
#> 2026-02-26 16:00:30.450557: Simplify component 'Intercept'
#> 2026-02-26 16:00:30.454116: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:30.46835: iinla: Construct inla stack
#> 2026-02-26 16:00:30.489839: iinla: Model initialisation completed
#> 2026-02-26 16:00:30.491198: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:31.250347: iinla: Computation completed
#> 2026-02-26 16:00:31.274547: bru: Preprocessing
#> 2026-02-26 16:00:31.283618: Evaluate component inputs for each observation model
#> 2026-02-26 16:00:31.284893: bru_input(bru_comp_list)
#> 2026-02-26 16:00:31.286306: bru_input.bru_comp(x)
#> 2026-02-26 16:00:31.287768: bru_input.bm_pipe(x)
#> 2026-02-26 16:00:31.289384: bru_input.bm_multi(x:mapper)
#> 2026-02-26 16:00:31.290926: bru_input.bru_mapper(x:mapper:main)
#> 2026-02-26 16:00:31.292323: bru_input(bru_input) for (x)
#> 2026-02-26 16:00:31.300885: bru_input.bru_comp(Intercept)
#> 2026-02-26 16:00:31.302325: bru_input.bm_pipe(Intercept)
#> 2026-02-26 16:00:31.303861: bru_input.bm_multi(Intercept:mapper)
#> 2026-02-26 16:00:31.305481: bru_input.bru_mapper(Intercept:mapper:main)
#> 2026-02-26 16:00:31.306879: bru_input(bru_input) for (Intercept)
#> 2026-02-26 16:00:31.32083: iinla: Start
#> 2026-02-26 16:00:31.32208: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:31.32374: Linearise components for each observation model
#> 2026-02-26 16:00:31.325721: Linearise component 'x'
#> 2026-02-26 16:00:31.329499: Linearise component 'Intercept'
#> 2026-02-26 16:00:31.333335: iinla: Evaluate component simplifications
#> 2026-02-26 16:00:31.335027: Simplify component mappers for each observation model
#> 2026-02-26 16:00:31.337009: Simplify component 'x'
#> 2026-02-26 16:00:31.34105: Simplify component 'Intercept'
#> 2026-02-26 16:00:31.344871: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:31.353282: iinla: Construct inla stack
#> 2026-02-26 16:00:31.369153: iinla: Model initialisation completed
#> 2026-02-26 16:00:31.37119: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:31.700727: iinla: Computation completed
#> 2026-02-26 16:00:31.739747: bru: Preprocessing
#> 2026-02-26 16:00:31.751118: Evaluate component inputs for each observation model
#> 2026-02-26 16:00:31.752893: bru_input(bru_comp_list)
#> 2026-02-26 16:00:31.754836: bru_input.bru_comp(z)
#> 2026-02-26 16:00:31.756718: bru_input.bm_pipe(z)
#> 2026-02-26 16:00:31.758896: bru_input.bm_multi(z:mapper)
#> 2026-02-26 16:00:31.761013: bru_input.bru_mapper(z:mapper:main)
#> 2026-02-26 16:00:31.762967: bru_input(bru_input) for (z)
#> 2026-02-26 16:00:31.771402: bru_input.bru_comp(Intercept)
#> 2026-02-26 16:00:31.773369: bru_input.bm_pipe(Intercept)
#> 2026-02-26 16:00:31.775487: bru_input.bm_multi(Intercept:mapper)
#> 2026-02-26 16:00:31.779112: bru_input.bru_mapper(Intercept:mapper:main)
#> 2026-02-26 16:00:31.782773: bru_input(bru_input) for (Intercept)
#> 2026-02-26 16:00:31.80012: iinla: Start
#> 2026-02-26 16:00:31.801832: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:31.803543: Linearise components for each observation model
#> 2026-02-26 16:00:31.80556: Linearise component 'z'
#> 2026-02-26 16:00:31.809238: Linearise component 'Intercept'
#> 2026-02-26 16:00:31.812757: iinla: Evaluate component simplifications
#> 2026-02-26 16:00:31.814466: Simplify component mappers for each observation model
#> 2026-02-26 16:00:31.81641: Simplify component 'z'
#> 2026-02-26 16:00:31.820171: Simplify component 'Intercept'
#> 2026-02-26 16:00:31.824053: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:31.828031: Linearise with respect to component 'z'
#> 2026-02-26 16:00:31.834852: Linearise with respect to component 'Intercept'
#> 2026-02-26 16:00:31.839403: iinla: Construct inla stack
#> 2026-02-26 16:00:31.85534: iinla: Model initialisation completed
#> 2026-02-26 16:00:31.857333: iinla: Iteration 1 [max: 10]
#> 2026-02-26 16:00:32.168823: iinla: Step rescaling: 61.8%, Contract (norm0 = 2398, norm1 = 2207, norm01 = 403.5)
#> 2026-02-26 16:00:32.171802: iinla: Step rescaling: 38.2%, Contract (norm0 = 477.1, norm1 = 350.8, norm01 = 403.5)
#> 2026-02-26 16:00:32.175608: iinla: Step rescaling: 27.01%, Approx Optimisation (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-02-26 16:00:32.177191: iinla: |lin1-lin0| = 403.5
#> <eta-lin1,delta>/|delta| = -231
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 123.1
#> 2026-02-26 16:00:32.178835: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-02-26 16:00:32.180779: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:32.182095: Linearise components for each observation model
#> 2026-02-26 16:00:32.183482: Linearise component 'z'
#> 2026-02-26 16:00:32.186352: Linearise component 'Intercept'
#> 2026-02-26 16:00:32.189153: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:32.191863: Linearise with respect to component 'z'
#> 2026-02-26 16:00:32.195675: Linearise with respect to component 'Intercept'
#> 2026-02-26 16:00:32.209512: iinla: Iteration 2 [max: 10]
#> 2026-02-26 16:00:32.788231: iinla: Step rescaling: 99.5%, Approx Optimisation (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-02-26 16:00:32.789927: iinla: |lin1-lin0| = 261.6
#> <eta-lin1,delta>/|delta| = -1.48
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 13.86
#> 2026-02-26 16:00:32.791536: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-02-26 16:00:32.793361: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:32.794529: Linearise components for each observation model
#> 2026-02-26 16:00:32.795889: Linearise component 'z'
#> 2026-02-26 16:00:32.798807: Linearise component 'Intercept'
#> 2026-02-26 16:00:32.801659: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:32.804301: Linearise with respect to component 'z'
#> 2026-02-26 16:00:32.807908: Linearise with respect to component 'Intercept'
#> 2026-02-26 16:00:32.820339: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:32.822834: iinla: Iteration 3 [max: 10]
#> 2026-02-26 16:00:33.11495: iinla: Step rescaling: 162%, Expand (norm0 = 21.91, norm1 = 7.974, norm01 = 13.93)
#> 2026-02-26 16:00:33.117891: iinla: Step rescaling: 100%, Overstep (norm0 = 13.69, norm1 = 0.2466, norm01 = 13.93)
#> 2026-02-26 16:00:33.121573: iinla: Step rescaling: 101.8%, Approx Optimisation (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-02-26 16:00:33.123065: iinla: |lin1-lin0| = 13.93
#> <eta-lin1,delta>/|delta| = -5.552e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.02384
#> 2026-02-26 16:00:33.124537: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-02-26 16:00:33.126266: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:33.127461: Linearise components for each observation model
#> 2026-02-26 16:00:33.128841: Linearise component 'z'
#> 2026-02-26 16:00:33.131787: Linearise component 'Intercept'
#> 2026-02-26 16:00:33.134764: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:33.137472: Linearise with respect to component 'z'
#> 2026-02-26 16:00:33.141145: Linearise with respect to component 'Intercept'
#> 2026-02-26 16:00:33.15347: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.155967: iinla: Iteration 4 [max: 10]
#> 2026-02-26 16:00:33.452155: iinla: Step rescaling: 162%, Expand (norm0 = 0.03859, norm1 = 0.01474, norm01 = 0.02385)
#> 2026-02-26 16:00:33.455315: iinla: Step rescaling: 100%, Overstep (norm0 = 0.02385, norm1 = 1.944e-07, norm01 = 0.02385)
#> 2026-02-26 16:00:33.459191: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.02385, norm1 = 1.935e-07, norm01 = 0.02385)
#> 2026-02-26 16:00:33.460801: iinla: |lin1-lin0| = 0.02385
#> <eta-lin1,delta>/|delta| = 3.925e-10
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 1.935e-07
#> 2026-02-26 16:00:33.462716: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:33.463925: Linearise components for each observation model
#> 2026-02-26 16:00:33.46537: Linearise component 'z'
#> 2026-02-26 16:00:33.468331: Linearise component 'Intercept'
#> 2026-02-26 16:00:33.471332: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:33.474017: Linearise with respect to component 'z'
#> 2026-02-26 16:00:33.477717: Linearise with respect to component 'Intercept'
#> 2026-02-26 16:00:33.489967: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.492554: iinla: Iteration 5 [max: 10]
#> 2026-02-26 16:00:33.787472: iinla: Step rescaling: 162%, Expand (norm0 = 7.019e-07, norm1 = 2.681e-07, norm01 = 4.338e-07)
#> 2026-02-26 16:00:33.790661: iinla: Step rescaling: 100%, Overstep (norm0 = 4.338e-07, norm1 = 4.827e-13, norm01 = 4.338e-07)
#> 2026-02-26 16:00:33.801177: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 4.338e-07, norm1 = 4.611e-13, norm01 = 4.338e-07)
#> 2026-02-26 16:00:33.803097: iinla: |lin1-lin0| = 4.338e-07
#> <eta-lin1,delta>/|delta| = -1.302e-15
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 4.611e-13
#> 2026-02-26 16:00:33.804888: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:33.806058: Linearise components for each observation model
#> 2026-02-26 16:00:33.807511: Linearise component 'z'
#> 2026-02-26 16:00:33.810647: Linearise component 'Intercept'
#> 2026-02-26 16:00:33.813484: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:33.816354: Linearise with respect to component 'z'
#> 2026-02-26 16:00:33.820019: Linearise with respect to component 'Intercept'
#> 2026-02-26 16:00:33.832424: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.833647: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-02-26 16:00:33.836154: iinla: Iteration 6 [max: 10]
#> 2026-02-26 16:00:34.136361: iinla: Computation completed
#> 2026-02-26 16:00:35.235011: bru: Preprocessing
#> 2026-02-26 16:00:35.244815: Evaluate component inputs for each observation model
#> 2026-02-26 16:00:35.246085: bru_input(bru_comp_list)
#> 2026-02-26 16:00:35.24747: bru_input.bru_comp(field)
#> 2026-02-26 16:00:35.248837: bru_input.bm_pipe(field)
#> 2026-02-26 16:00:35.250357: bru_input.bm_multi(field:mapper)
#> 2026-02-26 16:00:35.251843: bru_input.bru_mapper(field:mapper:main)
#> 2026-02-26 16:00:35.253209: bru_input(bru_input) for (field)
#> 2026-02-26 16:00:35.266489: iinla: Start
#> 2026-02-26 16:00:35.267687: iinla: Evaluate component linearisations
#> 2026-02-26 16:00:35.268878: Linearise components for each observation model
#> 2026-02-26 16:00:35.270259: Linearise component 'field'
#> 2026-02-26 16:00:35.277489: iinla: Evaluate component simplifications
#> 2026-02-26 16:00:35.278726: Simplify component mappers for each observation model
#> 2026-02-26 16:00:35.280203: Simplify component 'field'
#> 2026-02-26 16:00:35.286725: iinla: Evaluate predictor linearisation
#> 2026-02-26 16:00:35.290211: iinla: Construct inla stack
#> 2026-02-26 16:00:35.301071: iinla: Model initialisation completed
#> 2026-02-26 16:00:35.302529: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:35.709143: iinla: Computation completed
#> 2026-02-26 16:00:37.599853: bru_input(bru_comp_list)
#> 2026-02-26 16:00:40.210706: bru: Preprocessing
#> 2026-02-26 16:00:40.224017: Evaluate component inputs for each observation model
#> 2026-02-26 16:00:40.225333: bru_input(bru_comp_list)
#> 2026-02-26 16:00:40.226718: bru_input.bru_comp(x)
#> 2026-02-26 16:00:40.228113: bru_input.bm_pipe(x)
#> 2026-02-26 16:00:40.229707: bru_input.bm_multi(x:mapper)
#> 2026-02-26 16:00:40.231203: bru_input.bru_mapper(x:mapper:main)
#> 2026-02-26 16:00:40.232682: bru_input(bru_input) for (x)
#> 2026-02-26 16:00:40.241733: bru_input(bru_comp_list)
#> 2026-02-26 16:00:40.243146: bru_input.bru_comp(x)
#> 2026-02-26 16:00:40.244627: bru_input.bm_pipe(x)
#> 2026-02-26 16:00:40.246184: bru_input.bm_multi(x:mapper)
#> 2026-02-26 16:00:40.247784: bru_input.bru_mapper(x:mapper:main)
#> 2026-02-26 16:00:40.249151: bru_input(bru_input) for (x)
#> 2026-02-26 16:00:44.980505: bru_input(bru_input) for (LABEL)
bru_log(verbosity = 2L)
#> 2026-02-26 16:00:19.149533: inlabru loaded
#> 2026-02-26 16:00:19.149998: Clear override options
#> 2026-02-26 16:00:30.365678: bru: Preprocessing
#> 2026-02-26 16:00:30.491198: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:31.274547: bru: Preprocessing
#> 2026-02-26 16:00:31.37119: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:31.739747: bru: Preprocessing
#> 2026-02-26 16:00:31.857333: iinla: Iteration 1 [max: 10]
#> 2026-02-26 16:00:32.178835: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5)
#> 2026-02-26 16:00:32.209512: iinla: Iteration 2 [max: 10]
#> 2026-02-26 16:00:32.791536: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6)
#> 2026-02-26 16:00:32.820339: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:32.822834: iinla: Iteration 3 [max: 10]
#> 2026-02-26 16:00:33.124537: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93)
#> 2026-02-26 16:00:33.15347: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.155967: iinla: Iteration 4 [max: 10]
#> 2026-02-26 16:00:33.489967: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.492554: iinla: Iteration 5 [max: 10]
#> 2026-02-26 16:00:33.832424: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-02-26 16:00:33.833647: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-02-26 16:00:33.836154: iinla: Iteration 6 [max: 10]
#> 2026-02-26 16:00:35.235011: bru: Preprocessing
#> 2026-02-26 16:00:35.302529: iinla: Iteration 1 [max: 1]
#> 2026-02-26 16:00:40.210706: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-02-26 16:00:19.149533: inlabru loaded (level 1)
#> 2026-02-26 16:00:19.149998: Clear override options (level 1)
#> 2026-02-26 16:00:30.365678: bru: Preprocessing (level 1)
#> 2026-02-26 16:00:30.380701: Evaluate component inputs for each observation model (level 3)
#> 2026-02-26 16:00:30.38209: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:30.383559: bru_input.bru_comp(x) (level 4)
#> 2026-02-26 16:00:30.385006: bru_input.bm_pipe(x) (level 5)
#> 2026-02-26 16:00:30.386665: bru_input.bm_multi(x:mapper) (level 5)
#> 2026-02-26 16:00:30.388228: bru_input.bru_mapper(x:mapper:main) (level 5)
#> 2026-02-26 16:00:30.389898: bru_input(bru_input) for (x) (level 5)
#> 2026-02-26 16:00:30.398958: bru_input.bru_comp(Intercept) (level 4)
#> 2026-02-26 16:00:30.400437: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-02-26 16:00:30.401974: bru_input.bm_multi(Intercept:mapper) (level 5)
#> 2026-02-26 16:00:30.403512: bru_input.bru_mapper(Intercept:mapper:main) (level 5)
#> 2026-02-26 16:00:30.404899: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-02-26 16:00:30.421041: iinla: Start (level 3)
#> 2026-02-26 16:00:30.422291: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:30.423551: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:30.42506: Linearise component 'x' (level 4)
#> 2026-02-26 16:00:30.427937: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:30.430669: iinla: Evaluate component simplifications (level 3)
#> 2026-02-26 16:00:30.443782: Simplify component mappers for each observation model (level 3)
#> 2026-02-26 16:00:30.446181: Simplify component 'x' (level 4)
#> 2026-02-26 16:00:30.450557: Simplify component 'Intercept' (level 4)
#> 2026-02-26 16:00:30.454116: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:30.46835: iinla: Construct inla stack (level 3)
#> 2026-02-26 16:00:30.489839: iinla: Model initialisation completed (level 3)
#> 2026-02-26 16:00:30.491198: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-02-26 16:00:31.250347: iinla: Computation completed (level 3)
#> 2026-02-26 16:00:31.274547: bru: Preprocessing (level 1)
#> 2026-02-26 16:00:31.283618: Evaluate component inputs for each observation model (level 3)
#> 2026-02-26 16:00:31.284893: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:31.286306: bru_input.bru_comp(x) (level 4)
#> 2026-02-26 16:00:31.287768: bru_input.bm_pipe(x) (level 5)
#> 2026-02-26 16:00:31.289384: bru_input.bm_multi(x:mapper) (level 5)
#> 2026-02-26 16:00:31.290926: bru_input.bru_mapper(x:mapper:main) (level 5)
#> 2026-02-26 16:00:31.292323: bru_input(bru_input) for (x) (level 5)
#> 2026-02-26 16:00:31.300885: bru_input.bru_comp(Intercept) (level 4)
#> 2026-02-26 16:00:31.302325: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-02-26 16:00:31.303861: bru_input.bm_multi(Intercept:mapper) (level 5)
#> 2026-02-26 16:00:31.305481: bru_input.bru_mapper(Intercept:mapper:main) (level 5)
#> 2026-02-26 16:00:31.306879: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-02-26 16:00:31.32083: iinla: Start (level 3)
#> 2026-02-26 16:00:31.32208: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:31.32374: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:31.325721: Linearise component 'x' (level 4)
#> 2026-02-26 16:00:31.329499: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:31.333335: iinla: Evaluate component simplifications (level 3)
#> 2026-02-26 16:00:31.335027: Simplify component mappers for each observation model (level 3)
#> 2026-02-26 16:00:31.337009: Simplify component 'x' (level 4)
#> 2026-02-26 16:00:31.34105: Simplify component 'Intercept' (level 4)
#> 2026-02-26 16:00:31.344871: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:31.353282: iinla: Construct inla stack (level 3)
#> 2026-02-26 16:00:31.369153: iinla: Model initialisation completed (level 3)
#> 2026-02-26 16:00:31.37119: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-02-26 16:00:31.700727: iinla: Computation completed (level 3)
#> 2026-02-26 16:00:31.739747: bru: Preprocessing (level 1)
#> 2026-02-26 16:00:31.751118: Evaluate component inputs for each observation model (level 3)
#> 2026-02-26 16:00:31.752893: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:31.754836: bru_input.bru_comp(z) (level 4)
#> 2026-02-26 16:00:31.756718: bru_input.bm_pipe(z) (level 5)
#> 2026-02-26 16:00:31.758896: bru_input.bm_multi(z:mapper) (level 5)
#> 2026-02-26 16:00:31.761013: bru_input.bru_mapper(z:mapper:main) (level 5)
#> 2026-02-26 16:00:31.762967: bru_input(bru_input) for (z) (level 5)
#> 2026-02-26 16:00:31.771402: bru_input.bru_comp(Intercept) (level 4)
#> 2026-02-26 16:00:31.773369: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-02-26 16:00:31.775487: bru_input.bm_multi(Intercept:mapper) (level 5)
#> 2026-02-26 16:00:31.779112: bru_input.bru_mapper(Intercept:mapper:main) (level 5)
#> 2026-02-26 16:00:31.782773: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-02-26 16:00:31.80012: iinla: Start (level 3)
#> 2026-02-26 16:00:31.801832: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:31.803543: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:31.80556: Linearise component 'z' (level 4)
#> 2026-02-26 16:00:31.809238: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:31.812757: iinla: Evaluate component simplifications (level 3)
#> 2026-02-26 16:00:31.814466: Simplify component mappers for each observation model (level 3)
#> 2026-02-26 16:00:31.81641: Simplify component 'z' (level 4)
#> 2026-02-26 16:00:31.820171: Simplify component 'Intercept' (level 4)
#> 2026-02-26 16:00:31.824053: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:31.828031: Linearise with respect to component 'z' (level 5)
#> 2026-02-26 16:00:31.834852: Linearise with respect to component 'Intercept' (level 5)
#> 2026-02-26 16:00:31.839403: iinla: Construct inla stack (level 3)
#> 2026-02-26 16:00:31.85534: iinla: Model initialisation completed (level 3)
#> 2026-02-26 16:00:31.857333: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-02-26 16:00:32.168823: iinla: Step rescaling: 61.8%, Contract (norm0 = 2398, norm1 = 2207, norm01 = 403.5) (level 3)
#> 2026-02-26 16:00:32.171802: iinla: Step rescaling: 38.2%, Contract (norm0 = 477.1, norm1 = 350.8, norm01 = 403.5) (level 3)
#> 2026-02-26 16:00:32.175608: iinla: Step rescaling: 27.01%, Approx Optimisation (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5) (level 3)
#> 2026-02-26 16:00:32.177191: iinla: |lin1-lin0| = 403.5
#> <eta-lin1,delta>/|delta| = -231
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 123.1 (level 4)
#> 2026-02-26 16:00:32.178835: iinla: Step rescaling: 27% (norm0 = 211.9, norm1 = 261.7, norm01 = 403.5) (level 2)
#> 2026-02-26 16:00:32.180779: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:32.182095: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:32.183482: Linearise component 'z' (level 4)
#> 2026-02-26 16:00:32.186352: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:32.189153: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:32.191863: Linearise with respect to component 'z' (level 5)
#> 2026-02-26 16:00:32.195675: Linearise with respect to component 'Intercept' (level 5)
#> 2026-02-26 16:00:32.209512: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-02-26 16:00:32.788231: iinla: Step rescaling: 99.5%, Approx Optimisation (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6) (level 3)
#> 2026-02-26 16:00:32.789927: iinla: |lin1-lin0| = 261.6
#> <eta-lin1,delta>/|delta| = -1.48
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 13.86 (level 4)
#> 2026-02-26 16:00:32.791536: iinla: Step rescaling: 99.5% (norm0 = 260.5, norm1 = 13.94, norm01 = 261.6) (level 2)
#> 2026-02-26 16:00:32.793361: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:32.794529: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:32.795889: Linearise component 'z' (level 4)
#> 2026-02-26 16:00:32.798807: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:32.801659: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:32.804301: Linearise with respect to component 'z' (level 5)
#> 2026-02-26 16:00:32.807908: Linearise with respect to component 'Intercept' (level 5)
#> 2026-02-26 16:00:32.820339: iinla: Max deviation from previous: 54200% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-02-26 16:00:32.822834: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-02-26 16:00:33.11495: iinla: Step rescaling: 162%, Expand (norm0 = 21.91, norm1 = 7.974, norm01 = 13.93) (level 3)
#> 2026-02-26 16:00:33.117891: iinla: Step rescaling: 100%, Overstep (norm0 = 13.69, norm1 = 0.2466, norm01 = 13.93) (level 3)
#> 2026-02-26 16:00:33.121573: iinla: Step rescaling: 101.8%, Approx Optimisation (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93) (level 3)
#> 2026-02-26 16:00:33.123065: iinla: |lin1-lin0| = 13.93
#> <eta-lin1,delta>/|delta| = -5.552e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.02384 (level 4)
#> 2026-02-26 16:00:33.124537: iinla: Step rescaling: 102% (norm0 = 13.93, norm1 = 0.02384, norm01 = 13.93) (level 2)
#> 2026-02-26 16:00:33.126266: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:33.127461: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:33.128841: Linearise component 'z' (level 4)
#> 2026-02-26 16:00:33.131787: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:33.134764: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:33.137472: Linearise with respect to component 'z' (level 5)
#> 2026-02-26 16:00:33.141145: Linearise with respect to component 'Intercept' (level 5)
#> 2026-02-26 16:00:33.15347: iinla: Max deviation from previous: 648% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-02-26 16:00:33.155967: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-02-26 16:00:33.452155: iinla: Step rescaling: 162%, Expand (norm0 = 0.03859, norm1 = 0.01474, norm01 = 0.02385) (level 3)
#> 2026-02-26 16:00:33.455315: iinla: Step rescaling: 100%, Overstep (norm0 = 0.02385, norm1 = 1.944e-07, norm01 = 0.02385) (level 3)
#> 2026-02-26 16:00:33.459191: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.02385, norm1 = 1.935e-07, norm01 = 0.02385) (level 3)
#> 2026-02-26 16:00:33.460801: iinla: |lin1-lin0| = 0.02385
#> <eta-lin1,delta>/|delta| = 3.925e-10
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 1.935e-07 (level 4)
#> 2026-02-26 16:00:33.462716: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:33.463925: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:33.46537: Linearise component 'z' (level 4)
#> 2026-02-26 16:00:33.468331: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:33.471332: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:33.474017: Linearise with respect to component 'z' (level 5)
#> 2026-02-26 16:00:33.477717: Linearise with respect to component 'Intercept' (level 5)
#> 2026-02-26 16:00:33.489967: iinla: Max deviation from previous: 11.4% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-02-26 16:00:33.492554: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-02-26 16:00:33.787472: iinla: Step rescaling: 162%, Expand (norm0 = 7.019e-07, norm1 = 2.681e-07, norm01 = 4.338e-07) (level 3)
#> 2026-02-26 16:00:33.790661: iinla: Step rescaling: 100%, Overstep (norm0 = 4.338e-07, norm1 = 4.827e-13, norm01 = 4.338e-07) (level 3)
#> 2026-02-26 16:00:33.801177: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 4.338e-07, norm1 = 4.611e-13, norm01 = 4.338e-07) (level 3)
#> 2026-02-26 16:00:33.803097: iinla: |lin1-lin0| = 4.338e-07
#> <eta-lin1,delta>/|delta| = -1.302e-15
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 4.611e-13 (level 4)
#> 2026-02-26 16:00:33.804888: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:33.806058: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:33.807511: Linearise component 'z' (level 4)
#> 2026-02-26 16:00:33.810647: Linearise component 'Intercept' (level 4)
#> 2026-02-26 16:00:33.813484: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:33.816354: Linearise with respect to component 'z' (level 5)
#> 2026-02-26 16:00:33.820019: Linearise with respect to component 'Intercept' (level 5)
#> 2026-02-26 16:00:33.832424: iinla: Max deviation from previous: 0.205% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-02-26 16:00:33.833647: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-02-26 16:00:33.836154: iinla: Iteration 6 [max: 10] (level 1)
#> 2026-02-26 16:00:34.136361: iinla: Computation completed (level 3)
#> 2026-02-26 16:00:35.235011: bru: Preprocessing (level 1)
#> 2026-02-26 16:00:35.244815: Evaluate component inputs for each observation model (level 3)
#> 2026-02-26 16:00:35.246085: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:35.24747: bru_input.bru_comp(field) (level 4)
#> 2026-02-26 16:00:35.248837: bru_input.bm_pipe(field) (level 5)
#> 2026-02-26 16:00:35.250357: bru_input.bm_multi(field:mapper) (level 5)
#> 2026-02-26 16:00:35.251843: bru_input.bru_mapper(field:mapper:main) (level 5)
#> 2026-02-26 16:00:35.253209: bru_input(bru_input) for (field) (level 5)
#> 2026-02-26 16:00:35.266489: iinla: Start (level 3)
#> 2026-02-26 16:00:35.267687: iinla: Evaluate component linearisations (level 3)
#> 2026-02-26 16:00:35.268878: Linearise components for each observation model (level 3)
#> 2026-02-26 16:00:35.270259: Linearise component 'field' (level 4)
#> 2026-02-26 16:00:35.277489: iinla: Evaluate component simplifications (level 3)
#> 2026-02-26 16:00:35.278726: Simplify component mappers for each observation model (level 3)
#> 2026-02-26 16:00:35.280203: Simplify component 'field' (level 4)
#> 2026-02-26 16:00:35.286725: iinla: Evaluate predictor linearisation (level 3)
#> 2026-02-26 16:00:35.290211: iinla: Construct inla stack (level 3)
#> 2026-02-26 16:00:35.301071: iinla: Model initialisation completed (level 3)
#> 2026-02-26 16:00:35.302529: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-02-26 16:00:35.709143: iinla: Computation completed (level 3)
#> 2026-02-26 16:00:37.599853: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:40.210706: bru: Preprocessing (level 1)
#> 2026-02-26 16:00:40.224017: Evaluate component inputs for each observation model (level 3)
#> 2026-02-26 16:00:40.225333: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:40.226718: bru_input.bru_comp(x) (level 4)
#> 2026-02-26 16:00:40.228113: bru_input.bm_pipe(x) (level 5)
#> 2026-02-26 16:00:40.229707: bru_input.bm_multi(x:mapper) (level 5)
#> 2026-02-26 16:00:40.231203: bru_input.bru_mapper(x:mapper:main) (level 5)
#> 2026-02-26 16:00:40.232682: bru_input(bru_input) for (x) (level 5)
#> 2026-02-26 16:00:40.241733: bru_input(bru_comp_list) (level 4)
#> 2026-02-26 16:00:40.243146: bru_input.bru_comp(x) (level 4)
#> 2026-02-26 16:00:40.244627: bru_input.bm_pipe(x) (level 5)
#> 2026-02-26 16:00:40.246184: bru_input.bm_multi(x:mapper) (level 5)
#> 2026-02-26 16:00:40.247784: bru_input.bru_mapper(x:mapper:main) (level 5)
#> 2026-02-26 16:00:40.249151: bru_input(bru_input) for (x) (level 5)
#> 2026-02-26 16:00:44.980505: bru_input(bru_input) for (LABEL) (level 5)