Access method for bru_log objects.
Use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervectorbru_log[]: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
Pre-2.8.0 compatibility
Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_offset(),
bru_log_reset(),
new_bru_log()
Examples
bru_log(verbosity = 2L)
#> 2026-09-25 13:30:35.8133: inlabru loaded
#> 2026-09-25 13:30:35.81369: Clear override options
#> 2026-09-25 13:30:53.875076: bru: Preprocessing
#> 2026-09-25 13:30:53.973825: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:54.801136: bru: Preprocessing
#> 2026-09-25 13:30:54.874234: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:55.256108: bru: Preprocessing
#> 2026-09-25 13:30:55.333406: iinla: Iteration 1 [max: 10]
#> 2026-09-25 13:30:55.679737: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-09-25 13:30:55.696732: iinla: Iteration 2 [max: 10]
#> 2026-09-25 13:30:56.347224: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-09-25 13:30:56.362195: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:56.363672: iinla: Iteration 3 [max: 10]
#> 2026-09-25 13:30:56.709113: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-09-25 13:30:56.724965: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:56.72651: iinla: Iteration 4 [max: 10]
#> 2026-09-25 13:30:57.085852: iinla: Max deviation from previous: 8.05% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:57.086845: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-09-25 13:30:57.08834: iinla: Iteration 5 [max: 10]
#> 2026-09-25 13:30:58.967425: bru: Preprocessing
#> 2026-09-25 13:30:59.015939: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:59.455197: bru: Preprocessing
#> 2026-09-25 13:30:59.523999: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:01.513042: bru: Preprocessing
#> 2026-09-25 13:31:01.577724: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:08.415496: bru: Preprocessing
#> 2026-09-25 13:31:08.459883: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:10.491676: bru: Preprocessing
#> 2026-09-25 13:31:10.662189: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:45.239813: bru: Preprocessing
format(bru_log())
#> 2026-09-25 13:30:35.8133: inlabru loaded
#> 2026-09-25 13:30:35.81369: Clear override options
#> 2026-09-25 13:30:53.875076: bru: Preprocessing
#> 2026-09-25 13:30:53.887731: Evaluate component inputs for each observation model
#> 2026-09-25 13:30:53.88901: bru_input(bru_comp_list)
#> 2026-09-25 13:30:53.89013: bru_input.bru_comp(x)
#> 2026-09-25 13:30:53.891243: bru_input.bm_pipe(x)
#> 2026-09-25 13:30:53.892496: bru_input.bm_multi(x:core)
#> 2026-09-25 13:30:53.893675: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:30:53.894976: bru_input(bru_input) for (x)
#> 2026-09-25 13:30:53.901525: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:30:53.902647: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:30:53.903947: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:30:53.905241: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:30:53.906308: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:30:53.919638: iinla: Start
#> 2026-09-25 13:30:53.921005: iinla: Evaluate component simplifications
#> 2026-09-25 13:30:53.921971: Simplify component mappers for each observation model
#> 2026-09-25 13:30:53.923161: Simplify component 'NA'
#> 2026-09-25 13:30:53.925843: Simplify component 'NA'
#> 2026-09-25 13:30:53.928624: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:53.930227: Linearise predictor for each observation model
#> 2026-09-25 13:30:53.955792: iinla: Construct inla stack
#> 2026-09-25 13:30:53.972681: iinla: Model initialisation completed
#> 2026-09-25 13:30:53.973825: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:54.77863: iinla: Computation completed
#> 2026-09-25 13:30:54.801136: bru: Preprocessing
#> 2026-09-25 13:30:54.808005: Evaluate component inputs for each observation model
#> 2026-09-25 13:30:54.809208: bru_input(bru_comp_list)
#> 2026-09-25 13:30:54.810309: bru_input.bru_comp(x)
#> 2026-09-25 13:30:54.811507: bru_input.bm_pipe(x)
#> 2026-09-25 13:30:54.812712: bru_input.bm_multi(x:core)
#> 2026-09-25 13:30:54.813854: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:30:54.814901: bru_input(bru_input) for (x)
#> 2026-09-25 13:30:54.820665: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:30:54.821764: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:30:54.82295: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:30:54.824489: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:30:54.825937: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:30:54.838726: iinla: Start
#> 2026-09-25 13:30:54.840457: iinla: Evaluate component simplifications
#> 2026-09-25 13:30:54.841908: Simplify component mappers for each observation model
#> 2026-09-25 13:30:54.84338: Simplify component 'NA'
#> 2026-09-25 13:30:54.846505: Simplify component 'NA'
#> 2026-09-25 13:30:54.849884: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:54.851943: Linearise predictor for each observation model
#> 2026-09-25 13:30:54.859431: iinla: Construct inla stack
#> 2026-09-25 13:30:54.872737: iinla: Model initialisation completed
#> 2026-09-25 13:30:54.874234: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:55.231148: iinla: Computation completed
#> 2026-09-25 13:30:55.256108: bru: Preprocessing
#> 2026-09-25 13:30:55.264669: Evaluate component inputs for each observation model
#> 2026-09-25 13:30:55.266153: bru_input(bru_comp_list)
#> 2026-09-25 13:30:55.267585: bru_input.bru_comp(z)
#> 2026-09-25 13:30:55.268972: bru_input.bm_pipe(z)
#> 2026-09-25 13:30:55.270618: bru_input.bm_multi(z:core)
#> 2026-09-25 13:30:55.27211: bru_input.bru_mapper(z:core:main)
#> 2026-09-25 13:30:55.2735: bru_input(bru_input) for (z)
#> 2026-09-25 13:30:55.279972: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:30:55.281397: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:30:55.282908: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:30:55.284426: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:30:55.285859: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:30:55.298054: iinla: Start
#> 2026-09-25 13:30:55.299754: iinla: Evaluate component simplifications
#> 2026-09-25 13:30:55.301044: Simplify component mappers for each observation model
#> 2026-09-25 13:30:55.302461: Simplify component 'NA'
#> 2026-09-25 13:30:55.305528: Simplify component 'NA'
#> 2026-09-25 13:30:55.308825: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:55.310851: Linearise predictor for each observation model
#> 2026-09-25 13:30:55.318545: iinla: Construct inla stack
#> 2026-09-25 13:30:55.331867: iinla: Model initialisation completed
#> 2026-09-25 13:30:55.333406: iinla: Iteration 1 [max: 10]
#> 2026-09-25 13:30:55.672461: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8)
#> 2026-09-25 13:30:55.674464: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8)
#> 2026-09-25 13:30:55.677009: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-09-25 13:30:55.678425: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4
#> 2026-09-25 13:30:55.679737: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-09-25 13:30:55.681239: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:55.682887: Linearise predictor for each observation model
#> 2026-09-25 13:30:55.696732: iinla: Iteration 2 [max: 10]
#> 2026-09-25 13:30:56.340775: iinla: Step rescaling: 162%, Expand (norm0 = 365, norm1 = 141.6, norm01 = 225.4)
#> 2026-09-25 13:30:56.342757: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4)
#> 2026-09-25 13:30:56.345085: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-09-25 13:30:56.346179: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.007
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63
#> 2026-09-25 13:30:56.347224: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-09-25 13:30:56.348495: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:56.349885: Linearise predictor for each observation model
#> 2026-09-25 13:30:56.362195: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:56.363672: iinla: Iteration 3 [max: 10]
#> 2026-09-25 13:30:56.701899: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68)
#> 2026-09-25 13:30:56.703965: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1741, norm01 = 10.68)
#> 2026-09-25 13:30:56.706799: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-09-25 13:30:56.70798: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.242e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-09-25 13:30:56.709113: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-09-25 13:30:56.71039: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:56.711875: Linearise predictor for each observation model
#> 2026-09-25 13:30:56.724965: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:56.72651: iinla: Iteration 4 [max: 10]
#> 2026-09-25 13:30:57.063707: iinla: Step rescaling: 162%, Expand (norm0 = 0.01902, norm1 = 0.007265, norm01 = 0.01176)
#> 2026-09-25 13:30:57.065863: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 3.793e-08, norm01 = 0.01176)
#> 2026-09-25 13:30:57.068562: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 3.784e-08, norm01 = 0.01176)
#> 2026-09-25 13:30:57.069808: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 5.35e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 3.784e-08
#> 2026-09-25 13:30:57.071229: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:57.072762: Linearise predictor for each observation model
#> 2026-09-25 13:30:57.085852: iinla: Max deviation from previous: 8.05% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:57.086845: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-09-25 13:30:57.08834: iinla: Iteration 5 [max: 10]
#> 2026-09-25 13:30:57.431973: iinla: Computation completed
#> 2026-09-25 13:30:58.967425: bru: Preprocessing
#> 2026-09-25 13:30:58.972683: Evaluate component inputs for each observation model
#> 2026-09-25 13:30:58.973866: bru_input(bru_comp_list)
#> 2026-09-25 13:30:58.974958: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:30:58.976042: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:30:58.977251: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:30:58.978438: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:30:58.979513: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:30:58.990159: iinla: Start
#> 2026-09-25 13:30:58.99147: iinla: Evaluate component simplifications
#> 2026-09-25 13:30:58.992385: Simplify component mappers for each observation model
#> 2026-09-25 13:30:58.993435: Simplify component 'NA'
#> 2026-09-25 13:30:58.996411: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:58.997927: Linearise predictor for each observation model
#> 2026-09-25 13:30:59.005972: iinla: Construct inla stack
#> 2026-09-25 13:30:59.014804: iinla: Model initialisation completed
#> 2026-09-25 13:30:59.015939: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:59.351667: iinla: Computation completed
#> 2026-09-25 13:30:59.455197: bru: Preprocessing
#> 2026-09-25 13:30:59.462099: Evaluate component inputs for each observation model
#> 2026-09-25 13:30:59.463228: bru_input(bru_comp_list)
#> 2026-09-25 13:30:59.464268: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:30:59.465271: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:30:59.466367: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:30:59.467474: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:30:59.468451: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:30:59.474201: bru_input.bru_comp(field)
#> 2026-09-25 13:30:59.475236: bru_input.bm_pipe(field)
#> 2026-09-25 13:30:59.476334: bru_input.bm_multi(field:core)
#> 2026-09-25 13:30:59.477648: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:30:59.478637: bru_input(bru_input) for (field)
#> 2026-09-25 13:30:59.489306: iinla: Start
#> 2026-09-25 13:30:59.490634: iinla: Evaluate component simplifications
#> 2026-09-25 13:30:59.491602: Simplify component mappers for each observation model
#> 2026-09-25 13:30:59.492699: Simplify component 'NA'
#> 2026-09-25 13:30:59.495297: Simplify component 'NA'
#> 2026-09-25 13:30:59.503635: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:30:59.505194: Linearise predictor for each observation model
#> 2026-09-25 13:30:59.510746: iinla: Construct inla stack
#> 2026-09-25 13:30:59.522814: iinla: Model initialisation completed
#> 2026-09-25 13:30:59.523999: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:00.518662: iinla: Computation completed
#> 2026-09-25 13:31:01.513042: bru: Preprocessing
#> 2026-09-25 13:31:01.522227: Evaluate component inputs for each observation model
#> 2026-09-25 13:31:01.523306: bru_input(bru_comp_list)
#> 2026-09-25 13:31:01.524337: bru_input.bru_comp(x)
#> 2026-09-25 13:31:01.525329: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:01.526421: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:01.527506: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:01.528472: bru_input(bru_input) for (x)
#> 2026-09-25 13:31:01.534209: bru_input.bru_comp(field)
#> 2026-09-25 13:31:01.535252: bru_input.bm_pipe(field)
#> 2026-09-25 13:31:01.536335: bru_input.bm_multi(field:core)
#> 2026-09-25 13:31:01.537422: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:31:01.538411: bru_input(bru_input) for (field)
#> 2026-09-25 13:31:01.549453: iinla: Start
#> 2026-09-25 13:31:01.550908: iinla: Evaluate component simplifications
#> 2026-09-25 13:31:01.551817: Simplify component mappers for each observation model
#> 2026-09-25 13:31:01.552999: Simplify component 'NA'
#> 2026-09-25 13:31:01.555491: Simplify component 'NA'
#> 2026-09-25 13:31:01.558541: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:31:01.56: Linearise predictor for each observation model
#> 2026-09-25 13:31:01.565644: iinla: Construct inla stack
#> 2026-09-25 13:31:01.576596: iinla: Model initialisation completed
#> 2026-09-25 13:31:01.577724: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:01.918245: iinla: Computation completed
#> 2026-09-25 13:31:03.669736: bru_input(bru_comp_list)
#> 2026-09-25 13:31:04.849748: Evaluate component inputs for each observation model
#> 2026-09-25 13:31:04.850631: bru_input(bru_comp_list)
#> 2026-09-25 13:31:04.851436: bru_input.bru_comp(x)
#> 2026-09-25 13:31:04.852192: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:04.853065: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:04.853899: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:04.854636: bru_input(bru_input) for (x)
#> 2026-09-25 13:31:04.860333: bru_input.bru_comp(field)
#> 2026-09-25 13:31:04.861165: bru_input.bm_pipe(field)
#> 2026-09-25 13:31:04.862024: bru_input.bm_multi(field:core)
#> 2026-09-25 13:31:04.862845: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:31:04.863572: bru_input(bru_input) for (field)
#> 2026-09-25 13:31:04.867855: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:31:04.868661: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:31:04.86951: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:31:04.870323: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:31:04.871063: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:31:04.880192: bru_input(bru_comp_list)
#> 2026-09-25 13:31:04.880988: bru_input.bru_comp(x)
#> 2026-09-25 13:31:04.881751: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:04.882576: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:04.883408: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:04.884129: bru_input(bru_input) for (x)
#> 2026-09-25 13:31:04.888735: bru_input.bru_comp(field)
#> 2026-09-25 13:31:04.889525: bru_input.bm_pipe(field)
#> 2026-09-25 13:31:04.890349: bru_input.bm_multi(field:core)
#> 2026-09-25 13:31:04.89119: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:31:04.891932: bru_input(bru_input) for (field)
#> 2026-09-25 13:31:04.896153: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:31:04.896936: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:31:04.897803: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:31:04.898637: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:31:04.899374: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:31:04.903626: Simplify component 'NA'
#> 2026-09-25 13:31:04.906: Simplify component 'NA'
#> 2026-09-25 13:31:04.908386: Simplify component 'NA'
#> 2026-09-25 13:31:04.910895: bru_input(bru_comp_list)
#> 2026-09-25 13:31:04.911714: bru_input.bru_comp(x)
#> 2026-09-25 13:31:04.912464: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:04.913291: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:04.914106: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:04.914831: bru_input(bru_input) for (x)
#> 2026-09-25 13:31:04.919506: bru_input.bru_comp(field)
#> 2026-09-25 13:31:04.920281: bru_input.bm_pipe(field)
#> 2026-09-25 13:31:04.921126: bru_input.bm_multi(field:core)
#> 2026-09-25 13:31:04.921955: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:31:04.922693: bru_input(bru_input) for (field)
#> 2026-09-25 13:31:04.92697: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:31:04.927756: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:31:04.928616: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:31:04.929435: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:31:04.930169: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:31:04.934346: Simplify component 'NA'
#> 2026-09-25 13:31:04.936602: Simplify component 'NA'
#> 2026-09-25 13:31:04.938946: Simplify component 'NA'
#> 2026-09-25 13:31:04.942364: bru_input(bru_comp_list)
#> 2026-09-25 13:31:04.94317: bru_input.bru_comp(x)
#> 2026-09-25 13:31:04.943948: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:04.944797: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:04.945623: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:04.946341: bru_input(bru_input) for (x)
#> 2026-09-25 13:31:04.950963: bru_input.bru_comp(field)
#> 2026-09-25 13:31:04.951741: bru_input.bm_pipe(field)
#> 2026-09-25 13:31:04.952593: bru_input.bm_multi(field:core)
#> 2026-09-25 13:31:04.953451: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:31:04.954179: bru_input(bru_input) for (field)
#> 2026-09-25 13:31:04.958491: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:31:04.959273: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:31:04.96016: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:31:04.960997: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:31:04.961756: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:31:04.965991: Simplify component 'NA'
#> 2026-09-25 13:31:04.968207: Simplify component 'NA'
#> 2026-09-25 13:31:04.97057: Simplify component 'NA'
#> 2026-09-25 13:31:08.415496: bru: Preprocessing
#> 2026-09-25 13:31:08.420799: Evaluate component inputs for each observation model
#> 2026-09-25 13:31:08.421918: bru_input(bru_comp_list)
#> 2026-09-25 13:31:08.422958: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:31:08.423964: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:31:08.425082: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:31:08.426174: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:31:08.427134: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:31:08.440308: iinla: Start
#> 2026-09-25 13:31:08.441521: iinla: Evaluate component simplifications
#> 2026-09-25 13:31:08.442363: Simplify component mappers for each observation model
#> 2026-09-25 13:31:08.443325: Simplify component 'NA'
#> 2026-09-25 13:31:08.446213: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:31:08.447633: Linearise predictor for each observation model
#> 2026-09-25 13:31:08.451638: iinla: Construct inla stack
#> 2026-09-25 13:31:08.458812: iinla: Model initialisation completed
#> 2026-09-25 13:31:08.459883: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:09.277489: iinla: Computation completed
#> 2026-09-25 13:31:10.491676: bru: Preprocessing
#> 2026-09-25 13:31:10.498935: Evaluate component inputs for each observation model
#> 2026-09-25 13:31:10.500293: bru_input(bru_comp_list)
#> 2026-09-25 13:31:10.501343: bru_input.bru_comp(Intercept)
#> 2026-09-25 13:31:10.502562: bru_input.bm_pipe(Intercept)
#> 2026-09-25 13:31:10.503693: bru_input.bm_multi(Intercept:core)
#> 2026-09-25 13:31:10.504804: bru_input.bru_mapper(Intercept:core:main)
#> 2026-09-25 13:31:10.505796: bru_input(bru_input) for (Intercept)
#> 2026-09-25 13:31:10.511718: bru_input.bru_comp(field)
#> 2026-09-25 13:31:10.512859: bru_input.bm_pipe(field)
#> 2026-09-25 13:31:10.514048: bru_input.bm_multi(field:core)
#> 2026-09-25 13:31:10.515218: bru_input.bru_mapper(field:core:main)
#> 2026-09-25 13:31:10.516258: bru_input(bru_input) for (field)
#> 2026-09-25 13:31:10.529459: iinla: Start
#> 2026-09-25 13:31:10.53069: iinla: Evaluate component simplifications
#> 2026-09-25 13:31:10.531577: Simplify component mappers for each observation model
#> 2026-09-25 13:31:10.532644: Simplify component 'NA'
#> 2026-09-25 13:31:10.535249: Simplify component 'NA'
#> 2026-09-25 13:31:10.63898: iinla: Evaluate predictor linearisation
#> 2026-09-25 13:31:10.640514: Linearise predictor for each observation model
#> 2026-09-25 13:31:10.646535: iinla: Construct inla stack
#> 2026-09-25 13:31:10.661082: iinla: Model initialisation completed
#> 2026-09-25 13:31:10.662189: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:44.514909: iinla: Computation completed
#> 2026-09-25 13:31:45.239813: bru: Preprocessing
#> 2026-09-25 13:31:45.249406: Evaluate component inputs for each observation model
#> 2026-09-25 13:31:45.250566: bru_input(bru_comp_list)
#> 2026-09-25 13:31:45.251678: bru_input.bru_comp(x)
#> 2026-09-25 13:31:45.252763: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:45.253946: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:45.255258: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:45.256291: bru_input(bru_input) for (x)
#> 2026-09-25 13:31:45.262665: bru_input(bru_comp_list)
#> 2026-09-25 13:31:45.263829: bru_input.bru_comp(x)
#> 2026-09-25 13:31:45.264939: bru_input.bm_pipe(x)
#> 2026-09-25 13:31:45.273259: bru_input.bm_multi(x:core)
#> 2026-09-25 13:31:45.274393: bru_input.bru_mapper(x:core:main)
#> 2026-09-25 13:31:45.275341: bru_input(bru_input) for (x)
#> 2026-09-25 13:32:58.080497: bru_input(bru_input) for (LABEL)
#> 2026-09-25 13:32:59.325601: bru_input_text(bru_input) for (LABEL)
#> 2026-09-25 13:32:59.338123: bru_input.bru_comp(x)
#> 2026-09-25 13:32:59.339192: bru_input_text.bm_pipe(x)
#> 2026-09-25 13:32:59.3402: bru_input_text.bm_multi(x:core)
#> 2026-09-25 13:32:59.341127: bru_input_text.bru_mapper(x:core:main)
#> 2026-09-25 13:32:59.341904: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-09-25 13:30:35.8133: inlabru loaded
#> 2026-09-25 13:30:35.81369: Clear override options
#> 2026-09-25 13:30:53.875076: bru: Preprocessing
#> 2026-09-25 13:30:53.973825: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:54.801136: bru: Preprocessing
#> 2026-09-25 13:30:54.874234: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:55.256108: bru: Preprocessing
#> 2026-09-25 13:30:55.333406: iinla: Iteration 1 [max: 10]
#> 2026-09-25 13:30:55.679737: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-09-25 13:30:55.696732: iinla: Iteration 2 [max: 10]
#> 2026-09-25 13:30:56.347224: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-09-25 13:30:56.362195: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:56.363672: iinla: Iteration 3 [max: 10]
#> 2026-09-25 13:30:56.709113: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-09-25 13:30:56.724965: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:56.72651: iinla: Iteration 4 [max: 10]
#> 2026-09-25 13:30:57.085852: iinla: Max deviation from previous: 8.05% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-09-25 13:30:57.086845: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-09-25 13:30:57.08834: iinla: Iteration 5 [max: 10]
#> 2026-09-25 13:30:58.967425: bru: Preprocessing
#> 2026-09-25 13:30:59.015939: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:30:59.455197: bru: Preprocessing
#> 2026-09-25 13:30:59.523999: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:01.513042: bru: Preprocessing
#> 2026-09-25 13:31:01.577724: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:08.415496: bru: Preprocessing
#> 2026-09-25 13:31:08.459883: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:10.491676: bru: Preprocessing
#> 2026-09-25 13:31:10.662189: iinla: Iteration 1 [max: 1]
#> 2026-09-25 13:31:45.239813: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-09-25 13:30:35.8133: inlabru loaded (level 1)
#> 2026-09-25 13:30:35.81369: Clear override options (level 1)
#> 2026-09-25 13:30:53.875076: bru: Preprocessing (level 1)
#> 2026-09-25 13:30:53.887731: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:30:53.88901: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:30:53.89013: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:30:53.891243: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:30:53.892496: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:30:53.893675: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:30:53.894976: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:30:53.901525: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:30:53.902647: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:30:53.903947: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:30:53.905241: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:30:53.906308: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:30:53.919638: iinla: Start (level 3)
#> 2026-09-25 13:30:53.921005: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:30:53.921971: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:30:53.923161: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:53.925843: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:53.928624: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:53.930227: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:53.955792: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:30:53.972681: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:30:53.973825: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:30:54.77863: iinla: Computation completed (level 3)
#> 2026-09-25 13:30:54.801136: bru: Preprocessing (level 1)
#> 2026-09-25 13:30:54.808005: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:30:54.809208: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:30:54.810309: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:30:54.811507: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:30:54.812712: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:30:54.813854: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:30:54.814901: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:30:54.820665: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:30:54.821764: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:30:54.82295: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:30:54.824489: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:30:54.825937: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:30:54.838726: iinla: Start (level 3)
#> 2026-09-25 13:30:54.840457: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:30:54.841908: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:30:54.84338: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:54.846505: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:54.849884: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:54.851943: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:54.859431: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:30:54.872737: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:30:54.874234: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:30:55.231148: iinla: Computation completed (level 3)
#> 2026-09-25 13:30:55.256108: bru: Preprocessing (level 1)
#> 2026-09-25 13:30:55.264669: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:30:55.266153: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:30:55.267585: bru_input.bru_comp(z) (level 4)
#> 2026-09-25 13:30:55.268972: bru_input.bm_pipe(z) (level 5)
#> 2026-09-25 13:30:55.270618: bru_input.bm_multi(z:core) (level 5)
#> 2026-09-25 13:30:55.27211: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-09-25 13:30:55.2735: bru_input(bru_input) for (z) (level 5)
#> 2026-09-25 13:30:55.279972: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:30:55.281397: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:30:55.282908: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:30:55.284426: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:30:55.285859: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:30:55.298054: iinla: Start (level 3)
#> 2026-09-25 13:30:55.299754: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:30:55.301044: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:30:55.302461: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:55.305528: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:55.308825: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:55.310851: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:55.318545: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:30:55.331867: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:30:55.333406: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-09-25 13:30:55.672461: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8) (level 3)
#> 2026-09-25 13:30:55.674464: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8) (level 3)
#> 2026-09-25 13:30:55.677009: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 3)
#> 2026-09-25 13:30:55.678425: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4 (level 4)
#> 2026-09-25 13:30:55.679737: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 2)
#> 2026-09-25 13:30:55.681239: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:55.682887: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:55.696732: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-09-25 13:30:56.340775: iinla: Step rescaling: 162%, Expand (norm0 = 365, norm1 = 141.6, norm01 = 225.4) (level 3)
#> 2026-09-25 13:30:56.342757: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4) (level 3)
#> 2026-09-25 13:30:56.345085: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 3)
#> 2026-09-25 13:30:56.346179: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.007
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63 (level 4)
#> 2026-09-25 13:30:56.347224: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 2)
#> 2026-09-25 13:30:56.348495: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:56.349885: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:56.362195: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-09-25 13:30:56.363672: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-09-25 13:30:56.701899: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68) (level 3)
#> 2026-09-25 13:30:56.703965: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1741, norm01 = 10.68) (level 3)
#> 2026-09-25 13:30:56.706799: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-09-25 13:30:56.70798: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.242e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-09-25 13:30:56.709113: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-09-25 13:30:56.71039: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:56.711875: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:56.724965: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-09-25 13:30:56.72651: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-09-25 13:30:57.063707: iinla: Step rescaling: 162%, Expand (norm0 = 0.01902, norm1 = 0.007265, norm01 = 0.01176) (level 3)
#> 2026-09-25 13:30:57.065863: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 3.793e-08, norm01 = 0.01176) (level 3)
#> 2026-09-25 13:30:57.068562: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 3.784e-08, norm01 = 0.01176) (level 3)
#> 2026-09-25 13:30:57.069808: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 5.35e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 3.784e-08 (level 4)
#> 2026-09-25 13:30:57.071229: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:57.072762: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:57.085852: iinla: Max deviation from previous: 8.05% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-09-25 13:30:57.086845: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-09-25 13:30:57.08834: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-09-25 13:30:57.431973: iinla: Computation completed (level 3)
#> 2026-09-25 13:30:58.967425: bru: Preprocessing (level 1)
#> 2026-09-25 13:30:58.972683: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:30:58.973866: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:30:58.974958: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:30:58.976042: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:30:58.977251: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:30:58.978438: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:30:58.979513: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:30:58.990159: iinla: Start (level 3)
#> 2026-09-25 13:30:58.99147: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:30:58.992385: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:30:58.993435: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:58.996411: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:58.997927: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:59.005972: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:30:59.014804: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:30:59.015939: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:30:59.351667: iinla: Computation completed (level 3)
#> 2026-09-25 13:30:59.455197: bru: Preprocessing (level 1)
#> 2026-09-25 13:30:59.462099: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:30:59.463228: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:30:59.464268: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:30:59.465271: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:30:59.466367: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:30:59.467474: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:30:59.468451: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:30:59.474201: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:30:59.475236: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:30:59.476334: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:30:59.477648: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:30:59.478637: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:30:59.489306: iinla: Start (level 3)
#> 2026-09-25 13:30:59.490634: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:30:59.491602: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:30:59.492699: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:59.495297: Simplify component 'NA' (level 4)
#> 2026-09-25 13:30:59.503635: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:30:59.505194: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:30:59.510746: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:30:59.522814: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:30:59.523999: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:31:00.518662: iinla: Computation completed (level 3)
#> 2026-09-25 13:31:01.513042: bru: Preprocessing (level 1)
#> 2026-09-25 13:31:01.522227: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:31:01.523306: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:01.524337: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:01.525329: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:01.526421: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:01.527506: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:01.528472: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:31:01.534209: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:31:01.535252: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:31:01.536335: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:31:01.537422: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:31:01.538411: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:31:01.549453: iinla: Start (level 3)
#> 2026-09-25 13:31:01.550908: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:31:01.551817: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:31:01.552999: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:01.555491: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:01.558541: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:31:01.56: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:31:01.565644: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:31:01.576596: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:31:01.577724: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:31:01.918245: iinla: Computation completed (level 3)
#> 2026-09-25 13:31:03.669736: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:04.849748: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:31:04.850631: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:04.851436: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:04.852192: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:04.853065: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:04.853899: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:04.854636: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:31:04.860333: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:31:04.861165: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:31:04.862024: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:31:04.862845: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:31:04.863572: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:31:04.867855: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:31:04.868661: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:31:04.86951: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:31:04.870323: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:31:04.871063: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:31:04.880192: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:04.880988: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:04.881751: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:04.882576: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:04.883408: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:04.884129: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:31:04.888735: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:31:04.889525: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:31:04.890349: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:31:04.89119: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:31:04.891932: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:31:04.896153: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:31:04.896936: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:31:04.897803: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:31:04.898637: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:31:04.899374: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:31:04.903626: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.906: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.908386: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.910895: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:04.911714: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:04.912464: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:04.913291: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:04.914106: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:04.914831: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:31:04.919506: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:31:04.920281: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:31:04.921126: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:31:04.921955: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:31:04.922693: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:31:04.92697: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:31:04.927756: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:31:04.928616: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:31:04.929435: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:31:04.930169: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:31:04.934346: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.936602: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.938946: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.942364: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:04.94317: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:04.943948: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:04.944797: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:04.945623: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:04.946341: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:31:04.950963: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:31:04.951741: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:31:04.952593: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:31:04.953451: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:31:04.954179: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:31:04.958491: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:31:04.959273: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:31:04.96016: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:31:04.960997: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:31:04.961756: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:31:04.965991: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.968207: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:04.97057: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:08.415496: bru: Preprocessing (level 1)
#> 2026-09-25 13:31:08.420799: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:31:08.421918: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:08.422958: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:31:08.423964: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:31:08.425082: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:31:08.426174: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:31:08.427134: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:31:08.440308: iinla: Start (level 3)
#> 2026-09-25 13:31:08.441521: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:31:08.442363: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:31:08.443325: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:08.446213: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:31:08.447633: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:31:08.451638: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:31:08.458812: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:31:08.459883: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:31:09.277489: iinla: Computation completed (level 3)
#> 2026-09-25 13:31:10.491676: bru: Preprocessing (level 1)
#> 2026-09-25 13:31:10.498935: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:31:10.500293: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:10.501343: bru_input.bru_comp(Intercept) (level 4)
#> 2026-09-25 13:31:10.502562: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-09-25 13:31:10.503693: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-09-25 13:31:10.504804: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-09-25 13:31:10.505796: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-09-25 13:31:10.511718: bru_input.bru_comp(field) (level 4)
#> 2026-09-25 13:31:10.512859: bru_input.bm_pipe(field) (level 5)
#> 2026-09-25 13:31:10.514048: bru_input.bm_multi(field:core) (level 5)
#> 2026-09-25 13:31:10.515218: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-09-25 13:31:10.516258: bru_input(bru_input) for (field) (level 5)
#> 2026-09-25 13:31:10.529459: iinla: Start (level 3)
#> 2026-09-25 13:31:10.53069: iinla: Evaluate component simplifications (level 3)
#> 2026-09-25 13:31:10.531577: Simplify component mappers for each observation model (level 3)
#> 2026-09-25 13:31:10.532644: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:10.535249: Simplify component 'NA' (level 4)
#> 2026-09-25 13:31:10.63898: iinla: Evaluate predictor linearisation (level 3)
#> 2026-09-25 13:31:10.640514: Linearise predictor for each observation model (level 3)
#> 2026-09-25 13:31:10.646535: iinla: Construct inla stack (level 3)
#> 2026-09-25 13:31:10.661082: iinla: Model initialisation completed (level 3)
#> 2026-09-25 13:31:10.662189: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-09-25 13:31:44.514909: iinla: Computation completed (level 3)
#> 2026-09-25 13:31:45.239813: bru: Preprocessing (level 1)
#> 2026-09-25 13:31:45.249406: Evaluate component inputs for each observation model (level 3)
#> 2026-09-25 13:31:45.250566: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:45.251678: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:45.252763: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:45.253946: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:45.255258: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:45.256291: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:31:45.262665: bru_input(bru_comp_list) (level 4)
#> 2026-09-25 13:31:45.263829: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:31:45.264939: bru_input.bm_pipe(x) (level 5)
#> 2026-09-25 13:31:45.273259: bru_input.bm_multi(x:core) (level 5)
#> 2026-09-25 13:31:45.274393: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:31:45.275341: bru_input(bru_input) for (x) (level 5)
#> 2026-09-25 13:32:58.080497: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-09-25 13:32:59.325601: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-09-25 13:32:59.338123: bru_input.bru_comp(x) (level 4)
#> 2026-09-25 13:32:59.339192: bru_input_text.bm_pipe(x) (level 5)
#> 2026-09-25 13:32:59.3402: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-09-25 13:32:59.341127: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-09-25 13:32:59.341904: bru_input_text(bru_input) for (x) (level 5)