Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_offset(),
bru_log_reset(),
new_bru_log()
Examples
bru_log(verbosity = 2L)
#> 2026-07-28 16:31:39.828399: inlabru loaded
#> 2026-07-28 16:31:39.828853: Clear override options
#> 2026-07-28 16:31:53.380812: bru: Preprocessing
#> 2026-07-28 16:31:53.500182: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:54.368327: bru: Preprocessing
#> 2026-07-28 16:31:54.453792: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:54.797437: bru: Preprocessing
#> 2026-07-28 16:31:54.884923: iinla: Iteration 1 [max: 10]
#> 2026-07-28 16:31:55.210355: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.7, norm01 = 348)
#> 2026-07-28 16:31:55.231181: iinla: Iteration 2 [max: 10]
#> 2026-07-28 16:31:55.888376: iinla: Step rescaling: 99.7% (norm0 = 224.7, norm1 = 10.68, norm01 = 225.4)
#> 2026-07-28 16:31:55.906257: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:55.907932: iinla: Iteration 3 [max: 10]
#> 2026-07-28 16:31:56.218235: iinla: Step rescaling: 102% (norm0 = 10.69, norm1 = 0.01176, norm01 = 10.69)
#> 2026-07-28 16:31:56.238407: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:56.240309: iinla: Iteration 4 [max: 10]
#> 2026-07-28 16:31:56.572913: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:56.57409: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-07-28 16:31:56.575864: iinla: Iteration 5 [max: 10]
#> 2026-07-28 16:31:58.889554: bru: Preprocessing
#> 2026-07-28 16:31:58.950123: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:59.373182: bru: Preprocessing
#> 2026-07-28 16:31:59.456932: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:01.943841: bru: Preprocessing
#> 2026-07-28 16:32:02.022807: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:09.905286: bru: Preprocessing
#> 2026-07-28 16:32:09.964573: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:12.146586: bru: Preprocessing
#> 2026-07-28 16:32:12.339772: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:47.550491: bru: Preprocessing
format(bru_log())
#> 2026-07-28 16:31:39.828399: inlabru loaded
#> 2026-07-28 16:31:39.828853: Clear override options
#> 2026-07-28 16:31:53.380812: bru: Preprocessing
#> 2026-07-28 16:31:53.395633: Evaluate component inputs for each observation model
#> 2026-07-28 16:31:53.397181: bru_input(bru_comp_list)
#> 2026-07-28 16:31:53.398533: bru_input.bru_comp(x)
#> 2026-07-28 16:31:53.399883: bru_input.bm_pipe(x)
#> 2026-07-28 16:31:53.401459: bru_input.bm_multi(x:core)
#> 2026-07-28 16:31:53.402927: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:31:53.404506: bru_input(bru_input) for (x)
#> 2026-07-28 16:31:53.412361: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:31:53.413691: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:31:53.415224: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:31:53.416718: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:31:53.418105: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:31:53.434725: iinla: Start
#> 2026-07-28 16:31:53.436366: iinla: Evaluate component simplifications
#> 2026-07-28 16:31:53.437528: Simplify component mappers for each observation model
#> 2026-07-28 16:31:53.43899: Simplify component 'NA'
#> 2026-07-28 16:31:53.442398: Simplify component 'NA'
#> 2026-07-28 16:31:53.445976: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:53.447837: Linearise predictor for each observation model
#> 2026-07-28 16:31:53.477982: iinla: Construct inla stack
#> 2026-07-28 16:31:53.498629: iinla: Model initialisation completed
#> 2026-07-28 16:31:53.500182: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:54.345371: iinla: Computation completed
#> 2026-07-28 16:31:54.368327: bru: Preprocessing
#> 2026-07-28 16:31:54.377319: Evaluate component inputs for each observation model
#> 2026-07-28 16:31:54.378753: bru_input(bru_comp_list)
#> 2026-07-28 16:31:54.380115: bru_input.bru_comp(x)
#> 2026-07-28 16:31:54.381495: bru_input.bm_pipe(x)
#> 2026-07-28 16:31:54.382993: bru_input.bm_multi(x:core)
#> 2026-07-28 16:31:54.384525: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:31:54.385854: bru_input(bru_input) for (x)
#> 2026-07-28 16:31:54.3931: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:31:54.394425: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:31:54.395841: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:31:54.39727: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:31:54.398585: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:31:54.414392: iinla: Start
#> 2026-07-28 16:31:54.41623: iinla: Evaluate component simplifications
#> 2026-07-28 16:31:54.417522: Simplify component mappers for each observation model
#> 2026-07-28 16:31:54.41909: Simplify component 'NA'
#> 2026-07-28 16:31:54.422737: Simplify component 'NA'
#> 2026-07-28 16:31:54.426739: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:54.428861: Linearise predictor for each observation model
#> 2026-07-28 16:31:54.436996: iinla: Construct inla stack
#> 2026-07-28 16:31:54.45218: iinla: Model initialisation completed
#> 2026-07-28 16:31:54.453792: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:54.773305: iinla: Computation completed
#> 2026-07-28 16:31:54.797437: bru: Preprocessing
#> 2026-07-28 16:31:54.807225: Evaluate component inputs for each observation model
#> 2026-07-28 16:31:54.808893: bru_input(bru_comp_list)
#> 2026-07-28 16:31:54.810522: bru_input.bru_comp(z)
#> 2026-07-28 16:31:54.812091: bru_input.bm_pipe(z)
#> 2026-07-28 16:31:54.813813: bru_input.bm_multi(z:core)
#> 2026-07-28 16:31:54.815509: bru_input.bru_mapper(z:core:main)
#> 2026-07-28 16:31:54.817037: bru_input(bru_input) for (z)
#> 2026-07-28 16:31:54.824605: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:31:54.826089: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:31:54.827742: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:31:54.829389: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:31:54.830962: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:31:54.845171: iinla: Start
#> 2026-07-28 16:31:54.846969: iinla: Evaluate component simplifications
#> 2026-07-28 16:31:54.848265: Simplify component mappers for each observation model
#> 2026-07-28 16:31:54.849801: Simplify component 'NA'
#> 2026-07-28 16:31:54.853291: Simplify component 'NA'
#> 2026-07-28 16:31:54.8573: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:54.859401: Linearise predictor for each observation model
#> 2026-07-28 16:31:54.868192: iinla: Construct inla stack
#> 2026-07-28 16:31:54.883286: iinla: Model initialisation completed
#> 2026-07-28 16:31:54.884923: iinla: Iteration 1 [max: 10]
#> 2026-07-28 16:31:55.201565: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 348)
#> 2026-07-28 16:31:55.204236: iinla: Step rescaling: 38.2%, Contract (norm0 = 399.2, norm1 = 295.3, norm01 = 348)
#> 2026-07-28 16:31:55.207529: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.7, norm01 = 348)
#> 2026-07-28 16:31:55.208991: iinla: |lin1-lin0| = 348
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5
#> 2026-07-28 16:31:55.210355: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.7, norm01 = 348)
#> 2026-07-28 16:31:55.211964: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:55.213871: Linearise predictor for each observation model
#> 2026-07-28 16:31:55.231181: iinla: Iteration 2 [max: 10]
#> 2026-07-28 16:31:55.880598: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4)
#> 2026-07-28 16:31:55.882924: iinla: Step rescaling: 100%, Overstep (norm0 = 225.4, norm1 = 10.71, norm01 = 225.4)
#> 2026-07-28 16:31:55.88591: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.7, norm1 = 10.68, norm01 = 225.4)
#> 2026-07-28 16:31:55.887206: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-07-28 16:31:55.888376: iinla: Step rescaling: 99.7% (norm0 = 224.7, norm1 = 10.68, norm01 = 225.4)
#> 2026-07-28 16:31:55.889756: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:55.891286: Linearise predictor for each observation model
#> 2026-07-28 16:31:55.906257: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:55.907932: iinla: Iteration 3 [max: 10]
#> 2026-07-28 16:31:56.209203: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.153, norm01 = 10.69)
#> 2026-07-28 16:31:56.211822: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.69)
#> 2026-07-28 16:31:56.215342: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.69, norm1 = 0.01176, norm01 = 10.69)
#> 2026-07-28 16:31:56.216895: iinla: |lin1-lin0| = 10.69
#> <eta-lin1,delta>/|delta| = -1.243e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-07-28 16:31:56.218235: iinla: Step rescaling: 102% (norm0 = 10.69, norm1 = 0.01176, norm01 = 10.69)
#> 2026-07-28 16:31:56.219888: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:56.221579: Linearise predictor for each observation model
#> 2026-07-28 16:31:56.238407: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:56.240309: iinla: Iteration 4 [max: 10]
#> 2026-07-28 16:31:56.545051: iinla: Step rescaling: 162%, Expand (norm0 = 0.01902, norm1 = 0.007267, norm01 = 0.01176)
#> 2026-07-28 16:31:56.54782: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 3.793e-08, norm01 = 0.01176)
#> 2026-07-28 16:31:56.551307: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 3.785e-08, norm01 = 0.01176)
#> 2026-07-28 16:31:56.552824: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 5.349e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 3.785e-08
#> 2026-07-28 16:31:56.554503: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:56.556333: Linearise predictor for each observation model
#> 2026-07-28 16:31:56.572913: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:56.57409: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-07-28 16:31:56.575864: iinla: Iteration 5 [max: 10]
#> 2026-07-28 16:31:56.887877: iinla: Computation completed
#> 2026-07-28 16:31:58.889554: bru: Preprocessing
#> 2026-07-28 16:31:58.896485: Evaluate component inputs for each observation model
#> 2026-07-28 16:31:58.898033: bru_input(bru_comp_list)
#> 2026-07-28 16:31:58.899418: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:31:58.900767: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:31:58.902265: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:31:58.90375: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:31:58.905151: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:31:58.918497: iinla: Start
#> 2026-07-28 16:31:58.920064: iinla: Evaluate component simplifications
#> 2026-07-28 16:31:58.921135: Simplify component mappers for each observation model
#> 2026-07-28 16:31:58.922398: Simplify component 'NA'
#> 2026-07-28 16:31:58.92592: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:58.927629: Linearise predictor for each observation model
#> 2026-07-28 16:31:58.93803: iinla: Construct inla stack
#> 2026-07-28 16:31:58.948732: iinla: Model initialisation completed
#> 2026-07-28 16:31:58.950123: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:59.247765: iinla: Computation completed
#> 2026-07-28 16:31:59.373182: bru: Preprocessing
#> 2026-07-28 16:31:59.381405: Evaluate component inputs for each observation model
#> 2026-07-28 16:31:59.382758: bru_input(bru_comp_list)
#> 2026-07-28 16:31:59.383991: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:31:59.385198: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:31:59.386547: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:31:59.387871: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:31:59.389093: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:31:59.396113: bru_input.bru_comp(field)
#> 2026-07-28 16:31:59.397357: bru_input.bm_pipe(field)
#> 2026-07-28 16:31:59.398717: bru_input.bm_multi(field:core)
#> 2026-07-28 16:31:59.400057: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:31:59.401249: bru_input(bru_input) for (field)
#> 2026-07-28 16:31:59.415102: iinla: Start
#> 2026-07-28 16:31:59.416592: iinla: Evaluate component simplifications
#> 2026-07-28 16:31:59.417626: Simplify component mappers for each observation model
#> 2026-07-28 16:31:59.418905: Simplify component 'NA'
#> 2026-07-28 16:31:59.421881: Simplify component 'NA'
#> 2026-07-28 16:31:59.431511: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:31:59.433491: Linearise predictor for each observation model
#> 2026-07-28 16:31:59.44062: iinla: Construct inla stack
#> 2026-07-28 16:31:59.455561: iinla: Model initialisation completed
#> 2026-07-28 16:31:59.456932: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:00.489957: iinla: Computation completed
#> 2026-07-28 16:32:01.943841: bru: Preprocessing
#> 2026-07-28 16:32:01.954403: Evaluate component inputs for each observation model
#> 2026-07-28 16:32:01.955726: bru_input(bru_comp_list)
#> 2026-07-28 16:32:01.956949: bru_input.bru_comp(x)
#> 2026-07-28 16:32:01.958199: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:01.959602: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:01.960927: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:01.962166: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:01.969157: bru_input.bru_comp(field)
#> 2026-07-28 16:32:01.970362: bru_input.bm_pipe(field)
#> 2026-07-28 16:32:01.971658: bru_input.bm_multi(field:core)
#> 2026-07-28 16:32:01.972975: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:32:01.97418: bru_input(bru_input) for (field)
#> 2026-07-28 16:32:01.987661: iinla: Start
#> 2026-07-28 16:32:01.989121: iinla: Evaluate component simplifications
#> 2026-07-28 16:32:01.99012: Simplify component mappers for each observation model
#> 2026-07-28 16:32:01.99136: Simplify component 'NA'
#> 2026-07-28 16:32:01.994521: Simplify component 'NA'
#> 2026-07-28 16:32:01.998466: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:32:02.000277: Linearise predictor for each observation model
#> 2026-07-28 16:32:02.007407: iinla: Construct inla stack
#> 2026-07-28 16:32:02.021254: iinla: Model initialisation completed
#> 2026-07-28 16:32:02.022807: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:02.326476: iinla: Computation completed
#> 2026-07-28 16:32:04.239489: bru_input(bru_comp_list)
#> 2026-07-28 16:32:05.585385: Evaluate component inputs for each observation model
#> 2026-07-28 16:32:05.58647: bru_input(bru_comp_list)
#> 2026-07-28 16:32:05.587466: bru_input.bru_comp(x)
#> 2026-07-28 16:32:05.588378: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:05.58945: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:05.590502: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:05.591485: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:05.598435: bru_input.bru_comp(field)
#> 2026-07-28 16:32:05.599347: bru_input.bm_pipe(field)
#> 2026-07-28 16:32:05.600319: bru_input.bm_multi(field:core)
#> 2026-07-28 16:32:05.601331: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:32:05.60223: bru_input(bru_input) for (field)
#> 2026-07-28 16:32:05.60776: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:32:05.608773: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:32:05.609897: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:32:05.610949: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:32:05.61179: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:32:05.622644: bru_input(bru_comp_list)
#> 2026-07-28 16:32:05.62362: bru_input.bru_comp(x)
#> 2026-07-28 16:32:05.624516: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:05.625538: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:05.626548: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:05.627457: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:05.632863: bru_input.bru_comp(field)
#> 2026-07-28 16:32:05.63391: bru_input.bm_pipe(field)
#> 2026-07-28 16:32:05.634965: bru_input.bm_multi(field:core)
#> 2026-07-28 16:32:05.635978: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:32:05.636879: bru_input(bru_input) for (field)
#> 2026-07-28 16:32:05.6422: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:32:05.643157: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:32:05.644186: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:32:05.645191: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:32:05.646111: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:32:05.651402: Simplify component 'NA'
#> 2026-07-28 16:32:05.654133: Simplify component 'NA'
#> 2026-07-28 16:32:05.657116: Simplify component 'NA'
#> 2026-07-28 16:32:05.660271: bru_input(bru_comp_list)
#> 2026-07-28 16:32:05.661185: bru_input.bru_comp(x)
#> 2026-07-28 16:32:05.661988: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:05.662938: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:05.663879: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:05.664718: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:05.67006: bru_input.bru_comp(field)
#> 2026-07-28 16:32:05.67099: bru_input.bm_pipe(field)
#> 2026-07-28 16:32:05.672117: bru_input.bm_multi(field:core)
#> 2026-07-28 16:32:05.673155: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:32:05.67426: bru_input(bru_input) for (field)
#> 2026-07-28 16:32:05.679518: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:32:05.680556: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:32:05.681675: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:32:05.682767: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:32:05.68381: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:32:05.689112: Simplify component 'NA'
#> 2026-07-28 16:32:05.691746: Simplify component 'NA'
#> 2026-07-28 16:32:05.694547: Simplify component 'NA'
#> 2026-07-28 16:32:05.698846: bru_input(bru_comp_list)
#> 2026-07-28 16:32:05.699862: bru_input.bru_comp(x)
#> 2026-07-28 16:32:05.700809: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:05.702003: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:05.703084: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:05.704136: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:05.709734: bru_input.bru_comp(field)
#> 2026-07-28 16:32:05.710727: bru_input.bm_pipe(field)
#> 2026-07-28 16:32:05.711714: bru_input.bm_multi(field:core)
#> 2026-07-28 16:32:05.712831: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:32:05.713787: bru_input(bru_input) for (field)
#> 2026-07-28 16:32:05.719114: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:32:05.720152: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:32:05.721269: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:32:05.727793: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:32:05.728765: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:32:05.734032: Simplify component 'NA'
#> 2026-07-28 16:32:05.736687: Simplify component 'NA'
#> 2026-07-28 16:32:05.7395: Simplify component 'NA'
#> 2026-07-28 16:32:09.905286: bru: Preprocessing
#> 2026-07-28 16:32:09.911815: Evaluate component inputs for each observation model
#> 2026-07-28 16:32:09.913346: bru_input(bru_comp_list)
#> 2026-07-28 16:32:09.914785: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:32:09.921841: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:32:09.923254: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:32:09.924593: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:32:09.925814: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:32:09.94047: iinla: Start
#> 2026-07-28 16:32:09.941949: iinla: Evaluate component simplifications
#> 2026-07-28 16:32:09.942933: Simplify component mappers for each observation model
#> 2026-07-28 16:32:09.94416: Simplify component 'NA'
#> 2026-07-28 16:32:09.947716: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:32:09.949378: Linearise predictor for each observation model
#> 2026-07-28 16:32:09.954452: iinla: Construct inla stack
#> 2026-07-28 16:32:09.963262: iinla: Model initialisation completed
#> 2026-07-28 16:32:09.964573: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:10.796771: iinla: Computation completed
#> 2026-07-28 16:32:12.146586: bru: Preprocessing
#> 2026-07-28 16:32:12.155156: Evaluate component inputs for each observation model
#> 2026-07-28 16:32:12.156522: bru_input(bru_comp_list)
#> 2026-07-28 16:32:12.157803: bru_input.bru_comp(Intercept)
#> 2026-07-28 16:32:12.159233: bru_input.bm_pipe(Intercept)
#> 2026-07-28 16:32:12.160693: bru_input.bm_multi(Intercept:core)
#> 2026-07-28 16:32:12.162181: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-28 16:32:12.163403: bru_input(bru_input) for (Intercept)
#> 2026-07-28 16:32:12.170845: bru_input.bru_comp(field)
#> 2026-07-28 16:32:12.172097: bru_input.bm_pipe(field)
#> 2026-07-28 16:32:12.173445: bru_input.bm_multi(field:core)
#> 2026-07-28 16:32:12.174746: bru_input.bru_mapper(field:core:main)
#> 2026-07-28 16:32:12.175882: bru_input(bru_input) for (field)
#> 2026-07-28 16:32:12.19238: iinla: Start
#> 2026-07-28 16:32:12.193825: iinla: Evaluate component simplifications
#> 2026-07-28 16:32:12.194878: Simplify component mappers for each observation model
#> 2026-07-28 16:32:12.196106: Simplify component 'NA'
#> 2026-07-28 16:32:12.199216: Simplify component 'NA'
#> 2026-07-28 16:32:12.310203: iinla: Evaluate predictor linearisation
#> 2026-07-28 16:32:12.311933: Linearise predictor for each observation model
#> 2026-07-28 16:32:12.31966: iinla: Construct inla stack
#> 2026-07-28 16:32:12.338361: iinla: Model initialisation completed
#> 2026-07-28 16:32:12.339772: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:47.118654: iinla: Computation completed
#> 2026-07-28 16:32:47.550491: bru: Preprocessing
#> 2026-07-28 16:32:47.570922: Evaluate component inputs for each observation model
#> 2026-07-28 16:32:47.572268: bru_input(bru_comp_list)
#> 2026-07-28 16:32:47.573424: bru_input.bru_comp(x)
#> 2026-07-28 16:32:47.574611: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:47.575935: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:47.577232: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:47.578403: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:47.584422: bru_input(bru_comp_list)
#> 2026-07-28 16:32:47.585696: bru_input.bru_comp(x)
#> 2026-07-28 16:32:47.586878: bru_input.bm_pipe(x)
#> 2026-07-28 16:32:47.588166: bru_input.bm_multi(x:core)
#> 2026-07-28 16:32:47.58943: bru_input.bru_mapper(x:core:main)
#> 2026-07-28 16:32:47.590623: bru_input(bru_input) for (x)
#> 2026-07-28 16:32:51.203344: bru_input(bru_input) for (LABEL)
#> 2026-07-28 16:32:52.500102: bru_input_text(bru_input) for (LABEL)
#> 2026-07-28 16:32:52.510884: bru_input.bru_comp(x)
#> 2026-07-28 16:32:52.511963: bru_input_text.bm_pipe(x)
#> 2026-07-28 16:32:52.513171: bru_input_text.bm_multi(x:core)
#> 2026-07-28 16:32:52.514385: bru_input_text.bru_mapper(x:core:main)
#> 2026-07-28 16:32:52.515399: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-07-28 16:31:39.828399: inlabru loaded
#> 2026-07-28 16:31:39.828853: Clear override options
#> 2026-07-28 16:31:53.380812: bru: Preprocessing
#> 2026-07-28 16:31:53.500182: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:54.368327: bru: Preprocessing
#> 2026-07-28 16:31:54.453792: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:54.797437: bru: Preprocessing
#> 2026-07-28 16:31:54.884923: iinla: Iteration 1 [max: 10]
#> 2026-07-28 16:31:55.210355: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.7, norm01 = 348)
#> 2026-07-28 16:31:55.231181: iinla: Iteration 2 [max: 10]
#> 2026-07-28 16:31:55.888376: iinla: Step rescaling: 99.7% (norm0 = 224.7, norm1 = 10.68, norm01 = 225.4)
#> 2026-07-28 16:31:55.906257: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:55.907932: iinla: Iteration 3 [max: 10]
#> 2026-07-28 16:31:56.218235: iinla: Step rescaling: 102% (norm0 = 10.69, norm1 = 0.01176, norm01 = 10.69)
#> 2026-07-28 16:31:56.238407: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:56.240309: iinla: Iteration 4 [max: 10]
#> 2026-07-28 16:31:56.572913: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-07-28 16:31:56.57409: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-07-28 16:31:56.575864: iinla: Iteration 5 [max: 10]
#> 2026-07-28 16:31:58.889554: bru: Preprocessing
#> 2026-07-28 16:31:58.950123: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:31:59.373182: bru: Preprocessing
#> 2026-07-28 16:31:59.456932: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:01.943841: bru: Preprocessing
#> 2026-07-28 16:32:02.022807: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:09.905286: bru: Preprocessing
#> 2026-07-28 16:32:09.964573: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:12.146586: bru: Preprocessing
#> 2026-07-28 16:32:12.339772: iinla: Iteration 1 [max: 1]
#> 2026-07-28 16:32:47.550491: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-07-28 16:31:39.828399: inlabru loaded (level 1)
#> 2026-07-28 16:31:39.828853: Clear override options (level 1)
#> 2026-07-28 16:31:53.380812: bru: Preprocessing (level 1)
#> 2026-07-28 16:31:53.395633: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:31:53.397181: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:31:53.398533: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:31:53.399883: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:31:53.401459: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:31:53.402927: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:31:53.404506: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:31:53.412361: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:31:53.413691: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:31:53.415224: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:31:53.416718: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:31:53.418105: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:31:53.434725: iinla: Start (level 3)
#> 2026-07-28 16:31:53.436366: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:31:53.437528: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:31:53.43899: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:53.442398: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:53.445976: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:53.447837: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:53.477982: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:31:53.498629: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:31:53.500182: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:31:54.345371: iinla: Computation completed (level 3)
#> 2026-07-28 16:31:54.368327: bru: Preprocessing (level 1)
#> 2026-07-28 16:31:54.377319: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:31:54.378753: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:31:54.380115: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:31:54.381495: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:31:54.382993: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:31:54.384525: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:31:54.385854: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:31:54.3931: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:31:54.394425: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:31:54.395841: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:31:54.39727: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:31:54.398585: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:31:54.414392: iinla: Start (level 3)
#> 2026-07-28 16:31:54.41623: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:31:54.417522: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:31:54.41909: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:54.422737: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:54.426739: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:54.428861: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:54.436996: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:31:54.45218: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:31:54.453792: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:31:54.773305: iinla: Computation completed (level 3)
#> 2026-07-28 16:31:54.797437: bru: Preprocessing (level 1)
#> 2026-07-28 16:31:54.807225: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:31:54.808893: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:31:54.810522: bru_input.bru_comp(z) (level 4)
#> 2026-07-28 16:31:54.812091: bru_input.bm_pipe(z) (level 5)
#> 2026-07-28 16:31:54.813813: bru_input.bm_multi(z:core) (level 5)
#> 2026-07-28 16:31:54.815509: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-07-28 16:31:54.817037: bru_input(bru_input) for (z) (level 5)
#> 2026-07-28 16:31:54.824605: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:31:54.826089: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:31:54.827742: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:31:54.829389: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:31:54.830962: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:31:54.845171: iinla: Start (level 3)
#> 2026-07-28 16:31:54.846969: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:31:54.848265: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:31:54.849801: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:54.853291: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:54.8573: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:54.859401: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:54.868192: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:31:54.883286: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:31:54.884923: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-07-28 16:31:55.201565: iinla: Step rescaling: 61.8%, Contract (norm0 = 1970, norm1 = 1808, norm01 = 348) (level 3)
#> 2026-07-28 16:31:55.204236: iinla: Step rescaling: 38.2%, Contract (norm0 = 399.2, norm1 = 295.3, norm01 = 348) (level 3)
#> 2026-07-28 16:31:55.207529: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.2, norm1 = 225.7, norm01 = 348) (level 3)
#> 2026-07-28 16:31:55.208991: iinla: |lin1-lin0| = 348
#> <eta-lin1,delta>/|delta| = -198.4
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.5 (level 4)
#> 2026-07-28 16:31:55.210355: iinla: Step rescaling: 27.4% (norm0 = 184.2, norm1 = 225.7, norm01 = 348) (level 2)
#> 2026-07-28 16:31:55.211964: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:55.213871: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:55.231181: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-07-28 16:31:55.880598: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4) (level 3)
#> 2026-07-28 16:31:55.882924: iinla: Step rescaling: 100%, Overstep (norm0 = 225.4, norm1 = 10.71, norm01 = 225.4) (level 3)
#> 2026-07-28 16:31:55.88591: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.7, norm1 = 10.68, norm01 = 225.4) (level 3)
#> 2026-07-28 16:31:55.887206: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-07-28 16:31:55.888376: iinla: Step rescaling: 99.7% (norm0 = 224.7, norm1 = 10.68, norm01 = 225.4) (level 2)
#> 2026-07-28 16:31:55.889756: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:55.891286: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:55.906257: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-07-28 16:31:55.907932: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-07-28 16:31:56.209203: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.153, norm01 = 10.69) (level 3)
#> 2026-07-28 16:31:56.211822: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.69) (level 3)
#> 2026-07-28 16:31:56.215342: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.69, norm1 = 0.01176, norm01 = 10.69) (level 3)
#> 2026-07-28 16:31:56.216895: iinla: |lin1-lin0| = 10.69
#> <eta-lin1,delta>/|delta| = -1.243e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-07-28 16:31:56.218235: iinla: Step rescaling: 102% (norm0 = 10.69, norm1 = 0.01176, norm01 = 10.69) (level 2)
#> 2026-07-28 16:31:56.219888: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:56.221579: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:56.238407: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-07-28 16:31:56.240309: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-07-28 16:31:56.545051: iinla: Step rescaling: 162%, Expand (norm0 = 0.01902, norm1 = 0.007267, norm01 = 0.01176) (level 3)
#> 2026-07-28 16:31:56.54782: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 3.793e-08, norm01 = 0.01176) (level 3)
#> 2026-07-28 16:31:56.551307: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 3.785e-08, norm01 = 0.01176) (level 3)
#> 2026-07-28 16:31:56.552824: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 5.349e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 3.785e-08 (level 4)
#> 2026-07-28 16:31:56.554503: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:56.556333: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:56.572913: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-07-28 16:31:56.57409: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-07-28 16:31:56.575864: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-07-28 16:31:56.887877: iinla: Computation completed (level 3)
#> 2026-07-28 16:31:58.889554: bru: Preprocessing (level 1)
#> 2026-07-28 16:31:58.896485: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:31:58.898033: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:31:58.899418: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:31:58.900767: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:31:58.902265: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:31:58.90375: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:31:58.905151: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:31:58.918497: iinla: Start (level 3)
#> 2026-07-28 16:31:58.920064: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:31:58.921135: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:31:58.922398: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:58.92592: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:58.927629: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:58.93803: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:31:58.948732: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:31:58.950123: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:31:59.247765: iinla: Computation completed (level 3)
#> 2026-07-28 16:31:59.373182: bru: Preprocessing (level 1)
#> 2026-07-28 16:31:59.381405: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:31:59.382758: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:31:59.383991: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:31:59.385198: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:31:59.386547: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:31:59.387871: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:31:59.389093: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:31:59.396113: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:31:59.397357: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:31:59.398717: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:31:59.400057: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:31:59.401249: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:31:59.415102: iinla: Start (level 3)
#> 2026-07-28 16:31:59.416592: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:31:59.417626: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:31:59.418905: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:59.421881: Simplify component 'NA' (level 4)
#> 2026-07-28 16:31:59.431511: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:31:59.433491: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:31:59.44062: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:31:59.455561: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:31:59.456932: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:32:00.489957: iinla: Computation completed (level 3)
#> 2026-07-28 16:32:01.943841: bru: Preprocessing (level 1)
#> 2026-07-28 16:32:01.954403: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:32:01.955726: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:01.956949: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:01.958199: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:01.959602: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:01.960927: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:01.962166: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:01.969157: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:32:01.970362: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:32:01.971658: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:32:01.972975: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:32:01.97418: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:32:01.987661: iinla: Start (level 3)
#> 2026-07-28 16:32:01.989121: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:32:01.99012: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:32:01.99136: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:01.994521: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:01.998466: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:32:02.000277: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:32:02.007407: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:32:02.021254: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:32:02.022807: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:32:02.326476: iinla: Computation completed (level 3)
#> 2026-07-28 16:32:04.239489: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:05.585385: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:32:05.58647: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:05.587466: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:05.588378: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:05.58945: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:05.590502: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:05.591485: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:05.598435: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:32:05.599347: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:32:05.600319: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:32:05.601331: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:32:05.60223: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:32:05.60776: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:32:05.608773: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:32:05.609897: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:32:05.610949: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:32:05.61179: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:32:05.622644: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:05.62362: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:05.624516: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:05.625538: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:05.626548: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:05.627457: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:05.632863: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:32:05.63391: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:32:05.634965: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:32:05.635978: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:32:05.636879: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:32:05.6422: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:32:05.643157: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:32:05.644186: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:32:05.645191: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:32:05.646111: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:32:05.651402: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.654133: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.657116: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.660271: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:05.661185: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:05.661988: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:05.662938: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:05.663879: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:05.664718: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:05.67006: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:32:05.67099: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:32:05.672117: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:32:05.673155: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:32:05.67426: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:32:05.679518: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:32:05.680556: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:32:05.681675: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:32:05.682767: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:32:05.68381: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:32:05.689112: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.691746: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.694547: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.698846: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:05.699862: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:05.700809: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:05.702003: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:05.703084: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:05.704136: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:05.709734: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:32:05.710727: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:32:05.711714: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:32:05.712831: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:32:05.713787: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:32:05.719114: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:32:05.720152: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:32:05.721269: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:32:05.727793: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:32:05.728765: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:32:05.734032: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.736687: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:05.7395: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:09.905286: bru: Preprocessing (level 1)
#> 2026-07-28 16:32:09.911815: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:32:09.913346: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:09.914785: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:32:09.921841: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:32:09.923254: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:32:09.924593: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:32:09.925814: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:32:09.94047: iinla: Start (level 3)
#> 2026-07-28 16:32:09.941949: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:32:09.942933: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:32:09.94416: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:09.947716: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:32:09.949378: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:32:09.954452: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:32:09.963262: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:32:09.964573: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:32:10.796771: iinla: Computation completed (level 3)
#> 2026-07-28 16:32:12.146586: bru: Preprocessing (level 1)
#> 2026-07-28 16:32:12.155156: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:32:12.156522: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:12.157803: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-28 16:32:12.159233: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-28 16:32:12.160693: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-28 16:32:12.162181: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-28 16:32:12.163403: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-28 16:32:12.170845: bru_input.bru_comp(field) (level 4)
#> 2026-07-28 16:32:12.172097: bru_input.bm_pipe(field) (level 5)
#> 2026-07-28 16:32:12.173445: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-28 16:32:12.174746: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-28 16:32:12.175882: bru_input(bru_input) for (field) (level 5)
#> 2026-07-28 16:32:12.19238: iinla: Start (level 3)
#> 2026-07-28 16:32:12.193825: iinla: Evaluate component simplifications (level 3)
#> 2026-07-28 16:32:12.194878: Simplify component mappers for each observation model (level 3)
#> 2026-07-28 16:32:12.196106: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:12.199216: Simplify component 'NA' (level 4)
#> 2026-07-28 16:32:12.310203: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-28 16:32:12.311933: Linearise predictor for each observation model (level 3)
#> 2026-07-28 16:32:12.31966: iinla: Construct inla stack (level 3)
#> 2026-07-28 16:32:12.338361: iinla: Model initialisation completed (level 3)
#> 2026-07-28 16:32:12.339772: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-28 16:32:47.118654: iinla: Computation completed (level 3)
#> 2026-07-28 16:32:47.550491: bru: Preprocessing (level 1)
#> 2026-07-28 16:32:47.570922: Evaluate component inputs for each observation model (level 3)
#> 2026-07-28 16:32:47.572268: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:47.573424: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:47.574611: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:47.575935: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:47.577232: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:47.578403: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:47.584422: bru_input(bru_comp_list) (level 4)
#> 2026-07-28 16:32:47.585696: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:47.586878: bru_input.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:47.588166: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:47.58943: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:47.590623: bru_input(bru_input) for (x) (level 5)
#> 2026-07-28 16:32:51.203344: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-07-28 16:32:52.500102: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-07-28 16:32:52.510884: bru_input.bru_comp(x) (level 4)
#> 2026-07-28 16:32:52.511963: bru_input_text.bm_pipe(x) (level 5)
#> 2026-07-28 16:32:52.513171: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-07-28 16:32:52.514385: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-07-28 16:32:52.515399: bru_input_text(bru_input) for (x) (level 5)