Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-07-08 11:30:53.964308: inlabru loaded
#> 2026-07-08 11:30:53.964766: Clear override options
#> 2026-07-08 11:31:04.343678: bru: Preprocessing
#> 2026-07-08 11:31:04.460268: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:05.408963: bru: Preprocessing
#> 2026-07-08 11:31:05.515573: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:06.029721: bru: Preprocessing
#> 2026-07-08 11:31:06.121575: iinla: Iteration 1 [max: 10]
#> 2026-07-08 11:31:06.574743: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-07-08 11:31:06.604289: iinla: Iteration 2 [max: 10]
#> 2026-07-08 11:31:07.41216: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-07-08 11:31:07.440762: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:07.443201: iinla: Iteration 3 [max: 10]
#> 2026-07-08 11:31:07.893878: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-07-08 11:31:07.922018: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:07.924611: iinla: Iteration 4 [max: 10]
#> 2026-07-08 11:31:08.408586: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:08.409873: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-07-08 11:31:08.412381: iinla: Iteration 5 [max: 10]
#> 2026-07-08 11:31:12.637409: bru: Preprocessing
#> 2026-07-08 11:31:12.697313: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:15.154181: bru: Preprocessing
#> 2026-07-08 11:31:15.501407: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:00.379855: bru: Preprocessing
#> 2026-07-08 11:32:00.481069: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:06.956944: bru: Preprocessing
#> 2026-07-08 11:32:07.016954: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:10.131972: bru: Preprocessing
#> 2026-07-08 11:32:10.476392: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:55.349898: bru: Preprocessing
format(bru_log())
#> 2026-07-08 11:30:53.964308: inlabru loaded
#> 2026-07-08 11:30:53.964766: Clear override options
#> 2026-07-08 11:31:04.343678: bru: Preprocessing
#> 2026-07-08 11:31:04.359429: Evaluate component inputs for each observation model
#> 2026-07-08 11:31:04.360987: bru_input(bru_comp_list)
#> 2026-07-08 11:31:04.362551: bru_input.bru_comp(x)
#> 2026-07-08 11:31:04.363922: bru_input.bm_pipe(x)
#> 2026-07-08 11:31:04.365429: bru_input.bm_multi(x:core)
#> 2026-07-08 11:31:04.366937: bru_input.bru_mapper(x:core:main)
#> 2026-07-08 11:31:04.368539: bru_input(bru_input) for (x)
#> 2026-07-08 11:31:04.376433: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:31:04.377771: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:31:04.379192: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:31:04.380573: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:31:04.387383: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:31:04.407011: iinla: Start
#> 2026-07-08 11:31:04.408708: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:04.409912: Linearise components for each observation model
#> 2026-07-08 11:31:04.411448: Linearise component 'x'
#> 2026-07-08 11:31:04.414464: Linearise component 'Intercept'
#> 2026-07-08 11:31:04.417218: iinla: Evaluate component simplifications
#> 2026-07-08 11:31:04.418471: Simplify component mappers for each observation model
#> 2026-07-08 11:31:04.419923: Simplify component 'x'
#> 2026-07-08 11:31:04.423123: Simplify component 'Intercept'
#> 2026-07-08 11:31:04.426121: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:04.438792: iinla: Construct inla stack
#> 2026-07-08 11:31:04.458772: iinla: Model initialisation completed
#> 2026-07-08 11:31:04.460268: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:05.379776: iinla: Computation completed
#> 2026-07-08 11:31:05.408963: bru: Preprocessing
#> 2026-07-08 11:31:05.419797: Evaluate component inputs for each observation model
#> 2026-07-08 11:31:05.421637: bru_input(bru_comp_list)
#> 2026-07-08 11:31:05.42349: bru_input.bru_comp(x)
#> 2026-07-08 11:31:05.425309: bru_input.bm_pipe(x)
#> 2026-07-08 11:31:05.427312: bru_input.bm_multi(x:core)
#> 2026-07-08 11:31:05.429288: bru_input.bru_mapper(x:core:main)
#> 2026-07-08 11:31:05.431101: bru_input(bru_input) for (x)
#> 2026-07-08 11:31:05.439798: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:31:05.441664: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:31:05.443657: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:31:05.445589: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:31:05.447352: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:31:05.464462: iinla: Start
#> 2026-07-08 11:31:05.466652: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:05.468237: Linearise components for each observation model
#> 2026-07-08 11:31:05.470093: Linearise component 'x'
#> 2026-07-08 11:31:05.473883: Linearise component 'Intercept'
#> 2026-07-08 11:31:05.477265: iinla: Evaluate component simplifications
#> 2026-07-08 11:31:05.478733: Simplify component mappers for each observation model
#> 2026-07-08 11:31:05.480638: Simplify component 'x'
#> 2026-07-08 11:31:05.48436: Simplify component 'Intercept'
#> 2026-07-08 11:31:05.488039: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:05.496409: iinla: Construct inla stack
#> 2026-07-08 11:31:05.513577: iinla: Model initialisation completed
#> 2026-07-08 11:31:05.515573: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:05.991638: iinla: Computation completed
#> 2026-07-08 11:31:06.029721: bru: Preprocessing
#> 2026-07-08 11:31:06.038518: Evaluate component inputs for each observation model
#> 2026-07-08 11:31:06.039877: bru_input(bru_comp_list)
#> 2026-07-08 11:31:06.041265: bru_input.bru_comp(z)
#> 2026-07-08 11:31:06.042701: bru_input.bm_pipe(z)
#> 2026-07-08 11:31:06.044189: bru_input.bm_multi(z:core)
#> 2026-07-08 11:31:06.045659: bru_input.bru_mapper(z:core:main)
#> 2026-07-08 11:31:06.046974: bru_input(bru_input) for (z)
#> 2026-07-08 11:31:06.055383: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:31:06.05688: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:31:06.058587: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:31:06.059986: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:31:06.061305: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:31:06.075882: iinla: Start
#> 2026-07-08 11:31:06.077527: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:06.078731: Linearise components for each observation model
#> 2026-07-08 11:31:06.080217: Linearise component 'z'
#> 2026-07-08 11:31:06.083336: Linearise component 'Intercept'
#> 2026-07-08 11:31:06.086059: iinla: Evaluate component simplifications
#> 2026-07-08 11:31:06.087264: Simplify component mappers for each observation model
#> 2026-07-08 11:31:06.088628: Simplify component 'z'
#> 2026-07-08 11:31:06.09163: Simplify component 'Intercept'
#> 2026-07-08 11:31:06.09463: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:06.097837: Linearise with respect to component 'z'
#> 2026-07-08 11:31:06.103296: Linearise with respect to component 'Intercept'
#> 2026-07-08 11:31:06.10652: iinla: Construct inla stack
#> 2026-07-08 11:31:06.120109: iinla: Model initialisation completed
#> 2026-07-08 11:31:06.121575: iinla: Iteration 1 [max: 10]
#> 2026-07-08 11:31:06.565219: iinla: Step rescaling: 61.8%, Contract (norm0 = 1968, norm1 = 1806, norm01 = 347.6)
#> 2026-07-08 11:31:06.568059: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.7, norm1 = 294.9, norm01 = 347.6)
#> 2026-07-08 11:31:06.57179: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-07-08 11:31:06.57329: iinla: |lin1-lin0| = 347.6
#> <eta-lin1,delta>/|delta| = -198.2
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4
#> 2026-07-08 11:31:06.574743: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-07-08 11:31:06.576421: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:06.57755: Linearise components for each observation model
#> 2026-07-08 11:31:06.578888: Linearise component 'z'
#> 2026-07-08 11:31:06.581947: Linearise component 'Intercept'
#> 2026-07-08 11:31:06.584826: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:06.587691: Linearise with respect to component 'z'
#> 2026-07-08 11:31:06.591283: Linearise with respect to component 'Intercept'
#> 2026-07-08 11:31:06.604289: iinla: Iteration 2 [max: 10]
#> 2026-07-08 11:31:07.402565: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-07-08 11:31:07.405594: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-07-08 11:31:07.409198: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-07-08 11:31:07.410709: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-07-08 11:31:07.41216: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-07-08 11:31:07.413789: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:07.41489: Linearise components for each observation model
#> 2026-07-08 11:31:07.416194: Linearise component 'z'
#> 2026-07-08 11:31:07.419291: Linearise component 'Intercept'
#> 2026-07-08 11:31:07.422193: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:07.425045: Linearise with respect to component 'z'
#> 2026-07-08 11:31:07.428664: Linearise with respect to component 'Intercept'
#> 2026-07-08 11:31:07.440762: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:07.443201: iinla: Iteration 3 [max: 10]
#> 2026-07-08 11:31:07.884721: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-07-08 11:31:07.887537: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-07-08 11:31:07.89098: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-07-08 11:31:07.89247: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-07-08 11:31:07.893878: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-07-08 11:31:07.895551: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:07.896821: Linearise components for each observation model
#> 2026-07-08 11:31:07.89817: Linearise component 'z'
#> 2026-07-08 11:31:07.90112: Linearise component 'Intercept'
#> 2026-07-08 11:31:07.903884: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:07.906578: Linearise with respect to component 'z'
#> 2026-07-08 11:31:07.910098: Linearise with respect to component 'Intercept'
#> 2026-07-08 11:31:07.922018: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:07.924611: iinla: Iteration 4 [max: 10]
#> 2026-07-08 11:31:08.371694: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-07-08 11:31:08.374856: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-07-08 11:31:08.378366: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.856e-08, norm01 = 0.01176)
#> 2026-07-08 11:31:08.379993: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.23e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-07-08 11:31:08.381723: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:08.382863: Linearise components for each observation model
#> 2026-07-08 11:31:08.384255: Linearise component 'z'
#> 2026-07-08 11:31:08.38725: Linearise component 'Intercept'
#> 2026-07-08 11:31:08.390112: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:08.392918: Linearise with respect to component 'z'
#> 2026-07-08 11:31:08.39657: Linearise with respect to component 'Intercept'
#> 2026-07-08 11:31:08.408586: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:08.409873: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-07-08 11:31:08.412381: iinla: Iteration 5 [max: 10]
#> 2026-07-08 11:31:08.863608: iinla: Computation completed
#> 2026-07-08 11:31:12.637409: bru: Preprocessing
#> 2026-07-08 11:31:12.64414: Evaluate component inputs for each observation model
#> 2026-07-08 11:31:12.645436: bru_input(bru_comp_list)
#> 2026-07-08 11:31:12.646761: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:31:12.648: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:31:12.649346: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:31:12.650684: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:31:12.65188: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:31:12.667885: iinla: Start
#> 2026-07-08 11:31:12.66942: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:12.67051: Linearise components for each observation model
#> 2026-07-08 11:31:12.671783: Linearise component 'Intercept'
#> 2026-07-08 11:31:12.674731: iinla: Evaluate component simplifications
#> 2026-07-08 11:31:12.675891: Simplify component mappers for each observation model
#> 2026-07-08 11:31:12.677153: Simplify component 'Intercept'
#> 2026-07-08 11:31:12.680179: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:12.685602: iinla: Construct inla stack
#> 2026-07-08 11:31:12.695809: iinla: Model initialisation completed
#> 2026-07-08 11:31:12.697313: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:13.723203: iinla: Computation completed
#> 2026-07-08 11:31:15.154181: bru: Preprocessing
#> 2026-07-08 11:31:15.163281: Evaluate component inputs for each observation model
#> 2026-07-08 11:31:15.164575: bru_input(bru_comp_list)
#> 2026-07-08 11:31:15.165852: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:31:15.167126: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:31:15.168528: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:31:15.169871: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:31:15.171124: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:31:15.178833: bru_input.bru_comp(field)
#> 2026-07-08 11:31:15.180185: bru_input.bm_pipe(field)
#> 2026-07-08 11:31:15.181574: bru_input.bm_multi(field:core)
#> 2026-07-08 11:31:15.182911: bru_input.bru_mapper(field:core:main)
#> 2026-07-08 11:31:15.184164: bru_input(bru_input) for (field)
#> 2026-07-08 11:31:15.201212: iinla: Start
#> 2026-07-08 11:31:15.208815: iinla: Evaluate component linearisations
#> 2026-07-08 11:31:15.209965: Linearise components for each observation model
#> 2026-07-08 11:31:15.211351: Linearise component 'Intercept'
#> 2026-07-08 11:31:15.214467: Linearise component 'field'
#> 2026-07-08 11:31:15.339441: iinla: Evaluate component simplifications
#> 2026-07-08 11:31:15.340822: Simplify component mappers for each observation model
#> 2026-07-08 11:31:15.342281: Simplify component 'Intercept'
#> 2026-07-08 11:31:15.345438: Simplify component 'field'
#> 2026-07-08 11:31:15.475375: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:31:15.480621: iinla: Construct inla stack
#> 2026-07-08 11:31:15.499754: iinla: Model initialisation completed
#> 2026-07-08 11:31:15.501407: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:58.769132: iinla: Computation completed
#> 2026-07-08 11:32:00.379855: bru: Preprocessing
#> 2026-07-08 11:32:00.392517: Evaluate component inputs for each observation model
#> 2026-07-08 11:32:00.393848: bru_input(bru_comp_list)
#> 2026-07-08 11:32:00.395225: bru_input.bru_comp(x)
#> 2026-07-08 11:32:00.396514: bru_input.bm_pipe(x)
#> 2026-07-08 11:32:00.397934: bru_input.bm_multi(x:core)
#> 2026-07-08 11:32:00.399416: bru_input.bru_mapper(x:core:main)
#> 2026-07-08 11:32:00.400781: bru_input(bru_input) for (x)
#> 2026-07-08 11:32:00.408995: bru_input.bru_comp(field)
#> 2026-07-08 11:32:00.410408: bru_input.bm_pipe(field)
#> 2026-07-08 11:32:00.41185: bru_input.bm_multi(field:core)
#> 2026-07-08 11:32:00.413286: bru_input.bru_mapper(field:core:main)
#> 2026-07-08 11:32:00.414582: bru_input(bru_input) for (field)
#> 2026-07-08 11:32:00.442871: iinla: Start
#> 2026-07-08 11:32:00.44453: iinla: Evaluate component linearisations
#> 2026-07-08 11:32:00.445629: Linearise components for each observation model
#> 2026-07-08 11:32:00.446974: Linearise component 'x'
#> 2026-07-08 11:32:00.44995: Linearise component 'field'
#> 2026-07-08 11:32:00.453103: iinla: Evaluate component simplifications
#> 2026-07-08 11:32:00.454249: Simplify component mappers for each observation model
#> 2026-07-08 11:32:00.455562: Simplify component 'x'
#> 2026-07-08 11:32:00.458506: Simplify component 'field'
#> 2026-07-08 11:32:00.461835: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:32:00.466181: iinla: Construct inla stack
#> 2026-07-08 11:32:00.47963: iinla: Model initialisation completed
#> 2026-07-08 11:32:00.481069: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:00.92085: iinla: Computation completed
#> 2026-07-08 11:32:02.680146: bru_input(bru_comp_list)
#> 2026-07-08 11:32:06.956944: bru: Preprocessing
#> 2026-07-08 11:32:06.964516: Evaluate component inputs for each observation model
#> 2026-07-08 11:32:06.966007: bru_input(bru_comp_list)
#> 2026-07-08 11:32:06.967543: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:32:06.969032: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:32:06.970563: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:32:06.971908: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:32:06.973144: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:32:06.989269: iinla: Start
#> 2026-07-08 11:32:06.990899: iinla: Evaluate component linearisations
#> 2026-07-08 11:32:06.992017: Linearise components for each observation model
#> 2026-07-08 11:32:06.993337: Linearise component 'Intercept'
#> 2026-07-08 11:32:06.996405: iinla: Evaluate component simplifications
#> 2026-07-08 11:32:06.997606: Simplify component mappers for each observation model
#> 2026-07-08 11:32:06.998922: Simplify component 'Intercept'
#> 2026-07-08 11:32:07.001987: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:32:07.005909: iinla: Construct inla stack
#> 2026-07-08 11:32:07.015504: iinla: Model initialisation completed
#> 2026-07-08 11:32:07.016954: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:08.239241: iinla: Computation completed
#> 2026-07-08 11:32:10.131972: bru: Preprocessing
#> 2026-07-08 11:32:10.141165: Evaluate component inputs for each observation model
#> 2026-07-08 11:32:10.142461: bru_input(bru_comp_list)
#> 2026-07-08 11:32:10.143776: bru_input.bru_comp(Intercept)
#> 2026-07-08 11:32:10.145055: bru_input.bm_pipe(Intercept)
#> 2026-07-08 11:32:10.146423: bru_input.bm_multi(Intercept:core)
#> 2026-07-08 11:32:10.147744: bru_input.bru_mapper(Intercept:core:main)
#> 2026-07-08 11:32:10.148945: bru_input(bru_input) for (Intercept)
#> 2026-07-08 11:32:10.157853: bru_input.bru_comp(field)
#> 2026-07-08 11:32:10.159145: bru_input.bm_pipe(field)
#> 2026-07-08 11:32:10.160488: bru_input.bm_multi(field:core)
#> 2026-07-08 11:32:10.1618: bru_input.bru_mapper(field:core:main)
#> 2026-07-08 11:32:10.163016: bru_input(bru_input) for (field)
#> 2026-07-08 11:32:10.180393: iinla: Start
#> 2026-07-08 11:32:10.181952: iinla: Evaluate component linearisations
#> 2026-07-08 11:32:10.183042: Linearise components for each observation model
#> 2026-07-08 11:32:10.184348: Linearise component 'Intercept'
#> 2026-07-08 11:32:10.18728: Linearise component 'field'
#> 2026-07-08 11:32:10.311514: iinla: Evaluate component simplifications
#> 2026-07-08 11:32:10.312915: Simplify component mappers for each observation model
#> 2026-07-08 11:32:10.31434: Simplify component 'Intercept'
#> 2026-07-08 11:32:10.317357: Simplify component 'field'
#> 2026-07-08 11:32:10.444984: iinla: Evaluate predictor linearisation
#> 2026-07-08 11:32:10.457109: iinla: Construct inla stack
#> 2026-07-08 11:32:10.474947: iinla: Model initialisation completed
#> 2026-07-08 11:32:10.476392: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:53.750114: iinla: Computation completed
#> 2026-07-08 11:32:55.349898: bru: Preprocessing
#> 2026-07-08 11:32:55.363156: Evaluate component inputs for each observation model
#> 2026-07-08 11:32:55.364497: bru_input(bru_comp_list)
#> 2026-07-08 11:32:55.365802: bru_input.bru_comp(x)
#> 2026-07-08 11:32:55.367187: bru_input.bm_pipe(x)
#> 2026-07-08 11:32:55.368626: bru_input.bm_multi(x:core)
#> 2026-07-08 11:32:55.369989: bru_input.bru_mapper(x:core:main)
#> 2026-07-08 11:32:55.371243: bru_input(bru_input) for (x)
#> 2026-07-08 11:32:55.379597: bru_input(bru_comp_list)
#> 2026-07-08 11:32:55.38107: bru_input.bru_comp(x)
#> 2026-07-08 11:32:55.382421: bru_input.bm_pipe(x)
#> 2026-07-08 11:32:55.383834: bru_input.bm_multi(x:core)
#> 2026-07-08 11:32:55.385214: bru_input.bru_mapper(x:core:main)
#> 2026-07-08 11:32:55.386431: bru_input(bru_input) for (x)
#> 2026-07-08 11:32:58.450787: bru_input(bru_input) for (LABEL)
#> 2026-07-08 11:33:00.246319: bru_input_text(bru_input) for (LABEL)
#> 2026-07-08 11:33:00.258412: bru_input.bru_comp(x)
#> 2026-07-08 11:33:00.259556: bru_input_text.bm_pipe(x)
#> 2026-07-08 11:33:00.260796: bru_input_text.bm_multi(x:core)
#> 2026-07-08 11:33:00.262045: bru_input_text.bru_mapper(x:core:main)
#> 2026-07-08 11:33:00.263107: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-07-08 11:30:53.964308: inlabru loaded
#> 2026-07-08 11:30:53.964766: Clear override options
#> 2026-07-08 11:31:04.343678: bru: Preprocessing
#> 2026-07-08 11:31:04.460268: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:05.408963: bru: Preprocessing
#> 2026-07-08 11:31:05.515573: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:06.029721: bru: Preprocessing
#> 2026-07-08 11:31:06.121575: iinla: Iteration 1 [max: 10]
#> 2026-07-08 11:31:06.574743: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-07-08 11:31:06.604289: iinla: Iteration 2 [max: 10]
#> 2026-07-08 11:31:07.41216: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-07-08 11:31:07.440762: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:07.443201: iinla: Iteration 3 [max: 10]
#> 2026-07-08 11:31:07.893878: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-07-08 11:31:07.922018: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:07.924611: iinla: Iteration 4 [max: 10]
#> 2026-07-08 11:31:08.408586: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-07-08 11:31:08.409873: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-07-08 11:31:08.412381: iinla: Iteration 5 [max: 10]
#> 2026-07-08 11:31:12.637409: bru: Preprocessing
#> 2026-07-08 11:31:12.697313: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:31:15.154181: bru: Preprocessing
#> 2026-07-08 11:31:15.501407: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:00.379855: bru: Preprocessing
#> 2026-07-08 11:32:00.481069: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:06.956944: bru: Preprocessing
#> 2026-07-08 11:32:07.016954: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:10.131972: bru: Preprocessing
#> 2026-07-08 11:32:10.476392: iinla: Iteration 1 [max: 1]
#> 2026-07-08 11:32:55.349898: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-07-08 11:30:53.964308: inlabru loaded (level 1)
#> 2026-07-08 11:30:53.964766: Clear override options (level 1)
#> 2026-07-08 11:31:04.343678: bru: Preprocessing (level 1)
#> 2026-07-08 11:31:04.359429: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:31:04.360987: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:31:04.362551: bru_input.bru_comp(x) (level 4)
#> 2026-07-08 11:31:04.363922: bru_input.bm_pipe(x) (level 5)
#> 2026-07-08 11:31:04.365429: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-08 11:31:04.366937: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-08 11:31:04.368539: bru_input(bru_input) for (x) (level 5)
#> 2026-07-08 11:31:04.376433: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:31:04.377771: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:31:04.379192: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:31:04.380573: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:31:04.387383: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:31:04.407011: iinla: Start (level 3)
#> 2026-07-08 11:31:04.408708: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:04.409912: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:04.411448: Linearise component 'x' (level 4)
#> 2026-07-08 11:31:04.414464: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:04.417218: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:31:04.418471: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:31:04.419923: Simplify component 'x' (level 4)
#> 2026-07-08 11:31:04.423123: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:31:04.426121: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:04.438792: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:31:04.458772: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:31:04.460268: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:31:05.379776: iinla: Computation completed (level 3)
#> 2026-07-08 11:31:05.408963: bru: Preprocessing (level 1)
#> 2026-07-08 11:31:05.419797: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:31:05.421637: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:31:05.42349: bru_input.bru_comp(x) (level 4)
#> 2026-07-08 11:31:05.425309: bru_input.bm_pipe(x) (level 5)
#> 2026-07-08 11:31:05.427312: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-08 11:31:05.429288: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-08 11:31:05.431101: bru_input(bru_input) for (x) (level 5)
#> 2026-07-08 11:31:05.439798: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:31:05.441664: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:31:05.443657: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:31:05.445589: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:31:05.447352: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:31:05.464462: iinla: Start (level 3)
#> 2026-07-08 11:31:05.466652: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:05.468237: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:05.470093: Linearise component 'x' (level 4)
#> 2026-07-08 11:31:05.473883: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:05.477265: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:31:05.478733: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:31:05.480638: Simplify component 'x' (level 4)
#> 2026-07-08 11:31:05.48436: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:31:05.488039: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:05.496409: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:31:05.513577: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:31:05.515573: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:31:05.991638: iinla: Computation completed (level 3)
#> 2026-07-08 11:31:06.029721: bru: Preprocessing (level 1)
#> 2026-07-08 11:31:06.038518: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:31:06.039877: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:31:06.041265: bru_input.bru_comp(z) (level 4)
#> 2026-07-08 11:31:06.042701: bru_input.bm_pipe(z) (level 5)
#> 2026-07-08 11:31:06.044189: bru_input.bm_multi(z:core) (level 5)
#> 2026-07-08 11:31:06.045659: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-07-08 11:31:06.046974: bru_input(bru_input) for (z) (level 5)
#> 2026-07-08 11:31:06.055383: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:31:06.05688: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:31:06.058587: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:31:06.059986: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:31:06.061305: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:31:06.075882: iinla: Start (level 3)
#> 2026-07-08 11:31:06.077527: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:06.078731: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:06.080217: Linearise component 'z' (level 4)
#> 2026-07-08 11:31:06.083336: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:06.086059: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:31:06.087264: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:31:06.088628: Simplify component 'z' (level 4)
#> 2026-07-08 11:31:06.09163: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:31:06.09463: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:06.097837: Linearise with respect to component 'z' (level 5)
#> 2026-07-08 11:31:06.103296: Linearise with respect to component 'Intercept' (level 5)
#> 2026-07-08 11:31:06.10652: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:31:06.120109: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:31:06.121575: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-07-08 11:31:06.565219: iinla: Step rescaling: 61.8%, Contract (norm0 = 1968, norm1 = 1806, norm01 = 347.6) (level 3)
#> 2026-07-08 11:31:06.568059: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.7, norm1 = 294.9, norm01 = 347.6) (level 3)
#> 2026-07-08 11:31:06.57179: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184, norm1 = 225.4, norm01 = 347.6) (level 3)
#> 2026-07-08 11:31:06.57329: iinla: |lin1-lin0| = 347.6
#> <eta-lin1,delta>/|delta| = -198.2
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4 (level 4)
#> 2026-07-08 11:31:06.574743: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6) (level 2)
#> 2026-07-08 11:31:06.576421: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:06.57755: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:06.578888: Linearise component 'z' (level 4)
#> 2026-07-08 11:31:06.581947: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:06.584826: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:06.587691: Linearise with respect to component 'z' (level 5)
#> 2026-07-08 11:31:06.591283: Linearise with respect to component 'Intercept' (level 5)
#> 2026-07-08 11:31:06.604289: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-07-08 11:31:07.402565: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-07-08 11:31:07.405594: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-07-08 11:31:07.409198: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-07-08 11:31:07.410709: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-07-08 11:31:07.41216: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-07-08 11:31:07.413789: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:07.41489: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:07.416194: Linearise component 'z' (level 4)
#> 2026-07-08 11:31:07.419291: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:07.422193: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:07.425045: Linearise with respect to component 'z' (level 5)
#> 2026-07-08 11:31:07.428664: Linearise with respect to component 'Intercept' (level 5)
#> 2026-07-08 11:31:07.440762: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-07-08 11:31:07.443201: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-07-08 11:31:07.884721: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-07-08 11:31:07.887537: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-07-08 11:31:07.89098: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-07-08 11:31:07.89247: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-07-08 11:31:07.893878: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-07-08 11:31:07.895551: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:07.896821: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:07.89817: Linearise component 'z' (level 4)
#> 2026-07-08 11:31:07.90112: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:07.903884: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:07.906578: Linearise with respect to component 'z' (level 5)
#> 2026-07-08 11:31:07.910098: Linearise with respect to component 'Intercept' (level 5)
#> 2026-07-08 11:31:07.922018: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-07-08 11:31:07.924611: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-07-08 11:31:08.371694: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-07-08 11:31:08.374856: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-07-08 11:31:08.378366: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.856e-08, norm01 = 0.01176) (level 3)
#> 2026-07-08 11:31:08.379993: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.23e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-07-08 11:31:08.381723: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:08.382863: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:08.384255: Linearise component 'z' (level 4)
#> 2026-07-08 11:31:08.38725: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:08.390112: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:08.392918: Linearise with respect to component 'z' (level 5)
#> 2026-07-08 11:31:08.39657: Linearise with respect to component 'Intercept' (level 5)
#> 2026-07-08 11:31:08.408586: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-07-08 11:31:08.409873: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-07-08 11:31:08.412381: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-07-08 11:31:08.863608: iinla: Computation completed (level 3)
#> 2026-07-08 11:31:12.637409: bru: Preprocessing (level 1)
#> 2026-07-08 11:31:12.64414: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:31:12.645436: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:31:12.646761: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:31:12.648: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:31:12.649346: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:31:12.650684: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:31:12.65188: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:31:12.667885: iinla: Start (level 3)
#> 2026-07-08 11:31:12.66942: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:12.67051: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:12.671783: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:12.674731: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:31:12.675891: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:31:12.677153: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:31:12.680179: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:12.685602: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:31:12.695809: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:31:12.697313: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:31:13.723203: iinla: Computation completed (level 3)
#> 2026-07-08 11:31:15.154181: bru: Preprocessing (level 1)
#> 2026-07-08 11:31:15.163281: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:31:15.164575: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:31:15.165852: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:31:15.167126: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:31:15.168528: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:31:15.169871: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:31:15.171124: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:31:15.178833: bru_input.bru_comp(field) (level 4)
#> 2026-07-08 11:31:15.180185: bru_input.bm_pipe(field) (level 5)
#> 2026-07-08 11:31:15.181574: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-08 11:31:15.182911: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-08 11:31:15.184164: bru_input(bru_input) for (field) (level 5)
#> 2026-07-08 11:31:15.201212: iinla: Start (level 3)
#> 2026-07-08 11:31:15.208815: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:31:15.209965: Linearise components for each observation model (level 3)
#> 2026-07-08 11:31:15.211351: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:31:15.214467: Linearise component 'field' (level 4)
#> 2026-07-08 11:31:15.339441: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:31:15.340822: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:31:15.342281: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:31:15.345438: Simplify component 'field' (level 4)
#> 2026-07-08 11:31:15.475375: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:31:15.480621: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:31:15.499754: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:31:15.501407: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:31:58.769132: iinla: Computation completed (level 3)
#> 2026-07-08 11:32:00.379855: bru: Preprocessing (level 1)
#> 2026-07-08 11:32:00.392517: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:32:00.393848: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:32:00.395225: bru_input.bru_comp(x) (level 4)
#> 2026-07-08 11:32:00.396514: bru_input.bm_pipe(x) (level 5)
#> 2026-07-08 11:32:00.397934: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-08 11:32:00.399416: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-08 11:32:00.400781: bru_input(bru_input) for (x) (level 5)
#> 2026-07-08 11:32:00.408995: bru_input.bru_comp(field) (level 4)
#> 2026-07-08 11:32:00.410408: bru_input.bm_pipe(field) (level 5)
#> 2026-07-08 11:32:00.41185: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-08 11:32:00.413286: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-08 11:32:00.414582: bru_input(bru_input) for (field) (level 5)
#> 2026-07-08 11:32:00.442871: iinla: Start (level 3)
#> 2026-07-08 11:32:00.44453: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:32:00.445629: Linearise components for each observation model (level 3)
#> 2026-07-08 11:32:00.446974: Linearise component 'x' (level 4)
#> 2026-07-08 11:32:00.44995: Linearise component 'field' (level 4)
#> 2026-07-08 11:32:00.453103: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:32:00.454249: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:32:00.455562: Simplify component 'x' (level 4)
#> 2026-07-08 11:32:00.458506: Simplify component 'field' (level 4)
#> 2026-07-08 11:32:00.461835: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:32:00.466181: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:32:00.47963: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:32:00.481069: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:32:00.92085: iinla: Computation completed (level 3)
#> 2026-07-08 11:32:02.680146: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:32:06.956944: bru: Preprocessing (level 1)
#> 2026-07-08 11:32:06.964516: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:32:06.966007: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:32:06.967543: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:32:06.969032: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:32:06.970563: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:32:06.971908: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:32:06.973144: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:32:06.989269: iinla: Start (level 3)
#> 2026-07-08 11:32:06.990899: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:32:06.992017: Linearise components for each observation model (level 3)
#> 2026-07-08 11:32:06.993337: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:32:06.996405: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:32:06.997606: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:32:06.998922: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:32:07.001987: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:32:07.005909: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:32:07.015504: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:32:07.016954: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:32:08.239241: iinla: Computation completed (level 3)
#> 2026-07-08 11:32:10.131972: bru: Preprocessing (level 1)
#> 2026-07-08 11:32:10.141165: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:32:10.142461: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:32:10.143776: bru_input.bru_comp(Intercept) (level 4)
#> 2026-07-08 11:32:10.145055: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-07-08 11:32:10.146423: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-07-08 11:32:10.147744: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-07-08 11:32:10.148945: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-07-08 11:32:10.157853: bru_input.bru_comp(field) (level 4)
#> 2026-07-08 11:32:10.159145: bru_input.bm_pipe(field) (level 5)
#> 2026-07-08 11:32:10.160488: bru_input.bm_multi(field:core) (level 5)
#> 2026-07-08 11:32:10.1618: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-07-08 11:32:10.163016: bru_input(bru_input) for (field) (level 5)
#> 2026-07-08 11:32:10.180393: iinla: Start (level 3)
#> 2026-07-08 11:32:10.181952: iinla: Evaluate component linearisations (level 3)
#> 2026-07-08 11:32:10.183042: Linearise components for each observation model (level 3)
#> 2026-07-08 11:32:10.184348: Linearise component 'Intercept' (level 4)
#> 2026-07-08 11:32:10.18728: Linearise component 'field' (level 4)
#> 2026-07-08 11:32:10.311514: iinla: Evaluate component simplifications (level 3)
#> 2026-07-08 11:32:10.312915: Simplify component mappers for each observation model (level 3)
#> 2026-07-08 11:32:10.31434: Simplify component 'Intercept' (level 4)
#> 2026-07-08 11:32:10.317357: Simplify component 'field' (level 4)
#> 2026-07-08 11:32:10.444984: iinla: Evaluate predictor linearisation (level 3)
#> 2026-07-08 11:32:10.457109: iinla: Construct inla stack (level 3)
#> 2026-07-08 11:32:10.474947: iinla: Model initialisation completed (level 3)
#> 2026-07-08 11:32:10.476392: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-07-08 11:32:53.750114: iinla: Computation completed (level 3)
#> 2026-07-08 11:32:55.349898: bru: Preprocessing (level 1)
#> 2026-07-08 11:32:55.363156: Evaluate component inputs for each observation model (level 3)
#> 2026-07-08 11:32:55.364497: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:32:55.365802: bru_input.bru_comp(x) (level 4)
#> 2026-07-08 11:32:55.367187: bru_input.bm_pipe(x) (level 5)
#> 2026-07-08 11:32:55.368626: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-08 11:32:55.369989: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-08 11:32:55.371243: bru_input(bru_input) for (x) (level 5)
#> 2026-07-08 11:32:55.379597: bru_input(bru_comp_list) (level 4)
#> 2026-07-08 11:32:55.38107: bru_input.bru_comp(x) (level 4)
#> 2026-07-08 11:32:55.382421: bru_input.bm_pipe(x) (level 5)
#> 2026-07-08 11:32:55.383834: bru_input.bm_multi(x:core) (level 5)
#> 2026-07-08 11:32:55.385214: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-07-08 11:32:55.386431: bru_input(bru_input) for (x) (level 5)
#> 2026-07-08 11:32:58.450787: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-07-08 11:33:00.246319: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-07-08 11:33:00.258412: bru_input.bru_comp(x) (level 4)
#> 2026-07-08 11:33:00.259556: bru_input_text.bm_pipe(x) (level 5)
#> 2026-07-08 11:33:00.260796: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-07-08 11:33:00.262045: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-07-08 11:33:00.263107: bru_input_text(bru_input) for (x) (level 5)