Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-06-16 20:30:45.09502: inlabru loaded
#> 2026-06-16 20:30:45.095501: Clear override options
#> 2026-06-16 20:30:55.823966: bru: Preprocessing
#> 2026-06-16 20:30:55.942291: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:30:56.882642: bru: Preprocessing
#> 2026-06-16 20:30:56.987697: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:30:57.487463: bru: Preprocessing
#> 2026-06-16 20:30:57.598247: iinla: Iteration 1 [max: 10]
#> 2026-06-16 20:30:58.028605: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-06-16 20:30:58.057671: iinla: Iteration 2 [max: 10]
#> 2026-06-16 20:30:58.836868: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-06-16 20:30:58.86442: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:58.866829: iinla: Iteration 3 [max: 10]
#> 2026-06-16 20:30:59.298845: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-06-16 20:30:59.327023: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:59.3295: iinla: Iteration 4 [max: 10]
#> 2026-06-16 20:30:59.808815: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:59.810064: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-06-16 20:30:59.812497: iinla: Iteration 5 [max: 10]
#> 2026-06-16 20:31:05.247466: bru: Preprocessing
#> 2026-06-16 20:31:05.309615: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:09.941729: bru: Preprocessing
#> 2026-06-16 20:31:10.284269: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:54.810652: bru: Preprocessing
#> 2026-06-16 20:31:54.910264: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:03.837166: bru: Preprocessing
#> 2026-06-16 20:32:03.901387: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:08.594693: bru: Preprocessing
#> 2026-06-16 20:32:08.940093: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:53.546362: bru: Preprocessing
format(bru_log())
#> 2026-06-16 20:30:45.09502: inlabru loaded
#> 2026-06-16 20:30:45.095501: Clear override options
#> 2026-06-16 20:30:55.823966: bru: Preprocessing
#> 2026-06-16 20:30:55.839444: Evaluate component inputs for each observation model
#> 2026-06-16 20:30:55.840827: bru_input(bru_comp_list)
#> 2026-06-16 20:30:55.842193: bru_input.bru_comp(x)
#> 2026-06-16 20:30:55.843614: bru_input.bm_pipe(x)
#> 2026-06-16 20:30:55.84514: bru_input.bm_multi(x:core)
#> 2026-06-16 20:30:55.846673: bru_input.bru_mapper(x:core:main)
#> 2026-06-16 20:30:55.848344: bru_input(bru_input) for (x)
#> 2026-06-16 20:30:55.85645: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:30:55.85781: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:30:55.859238: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:30:55.860694: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:30:55.862187: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:30:55.878177: iinla: Start
#> 2026-06-16 20:30:55.8799: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:55.881083: Linearise components for each observation model
#> 2026-06-16 20:30:55.882723: Linearise component 'x'
#> 2026-06-16 20:30:55.885917: Linearise component 'Intercept'
#> 2026-06-16 20:30:55.888686: iinla: Evaluate component simplifications
#> 2026-06-16 20:30:55.889913: Simplify component mappers for each observation model
#> 2026-06-16 20:30:55.891332: Simplify component 'x'
#> 2026-06-16 20:30:55.894348: Simplify component 'Intercept'
#> 2026-06-16 20:30:55.897268: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:55.919712: iinla: Construct inla stack
#> 2026-06-16 20:30:55.940834: iinla: Model initialisation completed
#> 2026-06-16 20:30:55.942291: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:30:56.85404: iinla: Computation completed
#> 2026-06-16 20:30:56.882642: bru: Preprocessing
#> 2026-06-16 20:30:56.893692: Evaluate component inputs for each observation model
#> 2026-06-16 20:30:56.895518: bru_input(bru_comp_list)
#> 2026-06-16 20:30:56.89739: bru_input.bru_comp(x)
#> 2026-06-16 20:30:56.899193: bru_input.bm_pipe(x)
#> 2026-06-16 20:30:56.901222: bru_input.bm_multi(x:core)
#> 2026-06-16 20:30:56.903225: bru_input.bru_mapper(x:core:main)
#> 2026-06-16 20:30:56.905028: bru_input(bru_input) for (x)
#> 2026-06-16 20:30:56.913341: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:30:56.915227: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:30:56.917219: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:30:56.919221: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:30:56.921: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:30:56.937117: iinla: Start
#> 2026-06-16 20:30:56.93936: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:56.940937: Linearise components for each observation model
#> 2026-06-16 20:30:56.942756: Linearise component 'x'
#> 2026-06-16 20:30:56.946442: Linearise component 'Intercept'
#> 2026-06-16 20:30:56.949914: iinla: Evaluate component simplifications
#> 2026-06-16 20:30:56.951515: Simplify component mappers for each observation model
#> 2026-06-16 20:30:56.953344: Simplify component 'x'
#> 2026-06-16 20:30:56.957023: Simplify component 'Intercept'
#> 2026-06-16 20:30:56.960714: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:56.968688: iinla: Construct inla stack
#> 2026-06-16 20:30:56.985751: iinla: Model initialisation completed
#> 2026-06-16 20:30:56.987697: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:30:57.459836: iinla: Computation completed
#> 2026-06-16 20:30:57.487463: bru: Preprocessing
#> 2026-06-16 20:30:57.498141: Evaluate component inputs for each observation model
#> 2026-06-16 20:30:57.499931: bru_input(bru_comp_list)
#> 2026-06-16 20:30:57.501738: bru_input.bru_comp(z)
#> 2026-06-16 20:30:57.503552: bru_input.bm_pipe(z)
#> 2026-06-16 20:30:57.505592: bru_input.bm_multi(z:core)
#> 2026-06-16 20:30:57.5076: bru_input.bru_mapper(z:core:main)
#> 2026-06-16 20:30:57.509401: bru_input(bru_input) for (z)
#> 2026-06-16 20:30:57.517704: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:30:57.519559: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:30:57.521552: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:30:57.523509: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:30:57.525349: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:30:57.540499: iinla: Start
#> 2026-06-16 20:30:57.542623: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:57.544178: Linearise components for each observation model
#> 2026-06-16 20:30:57.556236: Linearise component 'z'
#> 2026-06-16 20:30:57.559581: Linearise component 'Intercept'
#> 2026-06-16 20:30:57.562364: iinla: Evaluate component simplifications
#> 2026-06-16 20:30:57.56357: Simplify component mappers for each observation model
#> 2026-06-16 20:30:57.564905: Simplify component 'z'
#> 2026-06-16 20:30:57.567895: Simplify component 'Intercept'
#> 2026-06-16 20:30:57.570926: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:57.574056: Linearise with respect to component 'z'
#> 2026-06-16 20:30:57.579499: Linearise with respect to component 'Intercept'
#> 2026-06-16 20:30:57.582791: iinla: Construct inla stack
#> 2026-06-16 20:30:57.596549: iinla: Model initialisation completed
#> 2026-06-16 20:30:57.598247: iinla: Iteration 1 [max: 10]
#> 2026-06-16 20:30:58.018912: iinla: Step rescaling: 61.8%, Contract (norm0 = 1968, norm1 = 1806, norm01 = 347.6)
#> 2026-06-16 20:30:58.021866: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.7, norm1 = 294.9, norm01 = 347.6)
#> 2026-06-16 20:30:58.02564: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-06-16 20:30:58.027147: iinla: |lin1-lin0| = 347.6
#> <eta-lin1,delta>/|delta| = -198.2
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4
#> 2026-06-16 20:30:58.028605: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-06-16 20:30:58.030298: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:58.031466: Linearise components for each observation model
#> 2026-06-16 20:30:58.032802: Linearise component 'z'
#> 2026-06-16 20:30:58.035709: Linearise component 'Intercept'
#> 2026-06-16 20:30:58.038529: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:58.041171: Linearise with respect to component 'z'
#> 2026-06-16 20:30:58.044721: Linearise with respect to component 'Intercept'
#> 2026-06-16 20:30:58.057671: iinla: Iteration 2 [max: 10]
#> 2026-06-16 20:30:58.827418: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5)
#> 2026-06-16 20:30:58.830457: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5)
#> 2026-06-16 20:30:58.834016: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-06-16 20:30:58.835491: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64
#> 2026-06-16 20:30:58.836868: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-06-16 20:30:58.838523: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:58.839605: Linearise components for each observation model
#> 2026-06-16 20:30:58.840868: Linearise component 'z'
#> 2026-06-16 20:30:58.843745: Linearise component 'Intercept'
#> 2026-06-16 20:30:58.846508: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:58.849077: Linearise with respect to component 'z'
#> 2026-06-16 20:30:58.852592: Linearise with respect to component 'Intercept'
#> 2026-06-16 20:30:58.86442: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:58.866829: iinla: Iteration 3 [max: 10]
#> 2026-06-16 20:30:59.289583: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68)
#> 2026-06-16 20:30:59.292392: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-06-16 20:30:59.295932: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-06-16 20:30:59.297441: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-06-16 20:30:59.298845: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-06-16 20:30:59.300526: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:59.301667: Linearise components for each observation model
#> 2026-06-16 20:30:59.303013: Linearise component 'z'
#> 2026-06-16 20:30:59.305983: Linearise component 'Intercept'
#> 2026-06-16 20:30:59.308815: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:59.311527: Linearise with respect to component 'z'
#> 2026-06-16 20:30:59.315102: Linearise with respect to component 'Intercept'
#> 2026-06-16 20:30:59.327023: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:59.3295: iinla: Iteration 4 [max: 10]
#> 2026-06-16 20:30:59.771804: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176)
#> 2026-06-16 20:30:59.775023: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-06-16 20:30:59.778654: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.856e-08, norm01 = 0.01176)
#> 2026-06-16 20:30:59.780185: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.23e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-06-16 20:30:59.781942: iinla: Evaluate component linearisations
#> 2026-06-16 20:30:59.783171: Linearise components for each observation model
#> 2026-06-16 20:30:59.784587: Linearise component 'z'
#> 2026-06-16 20:30:59.787725: Linearise component 'Intercept'
#> 2026-06-16 20:30:59.79054: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:30:59.79318: Linearise with respect to component 'z'
#> 2026-06-16 20:30:59.796812: Linearise with respect to component 'Intercept'
#> 2026-06-16 20:30:59.808815: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:59.810064: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-06-16 20:30:59.812497: iinla: Iteration 5 [max: 10]
#> 2026-06-16 20:31:00.261194: iinla: Computation completed
#> 2026-06-16 20:31:05.247466: bru: Preprocessing
#> 2026-06-16 20:31:05.254477: Evaluate component inputs for each observation model
#> 2026-06-16 20:31:05.255818: bru_input(bru_comp_list)
#> 2026-06-16 20:31:05.257231: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:31:05.258644: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:31:05.26017: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:31:05.261678: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:31:05.263008: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:31:05.279433: iinla: Start
#> 2026-06-16 20:31:05.281048: iinla: Evaluate component linearisations
#> 2026-06-16 20:31:05.282218: Linearise components for each observation model
#> 2026-06-16 20:31:05.28355: Linearise component 'Intercept'
#> 2026-06-16 20:31:05.286692: iinla: Evaluate component simplifications
#> 2026-06-16 20:31:05.287888: Simplify component mappers for each observation model
#> 2026-06-16 20:31:05.289343: Simplify component 'Intercept'
#> 2026-06-16 20:31:05.292493: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:31:05.297834: iinla: Construct inla stack
#> 2026-06-16 20:31:05.308159: iinla: Model initialisation completed
#> 2026-06-16 20:31:05.309615: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:06.526183: iinla: Computation completed
#> 2026-06-16 20:31:09.941729: bru: Preprocessing
#> 2026-06-16 20:31:09.951497: Evaluate component inputs for each observation model
#> 2026-06-16 20:31:09.952895: bru_input(bru_comp_list)
#> 2026-06-16 20:31:09.954355: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:31:09.95574: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:31:09.957274: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:31:09.958787: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:31:09.960216: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:31:09.967523: bru_input.bru_comp(field)
#> 2026-06-16 20:31:09.968916: bru_input.bm_pipe(field)
#> 2026-06-16 20:31:09.970428: bru_input.bm_multi(field:core)
#> 2026-06-16 20:31:09.97187: bru_input.bru_mapper(field:core:main)
#> 2026-06-16 20:31:09.973197: bru_input(bru_input) for (field)
#> 2026-06-16 20:31:09.989347: iinla: Start
#> 2026-06-16 20:31:09.990876: iinla: Evaluate component linearisations
#> 2026-06-16 20:31:09.991996: Linearise components for each observation model
#> 2026-06-16 20:31:09.993369: Linearise component 'Intercept'
#> 2026-06-16 20:31:09.996436: Linearise component 'field'
#> 2026-06-16 20:31:10.121238: iinla: Evaluate component simplifications
#> 2026-06-16 20:31:10.12265: Simplify component mappers for each observation model
#> 2026-06-16 20:31:10.124041: Simplify component 'Intercept'
#> 2026-06-16 20:31:10.127162: Simplify component 'field'
#> 2026-06-16 20:31:10.259171: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:31:10.264299: iinla: Construct inla stack
#> 2026-06-16 20:31:10.282805: iinla: Model initialisation completed
#> 2026-06-16 20:31:10.284269: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:53.642206: iinla: Computation completed
#> 2026-06-16 20:31:54.810652: bru: Preprocessing
#> 2026-06-16 20:31:54.823438: Evaluate component inputs for each observation model
#> 2026-06-16 20:31:54.824719: bru_input(bru_comp_list)
#> 2026-06-16 20:31:54.826028: bru_input.bru_comp(x)
#> 2026-06-16 20:31:54.827394: bru_input.bm_pipe(x)
#> 2026-06-16 20:31:54.828856: bru_input.bm_multi(x:core)
#> 2026-06-16 20:31:54.830255: bru_input.bru_mapper(x:core:main)
#> 2026-06-16 20:31:54.831605: bru_input(bru_input) for (x)
#> 2026-06-16 20:31:54.838988: bru_input.bru_comp(field)
#> 2026-06-16 20:31:54.840388: bru_input.bm_pipe(field)
#> 2026-06-16 20:31:54.841851: bru_input.bm_multi(field:core)
#> 2026-06-16 20:31:54.856585: bru_input.bru_mapper(field:core:main)
#> 2026-06-16 20:31:54.857935: bru_input(bru_input) for (field)
#> 2026-06-16 20:31:54.872648: iinla: Start
#> 2026-06-16 20:31:54.874172: iinla: Evaluate component linearisations
#> 2026-06-16 20:31:54.875264: Linearise components for each observation model
#> 2026-06-16 20:31:54.876553: Linearise component 'x'
#> 2026-06-16 20:31:54.879411: Linearise component 'field'
#> 2026-06-16 20:31:54.882597: iinla: Evaluate component simplifications
#> 2026-06-16 20:31:54.883781: Simplify component mappers for each observation model
#> 2026-06-16 20:31:54.885082: Simplify component 'x'
#> 2026-06-16 20:31:54.888045: Simplify component 'field'
#> 2026-06-16 20:31:54.891448: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:31:54.895689: iinla: Construct inla stack
#> 2026-06-16 20:31:54.908879: iinla: Model initialisation completed
#> 2026-06-16 20:31:54.910264: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:55.357566: iinla: Computation completed
#> 2026-06-16 20:31:57.152489: bru_input(bru_comp_list)
#> 2026-06-16 20:32:03.837166: bru: Preprocessing
#> 2026-06-16 20:32:03.844025: Evaluate component inputs for each observation model
#> 2026-06-16 20:32:03.845359: bru_input(bru_comp_list)
#> 2026-06-16 20:32:03.846699: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:32:03.848007: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:32:03.849474: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:32:03.850892: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:32:03.852176: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:32:03.868696: iinla: Start
#> 2026-06-16 20:32:03.870323: iinla: Evaluate component linearisations
#> 2026-06-16 20:32:03.871464: Linearise components for each observation model
#> 2026-06-16 20:32:03.872817: Linearise component 'Intercept'
#> 2026-06-16 20:32:03.875815: iinla: Evaluate component simplifications
#> 2026-06-16 20:32:03.877003: Simplify component mappers for each observation model
#> 2026-06-16 20:32:03.87834: Simplify component 'Intercept'
#> 2026-06-16 20:32:03.881369: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:32:03.885161: iinla: Construct inla stack
#> 2026-06-16 20:32:03.899895: iinla: Model initialisation completed
#> 2026-06-16 20:32:03.901387: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:05.100923: iinla: Computation completed
#> 2026-06-16 20:32:08.594693: bru: Preprocessing
#> 2026-06-16 20:32:08.60413: Evaluate component inputs for each observation model
#> 2026-06-16 20:32:08.605512: bru_input(bru_comp_list)
#> 2026-06-16 20:32:08.606919: bru_input.bru_comp(Intercept)
#> 2026-06-16 20:32:08.608291: bru_input.bm_pipe(Intercept)
#> 2026-06-16 20:32:08.609967: bru_input.bm_multi(Intercept:core)
#> 2026-06-16 20:32:08.611438: bru_input.bru_mapper(Intercept:core:main)
#> 2026-06-16 20:32:08.612808: bru_input(bru_input) for (Intercept)
#> 2026-06-16 20:32:08.621665: bru_input.bru_comp(field)
#> 2026-06-16 20:32:08.622993: bru_input.bm_pipe(field)
#> 2026-06-16 20:32:08.624469: bru_input.bm_multi(field:core)
#> 2026-06-16 20:32:08.625862: bru_input.bru_mapper(field:core:main)
#> 2026-06-16 20:32:08.627201: bru_input(bru_input) for (field)
#> 2026-06-16 20:32:08.643385: iinla: Start
#> 2026-06-16 20:32:08.644938: iinla: Evaluate component linearisations
#> 2026-06-16 20:32:08.64609: Linearise components for each observation model
#> 2026-06-16 20:32:08.647431: Linearise component 'Intercept'
#> 2026-06-16 20:32:08.650402: Linearise component 'field'
#> 2026-06-16 20:32:08.778909: iinla: Evaluate component simplifications
#> 2026-06-16 20:32:08.780364: Simplify component mappers for each observation model
#> 2026-06-16 20:32:08.781861: Simplify component 'Intercept'
#> 2026-06-16 20:32:08.785142: Simplify component 'field'
#> 2026-06-16 20:32:08.91502: iinla: Evaluate predictor linearisation
#> 2026-06-16 20:32:08.92024: iinla: Construct inla stack
#> 2026-06-16 20:32:08.938656: iinla: Model initialisation completed
#> 2026-06-16 20:32:08.940093: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:51.89553: iinla: Computation completed
#> 2026-06-16 20:32:53.546362: bru: Preprocessing
#> 2026-06-16 20:32:53.559824: Evaluate component inputs for each observation model
#> 2026-06-16 20:32:53.56118: bru_input(bru_comp_list)
#> 2026-06-16 20:32:53.562642: bru_input.bru_comp(x)
#> 2026-06-16 20:32:53.564086: bru_input.bm_pipe(x)
#> 2026-06-16 20:32:53.565698: bru_input.bm_multi(x:core)
#> 2026-06-16 20:32:53.567141: bru_input.bru_mapper(x:core:main)
#> 2026-06-16 20:32:53.568535: bru_input(bru_input) for (x)
#> 2026-06-16 20:32:53.576073: bru_input(bru_comp_list)
#> 2026-06-16 20:32:53.577442: bru_input.bru_comp(x)
#> 2026-06-16 20:32:53.578764: bru_input.bm_pipe(x)
#> 2026-06-16 20:32:53.580204: bru_input.bm_multi(x:core)
#> 2026-06-16 20:32:53.581586: bru_input.bru_mapper(x:core:main)
#> 2026-06-16 20:32:53.582841: bru_input(bru_input) for (x)
#> 2026-06-16 20:32:55.978679: bru_input(bru_input) for (LABEL)
#> 2026-06-16 20:32:57.899021: bru_input_text(bru_input) for (LABEL)
#> 2026-06-16 20:32:57.910962: bru_input.bru_comp(x)
#> 2026-06-16 20:32:57.912113: bru_input_text.bm_pipe(x)
#> 2026-06-16 20:32:57.913377: bru_input_text.bm_multi(x:core)
#> 2026-06-16 20:32:57.914555: bru_input_text.bru_mapper(x:core:main)
#> 2026-06-16 20:32:57.915535: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-06-16 20:30:45.09502: inlabru loaded
#> 2026-06-16 20:30:45.095501: Clear override options
#> 2026-06-16 20:30:55.823966: bru: Preprocessing
#> 2026-06-16 20:30:55.942291: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:30:56.882642: bru: Preprocessing
#> 2026-06-16 20:30:56.987697: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:30:57.487463: bru: Preprocessing
#> 2026-06-16 20:30:57.598247: iinla: Iteration 1 [max: 10]
#> 2026-06-16 20:30:58.028605: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6)
#> 2026-06-16 20:30:58.057671: iinla: Iteration 2 [max: 10]
#> 2026-06-16 20:30:58.836868: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5)
#> 2026-06-16 20:30:58.86442: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:58.866829: iinla: Iteration 3 [max: 10]
#> 2026-06-16 20:30:59.298845: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-06-16 20:30:59.327023: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:59.3295: iinla: Iteration 4 [max: 10]
#> 2026-06-16 20:30:59.808815: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-06-16 20:30:59.810064: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-06-16 20:30:59.812497: iinla: Iteration 5 [max: 10]
#> 2026-06-16 20:31:05.247466: bru: Preprocessing
#> 2026-06-16 20:31:05.309615: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:09.941729: bru: Preprocessing
#> 2026-06-16 20:31:10.284269: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:31:54.810652: bru: Preprocessing
#> 2026-06-16 20:31:54.910264: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:03.837166: bru: Preprocessing
#> 2026-06-16 20:32:03.901387: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:08.594693: bru: Preprocessing
#> 2026-06-16 20:32:08.940093: iinla: Iteration 1 [max: 1]
#> 2026-06-16 20:32:53.546362: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-06-16 20:30:45.09502: inlabru loaded (level 1)
#> 2026-06-16 20:30:45.095501: Clear override options (level 1)
#> 2026-06-16 20:30:55.823966: bru: Preprocessing (level 1)
#> 2026-06-16 20:30:55.839444: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:30:55.840827: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:30:55.842193: bru_input.bru_comp(x) (level 4)
#> 2026-06-16 20:30:55.843614: bru_input.bm_pipe(x) (level 5)
#> 2026-06-16 20:30:55.84514: bru_input.bm_multi(x:core) (level 5)
#> 2026-06-16 20:30:55.846673: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-06-16 20:30:55.848344: bru_input(bru_input) for (x) (level 5)
#> 2026-06-16 20:30:55.85645: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:30:55.85781: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:30:55.859238: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:30:55.860694: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:30:55.862187: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:30:55.878177: iinla: Start (level 3)
#> 2026-06-16 20:30:55.8799: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:55.881083: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:55.882723: Linearise component 'x' (level 4)
#> 2026-06-16 20:30:55.885917: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:55.888686: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:30:55.889913: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:30:55.891332: Simplify component 'x' (level 4)
#> 2026-06-16 20:30:55.894348: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:30:55.897268: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:55.919712: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:30:55.940834: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:30:55.942291: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:30:56.85404: iinla: Computation completed (level 3)
#> 2026-06-16 20:30:56.882642: bru: Preprocessing (level 1)
#> 2026-06-16 20:30:56.893692: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:30:56.895518: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:30:56.89739: bru_input.bru_comp(x) (level 4)
#> 2026-06-16 20:30:56.899193: bru_input.bm_pipe(x) (level 5)
#> 2026-06-16 20:30:56.901222: bru_input.bm_multi(x:core) (level 5)
#> 2026-06-16 20:30:56.903225: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-06-16 20:30:56.905028: bru_input(bru_input) for (x) (level 5)
#> 2026-06-16 20:30:56.913341: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:30:56.915227: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:30:56.917219: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:30:56.919221: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:30:56.921: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:30:56.937117: iinla: Start (level 3)
#> 2026-06-16 20:30:56.93936: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:56.940937: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:56.942756: Linearise component 'x' (level 4)
#> 2026-06-16 20:30:56.946442: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:56.949914: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:30:56.951515: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:30:56.953344: Simplify component 'x' (level 4)
#> 2026-06-16 20:30:56.957023: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:30:56.960714: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:56.968688: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:30:56.985751: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:30:56.987697: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:30:57.459836: iinla: Computation completed (level 3)
#> 2026-06-16 20:30:57.487463: bru: Preprocessing (level 1)
#> 2026-06-16 20:30:57.498141: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:30:57.499931: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:30:57.501738: bru_input.bru_comp(z) (level 4)
#> 2026-06-16 20:30:57.503552: bru_input.bm_pipe(z) (level 5)
#> 2026-06-16 20:30:57.505592: bru_input.bm_multi(z:core) (level 5)
#> 2026-06-16 20:30:57.5076: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-06-16 20:30:57.509401: bru_input(bru_input) for (z) (level 5)
#> 2026-06-16 20:30:57.517704: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:30:57.519559: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:30:57.521552: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:30:57.523509: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:30:57.525349: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:30:57.540499: iinla: Start (level 3)
#> 2026-06-16 20:30:57.542623: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:57.544178: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:57.556236: Linearise component 'z' (level 4)
#> 2026-06-16 20:30:57.559581: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:57.562364: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:30:57.56357: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:30:57.564905: Simplify component 'z' (level 4)
#> 2026-06-16 20:30:57.567895: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:30:57.570926: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:57.574056: Linearise with respect to component 'z' (level 5)
#> 2026-06-16 20:30:57.579499: Linearise with respect to component 'Intercept' (level 5)
#> 2026-06-16 20:30:57.582791: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:30:57.596549: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:30:57.598247: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-06-16 20:30:58.018912: iinla: Step rescaling: 61.8%, Contract (norm0 = 1968, norm1 = 1806, norm01 = 347.6) (level 3)
#> 2026-06-16 20:30:58.021866: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.7, norm1 = 294.9, norm01 = 347.6) (level 3)
#> 2026-06-16 20:30:58.02564: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184, norm1 = 225.4, norm01 = 347.6) (level 3)
#> 2026-06-16 20:30:58.027147: iinla: |lin1-lin0| = 347.6
#> <eta-lin1,delta>/|delta| = -198.2
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4 (level 4)
#> 2026-06-16 20:30:58.028605: iinla: Step rescaling: 27.4% (norm0 = 184, norm1 = 225.4, norm01 = 347.6) (level 2)
#> 2026-06-16 20:30:58.030298: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:58.031466: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:58.032802: Linearise component 'z' (level 4)
#> 2026-06-16 20:30:58.035709: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:58.038529: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:58.041171: Linearise with respect to component 'z' (level 5)
#> 2026-06-16 20:30:58.044721: Linearise with respect to component 'Intercept' (level 5)
#> 2026-06-16 20:30:58.057671: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-06-16 20:30:58.827418: iinla: Step rescaling: 162%, Expand (norm0 = 365.3, norm1 = 141.7, norm01 = 225.5) (level 3)
#> 2026-06-16 20:30:58.830457: iinla: Step rescaling: 100%, Overstep (norm0 = 225.5, norm1 = 10.71, norm01 = 225.5) (level 3)
#> 2026-06-16 20:30:58.834016: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 3)
#> 2026-06-16 20:30:58.835491: iinla: |lin1-lin0| = 225.5
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.64 (level 4)
#> 2026-06-16 20:30:58.836868: iinla: Step rescaling: 99.7% (norm0 = 224.8, norm1 = 10.69, norm01 = 225.5) (level 2)
#> 2026-06-16 20:30:58.838523: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:58.839605: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:58.840868: Linearise component 'z' (level 4)
#> 2026-06-16 20:30:58.843745: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:58.846508: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:58.849077: Linearise with respect to component 'z' (level 5)
#> 2026-06-16 20:30:58.852592: Linearise with respect to component 'Intercept' (level 5)
#> 2026-06-16 20:30:58.86442: iinla: Max deviation from previous: 46400% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-06-16 20:30:58.866829: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-06-16 20:30:59.289583: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.152, norm01 = 10.68) (level 3)
#> 2026-06-16 20:30:59.292392: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-06-16 20:30:59.295932: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-06-16 20:30:59.297441: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-06-16 20:30:59.298845: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-06-16 20:30:59.300526: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:59.301667: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:59.303013: Linearise component 'z' (level 4)
#> 2026-06-16 20:30:59.305983: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:59.308815: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:59.311527: Linearise with respect to component 'z' (level 5)
#> 2026-06-16 20:30:59.315102: Linearise with respect to component 'Intercept' (level 5)
#> 2026-06-16 20:30:59.327023: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-06-16 20:30:59.3295: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-06-16 20:30:59.771804: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007268, norm01 = 0.01176) (level 3)
#> 2026-06-16 20:30:59.775023: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-06-16 20:30:59.778654: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.856e-08, norm01 = 0.01176) (level 3)
#> 2026-06-16 20:30:59.780185: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.23e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-06-16 20:30:59.781942: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:30:59.783171: Linearise components for each observation model (level 3)
#> 2026-06-16 20:30:59.784587: Linearise component 'z' (level 4)
#> 2026-06-16 20:30:59.787725: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:30:59.79054: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:30:59.79318: Linearise with respect to component 'z' (level 5)
#> 2026-06-16 20:30:59.796812: Linearise with respect to component 'Intercept' (level 5)
#> 2026-06-16 20:30:59.808815: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-06-16 20:30:59.810064: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-06-16 20:30:59.812497: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-06-16 20:31:00.261194: iinla: Computation completed (level 3)
#> 2026-06-16 20:31:05.247466: bru: Preprocessing (level 1)
#> 2026-06-16 20:31:05.254477: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:31:05.255818: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:31:05.257231: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:31:05.258644: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:31:05.26017: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:31:05.261678: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:31:05.263008: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:31:05.279433: iinla: Start (level 3)
#> 2026-06-16 20:31:05.281048: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:31:05.282218: Linearise components for each observation model (level 3)
#> 2026-06-16 20:31:05.28355: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:31:05.286692: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:31:05.287888: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:31:05.289343: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:31:05.292493: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:31:05.297834: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:31:05.308159: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:31:05.309615: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:31:06.526183: iinla: Computation completed (level 3)
#> 2026-06-16 20:31:09.941729: bru: Preprocessing (level 1)
#> 2026-06-16 20:31:09.951497: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:31:09.952895: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:31:09.954355: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:31:09.95574: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:31:09.957274: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:31:09.958787: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:31:09.960216: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:31:09.967523: bru_input.bru_comp(field) (level 4)
#> 2026-06-16 20:31:09.968916: bru_input.bm_pipe(field) (level 5)
#> 2026-06-16 20:31:09.970428: bru_input.bm_multi(field:core) (level 5)
#> 2026-06-16 20:31:09.97187: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-06-16 20:31:09.973197: bru_input(bru_input) for (field) (level 5)
#> 2026-06-16 20:31:09.989347: iinla: Start (level 3)
#> 2026-06-16 20:31:09.990876: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:31:09.991996: Linearise components for each observation model (level 3)
#> 2026-06-16 20:31:09.993369: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:31:09.996436: Linearise component 'field' (level 4)
#> 2026-06-16 20:31:10.121238: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:31:10.12265: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:31:10.124041: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:31:10.127162: Simplify component 'field' (level 4)
#> 2026-06-16 20:31:10.259171: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:31:10.264299: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:31:10.282805: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:31:10.284269: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:31:53.642206: iinla: Computation completed (level 3)
#> 2026-06-16 20:31:54.810652: bru: Preprocessing (level 1)
#> 2026-06-16 20:31:54.823438: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:31:54.824719: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:31:54.826028: bru_input.bru_comp(x) (level 4)
#> 2026-06-16 20:31:54.827394: bru_input.bm_pipe(x) (level 5)
#> 2026-06-16 20:31:54.828856: bru_input.bm_multi(x:core) (level 5)
#> 2026-06-16 20:31:54.830255: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-06-16 20:31:54.831605: bru_input(bru_input) for (x) (level 5)
#> 2026-06-16 20:31:54.838988: bru_input.bru_comp(field) (level 4)
#> 2026-06-16 20:31:54.840388: bru_input.bm_pipe(field) (level 5)
#> 2026-06-16 20:31:54.841851: bru_input.bm_multi(field:core) (level 5)
#> 2026-06-16 20:31:54.856585: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-06-16 20:31:54.857935: bru_input(bru_input) for (field) (level 5)
#> 2026-06-16 20:31:54.872648: iinla: Start (level 3)
#> 2026-06-16 20:31:54.874172: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:31:54.875264: Linearise components for each observation model (level 3)
#> 2026-06-16 20:31:54.876553: Linearise component 'x' (level 4)
#> 2026-06-16 20:31:54.879411: Linearise component 'field' (level 4)
#> 2026-06-16 20:31:54.882597: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:31:54.883781: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:31:54.885082: Simplify component 'x' (level 4)
#> 2026-06-16 20:31:54.888045: Simplify component 'field' (level 4)
#> 2026-06-16 20:31:54.891448: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:31:54.895689: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:31:54.908879: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:31:54.910264: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:31:55.357566: iinla: Computation completed (level 3)
#> 2026-06-16 20:31:57.152489: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:32:03.837166: bru: Preprocessing (level 1)
#> 2026-06-16 20:32:03.844025: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:32:03.845359: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:32:03.846699: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:32:03.848007: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:32:03.849474: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:32:03.850892: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:32:03.852176: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:32:03.868696: iinla: Start (level 3)
#> 2026-06-16 20:32:03.870323: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:32:03.871464: Linearise components for each observation model (level 3)
#> 2026-06-16 20:32:03.872817: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:32:03.875815: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:32:03.877003: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:32:03.87834: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:32:03.881369: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:32:03.885161: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:32:03.899895: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:32:03.901387: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:32:05.100923: iinla: Computation completed (level 3)
#> 2026-06-16 20:32:08.594693: bru: Preprocessing (level 1)
#> 2026-06-16 20:32:08.60413: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:32:08.605512: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:32:08.606919: bru_input.bru_comp(Intercept) (level 4)
#> 2026-06-16 20:32:08.608291: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-06-16 20:32:08.609967: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-06-16 20:32:08.611438: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-06-16 20:32:08.612808: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-06-16 20:32:08.621665: bru_input.bru_comp(field) (level 4)
#> 2026-06-16 20:32:08.622993: bru_input.bm_pipe(field) (level 5)
#> 2026-06-16 20:32:08.624469: bru_input.bm_multi(field:core) (level 5)
#> 2026-06-16 20:32:08.625862: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-06-16 20:32:08.627201: bru_input(bru_input) for (field) (level 5)
#> 2026-06-16 20:32:08.643385: iinla: Start (level 3)
#> 2026-06-16 20:32:08.644938: iinla: Evaluate component linearisations (level 3)
#> 2026-06-16 20:32:08.64609: Linearise components for each observation model (level 3)
#> 2026-06-16 20:32:08.647431: Linearise component 'Intercept' (level 4)
#> 2026-06-16 20:32:08.650402: Linearise component 'field' (level 4)
#> 2026-06-16 20:32:08.778909: iinla: Evaluate component simplifications (level 3)
#> 2026-06-16 20:32:08.780364: Simplify component mappers for each observation model (level 3)
#> 2026-06-16 20:32:08.781861: Simplify component 'Intercept' (level 4)
#> 2026-06-16 20:32:08.785142: Simplify component 'field' (level 4)
#> 2026-06-16 20:32:08.91502: iinla: Evaluate predictor linearisation (level 3)
#> 2026-06-16 20:32:08.92024: iinla: Construct inla stack (level 3)
#> 2026-06-16 20:32:08.938656: iinla: Model initialisation completed (level 3)
#> 2026-06-16 20:32:08.940093: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-06-16 20:32:51.89553: iinla: Computation completed (level 3)
#> 2026-06-16 20:32:53.546362: bru: Preprocessing (level 1)
#> 2026-06-16 20:32:53.559824: Evaluate component inputs for each observation model (level 3)
#> 2026-06-16 20:32:53.56118: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:32:53.562642: bru_input.bru_comp(x) (level 4)
#> 2026-06-16 20:32:53.564086: bru_input.bm_pipe(x) (level 5)
#> 2026-06-16 20:32:53.565698: bru_input.bm_multi(x:core) (level 5)
#> 2026-06-16 20:32:53.567141: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-06-16 20:32:53.568535: bru_input(bru_input) for (x) (level 5)
#> 2026-06-16 20:32:53.576073: bru_input(bru_comp_list) (level 4)
#> 2026-06-16 20:32:53.577442: bru_input.bru_comp(x) (level 4)
#> 2026-06-16 20:32:53.578764: bru_input.bm_pipe(x) (level 5)
#> 2026-06-16 20:32:53.580204: bru_input.bm_multi(x:core) (level 5)
#> 2026-06-16 20:32:53.581586: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-06-16 20:32:53.582841: bru_input(bru_input) for (x) (level 5)
#> 2026-06-16 20:32:55.978679: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-06-16 20:32:57.899021: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-06-16 20:32:57.910962: bru_input.bru_comp(x) (level 4)
#> 2026-06-16 20:32:57.912113: bru_input_text.bm_pipe(x) (level 5)
#> 2026-06-16 20:32:57.913377: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-06-16 20:32:57.914555: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-06-16 20:32:57.915535: bru_input_text(bru_input) for (x) (level 5)