Access method for bru_log objects.
Note: Up to version 2.8.0, bru_log() was a deprecated alias for
bru_log_message(). When running on 2.8.0 or earlier, use bru_log_get()
to access the global log, and cat(fit$bru_iinla$log, sep = "\n") to print a
stored estimation object log.
After version 2.8.0, use bru_log() to access the global log, and
bru_log(fit) to access a stored estimation log.
Usage
bru_log(x = NULL, verbosity = NULL)
# S3 method for class 'character'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
bru_log(x, verbosity = NULL)
# S3 method for class 'iinla'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru'
bru_log(x, verbosity = NULL)
# S3 method for class 'bru_log'
format(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
print(x, ..., timestamp = TRUE, verbosity = FALSE)
# S3 method for class 'bru_log'
as.character(x, ...)
# S3 method for class 'bru_log'
x[i]
# S3 method for class 'bru_log'
c(...)
# S3 method for class 'bru_log'
length(x)Arguments
- x
An object that is, contains, or can be converted to, a
bru_logobject. IfNULL, refers to the globalinlabrulog.- verbosity
integer value for limiting the highest verbosity level being returned.
- ...
further arguments passed to or from other methods.
- timestamp
If
TRUE, include the timestamp of each message. DefaultTRUE.- i
indices specifying elements to extract. If
character, denotes the sequence between bookmarkiand the next bookmark (or the end of the log ifiis the last bookmark)
Value
bru_log A bru_log object, containing a
character vector of log messages, and potentially a vector of bookmarks.
Methods (by generic)
format(bru_log): Format abru_logobject for printing. IfverbosityisTRUE, include the verbosity level of each message.print(bru_log): Print abru_logobject withcat(x, sep = "\n"). IfverbosityisTRUE, include the verbosity level of each message.as.character(bru_log): Convertbru_logobject to a plaincharactervector[: Extract a subset of abru_logobjectc(bru_log): Concatenate severalbru_logorcharacterobjects into abru_logobject.length(bru_log): Obtain the number of log entries into abru_logobject.
Functions
bru_log(): Extract stored log messages. If non-NULL, theverbosityargument determines the maximum verbosity level of the messages to extract.
See also
Other inlabru log methods:
bru_log_bookmark(),
bru_log_message(),
bru_log_new(),
bru_log_offset(),
bru_log_reset()
Examples
bru_log(verbosity = 2L)
#> 2026-05-29 09:00:41.35138: inlabru loaded
#> 2026-05-29 09:00:41.351861: Clear override options
#> 2026-05-29 09:00:51.958454: bru: Preprocessing
#> 2026-05-29 09:00:52.086857: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:00:52.982005: bru: Preprocessing
#> 2026-05-29 09:00:53.084635: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:00:53.474881: bru: Preprocessing
#> 2026-05-29 09:00:53.588065: iinla: Iteration 1 [max: 10]
#> 2026-05-29 09:00:53.939259: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-29 09:00:53.969152: iinla: Iteration 2 [max: 10]
#> 2026-05-29 09:00:54.666774: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-29 09:00:54.694346: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:54.696753: iinla: Iteration 3 [max: 10]
#> 2026-05-29 09:00:55.033076: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-29 09:00:55.061196: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:55.06374: iinla: Iteration 4 [max: 10]
#> 2026-05-29 09:00:55.430036: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:55.431278: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-29 09:00:55.433759: iinla: Iteration 5 [max: 10]
#> 2026-05-29 09:01:00.602037: bru: Preprocessing
#> 2026-05-29 09:01:00.667676: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:05.178257: bru: Preprocessing
#> 2026-05-29 09:01:05.530502: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:53.377765: bru: Preprocessing
#> 2026-05-29 09:01:53.441613: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:01.95942: bru: Preprocessing
#> 2026-05-29 09:02:02.017184: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:06.391189: bru: Preprocessing
#> 2026-05-29 09:02:06.725042: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:55.034793: bru: Preprocessing
format(bru_log())
#> 2026-05-29 09:00:41.35138: inlabru loaded
#> 2026-05-29 09:00:41.351861: Clear override options
#> 2026-05-29 09:00:51.958454: bru: Preprocessing
#> 2026-05-29 09:00:51.974694: Evaluate component inputs for each observation model
#> 2026-05-29 09:00:51.976128: bru_input(bru_comp_list)
#> 2026-05-29 09:00:51.977547: bru_input.bru_comp(x)
#> 2026-05-29 09:00:51.978981: bru_input.bm_pipe(x)
#> 2026-05-29 09:00:51.980545: bru_input.bm_multi(x:core)
#> 2026-05-29 09:00:51.982039: bru_input.bru_mapper(x:core:main)
#> 2026-05-29 09:00:51.983662: bru_input(bru_input) for (x)
#> 2026-05-29 09:00:51.991678: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:00:52.00668: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:00:52.009406: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:00:52.012098: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:00:52.014308: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:00:52.03246: iinla: Start
#> 2026-05-29 09:00:52.034154: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:52.035453: Linearise components for each observation model
#> 2026-05-29 09:00:52.037008: Linearise component 'x'
#> 2026-05-29 09:00:52.039956: Linearise component 'Intercept'
#> 2026-05-29 09:00:52.042736: iinla: Evaluate component simplifications
#> 2026-05-29 09:00:52.043959: Simplify component mappers for each observation model
#> 2026-05-29 09:00:52.045408: Simplify component 'x'
#> 2026-05-29 09:00:52.048461: Simplify component 'Intercept'
#> 2026-05-29 09:00:52.05137: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:52.064404: iinla: Construct inla stack
#> 2026-05-29 09:00:52.084954: iinla: Model initialisation completed
#> 2026-05-29 09:00:52.086857: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:00:52.957328: iinla: Computation completed
#> 2026-05-29 09:00:52.982005: bru: Preprocessing
#> 2026-05-29 09:00:52.990825: Evaluate component inputs for each observation model
#> 2026-05-29 09:00:52.992107: bru_input(bru_comp_list)
#> 2026-05-29 09:00:52.993685: bru_input.bru_comp(x)
#> 2026-05-29 09:00:52.995462: bru_input.bm_pipe(x)
#> 2026-05-29 09:00:52.9975: bru_input.bm_multi(x:core)
#> 2026-05-29 09:00:52.999471: bru_input.bru_mapper(x:core:main)
#> 2026-05-29 09:00:53.001271: bru_input(bru_input) for (x)
#> 2026-05-29 09:00:53.009879: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:00:53.0118: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:00:53.013931: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:00:53.01591: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:00:53.017714: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:00:53.033754: iinla: Start
#> 2026-05-29 09:00:53.035915: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:53.037498: Linearise components for each observation model
#> 2026-05-29 09:00:53.039331: Linearise component 'x'
#> 2026-05-29 09:00:53.043028: Linearise component 'Intercept'
#> 2026-05-29 09:00:53.046467: iinla: Evaluate component simplifications
#> 2026-05-29 09:00:53.048103: Simplify component mappers for each observation model
#> 2026-05-29 09:00:53.049953: Simplify component 'x'
#> 2026-05-29 09:00:53.05366: Simplify component 'Intercept'
#> 2026-05-29 09:00:53.057319: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:53.065569: iinla: Construct inla stack
#> 2026-05-29 09:00:53.082663: iinla: Model initialisation completed
#> 2026-05-29 09:00:53.084635: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:00:53.446081: iinla: Computation completed
#> 2026-05-29 09:00:53.474881: bru: Preprocessing
#> 2026-05-29 09:00:53.48596: Evaluate component inputs for each observation model
#> 2026-05-29 09:00:53.487775: bru_input(bru_comp_list)
#> 2026-05-29 09:00:53.489594: bru_input.bru_comp(z)
#> 2026-05-29 09:00:53.49142: bru_input.bm_pipe(z)
#> 2026-05-29 09:00:53.493459: bru_input.bm_multi(z:core)
#> 2026-05-29 09:00:53.495447: bru_input.bru_mapper(z:core:main)
#> 2026-05-29 09:00:53.497233: bru_input(bru_input) for (z)
#> 2026-05-29 09:00:53.505734: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:00:53.507621: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:00:53.50964: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:00:53.511608: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:00:53.51338: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:00:53.529654: iinla: Start
#> 2026-05-29 09:00:53.531824: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:53.533394: Linearise components for each observation model
#> 2026-05-29 09:00:53.535246: Linearise component 'z'
#> 2026-05-29 09:00:53.539139: Linearise component 'Intercept'
#> 2026-05-29 09:00:53.542593: iinla: Evaluate component simplifications
#> 2026-05-29 09:00:53.544254: Simplify component mappers for each observation model
#> 2026-05-29 09:00:53.546096: Simplify component 'z'
#> 2026-05-29 09:00:53.549819: Simplify component 'Intercept'
#> 2026-05-29 09:00:53.553444: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:53.557525: Linearise with respect to component 'z'
#> 2026-05-29 09:00:53.564623: Linearise with respect to component 'Intercept'
#> 2026-05-29 09:00:53.568928: iinla: Construct inla stack
#> 2026-05-29 09:00:53.586128: iinla: Model initialisation completed
#> 2026-05-29 09:00:53.588065: iinla: Iteration 1 [max: 10]
#> 2026-05-29 09:00:53.929714: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8)
#> 2026-05-29 09:00:53.932741: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8)
#> 2026-05-29 09:00:53.936284: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-29 09:00:53.93781: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4
#> 2026-05-29 09:00:53.939259: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-29 09:00:53.941016: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:53.942283: Linearise components for each observation model
#> 2026-05-29 09:00:53.943658: Linearise component 'z'
#> 2026-05-29 09:00:53.946535: Linearise component 'Intercept'
#> 2026-05-29 09:00:53.949293: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:53.952008: Linearise with respect to component 'z'
#> 2026-05-29 09:00:53.955598: Linearise with respect to component 'Intercept'
#> 2026-05-29 09:00:53.969152: iinla: Iteration 2 [max: 10]
#> 2026-05-29 09:00:54.65724: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4)
#> 2026-05-29 09:00:54.66022: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4)
#> 2026-05-29 09:00:54.663823: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-29 09:00:54.665334: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63
#> 2026-05-29 09:00:54.666774: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-29 09:00:54.668439: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:54.669549: Linearise components for each observation model
#> 2026-05-29 09:00:54.670835: Linearise component 'z'
#> 2026-05-29 09:00:54.673798: Linearise component 'Intercept'
#> 2026-05-29 09:00:54.676592: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:54.679207: Linearise with respect to component 'z'
#> 2026-05-29 09:00:54.682691: Linearise with respect to component 'Intercept'
#> 2026-05-29 09:00:54.694346: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:54.696753: iinla: Iteration 3 [max: 10]
#> 2026-05-29 09:00:55.023747: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68)
#> 2026-05-29 09:00:55.026739: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68)
#> 2026-05-29 09:00:55.03015: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-29 09:00:55.031671: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176
#> 2026-05-29 09:00:55.033076: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-29 09:00:55.034781: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:55.035985: Linearise components for each observation model
#> 2026-05-29 09:00:55.037422: Linearise component 'z'
#> 2026-05-29 09:00:55.040383: Linearise component 'Intercept'
#> 2026-05-29 09:00:55.04319: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:55.045858: Linearise with respect to component 'z'
#> 2026-05-29 09:00:55.04937: Linearise with respect to component 'Intercept'
#> 2026-05-29 09:00:55.061196: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:55.06374: iinla: Iteration 4 [max: 10]
#> 2026-05-29 09:00:55.393747: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007267, norm01 = 0.01176)
#> 2026-05-29 09:00:55.396755: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176)
#> 2026-05-29 09:00:55.40028: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176)
#> 2026-05-29 09:00:55.401814: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.228e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08
#> 2026-05-29 09:00:55.40353: iinla: Evaluate component linearisations
#> 2026-05-29 09:00:55.404687: Linearise components for each observation model
#> 2026-05-29 09:00:55.406056: Linearise component 'z'
#> 2026-05-29 09:00:55.408975: Linearise component 'Intercept'
#> 2026-05-29 09:00:55.411728: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:00:55.414346: Linearise with respect to component 'z'
#> 2026-05-29 09:00:55.41792: Linearise with respect to component 'Intercept'
#> 2026-05-29 09:00:55.430036: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:55.431278: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-29 09:00:55.433759: iinla: Iteration 5 [max: 10]
#> 2026-05-29 09:00:55.775583: iinla: Computation completed
#> 2026-05-29 09:01:00.602037: bru: Preprocessing
#> 2026-05-29 09:01:00.608616: Evaluate component inputs for each observation model
#> 2026-05-29 09:01:00.609836: bru_input(bru_comp_list)
#> 2026-05-29 09:01:00.611067: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:01:00.612326: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:01:00.613736: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:01:00.615102: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:01:00.616321: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:01:00.631923: iinla: Start
#> 2026-05-29 09:01:00.633508: iinla: Evaluate component linearisations
#> 2026-05-29 09:01:00.634605: Linearise components for each observation model
#> 2026-05-29 09:01:00.635921: Linearise component 'Intercept'
#> 2026-05-29 09:01:00.638854: iinla: Evaluate component simplifications
#> 2026-05-29 09:01:00.640031: Simplify component mappers for each observation model
#> 2026-05-29 09:01:00.641379: Simplify component 'Intercept'
#> 2026-05-29 09:01:00.644431: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:01:00.649846: iinla: Construct inla stack
#> 2026-05-29 09:01:00.666199: iinla: Model initialisation completed
#> 2026-05-29 09:01:00.667676: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:01.755286: iinla: Computation completed
#> 2026-05-29 09:01:05.178257: bru: Preprocessing
#> 2026-05-29 09:01:05.18759: Evaluate component inputs for each observation model
#> 2026-05-29 09:01:05.188921: bru_input(bru_comp_list)
#> 2026-05-29 09:01:05.197285: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:01:05.198705: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:01:05.200214: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:01:05.201663: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:01:05.202952: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:01:05.210795: bru_input.bru_comp(field)
#> 2026-05-29 09:01:05.212188: bru_input.bm_pipe(field)
#> 2026-05-29 09:01:05.213682: bru_input.bm_multi(field:core)
#> 2026-05-29 09:01:05.215121: bru_input.bru_mapper(field:core:main)
#> 2026-05-29 09:01:05.216439: bru_input(bru_input) for (field)
#> 2026-05-29 09:01:05.234542: iinla: Start
#> 2026-05-29 09:01:05.236203: iinla: Evaluate component linearisations
#> 2026-05-29 09:01:05.23739: Linearise components for each observation model
#> 2026-05-29 09:01:05.238767: Linearise component 'Intercept'
#> 2026-05-29 09:01:05.241848: Linearise component 'field'
#> 2026-05-29 09:01:05.367824: iinla: Evaluate component simplifications
#> 2026-05-29 09:01:05.369217: Simplify component mappers for each observation model
#> 2026-05-29 09:01:05.370629: Simplify component 'Intercept'
#> 2026-05-29 09:01:05.373794: Simplify component 'field'
#> 2026-05-29 09:01:05.505748: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:01:05.510861: iinla: Construct inla stack
#> 2026-05-29 09:01:05.529047: iinla: Model initialisation completed
#> 2026-05-29 09:01:05.530502: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:52.128071: iinla: Computation completed
#> 2026-05-29 09:01:53.377765: bru: Preprocessing
#> 2026-05-29 09:01:53.387598: Evaluate component inputs for each observation model
#> 2026-05-29 09:01:53.388839: bru_input(bru_comp_list)
#> 2026-05-29 09:01:53.390106: bru_input.bru_comp(field)
#> 2026-05-29 09:01:53.391387: bru_input.bm_pipe(field)
#> 2026-05-29 09:01:53.392828: bru_input.bm_multi(field:core)
#> 2026-05-29 09:01:53.394177: bru_input.bru_mapper(field:core:main)
#> 2026-05-29 09:01:53.395386: bru_input(bru_input) for (field)
#> 2026-05-29 09:01:53.40757: iinla: Start
#> 2026-05-29 09:01:53.40906: iinla: Evaluate component linearisations
#> 2026-05-29 09:01:53.410152: Linearise components for each observation model
#> 2026-05-29 09:01:53.411399: Linearise component 'field'
#> 2026-05-29 09:01:53.417675: iinla: Evaluate component simplifications
#> 2026-05-29 09:01:53.418843: Simplify component mappers for each observation model
#> 2026-05-29 09:01:53.420112: Simplify component 'field'
#> 2026-05-29 09:01:53.426124: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:01:53.429524: iinla: Construct inla stack
#> 2026-05-29 09:01:53.440195: iinla: Model initialisation completed
#> 2026-05-29 09:01:53.441613: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:53.866693: iinla: Computation completed
#> 2026-05-29 09:01:55.670652: bru_input(bru_comp_list)
#> 2026-05-29 09:02:01.95942: bru: Preprocessing
#> 2026-05-29 09:02:01.966242: Evaluate component inputs for each observation model
#> 2026-05-29 09:02:01.967549: bru_input(bru_comp_list)
#> 2026-05-29 09:02:01.968862: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:02:01.970217: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:02:01.971716: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:02:01.973123: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:02:01.974416: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:02:01.990217: iinla: Start
#> 2026-05-29 09:02:01.991822: iinla: Evaluate component linearisations
#> 2026-05-29 09:02:01.992955: Linearise components for each observation model
#> 2026-05-29 09:02:01.994233: Linearise component 'Intercept'
#> 2026-05-29 09:02:01.997243: iinla: Evaluate component simplifications
#> 2026-05-29 09:02:01.998446: Simplify component mappers for each observation model
#> 2026-05-29 09:02:01.999767: Simplify component 'Intercept'
#> 2026-05-29 09:02:02.002795: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:02:02.006627: iinla: Construct inla stack
#> 2026-05-29 09:02:02.015785: iinla: Model initialisation completed
#> 2026-05-29 09:02:02.017184: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:03.469348: iinla: Computation completed
#> 2026-05-29 09:02:06.391189: bru: Preprocessing
#> 2026-05-29 09:02:06.400709: Evaluate component inputs for each observation model
#> 2026-05-29 09:02:06.402036: bru_input(bru_comp_list)
#> 2026-05-29 09:02:06.403357: bru_input.bru_comp(Intercept)
#> 2026-05-29 09:02:06.404659: bru_input.bm_pipe(Intercept)
#> 2026-05-29 09:02:06.406082: bru_input.bm_multi(Intercept:core)
#> 2026-05-29 09:02:06.407459: bru_input.bru_mapper(Intercept:core:main)
#> 2026-05-29 09:02:06.408709: bru_input(bru_input) for (Intercept)
#> 2026-05-29 09:02:06.41603: bru_input.bru_comp(field)
#> 2026-05-29 09:02:06.417401: bru_input.bm_pipe(field)
#> 2026-05-29 09:02:06.418835: bru_input.bm_multi(field:core)
#> 2026-05-29 09:02:06.420187: bru_input.bru_mapper(field:core:main)
#> 2026-05-29 09:02:06.421446: bru_input(bru_input) for (field)
#> 2026-05-29 09:02:06.437285: iinla: Start
#> 2026-05-29 09:02:06.438819: iinla: Evaluate component linearisations
#> 2026-05-29 09:02:06.439905: Linearise components for each observation model
#> 2026-05-29 09:02:06.441163: Linearise component 'Intercept'
#> 2026-05-29 09:02:06.444079: Linearise component 'field'
#> 2026-05-29 09:02:06.566203: iinla: Evaluate component simplifications
#> 2026-05-29 09:02:06.567568: Simplify component mappers for each observation model
#> 2026-05-29 09:02:06.568923: Simplify component 'Intercept'
#> 2026-05-29 09:02:06.571918: Simplify component 'field'
#> 2026-05-29 09:02:06.70032: iinla: Evaluate predictor linearisation
#> 2026-05-29 09:02:06.70527: iinla: Construct inla stack
#> 2026-05-29 09:02:06.723208: iinla: Model initialisation completed
#> 2026-05-29 09:02:06.725042: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:53.000327: iinla: Computation completed
#> 2026-05-29 09:02:55.034793: bru: Preprocessing
#> 2026-05-29 09:02:55.050571: Evaluate component inputs for each observation model
#> 2026-05-29 09:02:55.052297: bru_input(bru_comp_list)
#> 2026-05-29 09:02:55.054039: bru_input.bru_comp(x)
#> 2026-05-29 09:02:55.055663: bru_input.bm_pipe(x)
#> 2026-05-29 09:02:55.057223: bru_input.bm_multi(x:core)
#> 2026-05-29 09:02:55.058678: bru_input.bru_mapper(x:core:main)
#> 2026-05-29 09:02:55.059964: bru_input(bru_input) for (x)
#> 2026-05-29 09:02:55.067743: bru_input(bru_comp_list)
#> 2026-05-29 09:02:55.069159: bru_input.bru_comp(x)
#> 2026-05-29 09:02:55.070508: bru_input.bm_pipe(x)
#> 2026-05-29 09:02:55.071965: bru_input.bm_multi(x:core)
#> 2026-05-29 09:02:55.073418: bru_input.bru_mapper(x:core:main)
#> 2026-05-29 09:02:55.074735: bru_input(bru_input) for (x)
#> 2026-05-29 09:02:58.067441: bru_input(bru_input) for (LABEL)
#> 2026-05-29 09:02:59.821329: bru_input_text(bru_input) for (LABEL)
#> 2026-05-29 09:02:59.833545: bru_input.bru_comp(x)
#> 2026-05-29 09:02:59.834716: bru_input_text.bm_pipe(x)
#> 2026-05-29 09:02:59.835948: bru_input_text.bm_multi(x:core)
#> 2026-05-29 09:02:59.837167: bru_input_text.bru_mapper(x:core:main)
#> 2026-05-29 09:02:59.838187: bru_input_text(bru_input) for (x)
bru_log(verbosity = 2L)
#> 2026-05-29 09:00:41.35138: inlabru loaded
#> 2026-05-29 09:00:41.351861: Clear override options
#> 2026-05-29 09:00:51.958454: bru: Preprocessing
#> 2026-05-29 09:00:52.086857: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:00:52.982005: bru: Preprocessing
#> 2026-05-29 09:00:53.084635: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:00:53.474881: bru: Preprocessing
#> 2026-05-29 09:00:53.588065: iinla: Iteration 1 [max: 10]
#> 2026-05-29 09:00:53.939259: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8)
#> 2026-05-29 09:00:53.969152: iinla: Iteration 2 [max: 10]
#> 2026-05-29 09:00:54.666774: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4)
#> 2026-05-29 09:00:54.694346: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:54.696753: iinla: Iteration 3 [max: 10]
#> 2026-05-29 09:00:55.033076: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68)
#> 2026-05-29 09:00:55.061196: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:55.06374: iinla: Iteration 4 [max: 10]
#> 2026-05-29 09:00:55.430036: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive]
#> 2026-05-29 09:00:55.431278: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode.
#> 2026-05-29 09:00:55.433759: iinla: Iteration 5 [max: 10]
#> 2026-05-29 09:01:00.602037: bru: Preprocessing
#> 2026-05-29 09:01:00.667676: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:05.178257: bru: Preprocessing
#> 2026-05-29 09:01:05.530502: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:01:53.377765: bru: Preprocessing
#> 2026-05-29 09:01:53.441613: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:01.95942: bru: Preprocessing
#> 2026-05-29 09:02:02.017184: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:06.391189: bru: Preprocessing
#> 2026-05-29 09:02:06.725042: iinla: Iteration 1 [max: 1]
#> 2026-05-29 09:02:55.034793: bru: Preprocessing
print(bru_log(), timestamp = TRUE, verbosity = TRUE)
#> 2026-05-29 09:00:41.35138: inlabru loaded (level 1)
#> 2026-05-29 09:00:41.351861: Clear override options (level 1)
#> 2026-05-29 09:00:51.958454: bru: Preprocessing (level 1)
#> 2026-05-29 09:00:51.974694: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:00:51.976128: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:00:51.977547: bru_input.bru_comp(x) (level 4)
#> 2026-05-29 09:00:51.978981: bru_input.bm_pipe(x) (level 5)
#> 2026-05-29 09:00:51.980545: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-29 09:00:51.982039: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-29 09:00:51.983662: bru_input(bru_input) for (x) (level 5)
#> 2026-05-29 09:00:51.991678: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:00:52.00668: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:00:52.009406: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:00:52.012098: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:00:52.014308: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:00:52.03246: iinla: Start (level 3)
#> 2026-05-29 09:00:52.034154: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:52.035453: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:52.037008: Linearise component 'x' (level 4)
#> 2026-05-29 09:00:52.039956: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:52.042736: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:00:52.043959: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:00:52.045408: Simplify component 'x' (level 4)
#> 2026-05-29 09:00:52.048461: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:00:52.05137: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:52.064404: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:00:52.084954: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:00:52.086857: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:00:52.957328: iinla: Computation completed (level 3)
#> 2026-05-29 09:00:52.982005: bru: Preprocessing (level 1)
#> 2026-05-29 09:00:52.990825: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:00:52.992107: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:00:52.993685: bru_input.bru_comp(x) (level 4)
#> 2026-05-29 09:00:52.995462: bru_input.bm_pipe(x) (level 5)
#> 2026-05-29 09:00:52.9975: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-29 09:00:52.999471: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-29 09:00:53.001271: bru_input(bru_input) for (x) (level 5)
#> 2026-05-29 09:00:53.009879: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:00:53.0118: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:00:53.013931: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:00:53.01591: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:00:53.017714: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:00:53.033754: iinla: Start (level 3)
#> 2026-05-29 09:00:53.035915: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:53.037498: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:53.039331: Linearise component 'x' (level 4)
#> 2026-05-29 09:00:53.043028: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:53.046467: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:00:53.048103: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:00:53.049953: Simplify component 'x' (level 4)
#> 2026-05-29 09:00:53.05366: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:00:53.057319: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:53.065569: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:00:53.082663: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:00:53.084635: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:00:53.446081: iinla: Computation completed (level 3)
#> 2026-05-29 09:00:53.474881: bru: Preprocessing (level 1)
#> 2026-05-29 09:00:53.48596: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:00:53.487775: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:00:53.489594: bru_input.bru_comp(z) (level 4)
#> 2026-05-29 09:00:53.49142: bru_input.bm_pipe(z) (level 5)
#> 2026-05-29 09:00:53.493459: bru_input.bm_multi(z:core) (level 5)
#> 2026-05-29 09:00:53.495447: bru_input.bru_mapper(z:core:main) (level 5)
#> 2026-05-29 09:00:53.497233: bru_input(bru_input) for (z) (level 5)
#> 2026-05-29 09:00:53.505734: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:00:53.507621: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:00:53.50964: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:00:53.511608: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:00:53.51338: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:00:53.529654: iinla: Start (level 3)
#> 2026-05-29 09:00:53.531824: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:53.533394: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:53.535246: Linearise component 'z' (level 4)
#> 2026-05-29 09:00:53.539139: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:53.542593: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:00:53.544254: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:00:53.546096: Simplify component 'z' (level 4)
#> 2026-05-29 09:00:53.549819: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:00:53.553444: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:53.557525: Linearise with respect to component 'z' (level 5)
#> 2026-05-29 09:00:53.564623: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-29 09:00:53.568928: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:00:53.586128: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:00:53.588065: iinla: Iteration 1 [max: 10] (level 1)
#> 2026-05-29 09:00:53.929714: iinla: Step rescaling: 61.8%, Contract (norm0 = 1969, norm1 = 1807, norm01 = 347.8) (level 3)
#> 2026-05-29 09:00:53.932741: iinla: Step rescaling: 38.2%, Contract (norm0 = 398.9, norm1 = 295.1, norm01 = 347.8) (level 3)
#> 2026-05-29 09:00:53.936284: iinla: Step rescaling: 27.4%, Approx Optimisation (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 3)
#> 2026-05-29 09:00:53.93781: iinla: |lin1-lin0| = 347.8
#> <eta-lin1,delta>/|delta| = -198.3
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 107.4 (level 4)
#> 2026-05-29 09:00:53.939259: iinla: Step rescaling: 27.4% (norm0 = 184.1, norm1 = 225.5, norm01 = 347.8) (level 2)
#> 2026-05-29 09:00:53.941016: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:53.942283: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:53.943658: Linearise component 'z' (level 4)
#> 2026-05-29 09:00:53.946535: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:53.949293: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:53.952008: Linearise with respect to component 'z' (level 5)
#> 2026-05-29 09:00:53.955598: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-29 09:00:53.969152: iinla: Iteration 2 [max: 10] (level 1)
#> 2026-05-29 09:00:54.65724: iinla: Step rescaling: 162%, Expand (norm0 = 365.1, norm1 = 141.6, norm01 = 225.4) (level 3)
#> 2026-05-29 09:00:54.66022: iinla: Step rescaling: 100%, Overstep (norm0 = 225.3, norm1 = 10.71, norm01 = 225.4) (level 3)
#> 2026-05-29 09:00:54.663823: iinla: Step rescaling: 99.69%, Approx Optimisation (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 3)
#> 2026-05-29 09:00:54.665334: iinla: |lin1-lin0| = 225.4
#> <eta-lin1,delta>/|delta| = -1.008
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 10.63 (level 4)
#> 2026-05-29 09:00:54.666774: iinla: Step rescaling: 99.7% (norm0 = 224.6, norm1 = 10.68, norm01 = 225.4) (level 2)
#> 2026-05-29 09:00:54.668439: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:54.669549: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:54.670835: Linearise component 'z' (level 4)
#> 2026-05-29 09:00:54.673798: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:54.676592: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:54.679207: Linearise with respect to component 'z' (level 5)
#> 2026-05-29 09:00:54.682691: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-29 09:00:54.694346: iinla: Max deviation from previous: 46300% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-29 09:00:54.696753: iinla: Iteration 3 [max: 10] (level 1)
#> 2026-05-29 09:00:55.023747: iinla: Step rescaling: 162%, Expand (norm0 = 16.84, norm1 = 6.151, norm01 = 10.68) (level 3)
#> 2026-05-29 09:00:55.026739: iinla: Step rescaling: 100%, Overstep (norm0 = 10.51, norm1 = 0.1742, norm01 = 10.68) (level 3)
#> 2026-05-29 09:00:55.03015: iinla: Step rescaling: 101.7%, Approx Optimisation (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 3)
#> 2026-05-29 09:00:55.031671: iinla: |lin1-lin0| = 10.68
#> <eta-lin1,delta>/|delta| = -1.163e-05
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 0.01176 (level 4)
#> 2026-05-29 09:00:55.033076: iinla: Step rescaling: 102% (norm0 = 10.68, norm1 = 0.01176, norm01 = 10.68) (level 2)
#> 2026-05-29 09:00:55.034781: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:55.035985: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:55.037422: Linearise component 'z' (level 4)
#> 2026-05-29 09:00:55.040383: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:55.04319: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:55.045858: Linearise with respect to component 'z' (level 5)
#> 2026-05-29 09:00:55.04937: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-29 09:00:55.061196: iinla: Max deviation from previous: 496% of SD, and line search is active
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-29 09:00:55.06374: iinla: Iteration 4 [max: 10] (level 1)
#> 2026-05-29 09:00:55.393747: iinla: Step rescaling: 162%, Expand (norm0 = 0.01903, norm1 = 0.007267, norm01 = 0.01176) (level 3)
#> 2026-05-29 09:00:55.396755: iinla: Step rescaling: 100%, Overstep (norm0 = 0.01176, norm1 = 5.868e-08, norm01 = 0.01176) (level 3)
#> 2026-05-29 09:00:55.40028: iinla: Step rescaling: 100%, Approx Optimisation (norm0 = 0.01176, norm1 = 5.855e-08, norm01 = 0.01176) (level 3)
#> 2026-05-29 09:00:55.401814: iinla: |lin1-lin0| = 0.01176
#> <eta-lin1,delta>/|delta| = 8.228e-11
#> |eta-lin0 - delta <delta,eta-lin0>/<delta,delta>| = 5.855e-08 (level 4)
#> 2026-05-29 09:00:55.40353: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:00:55.404687: Linearise components for each observation model (level 3)
#> 2026-05-29 09:00:55.406056: Linearise component 'z' (level 4)
#> 2026-05-29 09:00:55.408975: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:00:55.411728: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:00:55.414346: Linearise with respect to component 'z' (level 5)
#> 2026-05-29 09:00:55.41792: Linearise with respect to component 'Intercept' (level 5)
#> 2026-05-29 09:00:55.430036: iinla: Max deviation from previous: 8.06% of SD, and line search is inactive
#> [stop if: < 10% and line search inactive] (level 1)
#> 2026-05-29 09:00:55.431278: iinla: Convergence criterion met.
#> Running final INLA integration step with known theta mode. (level 1)
#> 2026-05-29 09:00:55.433759: iinla: Iteration 5 [max: 10] (level 1)
#> 2026-05-29 09:00:55.775583: iinla: Computation completed (level 3)
#> 2026-05-29 09:01:00.602037: bru: Preprocessing (level 1)
#> 2026-05-29 09:01:00.608616: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:01:00.609836: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:01:00.611067: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:01:00.612326: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:01:00.613736: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:01:00.615102: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:01:00.616321: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:01:00.631923: iinla: Start (level 3)
#> 2026-05-29 09:01:00.633508: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:01:00.634605: Linearise components for each observation model (level 3)
#> 2026-05-29 09:01:00.635921: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:01:00.638854: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:01:00.640031: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:01:00.641379: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:01:00.644431: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:01:00.649846: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:01:00.666199: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:01:00.667676: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:01:01.755286: iinla: Computation completed (level 3)
#> 2026-05-29 09:01:05.178257: bru: Preprocessing (level 1)
#> 2026-05-29 09:01:05.18759: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:01:05.188921: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:01:05.197285: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:01:05.198705: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:01:05.200214: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:01:05.201663: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:01:05.202952: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:01:05.210795: bru_input.bru_comp(field) (level 4)
#> 2026-05-29 09:01:05.212188: bru_input.bm_pipe(field) (level 5)
#> 2026-05-29 09:01:05.213682: bru_input.bm_multi(field:core) (level 5)
#> 2026-05-29 09:01:05.215121: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-05-29 09:01:05.216439: bru_input(bru_input) for (field) (level 5)
#> 2026-05-29 09:01:05.234542: iinla: Start (level 3)
#> 2026-05-29 09:01:05.236203: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:01:05.23739: Linearise components for each observation model (level 3)
#> 2026-05-29 09:01:05.238767: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:01:05.241848: Linearise component 'field' (level 4)
#> 2026-05-29 09:01:05.367824: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:01:05.369217: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:01:05.370629: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:01:05.373794: Simplify component 'field' (level 4)
#> 2026-05-29 09:01:05.505748: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:01:05.510861: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:01:05.529047: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:01:05.530502: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:01:52.128071: iinla: Computation completed (level 3)
#> 2026-05-29 09:01:53.377765: bru: Preprocessing (level 1)
#> 2026-05-29 09:01:53.387598: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:01:53.388839: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:01:53.390106: bru_input.bru_comp(field) (level 4)
#> 2026-05-29 09:01:53.391387: bru_input.bm_pipe(field) (level 5)
#> 2026-05-29 09:01:53.392828: bru_input.bm_multi(field:core) (level 5)
#> 2026-05-29 09:01:53.394177: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-05-29 09:01:53.395386: bru_input(bru_input) for (field) (level 5)
#> 2026-05-29 09:01:53.40757: iinla: Start (level 3)
#> 2026-05-29 09:01:53.40906: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:01:53.410152: Linearise components for each observation model (level 3)
#> 2026-05-29 09:01:53.411399: Linearise component 'field' (level 4)
#> 2026-05-29 09:01:53.417675: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:01:53.418843: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:01:53.420112: Simplify component 'field' (level 4)
#> 2026-05-29 09:01:53.426124: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:01:53.429524: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:01:53.440195: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:01:53.441613: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:01:53.866693: iinla: Computation completed (level 3)
#> 2026-05-29 09:01:55.670652: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:02:01.95942: bru: Preprocessing (level 1)
#> 2026-05-29 09:02:01.966242: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:02:01.967549: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:02:01.968862: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:02:01.970217: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:02:01.971716: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:02:01.973123: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:02:01.974416: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:02:01.990217: iinla: Start (level 3)
#> 2026-05-29 09:02:01.991822: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:02:01.992955: Linearise components for each observation model (level 3)
#> 2026-05-29 09:02:01.994233: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:02:01.997243: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:02:01.998446: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:02:01.999767: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:02:02.002795: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:02:02.006627: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:02:02.015785: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:02:02.017184: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:02:03.469348: iinla: Computation completed (level 3)
#> 2026-05-29 09:02:06.391189: bru: Preprocessing (level 1)
#> 2026-05-29 09:02:06.400709: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:02:06.402036: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:02:06.403357: bru_input.bru_comp(Intercept) (level 4)
#> 2026-05-29 09:02:06.404659: bru_input.bm_pipe(Intercept) (level 5)
#> 2026-05-29 09:02:06.406082: bru_input.bm_multi(Intercept:core) (level 5)
#> 2026-05-29 09:02:06.407459: bru_input.bru_mapper(Intercept:core:main) (level 5)
#> 2026-05-29 09:02:06.408709: bru_input(bru_input) for (Intercept) (level 5)
#> 2026-05-29 09:02:06.41603: bru_input.bru_comp(field) (level 4)
#> 2026-05-29 09:02:06.417401: bru_input.bm_pipe(field) (level 5)
#> 2026-05-29 09:02:06.418835: bru_input.bm_multi(field:core) (level 5)
#> 2026-05-29 09:02:06.420187: bru_input.bru_mapper(field:core:main) (level 5)
#> 2026-05-29 09:02:06.421446: bru_input(bru_input) for (field) (level 5)
#> 2026-05-29 09:02:06.437285: iinla: Start (level 3)
#> 2026-05-29 09:02:06.438819: iinla: Evaluate component linearisations (level 3)
#> 2026-05-29 09:02:06.439905: Linearise components for each observation model (level 3)
#> 2026-05-29 09:02:06.441163: Linearise component 'Intercept' (level 4)
#> 2026-05-29 09:02:06.444079: Linearise component 'field' (level 4)
#> 2026-05-29 09:02:06.566203: iinla: Evaluate component simplifications (level 3)
#> 2026-05-29 09:02:06.567568: Simplify component mappers for each observation model (level 3)
#> 2026-05-29 09:02:06.568923: Simplify component 'Intercept' (level 4)
#> 2026-05-29 09:02:06.571918: Simplify component 'field' (level 4)
#> 2026-05-29 09:02:06.70032: iinla: Evaluate predictor linearisation (level 3)
#> 2026-05-29 09:02:06.70527: iinla: Construct inla stack (level 3)
#> 2026-05-29 09:02:06.723208: iinla: Model initialisation completed (level 3)
#> 2026-05-29 09:02:06.725042: iinla: Iteration 1 [max: 1] (level 1)
#> 2026-05-29 09:02:53.000327: iinla: Computation completed (level 3)
#> 2026-05-29 09:02:55.034793: bru: Preprocessing (level 1)
#> 2026-05-29 09:02:55.050571: Evaluate component inputs for each observation model (level 3)
#> 2026-05-29 09:02:55.052297: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:02:55.054039: bru_input.bru_comp(x) (level 4)
#> 2026-05-29 09:02:55.055663: bru_input.bm_pipe(x) (level 5)
#> 2026-05-29 09:02:55.057223: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-29 09:02:55.058678: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-29 09:02:55.059964: bru_input(bru_input) for (x) (level 5)
#> 2026-05-29 09:02:55.067743: bru_input(bru_comp_list) (level 4)
#> 2026-05-29 09:02:55.069159: bru_input.bru_comp(x) (level 4)
#> 2026-05-29 09:02:55.070508: bru_input.bm_pipe(x) (level 5)
#> 2026-05-29 09:02:55.071965: bru_input.bm_multi(x:core) (level 5)
#> 2026-05-29 09:02:55.073418: bru_input.bru_mapper(x:core:main) (level 5)
#> 2026-05-29 09:02:55.074735: bru_input(bru_input) for (x) (level 5)
#> 2026-05-29 09:02:58.067441: bru_input(bru_input) for (LABEL) (level 5)
#> 2026-05-29 09:02:59.821329: bru_input_text(bru_input) for (LABEL) (level 5)
#> 2026-05-29 09:02:59.833545: bru_input.bru_comp(x) (level 4)
#> 2026-05-29 09:02:59.834716: bru_input_text.bm_pipe(x) (level 5)
#> 2026-05-29 09:02:59.835948: bru_input_text.bm_multi(x:core) (level 5)
#> 2026-05-29 09:02:59.837167: bru_input_text.bru_mapper(x:core:main) (level 5)
#> 2026-05-29 09:02:59.838187: bru_input_text(bru_input) for (x) (level 5)