| bru_mapper | R Documentation |
bru_mapper objectsConstructors for bru_mapper objects
bru_mapper(...)
bru_mapper_define(mapper, new_class = NULL, remove_class = "list", ...)
... |
Arguments passed on to sub-methods, or used for special purposes, see details for each function below. |
mapper |
For |
new_class |
If non- |
remove_class |
If non- |
A bru_mapper object.
bru_mapper(): Generic mapper S3 constructor, used for constructing mappers for special
objects. See below for details of the default constructor
bru_mapper_define() that can be used to define new mapper clesses in user
code. To extracting mappers for latent component models, see
bru_get_mapper().
bru_mapper_define(): Adds the new_class and "bru_mapper" class names to
the inheritance list for the input mapper object, unless the object
already inherits from these.
To register mapper classes and methods in scripts, use .S3method()
to register the methods, e.g.
.S3method("ibm_jacobian", "my_mapper_class", ibm_jacobian.my_mapper_class).
In packages with Suggests: inlabru, add method information for delayed
registration, e.g.:
#' @rawNamespace S3method(inlabru::bru_get_mapper, inla_rspde) #' @rawNamespace S3method(inlabru::ibm_n, bru_mapper_inla_rspde) #' @rawNamespace S3method(inlabru::ibm_values, bru_mapper_inla_rspde) #' @rawNamespace S3method(inlabru::ibm_jacobian, bru_mapper_inla_rspde)
or before each method, use @exportS3Method:
#' @exportS3Method inlabru::bru_get_mapper
etc., which semi-automates it.
bru_mapper_generics for generic methods, the individual mapper pages for special method implementations, and bru_get_mapper for hooks to extract mappers from latent model object class objects.
Other mappers:
bm_aggregate(),
bm_collect(),
bm_const(),
bm_expr(),
bm_factor(),
bm_fm_mesh_1d,
bm_fmesher(),
bm_harmonics(),
bm_index(),
bm_linear(),
bm_logitaverage(),
bm_logsumexp(),
bm_marginal(),
bm_matrix(),
bm_multi(),
bm_pipe(),
bm_reparam(),
bm_repeat(),
bm_scale(),
bm_shift(),
bm_sum(),
bm_taylor(),
bru_get_mapper()
mapper <- bm_index(5)
ibm_jacobian(mapper, input = c(1, 3, 4, 5, 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.