Methods for the ibm_as_taylor() and ibm_simplify() methods for
bru model objects and related classes.
Usage
# S3 method for class 'bru_model'
ibm_as_taylor(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
# S3 method for class 'bru_comp_list'
ibm_as_taylor(mapper, input, state = NULL, ...)
# S3 method for class 'bru_model'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
# S3 method for class 'bru_comp'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
# S3 method for class 'bru_comp_list'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
# S3 method for class 'bm_list'
ibm_as_taylor(mapper, input, state = NULL, ...)
# S3 method for class 'bm_list'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
# S3 method for class 'bm_list'
ibm_eval2(mapper, input, state = NULL, ...)
# S3 method for class 'bm_list'
ibm_eval(mapper, input, state = NULL, ...)
# S3 method for class 'bm_list'
ibm_jacobian(mapper, input, state = NULL, ...)
# S3 method for class 'bru_model'
ibm_eval2(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
# S3 method for class 'bru_comp_list'
ibm_eval(mapper, input, state = NULL, ..., comp_mappers = NULL)
# S3 method for class 'bru_comp'
ibm_eval(mapper, input, state = NULL, ...)
# S3 method for class 'bru_model'
ibm_eval(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
# S3 method for class 'bru_model'
ibm_jacobian(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)Arguments
- mapper
A mapper S3 object, inheriting from
bru_mapper.- input
Data input for the mapper.
- state
A vector of latent state values for the mapping, of length
ibm_n(mapper, inla_f = FALSE)- ...
Arguments passed on to other methods
- options
A bru_options options object or a list of options passed on to
bru_options()- comp_mappers
A
bm_list()of mappers, either the original component mappers, or simplified mappers.- eval_fun
A list of functions, typically from
bru_eval_fun().
Functions
ibm_as_taylor(bru_model): Returns a list (one element per observation model) of bm_list objects, each with one bm_taylor entry for each included component. (autodiff == "pandemic")If
autodiffis not "pandemic", returns a list of bm_taylor objects, one for each observation model, with the offset and jacobians evaluated for the predictor of the observation model, and the component mappers passed on ascomp_mappersfor the evaluation of the jacobians.ibm_simplify(bru_model): Returns a list (one element per observation model) of bm_list objects, each with one bru_mapper entry for each included component.