| bru_model_mapper_methods | R Documentation |
Methods for the ibm_as_taylor() and ibm_simplify() methods for
bru model objects and related classes.
## S3 method for class 'bru_model'
ibm_as_taylor(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
## S3 method for class 'bru_comp_list'
ibm_as_taylor(mapper, input, state = NULL, ...)
## S3 method for class 'bru_model'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
## S3 method for class 'bru_comp'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
## S3 method for class 'bru_comp_list'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
## S3 method for class 'bm_list'
ibm_as_taylor(mapper, input, state = NULL, ...)
## S3 method for class 'bm_list'
ibm_simplify(mapper, input = NULL, state = NULL, ...)
## S3 method for class 'bm_list'
ibm_eval2(mapper, input, state = NULL, ...)
## S3 method for class 'bm_list'
ibm_eval(mapper, input, state = NULL, ...)
## S3 method for class 'bm_list'
ibm_jacobian(mapper, input, state = NULL, ...)
## S3 method for class 'bru_model'
ibm_eval2(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
## S3 method for class 'bru_comp_list'
ibm_eval(mapper, input, state = NULL, ..., comp_mappers = NULL)
## S3 method for class 'bru_comp'
ibm_eval(mapper, input, state = NULL, ...)
## S3 method for class 'bru_model'
ibm_eval(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
## S3 method for class 'bru_model'
ibm_jacobian(
mapper,
input,
state = NULL,
...,
options = NULL,
comp_mappers = NULL,
eval_fun = NULL
)
mapper |
A mapper S3 object, inheriting from |
input |
Data input for the mapper. |
state |
A vector of latent state values for the mapping,
of length |
... |
Arguments passed on to other methods |
options |
A bru_options options object or a list of options passed
on to |
comp_mappers |
A |
eval_fun |
A list of functions, typically from
|
ibm_as_taylor(bru_model): Returns a list (one element per
observation model) of bm_list objects, each with one bm_taylor
entry for each included component. (autodiff == "pandemic")
If autodiff is not "pandemic", returns a list of bm_taylor objects, one
for each observation model, with the offset and jacobians evaluated for the
predictor of the observation model, and the component mappers passed on as
comp_mappers for the evaluation of the jacobians.
ibm_simplify(bru_model): Returns a list (one element per
observation model) of bm_list objects, each with one bru_mapper
entry for each included component.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.