| bru_obs_gcpo | R Documentation |
Extract and combine INLA::control.gcpo options from bru_obs and
bru_obs_list objects, adjusting observation indices for multi-likelihood
models where the response vector is the concatenation of all likelihoods.
bru_obs_control_gcpo(x, ...)
## S3 method for class 'bru_obs'
bru_obs_control_gcpo(
x,
index_offset,
index_length = bru_response_size(x),
force_weights,
...
)
## S3 method for class 'bru_obs_list'
bru_obs_control_gcpo(x, control.gcpo = NULL, ...)
x |
A |
... |
Further arguments passed to submethods. |
index_offset |
integer; offset to add to indices in |
index_length |
integer; number of response rows for this likelihood.
Defaults to |
force_weights |
logical; if |
control.gcpo |
list of |
bru_obs_control_gcpo() returns a list with INLA::control.gcpo
options, with predictor/response variable indices unified for
multi-observation models. If a bru_obs model has a control.gcpo = NULL
argument, an empty list is returned for that model.
bru_obs(), bru_block_gcpo()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.