Utility functions for bru observation model objects
Usage
bru_obs_inla_family(x, ...)
# S3 method for class 'bru_obs'
bru_obs_inla_family(x, ...)
# S3 method for class 'bru_obs_list'
bru_obs_inla_family(x, ...)
# S3 method for class 'bru'
bru_obs_inla_family(x, ...)
bru_obs_family(x, ...)
# S3 method for class 'bru_obs'
bru_obs_family(x, ...)
# S3 method for class 'bru_obs_list'
bru_obs_family(x, ...)
# S3 method for class 'bru'
bru_obs_family(x, ...)
bru_obs_control_family(x, control.family = NULL, ...)
# S3 method for class 'bru_obs'
bru_obs_control_family(x, control.family = NULL, ...)
# S3 method for class 'bru_obs_list'
bru_obs_control_family(x, control.family = NULL, ...)Value
bru_obs_inla_family()returns a string or vector of strings of thefamilyname(s) used in theINLA::inla()call for the observation model(s) inx.
bru_obs_family()returns a string or vector of strings of thefamilyname(s) used to define eachbru_obs(). This may be different the internal technical name(s) used in theINLA::inla()call.
bru_obs_control_family()returns a list withINLA::control.familyoptions, or a list of such lists, with one element per observation model