View source: R/hexagon_tiling.R
| cv_partition | R Documentation |
Both the interface and function name
may change in future versions.
Partitions the region based on the given criteria for calculating residuals in each partition. Parts of this function are taken from concepts in https://rpubs.com/huanfaChen/grid_from_polygon
cv_partition(
samplers,
resolution = NULL,
nrows = NULL,
ncols = NULL,
chess = TRUE,
...
)
samplers |
A sf object containing region for which partitions to be created |
resolution |
resolution of the grids that are required |
nrows |
number of rows of grids that are required |
ncols |
number of columns of grids that are required |
chess |
chessboard partitioning |
... |
Unused. |
a partitioned sf object as required or a list of partitioned sf objects if chess is TRUE
Man Ho Suen
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.