| ibm_inla_subset | R Documentation |
Implementations must return a logical vector of TRUE/FALSE for the subset
such that, given the full A matrix and values output, A[, subset, drop = FALSE] and values[subset] (or values[subset, , drop = FALSE] for
data.frame values) are equal to the inla_f = TRUE version of A and values.
The default method uses the ibm_values output to construct the subset
indexing.
ibm_inla_subset(mapper, ...)
## Default S3 method:
ibm_inla_subset(mapper, ...)
mapper |
A mapper S3 object, inheriting from |
... |
Arguments passed on to other methods |
A logical vector of TRUE/FALSE for the subset such that, given the
full A matrix and values output, A[, subset, drop = FALSE] and
values[subset] (or values[subset, , drop = FALSE] for data.frame
values) are equal to the inla_f = TRUE version of A and values.
ibm_inla_subset(default): Uses the [ibm_values()] output to construct the inla subset indexing as the difference between inla_f=FALSEandinla_f=TRUE. Extra arguments such as multiare passed on to [ibm_values()]. This means it supports both regular vector values andmulti=1' data.frame values.
Other mapper methods:
bru_mapper_generics,
ibm_as_taylor(),
ibm_eval(),
ibm_eval2(),
ibm_invalid_output(),
ibm_is_linear(),
ibm_is_rowwise(),
ibm_jacobian(),
ibm_n(),
ibm_n_output(),
ibm_names(),
ibm_simplify(),
ibm_values()
m <- bm_collect(list(A = bm_linear(), B = bm_linear()), hidden = TRUE)
ibm_inla_subset(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.