| ibm_is_rowwise | R Documentation |
Implementations must return TRUE or FALSE.
If TRUE (returned by the default method unless the mapper
contains an is_rowwise variable), users of the mapper
may assume the mapper uses its inputs in "rowwise" manner, so that
blockwise evaluation is always possible.
ibm_is_rowwise(mapper, ...)
## Default S3 method:
ibm_is_rowwise(mapper, ...)
mapper |
A mapper S3 object, inheriting from |
... |
Arguments passed on to other methods |
logical; TRUE if the mapper is rowwise, FALSE otherwise.
ibm_is_rowwise(default): Returns logical
is_rowwise from the mapper object if it exists, and otherwise TRUE.
Other mapper methods:
bru_mapper_generics,
ibm_as_taylor(),
ibm_eval(),
ibm_eval2(),
ibm_inla_subset(),
ibm_invalid_output(),
ibm_is_linear(),
ibm_jacobian(),
ibm_n(),
ibm_n_output(),
ibm_names(),
ibm_simplify(),
ibm_values()
m <- bm_linear()
ibm_is_rowwise(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.