| ibm_values | R Documentation |
When inla_f=TRUE, implementations must return a vector that
would be interpretable by an INLA::f(..., values = ...) specification.
The exception is the method for bm_multi, that returns a
multi-column data frame if multi=TRUE.
ibm_values(mapper, inla_f = FALSE, ...)
## Default S3 method:
ibm_values(mapper, inla_f = FALSE, ...)
## S3 method for class 'bm_fmesher'
ibm_values(mapper, ...)
## S3 method for class 'bm_fm_mesh_1d'
ibm_values(mapper, ...)
## S3 method for class 'bm_taylor'
ibm_values(mapper, inla_f = FALSE, multi = FALSE, ...)
## S3 method for class 'bm_linear'
ibm_values(mapper, ...)
## S3 method for class 'bm_matrix'
ibm_values(mapper, ...)
## S3 method for class 'bm_factor'
ibm_values(mapper, ...)
## S3 method for class 'bm_const'
ibm_values(mapper, ...)
## S3 method for class 'bm_shift'
ibm_values(mapper, ..., state = NULL, n_state = NULL)
## S3 method for class 'bm_scale'
ibm_values(mapper, ..., state = NULL, n_state = NULL)
## S3 method for class 'bm_aggregate'
ibm_values(mapper, ..., state = NULL, n_state = NULL)
## S3 method for class 'bm_marginal'
ibm_values(mapper, ..., state = NULL, n_state = NULL)
## S3 method for class 'bm_pipe'
ibm_values(mapper, ...)
## S3 method for class 'bm_multi'
ibm_values(mapper, inla_f = FALSE, multi = FALSE, ...)
## S3 method for class 'bm_reparam'
ibm_values(mapper, ...)
## S3 method for class 'bm_collect'
ibm_values(mapper, inla_f = FALSE, multi = FALSE, ...)
## S3 method for class 'bm_expr'
ibm_values(mapper, inla_f = FALSE, ...)
## S3 method for class 'bm_repeat'
ibm_values(mapper, ...)
## S3 method for class 'bm_sum'
ibm_values(mapper, inla_f = FALSE, multi = FALSE, ...)
mapper |
A mapper S3 object, inheriting from |
inla_f |
logical; when |
... |
Arguments passed on to other methods |
multi |
logical;
If |
state |
A vector of latent state values for the mapping,
of length |
n_state |
integer giving the length of the state vector for mappers that have state dependent output size. |
A vector of length ibm_n(mapper, inla_f = FALSE)
ibm_values(default): Returns a non-null element
'values' from the mapper object, and seq_len(ibm_n(mapper)) if
it doesn't exist.
ibm_values(bm_fmesher): Returns an index vector for the mesh basis functions.
ibm_values(bm_fm_mesh_1d): Returns an index vector into the basis functions for
an indexed mapper. Otherwise, the mid values if present in the mesh being
mapped, and otherwise returns the loc values of the mesh.
ibm_values(bm_linear): Returns 1.0
ibm_values(bm_matrix): For integer labels, the vector of labels.
For character labels, the labels as a factor variable.
ibm_values(bm_factor): Returns the factor levels (minus the first level for
factor_mapping "contrast"), or an integer vector (if indexed = TRUE in
bm_factor()).
Other mapper methods:
bru_mapper_generics,
ibm_as_taylor(),
ibm_eval(),
ibm_eval2(),
ibm_inla_subset(),
ibm_invalid_output(),
ibm_is_linear(),
ibm_is_rowwise(),
ibm_jacobian(),
ibm_n(),
ibm_n_output(),
ibm_names(),
ibm_simplify()
m <- bm_index(4)
ibm_values(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.