| inlabru_group_cv_block_conversion | R Documentation |
Converts a vector of block indices into a list of node index vectors.
inlabru_group_cv_block_conversion(block, max_block, per_node)
block |
An integer vector of 1-based block indices, one for each node. |
max_block |
Precomputed maximal value of |
per_node |
Logical; if |
If per_node is false, a list of integer vectors, where each
vector contains the 1-based node indices of nodes belonging to the
corresponding block. If per_node is true, a list of integer vectors,
where each vector contains the 1-based node indices of nodes belonging to
the same block as the corresponding node; b[i] <- a[block[j]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.