Skip to contents

Create a bru_log object, by default empty.

Usage

new_bru_log(x = NULL, bookmarks = NULL)

Arguments

x

An optional character vector of log messages, or data.frame with columns message, timestamp, and verbosity, or a bru_log object.

bookmarks

An optional integer vector of named bookmarks message in x.

Value

A new bru_log object.

Examples

x <- new_bru_log()
x <- bru_log_message("Test message", x = x)
print(x)
#> 2026-07-28 16:34:29.462175: Test message