| new_bru_used | R Documentation |
Create a bru_used object from effect name character
vectors.
Create information about which components are used by a model, or
its individual observation models. If a non-NULL labels argument is
supplied, also calls bru_used_update() on the bru_used object.
new_bru_used(
x = NULL,
...,
effect = NULL,
effect_exclude = NULL,
latent = NULL,
labels = NULL
)
## S3 method for class ''NULL''
new_bru_used(
x = NULL,
...,
effect = NULL,
effect_exclude = NULL,
latent = NULL,
labels = NULL
)
## Default S3 method:
new_bru_used(
x,
...,
effect = NULL,
effect_exclude = NULL,
latent = NULL,
labels = NULL
)
## S3 method for class 'character'
new_bru_used(
x,
...,
effect = NULL,
effect_exclude = NULL,
latent = NULL,
labels = NULL
)
x |
|
... |
Parameters passed on to the other methods |
effect |
character; components used as effects. When |
effect_exclude |
character; components to specifically exclude from
effect evaluation. When |
latent |
character; components used as |
labels |
character; component labels passed on to
|
The arguments effect, effect_exclude, and latent control what
components and effects are available for use in predictor expressions.
effectCharacter vector of component labels that are used as effects
by the predictor expression; If NULL (default), the names
are extracted from the formula.
excludeCharacter vector of component labels to be excluded from the effect list
even if they have been auto-detected as being necessary.
Default is NULL; do not remove any components from the inclusion list.
include_latentCharacter vector.
Specifies which latent state variables need to be directly available to the
predictor expression, with a _latent suffix. This also makes evaluator
functions with suffix _eval available, taking parameters main, group,
and replicate, taking values for where to evaluate the component effect
that are different than those defined in the component definition itself
(see bru_comp_eval()). If NULL, the use of _latent and _eval
in the predictor expression is detected automatically.
A bru_used object (a list with elements effect
and latent)
new_bru_used(`NULL`): Create a bru_used object from effect name
character vectors.
new_bru_used(default): Create a bru_used object from an expression
object supported by bru_used_vars().
new_bru_used(character): Create a bru_used object from a string.
Other bru_used:
bru_used(),
bru_used_update(),
bru_used_vars()
(used <- new_bru_used(~.))
bru_used(used, labels = c("a", "c"))
(used <- new_bru_used(~ a + b + c_latent + d_latent))
bru_used(used, labels = c("a", "c"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.