Skip to contents

This function extracts the fixed effect coefficients or hyperparameters from a fitted bru object and returns them in a tidy tibble format. See generics::tidy() for more details on the tidy data format.

Usage

# S3 method for class 'bru'
tidy(x, effects = "fixed", ...)

Arguments

x

A fitted bru object.

effects

"fixed" (default) or "hyperpar".

...

Unused.

Value

A tibble with one row per term.